.x-panel-body-icecap {
	background-color: #eeeeee !important;
	-webkit-touch-callout: none;
	-webkit-user-select: none;
	-khtml-user-select: none;
	-moz-user-select: none;
	-ms-user-select: none;
	user-select: none;
}

.x-base-color {
	font-weight: bold !important;
}

.icecap-icon-excel {
	background-image: url(/system/images/icons/excel.gif);
}
.icecap-icon-krak {
	background-image: url(/system/images/icons/earth2.png);
}
.icecap-icon-send {
	background-image: url(/system/images/icons/edit.png);
}
.icecap-icon-create {
	background-image: url(/system/images/icons/add2.png);
}
.icecap-icon-change {
	background-image: url(/system/images/icons/edit.png);
}
.icecap-icon-copy {
	background-image: url(/system/images/icons/copy.png);
}
.icecap-icon-hold {
	background-image: url(/system/images/icons/edit.png);
}
.icecap-icon-delete {
	background-image: url(/system/images/icons/delete2.png);
}
.icecap-icon-display {
	background-image: url(/system/images/icons/view.png);
}
.icecap-icon-release {
	background-image: url(/system/images/icons/edit.png);
}
.icecap-icon-messages {
	background-image: url(/system/images/icons/edit.png);
}
.icecap-icon-attributes {
	background-image: url(/system/images/icons/edit.png);
}
.icecap-icon-work-with-printing-status {
	background-image: url(/system/images/icons/edit.png);
}

.icecap-icon-inputfield {
	background-image: url(/menu/images/input_field.png);
}
.icecap-icon-outputfield {
	background-image: url(/menu/images/output_field.png);
}
.icecap-icon-label {
	background-image: url(/menu/images/label.png);
}
.icecap-icon-grid {
	background-image: url(/system/images/icons/16x16/table_sql.png);
}
.icecap-icon-column {
	background-image: url(/system/images/icons/16x16/window_split_hor.png);
}
.icecap-icon-panel {
	background-image: url(/system/images/icons/16x16/window.png);
}
.icecap-icon-commandline {
}
.icecap-icon-ignorearea {
	background-image: url(/system/images/icons/16x16/window_delete.png);
}

.icecap-icon-page-next {
	background-image: url(/system/images/icons/16x16/arrow_right_blue.png);
}

.icecap-icon-page-prev {
	background-image: url(/system/images/icons/16x16/arrow_left_blue.png);
}

.icecap-form-link-trigger {
	background-image: url(/system/images/icons/earth-trigger.png);
	background-position: 0 center !important;
}

/* line 31, ../sass/Slate.scss */
.icecap-field {
	color: #000;
}

/* line 36, ../sass/Slate.scss */
.icecap-field .x-form-display-field-default {
	background: transparent;
	color: #000;
}

/* line 44, ../sass/Slate.scss */
.iceCap-input-password .x-form-trigger-wrap-default {
	background-color: transparent !important;
	border: none !important;
}
/* line 49, ../sass/Slate.scss */
.iceCap-input-password input {
	caret-color: #000 !important;
	color: transparent !important;
	background-color: transparent !important;
	border: none !important;
	-webkit-text-security: disc;
}
/* line 53, ../sass/Slate.scss */
.iceCap-input-password input::selection {
	color: transparent !important;
}

/* line 59, ../sass/Slate.scss */
.iceCap-row {
	background-color: transparent;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-20 {
	color: #000 !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-20 input {
	color: #000 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-20-protected input {
	background: #eff3f5 !important;
	color: #000 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-21 {
	background: #000 !important;
	color: white !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-21 input {
	background: #000 !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-21-protected input {
	background: #000 !important;
	color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-22 {
	color: #000 !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-22 input {
	color: #000 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-22-protected input {
	background: #eff3f5 !important;
	color: #000 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-23 {
	background: #000 !important;
	color: white !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-23 input {
	background: #000 !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-23-protected input {
	background: #000 !important;
	color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-24 {
	color: #000 !important;
	text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-24 input {
	color: #000 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-24-protected input {
	background: #eff3f5 !important;
	color: #000 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-25 {
	background: #000 !important;
	color: white !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-25 input {
	background: #000 !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-25-protected input {
	background: #000 !important;
	color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-26 {
	color: #000 !important;
	text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-26 input {
	color: #000 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-26-protected input {
	background: #eff3f5 !important;
	color: #000 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-27 {
	color: #e5e9eb !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-27 input {
	color: #000 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-27-protected input {
	background: #eff3f5 !important;
	color: #000 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-28 {
	color: #c22f2f !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-28 input {
	color: #c22f2f !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-28-protected input {
	background: #eff3f5 !important;
	color: #c22f2f !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-29 {
	background: #c22f2f !important;
	color: white !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-29 input {
	background: #c22f2f !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-29-protected input {
	background: #c22f2f !important;
	color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2A {
	color: #c22f2f !important;
	text-decoration: blink;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2A input {
	color: #c22f2f !important;
	text-decoration: blink;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2A-protected input {
	background: #eff3f5 !important;
	color: #c22f2f !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2B {
	background: #c22f2f !important;
	color: white !important;
	text-decoration: blink;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2B input {
	background: #c22f2f !important;
	color: white !important;
	text-decoration: blink;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2B-protected input {
	background: #c22f2f !important;
	color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2C {
	color: #c22f2f !important;
	text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2C input {
	color: #c22f2f !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2C-protected input {
	background: #eff3f5 !important;
	color: #c22f2f !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2D {
	background: #c22f2f !important;
	color: white !important;
	text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2D input {
	background: #c22f2f !important;
	color: white !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2D-protected input {
	background: #c22f2f !important;
	color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2E {
	color: #c22f2f !important;
	text-decoration: blink;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2E input {
	color: #c22f2f !important;
	text-decoration: blink;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2E-protected input {
	background: #eff3f5 !important;
	color: #c22f2f !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2F {
	color: #e5e9eb !important;
	text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2F input {
	color: #c22f2f !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2F-protected input {
	background: #eff3f5 !important;
	color: #c22f2f !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-30 {
	color: #2faec2 !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-30 input {
	color: #2faec2 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-30-protected input {
	background: #eff3f5 !important;
	color: #2faec2 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-31 {
	background: #2faec2 !important;
	color: white !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-31 input {
	background: #2faec2 !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-31-protected input {
	background: #2faec2 !important;
	color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-32 {
	color: #c2982f !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-32 input {
	color: #c2982f !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-32-protected input {
	background: #eff3f5 !important;
	color: #c2982f !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-33 {
	background: #c2982f !important;
	color: white !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-33 input {
	background: #c2982f !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-33-protected input {
	background: #c2982f !important;
	color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-34 {
	color: #2faec2 !important;
	text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-34 input {
	color: #2faec2 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-34-protected input {
	background: #eff3f5 !important;
	color: #2faec2 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-35 {
	background: #2faec2 !important;
	color: white !important;
	text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-35 input {
	background: #2faec2 !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-35-protected input {
	background: #2faec2 !important;
	color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-36 {
	color: #c2982f !important;
	text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-36 input {
	color: #c2982f !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-36-protected input {
	background: #eff3f5 !important;
	color: #c2982f !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-37 {
	color: #e5e9eb !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-37 input {
	color: #2faec2 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-37-protected input {
	background: #eff3f5 !important;
	color: #2faec2 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-38 {
	color: #c22fbb !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-38 input {
	color: #c22fbb !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-38-protected input {
	background: #eff3f5 !important;
	color: #c22fbb !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-39 {
	background: #c22fbb !important;
	color: white !important;
	text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-39 input {
	background: #c22fbb !important;
	color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-39-protected input {
	background: #c22fbb !important;
	color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3A {
	color: #0f42a9 !important;
	text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3A input {
	color: #0f42a9 !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3A-protected input {
	background: #eff3f5 !important;
	color: #0f42a9 !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3B {
	background: #0f42a9 !important;
	color: white !important;
	text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3B input {
	background: #0f42a9 !important;
	color: white !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3B-protected input {
	background: #0f42a9 !important;
	color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3C {
	color: #c22fbb !important;
	text-decoration: underline;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3C input {
	background: #000 !important;
	color: white !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3C-protected input {
	background: #eff3f5 !important;
	color: #c22fbb !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3D {
	background: #c22fbb !important;
	color: white !important;
	text-decoration: underline;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3D input {
	background: #c22fbb !important;
	color: white !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3D-protected input {
	background: #c22fbb !important;
	color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3E {
	color: #0f42a9 !important;
	text-decoration: underline;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3E input {
	color: #0f42a9 !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3E-protected input {
	background: #eff3f5 !important;
	color: #0f42a9 !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3F {
	color: #0f42a9 !important;
	text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3F input {
	color: #0f42a9 !important;
	text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3F-protected input {
	background: #eff3f5 !important;
	color: #0f42a9 !important;
}

.x-form-text-icecap-textarea-field.x-form-textarea {
	overflow: hidden;
    line-height: 20px !important;
    min-height: 24px !important;
}

.icecap-field input:read-only {
	background-color: transparent !important;
	color: black;
	outline: none;
	border: 0px;
}

.icecap-field input:read-only:focus {
	background-color: black !important;
	color: white !important;
}

.icecap-field input:read-only::selection {
	background: transparent !important;
}

.x-fieldset {
	border-top: none !important;
}

.x-unselectable-field input {
	border: transparent;
	background: transparent !important;
	-webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
}


