.x-panel-body-icecap-Slate {
	background-color: #eeeeee !important;
}

/* line 13, ../sass/Slate.scss */
.iceCap-cursor-Slate {
  border: 1px solid red !important;
}

/* line 18, ../sass/Slate.scss */
.icecap-marker-vertical-Slate {
  margin: 0px;
  position: absolute;
  border-left: 1px solid red;
}
/* line 23, ../sass/Slate.scss */
.icecap-marker-horizontal-Slate {
  margin: 0px;
  position: absolute;
  border-top: 1px solid red;
}

/* line 31, ../sass/Slate.scss */
.icecap-field-Slate {
  color: #4c647e;
}

/* line 36, ../sass/Slate.scss */
.icecap-field-Slate .x-form-display-field-default {
  background: transparent;
  color: #4c647e;
}

/* line 44, ../sass/Slate.scss */
.iceCap-input-password-Slate .x-form-trigger-wrap-default {
  background-color: transparent !important;
  border: none !important;
}
/* line 49, ../sass/Slate.scss */
.iceCap-input-password-Slate input {
  caret-color: #4c647e !important;
  color: transparent !important;
  background-color: transparent !important;
}
/* line 53, ../sass/Slate.scss */
.iceCap-input-password-Slate input::selection {
  color: transparent !important;
}

/* line 59, ../sass/Slate.scss */
.iceCap-row-Slate {
  background-color: transparent;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-20-Slate {
  color: #4c647e !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-20-Slate input {
  color: #33363a !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-20-Slate-protected input {
  background: #eff3f5 !important;
  color: #33363a !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-21-Slate {
  background: #4c647e !important;
  color: white !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-21-Slate input {
  background: #33363a !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-21-Slate-protected input {
  background: #33363a !important;
  color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-22-Slate {
  color: #33363a !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-22-Slate input {
  color: #4c647e !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-22-Slate-protected input {
  background: #eff3f5 !important;
  color: #4c647e !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-23-Slate {
  background: #33363a !important;
  color: white !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-23-Slate input {
  background: #4c647e !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-23-Slate-protected input {
  background: #4c647e !important;
  color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-24-Slate {
  color: #4c647e !important;
  text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-24-Slate input {
  color: #33363a !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-24-Slate-protected input {
  background: #eff3f5 !important;
  color: #33363a !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-25-Slate {
  background: #4c647e !important;
  color: white !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-25-Slate input {
  background: #33363a !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-25-Slate-protected input {
  background: #33363a !important;
  color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-26-Slate {
  color: #33363a !important;
  text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-26-Slate input {
  color: #4c647e !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-26-Slate-protected input {
  background: #eff3f5 !important;
  color: #4c647e !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-27-Slate {
  color: #e5e9eb !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-27-Slate input {
  color: #33363a !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-27-Slate-protected input {
  background: #eff3f5 !important;
  color: #33363a !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-28-Slate {
  color: #dc2222 !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-28-Slate input {
  color: #dc2222 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-28-Slate-protected input {
  background: #eff3f5 !important;
  color: #dc2222 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-29-Slate {
  background: #dc2222 !important;
  color: white !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-29-Slate input {
  background: #dc2222 !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-29-Slate-protected input {
  background: #dc2222 !important;
  color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2A-Slate {
  color: #dc2222 !important;
  text-decoration: blink;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2A-Slate input {
  color: #dc2222 !important;
  text-decoration: blink;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2A-Slate-protected input {
  background: #eff3f5 !important;
  color: #dc2222 !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2B-Slate {
  background: #dc2222 !important;
  color: white !important;
  text-decoration: blink;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2B-Slate input {
  background: #dc2222 !important;
  color: white !important;
  text-decoration: blink;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2B-Slate-protected input {
  background: #dc2222 !important;
  color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2C-Slate {
  color: #dc2222 !important;
  text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2C-Slate input {
  color: #dc2222 !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2C-Slate-protected input {
  background: #eff3f5 !important;
  color: #dc2222 !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2D-Slate {
  background: #dc2222 !important;
  color: white !important;
  text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2D-Slate input {
  background: #dc2222 !important;
  color: white !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2D-Slate-protected input {
  background: #dc2222 !important;
  color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2E-Slate {
  color: #dc2222 !important;
  text-decoration: blink;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2E-Slate input {
  color: #dc2222 !important;
  text-decoration: blink;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2E-Slate-protected input {
  background: #eff3f5 !important;
  color: #dc2222 !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-2F-Slate {
  color: #e5e9eb !important;
  text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-2F-Slate input {
  color: #dc2222 !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-2F-Slate-protected input {
  background: #eff3f5 !important;
  color: #dc2222 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-30-Slate {
  color: #1996a7 !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-30-Slate input {
  color: #1996a7 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-30-Slate-protected input {
  background: #eff3f5 !important;
  color: #1996a7 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-31-Slate {
  background: #1996a7 !important;
  color: white !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-31-Slate input {
  background: #1996a7 !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-31-Slate-protected input {
  background: #1996a7 !important;
  color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-32-Slate {
  color: #bc7a00 !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-32-Slate input {
  color: #bc7a00 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-32-Slate-protected input {
  background: #eff3f5 !important;
  color: #bc7a00 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-33-Slate {
  background: #bc7a00 !important;
  color: white !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-33-Slate input {
  background: #bc7a00 !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-33-Slate-protected input {
  background: #bc7a00 !important;
  color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-34-Slate {
  color: #1996a7 !important;
  text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-34-Slate input {
  color: #1996a7 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-34-Slate-protected input {
  background: #eff3f5 !important;
  color: #1996a7 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-35-Slate {
  background: #1996a7 !important;
  color: white !important;
  text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-35-Slate input {
  background: #1996a7 !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-35-Slate-protected input {
  background: #1996a7 !important;
  color: white !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-36-Slate {
  color: #bc7a00 !important;
  text-decoration: underline;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-36-Slate input {
  color: #bc7a00 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-36-Slate-protected input {
  background: #eff3f5 !important;
  color: #bc7a00 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-37-Slate {
  color: #e5e9eb !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-37-Slate input {
  color: #1996a7 !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-37-Slate-protected input {
  background: #eff3f5 !important;
  color: #1996a7 !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-38-Slate {
  color: #e941ff !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-38-Slate input {
  color: #e941ff !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-38-Slate-protected input {
  background: #eff3f5 !important;
  color: #e941ff !important;
}

/* line 322, ../sass/Slate.scss */
.iceCap-output-39-Slate {
  background: #e941ff !important;
  color: white !important;
  text-decoration: none;
}

/* line 329, ../sass/Slate.scss */
.iceCap-input-39-Slate input {
  background: #e941ff !important;
  color: white !important;
}
/* line 333, ../sass/Slate.scss */
.iceCap-input-39-Slate-protected input {
  background: #e941ff !important;
  color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3A-Slate {
  color: #94a2be !important;
  text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3A-Slate input {
  color: #94a2be !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3A-Slate-protected input {
  background: #eff3f5 !important;
  color: #94a2be !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3B-Slate {
  background: #94a2be !important;
  color: white !important;
  text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3B-Slate input {
  background: #94a2be !important;
  color: white !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3B-Slate-protected input {
  background: #94a2be !important;
  color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3C-Slate {
  color: fuchsia !important;
  text-decoration: underline;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3C-Slate input {
  background: black !important;
  color: white !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3C-Slate-protected input {
  background: #eff3f5 !important;
  color: #e941ff !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3D-Slate {
  background: #e941ff !important;
  color: white !important;
  text-decoration: underline;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3D-Slate input {
  background: #e941ff !important;
  color: white !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3D-Slate-protected input {
  background: #e941ff !important;
  color: white !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3E-Slate {
  color: #94a2be !important;
  text-decoration: underline;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3E-Slate input {
  color: #94a2be !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3E-Slate-protected input {
  background: #eff3f5 !important;
  color: #94a2be !important;
}

/* line 519, ../sass/Slate.scss */
.iceCap-output-3F-Slate {
  color: #94a2be !important;
  text-decoration: none;
}

/* line 527, ../sass/Slate.scss */
.iceCap-input-3F-Slate input {
  color: #94a2be !important;
  text-decoration: none;
}
/* line 533, ../sass/Slate.scss */
.iceCap-input-3F-Slate-protected input {
  background: #eff3f5 !important;
  color: #94a2be !important;
}
