

	/*!
	 * Automated Icon Libray v0.1.0 (http://www.ailcss.com)
	 * Copyright 2014 Splynxicon Inc.
	 */
		div[class*="icecap-icon-flag_"] {
			background-size: 16px;
			background-position: center center !important;
			background-repeat: no-repeat;
		}
		
	 	div[class*="icecap-icon-flag_"]:before {
			 content: "" !important;
		 }

		.icecap-icon-flag_slovakia {
			background-image: url("/icecap/app/theme/flags/flag_slovakia.png")
		}

		.icecap-icon-flag_mexico {
			background-image: url("/icecap/app/theme/flags/flag_mexico.png")
		}

		.icecap-icon-flag_turkey {
			background-image: url("/icecap/app/theme/flags/flag_turkey.png")
		}

		.icecap-icon-flag_rainbow {
			background-image: url("/icecap/app/theme/flags/flag_rainbow.png")
		}

		.icecap-icon-flag_belarus {
			background-image: url("/icecap/app/theme/flags/flag_belarus.png")
		}

		.icecap-icon-flag_togo {
			background-image: url("/icecap/app/theme/flags/flag_togo.png")
		}

		.icecap-icon-flag_singapore {
			background-image: url("/icecap/app/theme/flags/flag_singapore.png")
		}

		.icecap-icon-flag_madagascar {
			background-image: url("/icecap/app/theme/flags/flag_madagascar.png")
		}

		.icecap-icon-flag_qatar {
			background-image: url("/icecap/app/theme/flags/flag_qatar.png")
		}

		.icecap-icon-flag_sao_tome_and_principe {
			background-image: url("/icecap/app/theme/flags/flag_sao_tome_and_principe.png")
		}

		.icecap-icon-flag_uganda {
			background-image: url("/icecap/app/theme/flags/flag_uganda.png")
		}

		.icecap-icon-flag_yemen {
			background-image: url("/icecap/app/theme/flags/flag_yemen.png")
		}

		.icecap-icon-flag_sudan {
			background-image: url("/icecap/app/theme/flags/flag_sudan.png")
		}

		.icecap-icon-flag_iceland {
			background-image: url("/icecap/app/theme/flags/flag_iceland.png")
		}

		.icecap-icon-flag_namibia {
			background-image: url("/icecap/app/theme/flags/flag_namibia.png")
		}

		.icecap-icon-flag_angola {
			background-image: url("/icecap/app/theme/flags/flag_angola.png")
		}

		.icecap-icon-flag_guernsey {
			background-image: url("/icecap/app/theme/flags/flag_guernsey.png")
		}

		.icecap-icon-flag_wales {
			background-image: url("/icecap/app/theme/flags/flag_wales.png")
		}

		.icecap-icon-flag_equatorial_guinea {
			background-image: url("/icecap/app/theme/flags/flag_equatorial_guinea.png")
		}

		.icecap-icon-flag_isle_of_man {
			background-image: url("/icecap/app/theme/flags/flag_isle_of_man.png")
		}

		.icecap-icon-flag_iran {
			background-image: url("/icecap/app/theme/flags/flag_iran.png")
		}

		.icecap-icon-flag_new_zealand {
			background-image: url("/icecap/app/theme/flags/flag_new_zealand.png")
		}

		.icecap-icon-flag_saint_helena {
			background-image: url("/icecap/app/theme/flags/flag_saint_helena.png")
		}

		.icecap-icon-flag_bhutan {
			background-image: url("/icecap/app/theme/flags/flag_bhutan.png")
		}

		.icecap-icon-flag_austria {
			background-image: url("/icecap/app/theme/flags/flag_austria.png")
		}

		.icecap-icon-flag_taiwan {
			background-image: url("/icecap/app/theme/flags/flag_taiwan.png")
		}

		.icecap-icon-flag_south_africa {
			background-image: url("/icecap/app/theme/flags/flag_south_africa.png")
		}

		.icecap-icon-flag_colombia {
			background-image: url("/icecap/app/theme/flags/flag_colombia.png")
		}

		.icecap-icon-flag_guinea_bissau {
			background-image: url("/icecap/app/theme/flags/flag_guinea_bissau.png")
		}

		.icecap-icon-flag_djibouti {
			background-image: url("/icecap/app/theme/flags/flag_djibouti.png")
		}

		.icecap-icon-flag_israel {
			background-image: url("/icecap/app/theme/flags/flag_israel.png")
		}

		.icecap-icon-flag_anguilla {
			background-image: url("/icecap/app/theme/flags/flag_anguilla.png")
		}

		.icecap-icon-flag_saudi_arabia {
			background-image: url("/icecap/app/theme/flags/flag_saudi_arabia.png")
		}

		.icecap-icon-flag_macau {
			background-image: url("/icecap/app/theme/flags/flag_macau.png")
		}

		.icecap-icon-flag_uruguay {
			background-image: url("/icecap/app/theme/flags/flag_uruguay.png")
		}

		.icecap-icon-flag_botswana {
			background-image: url("/icecap/app/theme/flags/flag_botswana.png")
		}

		.icecap-icon-flag_south_korea {
			background-image: url("/icecap/app/theme/flags/flag_south_korea.png")
		}

		.icecap-icon-flag_italy {
			background-image: url("/icecap/app/theme/flags/flag_italy.png")
		}

		.icecap-icon-flag_dominica {
			background-image: url("/icecap/app/theme/flags/flag_dominica.png")
		}

		.icecap-icon-flag_niger {
			background-image: url("/icecap/app/theme/flags/flag_niger.png")
		}

		.icecap-icon-flag_hong_kong {
			background-image: url("/icecap/app/theme/flags/flag_hong_kong.png")
		}

		.icecap-icon-flag_portugal {
			background-image: url("/icecap/app/theme/flags/flag_portugal.png")
		}

		.icecap-icon-flag_seychelles {
			background-image: url("/icecap/app/theme/flags/flag_seychelles.png")
		}

		.icecap-icon-flag_nicaragua {
			background-image: url("/icecap/app/theme/flags/flag_nicaragua.png")
		}

		.icecap-icon-flag_vatican_city {
			background-image: url("/icecap/app/theme/flags/flag_vatican_city.png")
		}

		.icecap-icon-flag_sierra_leone {
			background-image: url("/icecap/app/theme/flags/flag_sierra_leone.png")
		}

		.icecap-icon-flag_indonesia {
			background-image: url("/icecap/app/theme/flags/flag_indonesia.png")
		}

		.icecap-icon-flag_nepal {
			background-image: url("/icecap/app/theme/flags/flag_nepal.png")
		}

		.icecap-icon-flag_belgium {
			background-image: url("/icecap/app/theme/flags/flag_belgium.png")
		}

		.icecap-icon-flag_syria {
			background-image: url("/icecap/app/theme/flags/flag_syria.png")
		}

		.icecap-icon-flag_venezuela {
			background-image: url("/icecap/app/theme/flags/flag_venezuela.png")
		}

		.icecap-icon-flag_gabon {
			background-image: url("/icecap/app/theme/flags/flag_gabon.png")
		}

		.icecap-icon-flag_belize {
			background-image: url("/icecap/app/theme/flags/flag_belize.png")
		}

		.icecap-icon-flag_kiribati {
			background-image: url("/icecap/app/theme/flags/flag_kiribati.png")
		}

		.icecap-icon-flag_ukraine {
			background-image: url("/icecap/app/theme/flags/flag_ukraine.png")
		}

		.icecap-icon-flag_guam {
			background-image: url("/icecap/app/theme/flags/flag_guam.png")
		}

		.icecap-icon-flag_cayman_islands {
			background-image: url("/icecap/app/theme/flags/flag_cayman_islands.png")
		}

		.icecap-icon-flag_eu {
			background-image: url("/icecap/app/theme/flags/flag_eu.png")
		}

		.icecap-icon-flag_da {
			background-image: url("/icecap/app/theme/flags/flag_da.png")
		}

		.icecap-icon-flag_united_arab_emirates {
			background-image: url("/icecap/app/theme/flags/flag_united_arab_emirates.png")
		}

		.icecap-icon-flag_american_samoa {
			background-image: url("/icecap/app/theme/flags/flag_american_samoa.png")
		}

		.icecap-icon-flag_zimbabwe {
			background-image: url("/icecap/app/theme/flags/flag_zimbabwe.png")
		}

		.icecap-icon-flag_jamaica {
			background-image: url("/icecap/app/theme/flags/flag_jamaica.png")
		}

		.icecap-icon-flag_liberia {
			background-image: url("/icecap/app/theme/flags/flag_liberia.png")
		}

		.icecap-icon-flag_lesotho {
			background-image: url("/icecap/app/theme/flags/flag_lesotho.png")
		}

		.icecap-icon-flag_eritrea {
			background-image: url("/icecap/app/theme/flags/flag_eritrea.png")
		}

		.icecap-icon-flag_egypt {
			background-image: url("/icecap/app/theme/flags/flag_egypt.png")
		}

		.icecap-icon-flag_en {
			background-image: url("/icecap/app/theme/flags/flag_en.png")
		}

		.icecap-icon-flag_senegal {
			background-image: url("/icecap/app/theme/flags/flag_senegal.png")
		}

		.icecap-icon-flag_ireland {
			background-image: url("/icecap/app/theme/flags/flag_ireland.png")
		}

		.icecap-icon-flag_sri_lanka {
			background-image: url("/icecap/app/theme/flags/flag_sri_lanka.png")
		}

		.icecap-icon-flag_peru {
			background-image: url("/icecap/app/theme/flags/flag_peru.png")
		}

		.icecap-icon-flag_norfolk_island {
			background-image: url("/icecap/app/theme/flags/flag_norfolk_island.png")
		}

		.icecap-icon-flag_monaco {
			background-image: url("/icecap/app/theme/flags/flag_monaco.png")
		}

		.icecap-icon-flag_central_african_republic {
			background-image: url("/icecap/app/theme/flags/flag_central_african_republic.png")
		}

		.icecap-icon-flag_kyrgyzstan {
			background-image: url("/icecap/app/theme/flags/flag_kyrgyzstan.png")
		}

		.icecap-icon-flag_dominican_republic {
			background-image: url("/icecap/app/theme/flags/flag_dominican_republic.png")
		}

		.icecap-icon-flag_pakistan {
			background-image: url("/icecap/app/theme/flags/flag_pakistan.png")
		}

		.icecap-icon-flag_burundi {
			background-image: url("/icecap/app/theme/flags/flag_burundi.png")
		}

		.icecap-icon-flag_east_timor {
			background-image: url("/icecap/app/theme/flags/flag_east_timor.png")
		}

		.icecap-icon-flag_cyprus {
			background-image: url("/icecap/app/theme/flags/flag_cyprus.png")
		}

		.icecap-icon-flag_china {
			background-image: url("/icecap/app/theme/flags/flag_china.png")
		}

		.icecap-icon-flag_saint_vincent_and_the_grenadines {
			background-image: url("/icecap/app/theme/flags/flag_saint_vincent_and_the_grenadines.png")
		}

		.icecap-icon-flag_cook_islands {
			background-image: url("/icecap/app/theme/flags/flag_cook_islands.png")
		}

		.icecap-icon-flag_martinique {
			background-image: url("/icecap/app/theme/flags/flag_martinique.png")
		}

		.icecap-icon-flag_palau {
			background-image: url("/icecap/app/theme/flags/flag_palau.png")
		}

		.icecap-icon-flag_oman {
			background-image: url("/icecap/app/theme/flags/flag_oman.png")
		}

		.icecap-icon-flag_wallis_and_futuna {
			background-image: url("/icecap/app/theme/flags/flag_wallis_and_futuna.png")
		}

		.icecap-icon-flag_uzbekistan {
			background-image: url("/icecap/app/theme/flags/flag_uzbekistan.png")
		}

		.icecap-icon-flag_poland {
			background-image: url("/icecap/app/theme/flags/flag_poland.png")
		}

		.icecap-icon-flag_es {
			background-image: url("/icecap/app/theme/flags/flag_es.png")
		}

		.icecap-icon-flag_british_virgin_islands {
			background-image: url("/icecap/app/theme/flags/flag_british_virgin_islands.png")
		}

		.icecap-icon-flag_ecuador {
			background-image: url("/icecap/app/theme/flags/flag_ecuador.png")
		}

		.icecap-icon-flag_fiji {
			background-image: url("/icecap/app/theme/flags/flag_fiji.png")
		}

		.icecap-icon-flag_usa {
			background-image: url("/icecap/app/theme/flags/flag_usa.png")
		}

		.icecap-icon-flag_mali {
			background-image: url("/icecap/app/theme/flags/flag_mali.png")
		}

		.icecap-icon-flag_antigua_and_barbuda {
			background-image: url("/icecap/app/theme/flags/flag_antigua_and_barbuda.png")
		}

		.icecap-icon-flag_generic {
			background-image: url("/icecap/app/theme/flags/flag_generic.png")
		}

		.icecap-icon-flag_bosnia_and_herzegovina {
			background-image: url("/icecap/app/theme/flags/flag_bosnia_and_herzegovina.png")
		}

		.icecap-icon-flag_marshall_islands {
			background-image: url("/icecap/app/theme/flags/flag_marshall_islands.png")
		}

		.icecap-icon-flag_northern_mariana_islands {
			background-image: url("/icecap/app/theme/flags/flag_northern_mariana_islands.png")
		}

		.icecap-icon-flag_netherlands_antilles {
			background-image: url("/icecap/app/theme/flags/flag_netherlands_antilles.png")
		}

		.icecap-icon-flag_turkmenistan {
			background-image: url("/icecap/app/theme/flags/flag_turkmenistan.png")
		}

		.icecap-icon-flag_burma {
			background-image: url("/icecap/app/theme/flags/flag_burma.png")
		}

		.icecap-icon-flag_british_indian_ocean_territory {
			background-image: url("/icecap/app/theme/flags/flag_british_indian_ocean_territory.png")
		}

		.icecap-icon-flag_guinea {
			background-image: url("/icecap/app/theme/flags/flag_guinea.png")
		}

		.icecap-icon-flag_latvia {
			background-image: url("/icecap/app/theme/flags/flag_latvia.png")
		}

		.icecap-icon-flag_algeria {
			background-image: url("/icecap/app/theme/flags/flag_algeria.png")
		}

		.icecap-icon-flag_armenia {
			background-image: url("/icecap/app/theme/flags/flag_armenia.png")
		}

		.icecap-icon-flag_tajikistan {
			background-image: url("/icecap/app/theme/flags/flag_tajikistan.png")
		}

		.icecap-icon-flag_india {
			background-image: url("/icecap/app/theme/flags/flag_india.png")
		}

		.icecap-icon-flag_guyana {
			background-image: url("/icecap/app/theme/flags/flag_guyana.png")
		}

		.icecap-icon-flag_saint_pierre_and_miquelon {
			background-image: url("/icecap/app/theme/flags/flag_saint_pierre_and_miquelon.png")
		}

		.icecap-icon-flag_jordan {
			background-image: url("/icecap/app/theme/flags/flag_jordan.png")
		}

		.icecap-icon-flag_australia {
			background-image: url("/icecap/app/theme/flags/flag_australia.png")
		}

		.icecap-icon-flag_mozambique {
			background-image: url("/icecap/app/theme/flags/flag_mozambique.png")
		}

		.icecap-icon-flag_no {
			background-image: url("/icecap/app/theme/flags/flag_no.png")
		}

		.icecap-icon-flag_morocco {
			background-image: url("/icecap/app/theme/flags/flag_morocco.png")
		}

		.icecap-icon-flag_afghanistan {
			background-image: url("/icecap/app/theme/flags/flag_afghanistan.png")
		}

		.icecap-icon-flag_comoros {
			background-image: url("/icecap/app/theme/flags/flag_comoros.png")
		}

		.icecap-icon-flag_libya {
			background-image: url("/icecap/app/theme/flags/flag_libya.png")
		}

		.icecap-icon-flag_saint_kitts_and_nevis {
			background-image: url("/icecap/app/theme/flags/flag_saint_kitts_and_nevis.png")
		}

		.icecap-icon-flag_pitcairn_islands {
			background-image: url("/icecap/app/theme/flags/flag_pitcairn_islands.png")
		}

		.icecap-icon-flag_lithuania {
			background-image: url("/icecap/app/theme/flags/flag_lithuania.png")
		}

		.icecap-icon-flag_bahamas {
			background-image: url("/icecap/app/theme/flags/flag_bahamas.png")
		}

		.icecap-icon-flag_gambia {
			background-image: url("/icecap/app/theme/flags/flag_gambia.png")
		}

		.icecap-icon-flag_albania {
			background-image: url("/icecap/app/theme/flags/flag_albania.png")
		}

		.icecap-icon-flag_south_georgia {
			background-image: url("/icecap/app/theme/flags/flag_south_georgia.png")
		}

		.icecap-icon-flag_maldives {
			background-image: url("/icecap/app/theme/flags/flag_maldives.png")
		}

		.icecap-icon-flag_malawi {
			background-image: url("/icecap/app/theme/flags/flag_malawi.png")
		}

		.icecap-icon-flag_greece {
			background-image: url("/icecap/app/theme/flags/flag_greece.png")
		}

		.icecap-icon-flag_bahrain {
			background-image: url("/icecap/app/theme/flags/flag_bahrain.png")
		}

		.icecap-icon-flag_haiti {
			background-image: url("/icecap/app/theme/flags/flag_haiti.png")
		}

		.icecap-icon-flag_falkland_islands {
			background-image: url("/icecap/app/theme/flags/flag_falkland_islands.png")
		}

		.icecap-icon-flag_cote_divoire {
			background-image: url("/icecap/app/theme/flags/flag_cote_divoire.png")
		}

		.icecap-icon-flag_grenada {
			background-image: url("/icecap/app/theme/flags/flag_grenada.png")
		}

		.icecap-icon-flag_jersey {
			background-image: url("/icecap/app/theme/flags/flag_jersey.png")
		}

		.icecap-icon-flag_virgin_islands {
			background-image: url("/icecap/app/theme/flags/flag_virgin_islands.png")
		}

		.icecap-icon-flag_somalia {
			background-image: url("/icecap/app/theme/flags/flag_somalia.png")
		}

		.icecap-icon-flag_tanzania {
			background-image: url("/icecap/app/theme/flags/flag_tanzania.png")
		}

		.icecap-icon-flag_cameroon {
			background-image: url("/icecap/app/theme/flags/flag_cameroon.png")
		}

		.icecap-icon-flag_japan {
			background-image: url("/icecap/app/theme/flags/flag_japan.png")
		}

		.icecap-icon-flag_micronesia {
			background-image: url("/icecap/app/theme/flags/flag_micronesia.png")
		}

		.icecap-icon-flag_vanuatu {
			background-image: url("/icecap/app/theme/flags/flag_vanuatu.png")
		}

		.icecap-icon-flag_scotland {
			background-image: url("/icecap/app/theme/flags/flag_scotland.png")
		}

		.icecap-icon-flag_samoa {
			background-image: url("/icecap/app/theme/flags/flag_samoa.png")
		}

		.icecap-icon-flag_romania {
			background-image: url("/icecap/app/theme/flags/flag_romania.png")
		}

		.icecap-icon-flag_malaysia {
			background-image: url("/icecap/app/theme/flags/flag_malaysia.png")
		}

		.icecap-icon-flag_gibraltar {
			background-image: url("/icecap/app/theme/flags/flag_gibraltar.png")
		}

		.icecap-icon-flag_serbia {
			background-image: url("/icecap/app/theme/flags/flag_serbia.png")
		}

		.icecap-icon-flag_kenya {
			background-image: url("/icecap/app/theme/flags/flag_kenya.png")
		}

		.icecap-icon-flag_rwanda {
			background-image: url("/icecap/app/theme/flags/flag_rwanda.png")
		}

		.icecap-icon-flag_mauritius {
			background-image: url("/icecap/app/theme/flags/flag_mauritius.png")
		}

		.icecap-icon-flag_white {
			background-image: url("/icecap/app/theme/flags/flag_white.png")
		}

		.icecap-icon-flag_bulgaria {
			background-image: url("/icecap/app/theme/flags/flag_bulgaria.png")
		}

		.icecap-icon-flag_nauru {
			background-image: url("/icecap/app/theme/flags/flag_nauru.png")
		}

		.icecap-icon-flag_thailand {
			background-image: url("/icecap/app/theme/flags/flag_thailand.png")
		}

		.icecap-icon-flag_turks_and_caicos_islands {
			background-image: url("/icecap/app/theme/flags/flag_turks_and_caicos_islands.png")
		}

		.icecap-icon-flag_solomon_islands {
			background-image: url("/icecap/app/theme/flags/flag_solomon_islands.png")
		}

		.icecap-icon-flag_cape_verde {
			background-image: url("/icecap/app/theme/flags/flag_cape_verde.png")
		}

		.icecap-icon-flag_kazakhstan {
			background-image: url("/icecap/app/theme/flags/flag_kazakhstan.png")
		}

		.icecap-icon-flag_azerbaijan {
			background-image: url("/icecap/app/theme/flags/flag_azerbaijan.png")
		}

		.icecap-icon-flag_mongolia {
			background-image: url("/icecap/app/theme/flags/flag_mongolia.png")
		}

		.icecap-icon-flag_macedonia {
			background-image: url("/icecap/app/theme/flags/flag_macedonia.png")
		}

		.icecap-icon-flag_swaziland {
			background-image: url("/icecap/app/theme/flags/flag_swaziland.png")
		}

		.icecap-icon-flag_paraguay {
			background-image: url("/icecap/app/theme/flags/flag_paraguay.png")
		}

		.icecap-icon-flag_bolivia {
			background-image: url("/icecap/app/theme/flags/flag_bolivia.png")
		}

		.icecap-icon-flag_croatia {
			background-image: url("/icecap/app/theme/flags/flag_croatia.png")
		}

		.icecap-icon-flag_el_salvador {
			background-image: url("/icecap/app/theme/flags/flag_el_salvador.png")
		}

		.icecap-icon-flag_de {
			background-image: url("/icecap/app/theme/flags/flag_de.png")
		}

		.icecap-icon-flag_switzerland {
			background-image: url("/icecap/app/theme/flags/flag_switzerland.png")
		}

		.icecap-icon-flag_malta {
			background-image: url("/icecap/app/theme/flags/flag_malta.png")
		}

		.icecap-icon-flag_fr {
			background-image: url("/icecap/app/theme/flags/flag_fr.png")
		}

		.icecap-icon-flag_french_polynesia {
			background-image: url("/icecap/app/theme/flags/flag_french_polynesia.png")
		}

		.icecap-icon-flag_bermuda {
			background-image: url("/icecap/app/theme/flags/flag_bermuda.png")
		}

		.icecap-icon-flag_kuwait {
			background-image: url("/icecap/app/theme/flags/flag_kuwait.png")
		}

		.icecap-icon-flag_russia {
			background-image: url("/icecap/app/theme/flags/flag_russia.png")
		}

		.icecap-icon-flag_cambodia {
			background-image: url("/icecap/app/theme/flags/flag_cambodia.png")
		}

		.icecap-icon-flag_chile {
			background-image: url("/icecap/app/theme/flags/flag_chile.png")
		}

		.icecap-icon-flag_slovenia {
			background-image: url("/icecap/app/theme/flags/flag_slovenia.png")
		}

		.icecap-icon-flag_czech_republic {
			background-image: url("/icecap/app/theme/flags/flag_czech_republic.png")
		}

		.icecap-icon-flag_iraq {
			background-image: url("/icecap/app/theme/flags/flag_iraq.png")
		}

		.icecap-icon-flag_lebanon {
			background-image: url("/icecap/app/theme/flags/flag_lebanon.png")
		}

		.icecap-icon-flag_barbados {
			background-image: url("/icecap/app/theme/flags/flag_barbados.png")
		}

		.icecap-icon-flag_moldova {
			background-image: url("/icecap/app/theme/flags/flag_moldova.png")
		}

		.icecap-icon-flag_ghana {
			background-image: url("/icecap/app/theme/flags/flag_ghana.png")
		}

		.icecap-icon-flag_pirate {
			background-image: url("/icecap/app/theme/flags/flag_pirate.png")
		}

		.icecap-icon-flag_faeroe_islands {
			background-image: url("/icecap/app/theme/flags/flag_faeroe_islands.png")
		}

		.icecap-icon-flag_puerto_rico {
			background-image: url("/icecap/app/theme/flags/flag_puerto_rico.png")
		}

		.icecap-icon-flag_ethiopia {
			background-image: url("/icecap/app/theme/flags/flag_ethiopia.png")
		}

		.icecap-icon-flag_mauritania {
			background-image: url("/icecap/app/theme/flags/flag_mauritania.png")
		}

		.icecap-icon-flag_trinidad_and_tobago {
			background-image: url("/icecap/app/theme/flags/flag_trinidad_and_tobago.png")
		}

		.icecap-icon-flag_nigeria {
			background-image: url("/icecap/app/theme/flags/flag_nigeria.png")
		}

		.icecap-icon-flag_niue {
			background-image: url("/icecap/app/theme/flags/flag_niue.png")
		}

		.icecap-icon-flag_luxembourg {
			background-image: url("/icecap/app/theme/flags/flag_luxembourg.png")
		}

		.icecap-icon-flag_france {
			background-image: url("/icecap/app/theme/flags/flag_fr.png")
		}

		.icecap-icon-flag_tuvalu {
			background-image: url("/icecap/app/theme/flags/flag_tuvalu.png")
		}

		.icecap-icon-flag_costa_rica {
			background-image: url("/icecap/app/theme/flags/flag_costa_rica.png")
		}

		.icecap-icon-flag_burkina_faso {
			background-image: url("/icecap/app/theme/flags/flag_burkina_faso.png")
		}

		.icecap-icon-flag_england {
			background-image: url("/icecap/app/theme/flags/flag_england.png")
		}

		.icecap-icon-flag_fi {
			background-image: url("/icecap/app/theme/flags/flag_finland.png")
		}

		.icecap-icon-flag_finland {
			background-image: url("/icecap/app/theme/flags/flag_finland.png")
		}

		.icecap-icon-flag_checkered {
			background-image: url("/icecap/app/theme/flags/flag_checkered.png")
		}

		.icecap-icon-flag_congo_republic {
			background-image: url("/icecap/app/theme/flags/flag_congo_republic.png")
		}

		.icecap-icon-flag_tibet {
			background-image: url("/icecap/app/theme/flags/flag_tibet.png")
		}

		.icecap-icon-flag_vietnam {
			background-image: url("/icecap/app/theme/flags/flag_vietnam.png")
		}

		.icecap-icon-flag_estonia {
			background-image: url("/icecap/app/theme/flags/flag_estonia.png")
		}

		.icecap-icon-flag_tunisia {
			background-image: url("/icecap/app/theme/flags/flag_tunisia.png")
		}

		.icecap-icon-flag_zambia {
			background-image: url("/icecap/app/theme/flags/flag_zambia.png")
		}

		.icecap-icon-flag_tonga {
			background-image: url("/icecap/app/theme/flags/flag_tonga.png")
		}

		.icecap-icon-flag_guatemala {
			background-image: url("/icecap/app/theme/flags/flag_guatemala.png")
		}

		.icecap-icon-flag_brunei {
			background-image: url("/icecap/app/theme/flags/flag_brunei.png")
		}

		.icecap-icon-flag_brazil {
			background-image: url("/icecap/app/theme/flags/flag_brazil.png")
		}

		.icecap-icon-flag_montenegro {
			background-image: url("/icecap/app/theme/flags/flag_montenegro.png")
		}

		.icecap-icon-flag_san_marino {
			background-image: url("/icecap/app/theme/flags/flag_san_marino.png")
		}

		.icecap-icon-flag_panama {
			background-image: url("/icecap/app/theme/flags/flag_panama.png")
		}

		.icecap-icon-flag_north_korea {
			background-image: url("/icecap/app/theme/flags/flag_north_korea.png")
		}

		.icecap-icon-flag_papua_new_guinea {
			background-image: url("/icecap/app/theme/flags/flag_papua_new_guinea.png")
		}

		.icecap-icon-flag_honduras {
			background-image: url("/icecap/app/theme/flags/flag_honduras.png")
		}

		.icecap-icon-flag_suriname {
			background-image: url("/icecap/app/theme/flags/flag_suriname.png")
		}

		.icecap-icon-flag_andorra {
			background-image: url("/icecap/app/theme/flags/flag_andorra.png")
		}

		.icecap-icon-flag_nl {
			background-image: url("/icecap/app/theme/flags/flag_nl.png")
		}

		.icecap-icon-flag_hungary {
			background-image: url("/icecap/app/theme/flags/flag_hungary.png")
		}

		.icecap-icon-flag_chad {
			background-image: url("/icecap/app/theme/flags/flag_chad.png")
		}

		.icecap-icon-flag_georgia {
			background-image: url("/icecap/app/theme/flags/flag_georgia.png")
		}

		.icecap-icon-flag_laos {
			background-image: url("/icecap/app/theme/flags/flag_laos.png")
		}

		.icecap-icon-flag_saint_lucia {
			background-image: url("/icecap/app/theme/flags/flag_saint_lucia.png")
		}

		.icecap-icon-flag_cuba {
			background-image: url("/icecap/app/theme/flags/flag_cuba.png")
		}

		.icecap-icon-flag_bangladesh {
			background-image: url("/icecap/app/theme/flags/flag_bangladesh.png")
		}

		.icecap-icon-flag_benin {
			background-image: url("/icecap/app/theme/flags/flag_benin.png")
		}

		.icecap-icon-flag_argentina {
			background-image: url("/icecap/app/theme/flags/flag_argentina.png")
		}

		.icecap-icon-flag_philippines {
			background-image: url("/icecap/app/theme/flags/flag_philippines.png")
		}

		.icecap-icon-flag_greenland {
			background-image: url("/icecap/app/theme/flags/flag_greenland.png")
		}

		.icecap-icon-flag_congo_democratic_republic {
			background-image: url("/icecap/app/theme/flags/flag_congo_democratic_republic.png")
		}

		.icecap-icon-flag_canada {
			background-image: url("/icecap/app/theme/flags/flag_canada.png")
		}

		.icecap-icon-flag_liechtenstein {
			background-image: url("/icecap/app/theme/flags/flag_liechtenstein.png")
		}

		.icecap-icon-flag_montserrat {
			background-image: url("/icecap/app/theme/flags/flag_montserrat.png")
		}

		.icecap-icon-flag_sv {
			background-image: url("/icecap/app/theme/flags/flag_sv.png")
		}

		.icecap-icon-flag_aruba {
			background-image: url("/icecap/app/theme/flags/flag_aruba.png")
		}

