$image-search-path: 'C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/build/resources' !default;
$theme-name:  'icecap-theme' !default;
$include-ext-abstractcomponent: dynamic(true);;
$include-ext-abstractcontainer: dynamic(true);;
$include-ext-abstractmanager: dynamic(true);;
$include-ext-abstractplugin: dynamic(true);;
$include-ext-abstractselectionmodel: dynamic(true);;
$include-ext-action: dynamic(true);;
$include-ext-ajax: dynamic(true);;
$include-ext-animationqueue: dynamic(true);;
$include-ext-animator: dynamic(true);;
$include-ext-boundlist: dynamic(true);;
$include-ext-button: dynamic(true);;
$include-ext-buttongroup: dynamic(true);;
$include-ext-buttontogglemanager: dynamic(true);;
$include-ext-colorpalette: dynamic(true);;
$include-ext-component: dynamic(true);;
$include-ext-componentloader: dynamic(true);;
$include-ext-componentmanager: dynamic(true);;
$include-ext-componentmgr: dynamic(true);;
$include-ext-componentquery: dynamic(true);;
$include-ext-compositeelement: dynamic(true);;
$include-ext-compositeelementlite: dynamic(true);;
$include-ext-container: dynamic(true);;
$include-ext-cyclebutton: dynamic(true);;
$include-ext-dataview: dynamic(true);;
$include-ext-datepicker: dynamic(true);;
$include-ext-deferred: dynamic(true);;
$include-ext-domhelper: dynamic(true);;
$include-ext-domquery: dynamic(true);;
$include-ext-editor: dynamic(true);;
$include-ext-element: dynamic(true);;
$include-ext-elementloader: dynamic(true);;
$include-ext-eventmanager: dynamic(true);;
$include-ext-eventobjectimpl: dynamic(true);;
$include-ext-evented: dynamic(true);;
$include-ext-eventedbase: dynamic(true);;
$include-ext-flashcomponent: dynamic(true);;
$include-ext-formpanel: dynamic(true);;
$include-ext-gadget: dynamic(true);;
$include-ext-globalevents: dynamic(true);;
$include-ext-glyph: dynamic(true);;
$include-ext-history: dynamic(true);;
$include-ext-img: dynamic(true);;
$include-ext-itemcollection: dynamic(true);;
$include-ext-keymap: dynamic(true);;
$include-ext-keynav: dynamic(true);;
$include-ext-layer: dynamic(true);;
$include-ext-listview: dynamic(true);;
$include-ext-loadmask: dynamic(true);;
$include-ext-mixin: dynamic(true);;
$include-ext-modelmgr: dynamic(true);;
$include-ext-monthpicker: dynamic(true);;
$include-ext-pagingtoolbar: dynamic(true);;
$include-ext-panel: dynamic(true);;
$include-ext-perf: dynamic(true);;
$include-ext-pluginmanager: dynamic(true);;
$include-ext-pluginmgr: dynamic(true);;
$include-ext-progress: dynamic(true);;
$include-ext-progressbar: dynamic(true);;
$include-ext-progressbarwidget: dynamic(true);;
$include-ext-progressbase: dynamic(true);;
$include-ext-promise: dynamic(true);;
$include-ext-propgridproperty: dynamic(true);;
$include-ext-quicktip: dynamic(true);;
$include-ext-quicktips: dynamic(true);;
$include-ext-resizable: dynamic(true);;
$include-ext-shadow: dynamic(true);;
$include-ext-slider: dynamic(true);;
$include-ext-splitbutton: dynamic(true);;
$include-ext-storemanager: dynamic(true);;
$include-ext-storemgr: dynamic(true);;
$include-ext-tabpanel: dynamic(true);;
$include-ext-taskmanager: dynamic(true);;
$include-ext-taskqueue: dynamic(true);;
$include-ext-template: dynamic(true);;
$include-ext-tip: dynamic(true);;
$include-ext-tooltip: dynamic(true);;
$include-ext-toolbar: dynamic(true);;
$include-ext-toolbar-fill: dynamic(true);;
$include-ext-toolbar-item: dynamic(true);;
$include-ext-toolbar-separator: dynamic(true);;
$include-ext-toolbar-spacer: dynamic(true);;
$include-ext-toolbar-textitem: dynamic(true);;
$include-ext-treepanel: dynamic(true);;
$include-ext-viewport: dynamic(true);;
$include-ext-widget: dynamic(true);;
$include-ext-window: dynamic(true);;
$include-ext-windowgroup: dynamic(true);;
$include-ext-xtemplate: dynamic(true);;
$include-ext-zindexmanager: dynamic(true);;
$include-ext-app-application: dynamic(true);;
$include-ext-app-basecontroller: dynamic(true);;
$include-ext-app-controller: dynamic(true);;
$include-ext-app-eventbus: dynamic(true);;
$include-ext-app-eventdomain: dynamic(true);;
$include-ext-app-profile: dynamic(true);;
$include-ext-app-util: dynamic(true);;
$include-ext-app-viewcontroller: dynamic(true);;
$include-ext-app-viewmodel: dynamic(true);;
$include-ext-app-bind-abstractstub: dynamic(true);;
$include-ext-app-bind-basebinding: dynamic(true);;
$include-ext-app-bind-binding: dynamic(true);;
$include-ext-app-bind-formula: dynamic(true);;
$include-ext-app-bind-linkstub: dynamic(true);;
$include-ext-app-bind-multi: dynamic(true);;
$include-ext-app-bind-parser: dynamic(true);;
$include-ext-app-bind-rootstub: dynamic(true);;
$include-ext-app-bind-stub: dynamic(true);;
$include-ext-app-bind-template: dynamic(true);;
$include-ext-app-bind-templatebinding: dynamic(true);;
$include-ext-app-domain-component: dynamic(true);;
$include-ext-app-domain-controller: dynamic(true);;
$include-ext-app-domain-direct: dynamic(true);;
$include-ext-app-domain-global: dynamic(true);;
$include-ext-app-domain-store: dynamic(true);;
$include-ext-app-domain-view: dynamic(true);;
$include-ext-button-button: dynamic(true);;
$include-ext-button-cycle: dynamic(true);;
$include-ext-button-manager: dynamic(true);;
$include-ext-button-segmented: dynamic(true);;
$include-ext-button-split: dynamic(true);;
$include-ext-container-buttongroup: dynamic(true);;
$include-ext-container-container: dynamic(true);;
$include-ext-container-dockingcontainer: dynamic(true);;
$include-ext-container-monitor: dynamic(true);;
$include-ext-container-viewport: dynamic(true);;
$include-ext-core-domhelper: dynamic(true);;
$include-ext-core-domquery: dynamic(true);;
$include-ext-dashboard-column: dynamic(true);;
$include-ext-dashboard-dashboard: dynamic(true);;
$include-ext-dashboard-dropzone: dynamic(true);;
$include-ext-dashboard-panel: dynamic(true);;
$include-ext-dashboard-part: dynamic(true);;
$include-ext-data-abstractstore: dynamic(true);;
$include-ext-data-ajaxproxy: dynamic(true);;
$include-ext-data-arrayreader: dynamic(true);;
$include-ext-data-arraystore: dynamic(true);;
$include-ext-data-batch: dynamic(true);;
$include-ext-data-bufferedstore: dynamic(true);;
$include-ext-data-chainedstore: dynamic(true);;
$include-ext-data-clientproxy: dynamic(true);;
$include-ext-data-connection: dynamic(true);;
$include-ext-data-dataproxy: dynamic(true);;
$include-ext-data-datareader: dynamic(true);;
$include-ext-data-datawriter: dynamic(true);;
$include-ext-data-directproxy: dynamic(true);;
$include-ext-data-directstore: dynamic(true);;
$include-ext-data-error: dynamic(true);;
$include-ext-data-errorcollection: dynamic(true);;
$include-ext-data-errors: dynamic(true);;
$include-ext-data-field: dynamic(true);;
$include-ext-data-group: dynamic(true);;
$include-ext-data-httpproxy: dynamic(true);;
$include-ext-data-jsonp: dynamic(true);;
$include-ext-data-jsonpstore: dynamic(true);;
$include-ext-data-jsonreader: dynamic(true);;
$include-ext-data-jsonstore: dynamic(true);;
$include-ext-data-jsonwriter: dynamic(true);;
$include-ext-data-localstorageproxy: dynamic(true);;
$include-ext-data-localstore: dynamic(true);;
$include-ext-data-memoryproxy: dynamic(true);;
$include-ext-data-model: dynamic(true);;
$include-ext-data-modelmanager: dynamic(true);;
$include-ext-data-nodeinterface: dynamic(true);;
$include-ext-data-nodestore: dynamic(true);;
$include-ext-data-operation: dynamic(true);;
$include-ext-data-pagemap: dynamic(true);;
$include-ext-data-proxy: dynamic(true);;
$include-ext-data-proxystore: dynamic(true);;
$include-ext-data-range: dynamic(true);;
$include-ext-data-reader: dynamic(true);;
$include-ext-data-record: dynamic(true);;
$include-ext-data-request: dynamic(true);;
$include-ext-data-restproxy: dynamic(true);;
$include-ext-data-resultset: dynamic(true);;
$include-ext-data-scripttagproxy: dynamic(true);;
$include-ext-data-serverproxy: dynamic(true);;
$include-ext-data-session: dynamic(true);;
$include-ext-data-sessionstorageproxy: dynamic(true);;
$include-ext-data-simplestore: dynamic(true);;
$include-ext-data-sorttypes: dynamic(true);;
$include-ext-data-store: dynamic(true);;
$include-ext-data-storemanager: dynamic(true);;
$include-ext-data-storemgr: dynamic(true);;
$include-ext-data-treemodel: dynamic(true);;
$include-ext-data-treestore: dynamic(true);;
$include-ext-data-types: dynamic(true);;
$include-ext-data-validation: dynamic(true);;
$include-ext-data-webstorageproxy: dynamic(true);;
$include-ext-data-writer: dynamic(true);;
$include-ext-data-xmlreader: dynamic(true);;
$include-ext-data-xmlstore: dynamic(true);;
$include-ext-data-xmlwriter: dynamic(true);;
$include-ext-data-field-boolean: dynamic(true);;
$include-ext-data-field-date: dynamic(true);;
$include-ext-data-field-field: dynamic(true);;
$include-ext-data-field-integer: dynamic(true);;
$include-ext-data-field-number: dynamic(true);;
$include-ext-data-field-string: dynamic(true);;
$include-ext-data-flash-binaryxhr: dynamic(true);;
$include-ext-data-identifier-generator: dynamic(true);;
$include-ext-data-identifier-negative: dynamic(true);;
$include-ext-data-identifier-sequential: dynamic(true);;
$include-ext-data-identifier-uuid: dynamic(true);;
$include-ext-data-matrix-matrix: dynamic(true);;
$include-ext-data-matrix-side: dynamic(true);;
$include-ext-data-matrix-slice: dynamic(true);;
$include-ext-data-operation-create: dynamic(true);;
$include-ext-data-operation-destroy: dynamic(true);;
$include-ext-data-operation-operation: dynamic(true);;
$include-ext-data-operation-read: dynamic(true);;
$include-ext-data-operation-update: dynamic(true);;
$include-ext-data-proxy-ajax: dynamic(true);;
$include-ext-data-proxy-client: dynamic(true);;
$include-ext-data-proxy-direct: dynamic(true);;
$include-ext-data-proxy-jsonp: dynamic(true);;
$include-ext-data-proxy-localstorage: dynamic(true);;
$include-ext-data-proxy-memory: dynamic(true);;
$include-ext-data-proxy-proxy: dynamic(true);;
$include-ext-data-proxy-rest: dynamic(true);;
$include-ext-data-proxy-server: dynamic(true);;
$include-ext-data-proxy-sessionstorage: dynamic(true);;
$include-ext-data-proxy-webstorage: dynamic(true);;
$include-ext-data-reader-array: dynamic(true);;
$include-ext-data-reader-json: dynamic(true);;
$include-ext-data-reader-reader: dynamic(true);;
$include-ext-data-reader-xml: dynamic(true);;
$include-ext-data-request-ajax: dynamic(true);;
$include-ext-data-request-base: dynamic(true);;
$include-ext-data-request-form: dynamic(true);;
$include-ext-data-schema-association: dynamic(true);;
$include-ext-data-schema-manytomany: dynamic(true);;
$include-ext-data-schema-manytoone: dynamic(true);;
$include-ext-data-schema-namer: dynamic(true);;
$include-ext-data-schema-onetoone: dynamic(true);;
$include-ext-data-schema-role: dynamic(true);;
$include-ext-data-schema-schema: dynamic(true);;
$include-ext-data-session-batchvisitor: dynamic(true);;
$include-ext-data-session-changesvisitor: dynamic(true);;
$include-ext-data-session-childchangesvisitor: dynamic(true);;
$include-ext-data-summary-average: dynamic(true);;
$include-ext-data-summary-base: dynamic(true);;
$include-ext-data-summary-count: dynamic(true);;
$include-ext-data-summary-max: dynamic(true);;
$include-ext-data-summary-min: dynamic(true);;
$include-ext-data-summary-sum: dynamic(true);;
$include-ext-data-validator-abstractdate: dynamic(true);;
$include-ext-data-validator-bound: dynamic(true);;
$include-ext-data-validator-cidrv4: dynamic(true);;
$include-ext-data-validator-cidrv6: dynamic(true);;
$include-ext-data-validator-currency: dynamic(true);;
$include-ext-data-validator-currencyus: dynamic(true);;
$include-ext-data-validator-date: dynamic(true);;
$include-ext-data-validator-datetime: dynamic(true);;
$include-ext-data-validator-email: dynamic(true);;
$include-ext-data-validator-exclusion: dynamic(true);;
$include-ext-data-validator-format: dynamic(true);;
$include-ext-data-validator-ipaddress: dynamic(true);;
$include-ext-data-validator-inclusion: dynamic(true);;
$include-ext-data-validator-length: dynamic(true);;
$include-ext-data-validator-list: dynamic(true);;
$include-ext-data-validator-notnull: dynamic(true);;
$include-ext-data-validator-number: dynamic(true);;
$include-ext-data-validator-phone: dynamic(true);;
$include-ext-data-validator-presence: dynamic(true);;
$include-ext-data-validator-range: dynamic(true);;
$include-ext-data-validator-time: dynamic(true);;
$include-ext-data-validator-url: dynamic(true);;
$include-ext-data-validator-validator: dynamic(true);;
$include-ext-data-virtual-group: dynamic(true);;
$include-ext-data-virtual-page: dynamic(true);;
$include-ext-data-virtual-pagemap: dynamic(true);;
$include-ext-data-virtual-range: dynamic(true);;
$include-ext-data-virtual-store: dynamic(true);;
$include-ext-data-writer-json: dynamic(true);;
$include-ext-data-writer-writer: dynamic(true);;
$include-ext-data-writer-xml: dynamic(true);;
$include-ext-dd-dd: dynamic(true);;
$include-ext-dd-ddm: dynamic(true);;
$include-ext-dd-ddproxy: dynamic(true);;
$include-ext-dd-ddtarget: dynamic(true);;
$include-ext-dd-dragdrop: dynamic(true);;
$include-ext-dd-dragdropmanager: dynamic(true);;
$include-ext-dd-dragdropmgr: dynamic(true);;
$include-ext-dd-dragsource: dynamic(true);;
$include-ext-dd-dragtracker: dynamic(true);;
$include-ext-dd-dragzone: dynamic(true);;
$include-ext-dd-droptarget: dynamic(true);;
$include-ext-dd-dropzone: dynamic(true);;
$include-ext-dd-panelproxy: dynamic(true);;
$include-ext-dd-registry: dynamic(true);;
$include-ext-dd-scrollmanager: dynamic(true);;
$include-ext-dd-statusproxy: dynamic(true);;
$include-ext-direct-event: dynamic(true);;
$include-ext-direct-exceptionevent: dynamic(true);;
$include-ext-direct-jsonprovider: dynamic(true);;
$include-ext-direct-manager: dynamic(true);;
$include-ext-direct-pollingprovider: dynamic(true);;
$include-ext-direct-provider: dynamic(true);;
$include-ext-direct-remotingevent: dynamic(true);;
$include-ext-direct-remotingmethod: dynamic(true);;
$include-ext-direct-remotingprovider: dynamic(true);;
$include-ext-direct-transaction: dynamic(true);;
$include-ext-dom-buttonelement: dynamic(true);;
$include-ext-dom-compositeelement: dynamic(true);;
$include-ext-dom-compositeelementlite: dynamic(true);;
$include-ext-dom-element: dynamic(true);;
$include-ext-dom-element-fly: dynamic(true);;
$include-ext-dom-elementevent: dynamic(true);;
$include-ext-dom-fly: dynamic(true);;
$include-ext-dom-garbagecollector: dynamic(true);;
$include-ext-dom-helper: dynamic(true);;
$include-ext-dom-layer: dynamic(true);;
$include-ext-dom-query: dynamic(true);;
$include-ext-dom-shadow: dynamic(true);;
$include-ext-dom-shim: dynamic(true);;
$include-ext-dom-touchaction: dynamic(true);;
$include-ext-dom-underlay: dynamic(true);;
$include-ext-dom-underlaypool: dynamic(true);;
$include-ext-drag-constraint: dynamic(true);;
$include-ext-drag-info: dynamic(true);;
$include-ext-drag-item: dynamic(true);;
$include-ext-drag-manager: dynamic(true);;
$include-ext-drag-source: dynamic(true);;
$include-ext-drag-target: dynamic(true);;
$include-ext-drag-proxy-none: dynamic(true);;
$include-ext-drag-proxy-original: dynamic(true);;
$include-ext-drag-proxy-placeholder: dynamic(true);;
$include-ext-draw-color: dynamic(true);;
$include-ext-event-event: dynamic(true);;
$include-ext-event-gesture-doubletap: dynamic(true);;
$include-ext-event-gesture-drag: dynamic(true);;
$include-ext-event-gesture-edgeswipe: dynamic(true);;
$include-ext-event-gesture-longpress: dynamic(true);;
$include-ext-event-gesture-multitouch: dynamic(true);;
$include-ext-event-gesture-pinch: dynamic(true);;
$include-ext-event-gesture-recognizer: dynamic(true);;
$include-ext-event-gesture-rotate: dynamic(true);;
$include-ext-event-gesture-singletouch: dynamic(true);;
$include-ext-event-gesture-swipe: dynamic(true);;
$include-ext-event-gesture-tap: dynamic(true);;
$include-ext-event-publisher-dom: dynamic(true);;
$include-ext-event-publisher-elementpaint: dynamic(true);;
$include-ext-event-publisher-elementsize: dynamic(true);;
$include-ext-event-publisher-focus: dynamic(true);;
$include-ext-event-publisher-gesture: dynamic(true);;
$include-ext-event-publisher-mouseenterleave: dynamic(true);;
$include-ext-event-publisher-publisher: dynamic(true);;
$include-ext-field-inputmask: dynamic(true);;
$include-ext-flash-component: dynamic(true);;
$include-ext-form-action: dynamic(true);;
$include-ext-form-action-directload: dynamic(true);;
$include-ext-form-action-directsubmit: dynamic(true);;
$include-ext-form-action-load: dynamic(true);;
$include-ext-form-action-submit: dynamic(true);;
$include-ext-form-basefield: dynamic(true);;
$include-ext-form-basic: dynamic(true);;
$include-ext-form-basicform: dynamic(true);;
$include-ext-form-checkbox: dynamic(true);;
$include-ext-form-checkboxgroup: dynamic(true);;
$include-ext-form-checkboxmanager: dynamic(true);;
$include-ext-form-combobox: dynamic(true);;
$include-ext-form-date: dynamic(true);;
$include-ext-form-datefield: dynamic(true);;
$include-ext-form-display: dynamic(true);;
$include-ext-form-displayfield: dynamic(true);;
$include-ext-form-field: dynamic(true);;
$include-ext-form-fieldancestor: dynamic(true);;
$include-ext-form-fieldcontainer: dynamic(true);;
$include-ext-form-fieldset: dynamic(true);;
$include-ext-form-file: dynamic(true);;
$include-ext-form-fileuploadfield: dynamic(true);;
$include-ext-form-formpanel: dynamic(true);;
$include-ext-form-hidden: dynamic(true);;
$include-ext-form-htmleditor: dynamic(true);;
$include-ext-form-label: dynamic(true);;
$include-ext-form-labelable: dynamic(true);;
$include-ext-form-number: dynamic(true);;
$include-ext-form-numberfield: dynamic(true);;
$include-ext-form-panel: dynamic(true);;
$include-ext-form-picker: dynamic(true);;
$include-ext-form-radio: dynamic(true);;
$include-ext-form-radiogroup: dynamic(true);;
$include-ext-form-radiomanager: dynamic(true);;
$include-ext-form-sliderfield: dynamic(true);;
$include-ext-form-spinner: dynamic(true);;
$include-ext-form-text: dynamic(true);;
$include-ext-form-textarea: dynamic(true);;
$include-ext-form-textfield: dynamic(true);;
$include-ext-form-time: dynamic(true);;
$include-ext-form-timefield: dynamic(true);;
$include-ext-form-trigger: dynamic(true);;
$include-ext-form-triggerfield: dynamic(true);;
$include-ext-form-twintriggerfield: dynamic(true);;
$include-ext-form-vtypes: dynamic(true);;
$include-ext-form-action-action: dynamic(true);;
$include-ext-form-action-directaction: dynamic(true);;
$include-ext-form-action-directload: dynamic(true);;
$include-ext-form-action-directsubmit: dynamic(true);;
$include-ext-form-action-load: dynamic(true);;
$include-ext-form-action-standardsubmit: dynamic(true);;
$include-ext-form-action-submit: dynamic(true);;
$include-ext-form-field-base: dynamic(true);;
$include-ext-form-field-checkbox: dynamic(true);;
$include-ext-form-field-combobox: dynamic(true);;
$include-ext-form-field-date: dynamic(true);;
$include-ext-form-field-display: dynamic(true);;
$include-ext-form-field-field: dynamic(true);;
$include-ext-form-field-file: dynamic(true);;
$include-ext-form-field-filebutton: dynamic(true);;
$include-ext-form-field-hidden: dynamic(true);;
$include-ext-form-field-htmleditor: dynamic(true);;
$include-ext-form-field-number: dynamic(true);;
$include-ext-form-field-picker: dynamic(true);;
$include-ext-form-field-radio: dynamic(true);;
$include-ext-form-field-spinner: dynamic(true);;
$include-ext-form-field-tag: dynamic(true);;
$include-ext-form-field-text: dynamic(true);;
$include-ext-form-field-textarea: dynamic(true);;
$include-ext-form-field-time: dynamic(true);;
$include-ext-form-field-trigger: dynamic(true);;
$include-ext-form-field-vtypes: dynamic(true);;
$include-ext-form-trigger-component: dynamic(true);;
$include-ext-form-trigger-spinner: dynamic(true);;
$include-ext-form-trigger-trigger: dynamic(true);;
$include-ext-fx-anim: dynamic(true);;
$include-ext-fx-animation: dynamic(true);;
$include-ext-fx-animator: dynamic(true);;
$include-ext-fx-cubicbezier: dynamic(true);;
$include-ext-fx-drawpath: dynamic(true);;
$include-ext-fx-easing: dynamic(true);;
$include-ext-fx-manager: dynamic(true);;
$include-ext-fx-propertyhandler: dynamic(true);;
$include-ext-fx-queue: dynamic(true);;
$include-ext-fx-runner: dynamic(true);;
$include-ext-fx-state: dynamic(true);;
$include-ext-fx-animation-abstract: dynamic(true);;
$include-ext-fx-animation-cube: dynamic(true);;
$include-ext-fx-animation-fade: dynamic(true);;
$include-ext-fx-animation-fadein: dynamic(true);;
$include-ext-fx-animation-fadeout: dynamic(true);;
$include-ext-fx-animation-flip: dynamic(true);;
$include-ext-fx-animation-pop: dynamic(true);;
$include-ext-fx-animation-popin: dynamic(true);;
$include-ext-fx-animation-popout: dynamic(true);;
$include-ext-fx-animation-slide: dynamic(true);;
$include-ext-fx-animation-slidein: dynamic(true);;
$include-ext-fx-animation-slideout: dynamic(true);;
$include-ext-fx-animation-wipe: dynamic(true);;
$include-ext-fx-animation-wipein: dynamic(true);;
$include-ext-fx-animation-wipeout: dynamic(true);;
$include-ext-fx-easing-abstract: dynamic(true);;
$include-ext-fx-easing-bounce: dynamic(true);;
$include-ext-fx-easing-boundmomentum: dynamic(true);;
$include-ext-fx-easing-easein: dynamic(true);;
$include-ext-fx-easing-easeout: dynamic(true);;
$include-ext-fx-easing-easing: dynamic(true);;
$include-ext-fx-easing-linear: dynamic(true);;
$include-ext-fx-easing-momentum: dynamic(true);;
$include-ext-fx-runner-css: dynamic(true);;
$include-ext-fx-runner-cssanimation: dynamic(true);;
$include-ext-fx-runner-csstransition: dynamic(true);;
$include-ext-fx-target-component: dynamic(true);;
$include-ext-fx-target-compositeelement: dynamic(true);;
$include-ext-fx-target-compositeelementcss: dynamic(true);;
$include-ext-fx-target-compositesprite: dynamic(true);;
$include-ext-fx-target-element: dynamic(true);;
$include-ext-fx-target-elementcss: dynamic(true);;
$include-ext-fx-target-sprite: dynamic(true);;
$include-ext-fx-target-target: dynamic(true);;
$include-ext-globalevents: dynamic(true);;
$include-ext-grid-actioncolumn: dynamic(true);;
$include-ext-grid-booleancolumn: dynamic(true);;
$include-ext-grid-cellcontext: dynamic(true);;
$include-ext-grid-celleditor: dynamic(true);;
$include-ext-grid-column: dynamic(true);;
$include-ext-grid-columncomponentlayout: dynamic(true);;
$include-ext-grid-columnlayout: dynamic(true);;
$include-ext-grid-columnmanager: dynamic(true);;
$include-ext-grid-columnmodel: dynamic(true);;
$include-ext-grid-datecolumn: dynamic(true);;
$include-ext-grid-gridpanel: dynamic(true);;
$include-ext-grid-lockable: dynamic(true);;
$include-ext-grid-lockingview: dynamic(true);;
$include-ext-grid-navigationmodel: dynamic(true);;
$include-ext-grid-numbercolumn: dynamic(true);;
$include-ext-grid-panel: dynamic(true);;
$include-ext-grid-propertycolumnmodel: dynamic(true);;
$include-ext-grid-propertygrid: dynamic(true);;
$include-ext-grid-propertystore: dynamic(true);;
$include-ext-grid-rowcontext: dynamic(true);;
$include-ext-grid-roweditor: dynamic(true);;
$include-ext-grid-roweditorbuttons: dynamic(true);;
$include-ext-grid-rownumberer: dynamic(true);;
$include-ext-grid-templatecolumn: dynamic(true);;
$include-ext-grid-view: dynamic(true);;
$include-ext-grid-viewdropzone: dynamic(true);;
$include-ext-grid-column-action: dynamic(true);;
$include-ext-grid-column-actionproxy: dynamic(true);;
$include-ext-grid-column-boolean: dynamic(true);;
$include-ext-grid-column-check: dynamic(true);;
$include-ext-grid-column-checkcolumn: dynamic(true);;
$include-ext-grid-column-column: dynamic(true);;
$include-ext-grid-column-date: dynamic(true);;
$include-ext-grid-column-number: dynamic(true);;
$include-ext-grid-column-rownumberer: dynamic(true);;
$include-ext-grid-column-template: dynamic(true);;
$include-ext-grid-column-widget: dynamic(true);;
$include-ext-grid-feature-abstractsummary: dynamic(true);;
$include-ext-grid-feature-feature: dynamic(true);;
$include-ext-grid-feature-groupstore: dynamic(true);;
$include-ext-grid-feature-grouping: dynamic(true);;
$include-ext-grid-feature-groupingsummary: dynamic(true);;
$include-ext-grid-feature-rowbody: dynamic(true);;
$include-ext-grid-feature-summary: dynamic(true);;
$include-ext-grid-filters-filters: dynamic(true);;
$include-ext-grid-filters-filter-base: dynamic(true);;
$include-ext-grid-filters-filter-boolean: dynamic(true);;
$include-ext-grid-filters-filter-date: dynamic(true);;
$include-ext-grid-filters-filter-list: dynamic(true);;
$include-ext-grid-filters-filter-number: dynamic(true);;
$include-ext-grid-filters-filter-singlefilter: dynamic(true);;
$include-ext-grid-filters-filter-string: dynamic(true);;
$include-ext-grid-filters-filter-trifilter: dynamic(true);;
$include-ext-grid-header-container: dynamic(true);;
$include-ext-grid-header-dragzone: dynamic(true);;
$include-ext-grid-header-dropzone: dynamic(true);;
$include-ext-grid-locking-headercontainer: dynamic(true);;
$include-ext-grid-locking-lockable: dynamic(true);;
$include-ext-grid-locking-rowsynchronizer: dynamic(true);;
$include-ext-grid-locking-view: dynamic(true);;
$include-ext-grid-plugin-bufferedrenderer: dynamic(true);;
$include-ext-grid-plugin-cellediting: dynamic(true);;
$include-ext-grid-plugin-clipboard: dynamic(true);;
$include-ext-grid-plugin-dragdrop: dynamic(true);;
$include-ext-grid-plugin-editing: dynamic(true);;
$include-ext-grid-plugin-headerreorderer: dynamic(true);;
$include-ext-grid-plugin-headerresizer: dynamic(true);;
$include-ext-grid-plugin-rowediting: dynamic(true);;
$include-ext-grid-plugin-rowexpander: dynamic(true);;
$include-ext-grid-plugin-rowwidget: dynamic(true);;
$include-ext-grid-property-grid: dynamic(true);;
$include-ext-grid-property-headercontainer: dynamic(true);;
$include-ext-grid-property-property: dynamic(true);;
$include-ext-grid-property-reader: dynamic(true);;
$include-ext-grid-property-store: dynamic(true);;
$include-ext-grid-selection-cells: dynamic(true);;
$include-ext-grid-selection-columns: dynamic(true);;
$include-ext-grid-selection-replicator: dynamic(true);;
$include-ext-grid-selection-rows: dynamic(true);;
$include-ext-grid-selection-selection: dynamic(true);;
$include-ext-grid-selection-selectionextender: dynamic(true);;
$include-ext-grid-selection-spreadsheetmodel: dynamic(true);;
$include-ext-layout-absolutelayout: dynamic(true);;
$include-ext-layout-accordionlayout: dynamic(true);;
$include-ext-layout-anchorlayout: dynamic(true);;
$include-ext-layout-borderlayout: dynamic(true);;
$include-ext-layout-boxlayout: dynamic(true);;
$include-ext-layout-cardlayout: dynamic(true);;
$include-ext-layout-columnlayout: dynamic(true);;
$include-ext-layout-containerlayout: dynamic(true);;
$include-ext-layout-context: dynamic(true);;
$include-ext-layout-contextitem: dynamic(true);;
$include-ext-layout-fit: dynamic(true);;
$include-ext-layout-fitlayout: dynamic(true);;
$include-ext-layout-formlayout: dynamic(true);;
$include-ext-layout-hboxlayout: dynamic(true);;
$include-ext-layout-layout: dynamic(true);;
$include-ext-layout-sizemodel: dynamic(true);;
$include-ext-layout-tablelayout: dynamic(true);;
$include-ext-layout-vboxlayout: dynamic(true);;
$include-ext-layout-boxoverflow-menu: dynamic(true);;
$include-ext-layout-boxoverflow-none: dynamic(true);;
$include-ext-layout-boxoverflow-scroller: dynamic(true);;
$include-ext-layout-component-abstractdock: dynamic(true);;
$include-ext-layout-component-auto: dynamic(true);;
$include-ext-layout-component-body: dynamic(true);;
$include-ext-layout-component-boundlist: dynamic(true);;
$include-ext-layout-component-component: dynamic(true);;
$include-ext-layout-component-dock: dynamic(true);;
$include-ext-layout-component-fieldset: dynamic(true);;
$include-ext-layout-component-progressbar: dynamic(true);;
$include-ext-layout-component-field-fieldcontainer: dynamic(true);;
$include-ext-layout-component-field-htmleditor: dynamic(true);;
$include-ext-layout-component-field-text: dynamic(true);;
$include-ext-layout-container-absolute: dynamic(true);;
$include-ext-layout-container-accordion: dynamic(true);;
$include-ext-layout-container-anchor: dynamic(true);;
$include-ext-layout-container-auto: dynamic(true);;
$include-ext-layout-container-border: dynamic(true);;
$include-ext-layout-container-box: dynamic(true);;
$include-ext-layout-container-card: dynamic(true);;
$include-ext-layout-container-center: dynamic(true);;
$include-ext-layout-container-checkboxgroup: dynamic(true);;
$include-ext-layout-container-column: dynamic(true);;
$include-ext-layout-container-columnsplitter: dynamic(true);;
$include-ext-layout-container-columnsplittertracker: dynamic(true);;
$include-ext-layout-container-container: dynamic(true);;
$include-ext-layout-container-dashboard: dynamic(true);;
$include-ext-layout-container-editor: dynamic(true);;
$include-ext-layout-container-fit: dynamic(true);;
$include-ext-layout-container-form: dynamic(true);;
$include-ext-layout-container-hbox: dynamic(true);;
$include-ext-layout-container-segmentedbutton: dynamic(true);;
$include-ext-layout-container-table: dynamic(true);;
$include-ext-layout-container-vbox: dynamic(true);;
$include-ext-layout-container-border-region: dynamic(true);;
$include-ext-layout-container-boxoverflow-menu: dynamic(true);;
$include-ext-layout-container-boxoverflow-none: dynamic(true);;
$include-ext-layout-container-boxoverflow-scroller: dynamic(true);;
$include-ext-list-abstracttreeitem: dynamic(true);;
$include-ext-list-listview: dynamic(true);;
$include-ext-list-roottreeitem: dynamic(true);;
$include-ext-list-tree: dynamic(true);;
$include-ext-list-treeitem: dynamic(true);;
$include-ext-menu-bar: dynamic(true);;
$include-ext-menu-checkitem: dynamic(true);;
$include-ext-menu-colorpicker: dynamic(true);;
$include-ext-menu-datepicker: dynamic(true);;
$include-ext-menu-item: dynamic(true);;
$include-ext-menu-manager: dynamic(true);;
$include-ext-menu-menu: dynamic(true);;
$include-ext-menu-menumgr: dynamic(true);;
$include-ext-menu-separator: dynamic(true);;
$include-ext-menu-textitem: dynamic(true);;
$include-ext-mixin-accessible: dynamic(true);;
$include-ext-mixin-bindable: dynamic(true);;
$include-ext-mixin-bufferable: dynamic(true);;
$include-ext-mixin-componentdelegation: dynamic(true);;
$include-ext-mixin-configproxy: dynamic(true);;
$include-ext-mixin-configstate: dynamic(true);;
$include-ext-mixin-container: dynamic(true);;
$include-ext-mixin-dirty: dynamic(true);;
$include-ext-mixin-factoryable: dynamic(true);;
$include-ext-mixin-focusable: dynamic(true);;
$include-ext-mixin-focusablecontainer: dynamic(true);;
$include-ext-mixin-hookable: dynamic(true);;
$include-ext-mixin-identifiable: dynamic(true);;
$include-ext-mixin-inheritable: dynamic(true);;
$include-ext-mixin-itemrippler: dynamic(true);;
$include-ext-mixin-keyboard: dynamic(true);;
$include-ext-mixin-mashup: dynamic(true);;
$include-ext-mixin-observable: dynamic(true);;
$include-ext-mixin-pluggable: dynamic(true);;
$include-ext-mixin-queryable: dynamic(true);;
$include-ext-mixin-responsive: dynamic(true);;
$include-ext-mixin-selectable: dynamic(true);;
$include-ext-mixin-storewatcher: dynamic(true);;
$include-ext-mixin-stylecacher: dynamic(true);;
$include-ext-mixin-templatable: dynamic(true);;
$include-ext-mixin-traversable: dynamic(true);;
$include-ext-override-sparkline-base: dynamic(true);;
$include-ext-overrides-globalevents: dynamic(true);;
$include-ext-overrides-progress: dynamic(true);;
$include-ext-overrides-widget: dynamic(true);;
$include-ext-overrides-app-application: dynamic(true);;
$include-ext-overrides-app-domain-component: dynamic(true);;
$include-ext-overrides-app-domain-view: dynamic(true);;
$include-ext-overrides-dom-element: dynamic(true);;
$include-ext-overrides-dom-helper: dynamic(true);;
$include-ext-overrides-event-event: dynamic(true);;
$include-ext-overrides-event-publisher-dom: dynamic(true);;
$include-ext-overrides-event-publisher-gesture: dynamic(true);;
$include-ext-overrides-list-abstracttreeitem: dynamic(true);;
$include-ext-overrides-list-tree: dynamic(true);;
$include-ext-overrides-list-treeitem: dynamic(true);;
$include-ext-overrides-mixin-focusable: dynamic(true);;
$include-ext-overrides-plugin-abstract: dynamic(true);;
$include-ext-overrides-util-positionable: dynamic(true);;
$include-ext-panel-bar: dynamic(true);;
$include-ext-panel-dd: dynamic(true);;
$include-ext-panel-header: dynamic(true);;
$include-ext-panel-panel: dynamic(true);;
$include-ext-panel-pinnable: dynamic(true);;
$include-ext-panel-proxy: dynamic(true);;
$include-ext-panel-table: dynamic(true);;
$include-ext-panel-title: dynamic(true);;
$include-ext-panel-tool: dynamic(true);;
$include-ext-parse-parser: dynamic(true);;
$include-ext-parse-symbol: dynamic(true);;
$include-ext-parse-tokenizer: dynamic(true);;
$include-ext-parse-symbol-constant: dynamic(true);;
$include-ext-parse-symbol-infix: dynamic(true);;
$include-ext-parse-symbol-infixright: dynamic(true);;
$include-ext-parse-symbol-paren: dynamic(true);;
$include-ext-parse-symbol-prefix: dynamic(true);;
$include-ext-perf-accumulator: dynamic(true);;
$include-ext-perf-monitor: dynamic(true);;
$include-ext-picker-color: dynamic(true);;
$include-ext-picker-date: dynamic(true);;
$include-ext-picker-month: dynamic(true);;
$include-ext-picker-time: dynamic(true);;
$include-ext-plugin-abstract: dynamic(true);;
$include-ext-plugin-abstractclipboard: dynamic(true);;
$include-ext-plugin-lazyitems: dynamic(true);;
$include-ext-plugin-manager: dynamic(true);;
$include-ext-plugin-mouseenter: dynamic(true);;
$include-ext-plugin-responsive: dynamic(true);;
$include-ext-plugin-viewport: dynamic(true);;
$include-ext-promise-consequence: dynamic(true);;
$include-ext-promise-deferred: dynamic(true);;
$include-ext-promise-promise: dynamic(true);;
$include-ext-resizer-bordersplitter: dynamic(true);;
$include-ext-resizer-bordersplittertracker: dynamic(true);;
$include-ext-resizer-handle: dynamic(true);;
$include-ext-resizer-resizetracker: dynamic(true);;
$include-ext-resizer-resizer: dynamic(true);;
$include-ext-resizer-splitter: dynamic(true);;
$include-ext-resizer-splittertracker: dynamic(true);;
$include-ext-route-action: dynamic(true);;
$include-ext-route-handler: dynamic(true);;
$include-ext-route-mixin: dynamic(true);;
$include-ext-route-route: dynamic(true);;
$include-ext-route-router: dynamic(true);;
$include-ext-rtl-component: dynamic(true);;
$include-ext-rtl-button-button: dynamic(true);;
$include-ext-rtl-button-segmented: dynamic(true);;
$include-ext-rtl-container-container: dynamic(true);;
$include-ext-rtl-dd-dd: dynamic(true);;
$include-ext-rtl-dom-element: dynamic(true);;
$include-ext-rtl-event-event: dynamic(true);;
$include-ext-rtl-form-labelable: dynamic(true);;
$include-ext-rtl-form-field-tag: dynamic(true);;
$include-ext-rtl-grid-celleditor: dynamic(true);;
$include-ext-rtl-grid-columnlayout: dynamic(true);;
$include-ext-rtl-grid-navigationmodel: dynamic(true);;
$include-ext-rtl-grid-column-column: dynamic(true);;
$include-ext-rtl-grid-locking-lockable: dynamic(true);;
$include-ext-rtl-grid-plugin-bufferedrenderer: dynamic(true);;
$include-ext-rtl-grid-plugin-headerresizer: dynamic(true);;
$include-ext-rtl-grid-plugin-rowediting: dynamic(true);;
$include-ext-rtl-layout-contextitem: dynamic(true);;
$include-ext-rtl-layout-component-dock: dynamic(true);;
$include-ext-rtl-layout-container-absolute: dynamic(true);;
$include-ext-rtl-layout-container-border: dynamic(true);;
$include-ext-rtl-layout-container-box: dynamic(true);;
$include-ext-rtl-layout-container-column: dynamic(true);;
$include-ext-rtl-layout-container-hbox: dynamic(true);;
$include-ext-rtl-layout-container-vbox: dynamic(true);;
$include-ext-rtl-layout-container-boxoverflow-menu: dynamic(true);;
$include-ext-rtl-layout-container-boxoverflow-scroller: dynamic(true);;
$include-ext-rtl-panel-bar: dynamic(true);;
$include-ext-rtl-panel-panel: dynamic(true);;
$include-ext-rtl-panel-title: dynamic(true);;
$include-ext-rtl-resizer-bordersplittertracker: dynamic(true);;
$include-ext-rtl-resizer-resizetracker: dynamic(true);;
$include-ext-rtl-resizer-splittertracker: dynamic(true);;
$include-ext-rtl-scroll-scroller: dynamic(true);;
$include-ext-rtl-slider-multi: dynamic(true);;
$include-ext-rtl-slider-widget: dynamic(true);;
$include-ext-rtl-tab-bar: dynamic(true);;
$include-ext-rtl-tip-quicktipmanager: dynamic(true);;
$include-ext-rtl-tree-column: dynamic(true);;
$include-ext-rtl-util-renderable: dynamic(true);;
$include-ext-rtl-view-navigationmodel: dynamic(true);;
$include-ext-rtl-view-table: dynamic(true);;
$include-ext-scroll-lockingscroller: dynamic(true);;
$include-ext-scroll-scroller: dynamic(true);;
$include-ext-scroll-tablescroller: dynamic(true);;
$include-ext-selection-cellmodel: dynamic(true);;
$include-ext-selection-checkboxmodel: dynamic(true);;
$include-ext-selection-dataviewmodel: dynamic(true);;
$include-ext-selection-model: dynamic(true);;
$include-ext-selection-rowmodel: dynamic(true);;
$include-ext-selection-treemodel: dynamic(true);;
$include-ext-slider-multi: dynamic(true);;
$include-ext-slider-multislider: dynamic(true);;
$include-ext-slider-single: dynamic(true);;
$include-ext-slider-singleslider: dynamic(true);;
$include-ext-slider-slider: dynamic(true);;
$include-ext-slider-thumb: dynamic(true);;
$include-ext-slider-tip: dynamic(true);;
$include-ext-slider-widget: dynamic(true);;
$include-ext-sparkline-bar: dynamic(true);;
$include-ext-sparkline-barbase: dynamic(true);;
$include-ext-sparkline-base: dynamic(true);;
$include-ext-sparkline-box: dynamic(true);;
$include-ext-sparkline-bullet: dynamic(true);;
$include-ext-sparkline-canvasbase: dynamic(true);;
$include-ext-sparkline-canvascanvas: dynamic(true);;
$include-ext-sparkline-discrete: dynamic(true);;
$include-ext-sparkline-line: dynamic(true);;
$include-ext-sparkline-pie: dynamic(true);;
$include-ext-sparkline-rangemap: dynamic(true);;
$include-ext-sparkline-shape: dynamic(true);;
$include-ext-sparkline-tristate: dynamic(true);;
$include-ext-sparkline-vmlcanvas: dynamic(true);;
$include-ext-state-cookieprovider: dynamic(true);;
$include-ext-state-localstorageprovider: dynamic(true);;
$include-ext-state-manager: dynamic(true);;
$include-ext-state-provider: dynamic(true);;
$include-ext-state-stateful: dynamic(true);;
$include-ext-tab-bar: dynamic(true);;
$include-ext-tab-panel: dynamic(true);;
$include-ext-tab-tab: dynamic(true);;
$include-ext-theme-neptune-component: dynamic(true);;
$include-ext-theme-neptune-container-buttongroup: dynamic(true);;
$include-ext-theme-neptune-form-field-htmleditor: dynamic(true);;
$include-ext-theme-neptune-grid-roweditor: dynamic(true);;
$include-ext-theme-neptune-grid-column-rownumberer: dynamic(true);;
$include-ext-theme-neptune-layout-component-dock: dynamic(true);;
$include-ext-theme-neptune-menu-menu: dynamic(true);;
$include-ext-theme-neptune-menu-separator: dynamic(true);;
$include-ext-theme-neptune-panel-panel: dynamic(true);;
$include-ext-theme-neptune-panel-table: dynamic(true);;
$include-ext-theme-neptune-picker-month: dynamic(true);;
$include-ext-theme-neptune-resizer-splitter: dynamic(true);;
$include-ext-theme-neptune-toolbar-paging: dynamic(true);;
$include-ext-theme-neptune-toolbar-toolbar: dynamic(true);;
$include-ext-theme-triton-component: dynamic(true);;
$include-ext-theme-triton-form-field-checkbox: dynamic(true);;
$include-ext-theme-triton-grid-column-check: dynamic(true);;
$include-ext-theme-triton-grid-column-column: dynamic(true);;
$include-ext-theme-triton-grid-column-rownumberer: dynamic(true);;
$include-ext-theme-triton-grid-plugin-rowexpander: dynamic(true);;
$include-ext-theme-triton-grid-selection-spreadsheetmodel: dynamic(true);;
$include-ext-theme-triton-list-treeitem: dynamic(true);;
$include-ext-theme-triton-menu-item: dynamic(true);;
$include-ext-theme-triton-menu-menu: dynamic(true);;
$include-ext-theme-triton-picker-date: dynamic(true);;
$include-ext-theme-triton-picker-month: dynamic(true);;
$include-ext-theme-triton-resizer-splitter: dynamic(true);;
$include-ext-theme-triton-selection-checkboxmodel: dynamic(true);;
$include-ext-theme-triton-toolbar-paging: dynamic(true);;
$include-ext-tip-quicktip: dynamic(true);;
$include-ext-tip-quicktipmanager: dynamic(true);;
$include-ext-tip-tip: dynamic(true);;
$include-ext-tip-tooltip: dynamic(true);;
$include-ext-toolbar-breadcrumb: dynamic(true);;
$include-ext-toolbar-fill: dynamic(true);;
$include-ext-toolbar-item: dynamic(true);;
$include-ext-toolbar-paging: dynamic(true);;
$include-ext-toolbar-separator: dynamic(true);;
$include-ext-toolbar-spacer: dynamic(true);;
$include-ext-toolbar-textitem: dynamic(true);;
$include-ext-toolbar-toolbar: dynamic(true);;
$include-ext-tree-column: dynamic(true);;
$include-ext-tree-navigationmodel: dynamic(true);;
$include-ext-tree-panel: dynamic(true);;
$include-ext-tree-treepanel: dynamic(true);;
$include-ext-tree-view: dynamic(true);;
$include-ext-tree-viewdragzone: dynamic(true);;
$include-ext-tree-viewdropzone: dynamic(true);;
$include-ext-tree-plugin-treeviewdragdrop: dynamic(true);;
$include-ext-util-abstractmixedcollection: dynamic(true);;
$include-ext-util-animate: dynamic(true);;
$include-ext-util-bag: dynamic(true);;
$include-ext-util-base64: dynamic(true);;
$include-ext-util-css: dynamic(true);;
$include-ext-util-csv: dynamic(true);;
$include-ext-util-clickrepeater: dynamic(true);;
$include-ext-util-collection: dynamic(true);;
$include-ext-util-collectionkey: dynamic(true);;
$include-ext-util-color: dynamic(true);;
$include-ext-util-componentdragger: dynamic(true);;
$include-ext-util-cookies: dynamic(true);;
$include-ext-util-delimitedvalue: dynamic(true);;
$include-ext-util-elementcontainer: dynamic(true);;
$include-ext-util-event: dynamic(true);;
$include-ext-util-filter: dynamic(true);;
$include-ext-util-filtercollection: dynamic(true);;
$include-ext-util-floating: dynamic(true);;
$include-ext-util-fly: dynamic(true);;
$include-ext-util-format: dynamic(true);;
$include-ext-util-group: dynamic(true);;
$include-ext-util-groupcollection: dynamic(true);;
$include-ext-util-grouper: dynamic(true);;
$include-ext-util-hashmap: dynamic(true);;
$include-ext-util-history: dynamic(true);;
$include-ext-util-inflector: dynamic(true);;
$include-ext-util-itemcollection: dynamic(true);;
$include-ext-util-keymap: dynamic(true);;
$include-ext-util-keynav: dynamic(true);;
$include-ext-util-localstorage: dynamic(true);;
$include-ext-util-lrucache: dynamic(true);;
$include-ext-util-memento: dynamic(true);;
$include-ext-util-mixedcollection: dynamic(true);;
$include-ext-util-objecttemplate: dynamic(true);;
$include-ext-util-observable: dynamic(true);;
$include-ext-util-offset: dynamic(true);;
$include-ext-util-paintmonitor: dynamic(true);;
$include-ext-util-point: dynamic(true);;
$include-ext-util-positionable: dynamic(true);;
$include-ext-util-protoelement: dynamic(true);;
$include-ext-util-queue: dynamic(true);;
$include-ext-util-region: dynamic(true);;
$include-ext-util-renderable: dynamic(true);;
$include-ext-util-schedulable: dynamic(true);;
$include-ext-util-scheduler: dynamic(true);;
$include-ext-util-sizemonitor: dynamic(true);;
$include-ext-util-sortable: dynamic(true);;
$include-ext-util-sorter: dynamic(true);;
$include-ext-util-sortercollection: dynamic(true);;
$include-ext-util-spans: dynamic(true);;
$include-ext-util-storeholder: dynamic(true);;
$include-ext-util-tsv: dynamic(true);;
$include-ext-util-taprepeater: dynamic(true);;
$include-ext-util-taskmanager: dynamic(true);;
$include-ext-util-taskrunner: dynamic(true);;
$include-ext-util-textmetrics: dynamic(true);;
$include-ext-util-tsvdecoder: dynamic(true);;
$include-ext-util-xtemplatecompiler: dynamic(true);;
$include-ext-util-xtemplateparser: dynamic(true);;
$include-ext-util-paintmonitor-abstract: dynamic(true);;
$include-ext-util-paintmonitor-cssanimation: dynamic(true);;
$include-ext-util-paintmonitor-overflowchange: dynamic(true);;
$include-ext-util-sizemonitor-abstract: dynamic(true);;
$include-ext-util-sizemonitor-overflowchange: dynamic(true);;
$include-ext-util-sizemonitor-scroll: dynamic(true);;
$include-ext-util-translatable-abstract: dynamic(true);;
$include-ext-util-translatable-cssposition: dynamic(true);;
$include-ext-util-translatable-csstransform: dynamic(true);;
$include-ext-util-translatable-dom: dynamic(true);;
$include-ext-util-translatable-scrollparent: dynamic(true);;
$include-ext-util-translatable-scrollposition: dynamic(true);;
$include-ext-ux-checkcolumn: dynamic(true);;
$include-ext-ux-form-fileuploadfield: dynamic(true);;
$include-ext-ux-layout-center: dynamic(true);;
$include-ext-view-abstractview: dynamic(true);;
$include-ext-view-boundlist: dynamic(true);;
$include-ext-view-boundlistkeynav: dynamic(true);;
$include-ext-view-dragzone: dynamic(true);;
$include-ext-view-dropzone: dynamic(true);;
$include-ext-view-multiselector: dynamic(true);;
$include-ext-view-multiselectorsearch: dynamic(true);;
$include-ext-view-navigationmodel: dynamic(true);;
$include-ext-view-nodecache: dynamic(true);;
$include-ext-view-table: dynamic(true);;
$include-ext-view-tablelayout: dynamic(true);;
$include-ext-view-tagkeynav: dynamic(true);;
$include-ext-view-view: dynamic(true);;
$include-ext-window-messagebox: dynamic(true);;
$include-ext-window-toast: dynamic(true);;
$include-ext-window-window: dynamic(true);;
$include-icecap-overrides-toolbar-toolbar: dynamic(true);;
$include-sitemule-overrides-loadmask: dynamic(true);;
$include-sitemule-overrides-button-button: dynamic(true);;
$include-sitemule-overrides-data-request-ajax: dynamic(true);;
$include-sitemule-overrides-dom-element: dynamic(true);;
$include-sitemule-overrides-form-fieldset: dynamic(true);;
$include-sitemule-overrides-grid-column: dynamic(true);;
$include-sitemule-overrides-panel-panel: dynamic(true);;
$include-sitemule-overrides-resizer-splitter: dynamic(true);;
$include-sitemule-overrides-tab-bar: dynamic(true);;
$include-sitemule-overrides-tab-panel: dynamic(true);;
$include-sitemule-overrides-toolbar-separator: dynamic(true);;
$include-sitemule-overrides-toolbar-toolbar: dynamic(true);;
$include-sitemule-overrides-window-window: dynamic(true);;


/* ======================== ETC ======================== */

/* including package ext */
$ext-resource-root: '' !default;
$ext-resource-path: 'images' !default;
$current-package: 'ext';
$current-resource-root: $ext-resource-root;
$relative-image-path-for-uis: $ext-resource-path;
@import '../../../../ext/sass/etc/all';

/* including package core */
$core-resource-root: '' !default;
$core-resource-path: 'images' !default;
$current-package: 'core';
$current-resource-root: $core-resource-root;
$relative-image-path-for-uis: $core-resource-path;
@import '../../../../ext/packages/core/sass/etc/all';

/* including package theme-base */
$theme-base-resource-root: '' !default;
$theme-base-resource-path: 'images' !default;
$current-package: 'theme-base';
$current-resource-root: $theme-base-resource-root;
$relative-image-path-for-uis: $theme-base-resource-path;
@import '../../../../ext/classic/theme-base/sass/etc/all';

/* including package theme-neutral */
$theme-neutral-resource-root: '' !default;
$theme-neutral-resource-path: 'images' !default;
$current-package: 'theme-neutral';
$current-resource-root: $theme-neutral-resource-root;
$relative-image-path-for-uis: $theme-neutral-resource-path;
@import '../../../../ext/classic/theme-neutral/sass/etc/all';

/* including package theme-neptune */
$theme-neptune-resource-root: '' !default;
$theme-neptune-resource-path: 'images' !default;
$current-package: 'theme-neptune';
$current-resource-root: $theme-neptune-resource-root;
$relative-image-path-for-uis: $theme-neptune-resource-path;
@import '../../../../ext/classic/theme-neptune/sass/etc/all';

/* including package font-awesome */
$font-awesome-resource-root: 'font-awesome' !default;
$font-awesome-resource-path: 'font-awesome/images' !default;
$current-package: 'font-awesome';
$current-resource-root: $font-awesome-resource-root;
$relative-image-path-for-uis: $font-awesome-resource-path;
@import '../../../../ext/packages/font-awesome/sass/etc/all';

/* including package theme-triton */
$theme-triton-resource-root: '' !default;
$theme-triton-resource-path: 'images' !default;
$current-package: 'theme-triton';
$current-resource-root: $theme-triton-resource-root;
$relative-image-path-for-uis: $theme-triton-resource-path;
@import '../../../../ext/classic/theme-triton/sass/etc/all';

/* including package sitemule-theme */
$sitemule-theme-resource-root: '' !default;
$sitemule-theme-resource-path: 'images' !default;
$current-package: 'sitemule-theme';
$current-resource-root: $sitemule-theme-resource-root;
$relative-image-path-for-uis: $sitemule-theme-resource-path;
@import '../../sitemule-theme/sass/etc/all';

/* including package icecap-theme */
$icecap-theme-resource-root: '' !default;
$icecap-theme-resource-path: 'images' !default;
$current-package: 'icecap-theme';
$current-resource-root: $icecap-theme-resource-root;
$relative-image-path-for-uis: $icecap-theme-resource-path;
@import '../sass/etc/all';


/* ======================== VAR ======================== */

/* including package core */
$core-resource-root: '' !default;
$core-resource-path: 'images' !default;
$current-package: 'core';
$current-resource-root: $core-resource-root;
$relative-image-path-for-uis: $core-resource-path;
@import '../../../../ext/packages/core/sass/var/dom/Element';
@import '../../../../ext/packages/core/sass/var/Component';
@import '../../../../ext/packages/core/sass/var/list/TreeItem';

/* including package theme-base */
$theme-base-resource-root: '' !default;
$theme-base-resource-path: 'images' !default;
$current-package: 'theme-base';
$current-resource-root: $theme-base-resource-root;
$relative-image-path-for-uis: $theme-base-resource-path;
@import '../../../../ext/classic/theme-base/sass/var/Component';
@import '../../../../ext/classic/theme-base/sass/var/button/Button';

/* including package theme-neutral */
$theme-neutral-resource-root: '' !default;
$theme-neutral-resource-path: 'images' !default;
$current-package: 'theme-neutral';
$current-resource-root: $theme-neutral-resource-root;
$relative-image-path-for-uis: $theme-neutral-resource-path;
@import '../../../../ext/classic/theme-neutral/sass/var/Component';
@import '../../../../ext/classic/theme-neutral/sass/var/list/TreeItem';
@import '../../../../ext/classic/theme-neutral/sass/var/LoadMask';
@import '../../../../ext/classic/theme-neutral/sass/var/ProgressBar';
@import '../../../../ext/classic/theme-neutral/sass/var/button/Button';
@import '../../../../ext/classic/theme-neutral/sass/var/panel/Tool';
@import '../../../../ext/classic/theme-neutral/sass/var/panel/Header';
@import '../../../../ext/classic/theme-neutral/sass/var/resizer/Splitter';
@import '../../../../ext/classic/theme-neutral/sass/var/layout/container/Box';
@import '../../../../ext/classic/theme-neutral/sass/var/toolbar/Toolbar';
@import '../../../../ext/classic/theme-neutral/sass/var/dd/StatusProxy';
@import '../../../../ext/classic/theme-neutral/sass/var/panel/Panel';
@import '../../../../ext/classic/theme-neutral/sass/var/container/ButtonGroup';
@import '../../../../ext/classic/theme-neutral/sass/var/dashboard/Dashboard';
@import '../../../../ext/classic/theme-neutral/sass/var/window/Window';
@import '../../../../ext/classic/theme-neutral/sass/var/form/Labelable';
@import '../../../../ext/classic/theme-neutral/sass/var/form/field/Base';
@import '../../../../ext/classic/theme-neutral/sass/var/form/field/Text';
@import '../../../../ext/classic/theme-neutral/sass/var/window/MessageBox';
@import '../../../../ext/classic/theme-neutral/sass/var/form/field/Checkbox';
@import '../../../../ext/classic/theme-neutral/sass/var/form/CheckboxGroup';
@import '../../../../ext/classic/theme-neutral/sass/var/form/FieldSet';
@import '../../../../ext/classic/theme-neutral/sass/var/form/trigger/Spinner';
@import '../../../../ext/classic/theme-neutral/sass/var/toolbar/Paging';
@import '../../../../ext/classic/theme-neutral/sass/var/view/BoundList';
@import '../../../../ext/classic/theme-neutral/sass/var/picker/Date';
@import '../../../../ext/classic/theme-neutral/sass/var/form/field/Display';
@import '../../../../ext/classic/theme-neutral/sass/var/tip/Tip';
@import '../../../../ext/classic/theme-neutral/sass/var/picker/Color';
@import '../../../../ext/classic/theme-neutral/sass/var/form/field/HtmlEditor';
@import '../../../../ext/classic/theme-neutral/sass/var/form/field/Tag';
@import '../../../../ext/classic/theme-neutral/sass/var/view/Table';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/header/DropZone';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/header/Container';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/column/Column';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/column/Action';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/column/Check';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/column/RowNumberer';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/column/Widget';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/feature/Grouping';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/feature/RowBody';
@import '../../../../ext/classic/theme-neutral/sass/var/menu/Menu';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/filters/Filters';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/locking/Lockable';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/plugin/Editing';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/plugin/RowEditing';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/plugin/RowExpander';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/property/Grid';
@import '../../../../ext/classic/theme-neutral/sass/var/grid/selection/SpreadsheetModel';
@import '../../../../ext/classic/theme-neutral/sass/var/layout/container/Accordion';
@import '../../../../ext/classic/theme-neutral/sass/var/layout/container/Border';
@import '../../../../ext/classic/theme-neutral/sass/var/resizer/Resizer';
@import '../../../../ext/classic/theme-neutral/sass/var/selection/CheckboxModel';
@import '../../../../ext/classic/theme-neutral/sass/var/slider/Multi';
@import '../../../../ext/classic/theme-neutral/sass/var/tab/Tab';
@import '../../../../ext/classic/theme-neutral/sass/var/tab/Bar';
@import '../../../../ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb';
@import '../../../../ext/classic/theme-neutral/sass/var/tree/View';
@import '../../../../ext/classic/theme-neutral/sass/var/view/MultiSelector';
@import '../../../../ext/classic/theme-neutral/sass/var/window/Toast';

/* including package theme-neptune */
$theme-neptune-resource-root: '' !default;
$theme-neptune-resource-path: 'images' !default;
$current-package: 'theme-neptune';
$current-resource-root: $theme-neptune-resource-root;
$relative-image-path-for-uis: $theme-neptune-resource-path;
@import '../../../../ext/classic/theme-neptune/sass/var/Component';
@import '../../../../ext/classic/theme-neptune/sass/var/LoadMask';
@import '../../../../ext/classic/theme-neptune/sass/var/ProgressBar';
@import '../../../../ext/classic/theme-neptune/sass/var/button/Button';
@import '../../../../ext/classic/theme-neptune/sass/var/panel/Tool';
@import '../../../../ext/classic/theme-neptune/sass/var/resizer/Splitter';
@import '../../../../ext/classic/theme-neptune/sass/var/toolbar/Toolbar';
@import '../../../../ext/classic/theme-neptune/sass/var/dd/StatusProxy';
@import '../../../../ext/classic/theme-neptune/sass/var/panel/Panel';
@import '../../../../ext/classic/theme-neptune/sass/var/container/ButtonGroup';
@import '../../../../ext/classic/theme-neptune/sass/var/window/Window';
@import '../../../../ext/classic/theme-neptune/sass/var/form/Labelable';
@import '../../../../ext/classic/theme-neptune/sass/var/form/field/Base';
@import '../../../../ext/classic/theme-neptune/sass/var/form/field/Text';
@import '../../../../ext/classic/theme-neptune/sass/var/form/field/Checkbox';
@import '../../../../ext/classic/theme-neptune/sass/var/form/FieldSet';
@import '../../../../ext/classic/theme-neptune/sass/var/toolbar/Paging';
@import '../../../../ext/classic/theme-neptune/sass/var/view/BoundList';
@import '../../../../ext/classic/theme-neptune/sass/var/picker/Date';
@import '../../../../ext/classic/theme-neptune/sass/var/form/field/Display';
@import '../../../../ext/classic/theme-neptune/sass/var/tip/Tip';
@import '../../../../ext/classic/theme-neptune/sass/var/picker/Color';
@import '../../../../ext/classic/theme-neptune/sass/var/form/field/Tag';
@import '../../../../ext/classic/theme-neptune/sass/var/form/field/Trigger';
@import '../../../../ext/classic/theme-neptune/sass/var/view/Table';
@import '../../../../ext/classic/theme-neptune/sass/var/grid/header/Container';
@import '../../../../ext/classic/theme-neptune/sass/var/grid/column/Column';
@import '../../../../ext/classic/theme-neptune/sass/var/grid/column/Action';
@import '../../../../ext/classic/theme-neptune/sass/var/grid/column/Check';
@import '../../../../ext/classic/theme-neptune/sass/var/grid/feature/Grouping';
@import '../../../../ext/classic/theme-neptune/sass/var/menu/Menu';
@import '../../../../ext/classic/theme-neptune/sass/var/grid/filters/Filters';
@import '../../../../ext/classic/theme-neptune/sass/var/grid/plugin/RowEditing';
@import '../../../../ext/classic/theme-neptune/sass/var/layout/container/Accordion';
@import '../../../../ext/classic/theme-neptune/sass/var/layout/container/Border';
@import '../../../../ext/classic/theme-neptune/sass/var/resizer/Resizer';
@import '../../../../ext/classic/theme-neptune/sass/var/selection/CheckboxModel';
@import '../../../../ext/classic/theme-neptune/sass/var/tab/Tab';
@import '../../../../ext/classic/theme-neptune/sass/var/tab/Bar';
@import '../../../../ext/classic/theme-neptune/sass/var/toolbar/Breadcrumb';
@import '../../../../ext/classic/theme-neptune/sass/var/tree/View';
@import '../../../../ext/classic/theme-neptune/sass/var/window/Toast';

/* including package theme-triton */
$theme-triton-resource-root: '' !default;
$theme-triton-resource-path: 'images' !default;
$current-package: 'theme-triton';
$current-resource-root: $theme-triton-resource-root;
$relative-image-path-for-uis: $theme-triton-resource-path;
@import '../../../../ext/classic/theme-triton/sass/var/Component';
@import '../../../../ext/classic/theme-triton/sass/var/LoadMask';
@import '../../../../ext/classic/theme-triton/sass/var/ProgressBar';
@import '../../../../ext/classic/theme-triton/sass/var/button/Button';
@import '../../../../ext/classic/theme-triton/sass/var/panel/Tool';
@import '../../../../ext/classic/theme-triton/sass/var/resizer/Splitter';
@import '../../../../ext/classic/theme-triton/sass/var/toolbar/Toolbar';
@import '../../../../ext/classic/theme-triton/sass/var/panel/Panel';
@import '../../../../ext/classic/theme-triton/sass/var/container/ButtonGroup';
@import '../../../../ext/classic/theme-triton/sass/var/window/Window';
@import '../../../../ext/classic/theme-triton/sass/var/form/field/Base';
@import '../../../../ext/classic/theme-triton/sass/var/window/MessageBox';
@import '../../../../ext/classic/theme-triton/sass/var/form/field/Checkbox';
@import '../../../../ext/classic/theme-triton/sass/var/form/FieldSet';
@import '../../../../ext/classic/theme-triton/sass/var/view/BoundList';
@import '../../../../ext/classic/theme-triton/sass/var/picker/Date';
@import '../../../../ext/classic/theme-triton/sass/var/tip/Tip';
@import '../../../../ext/classic/theme-triton/sass/var/form/field/HtmlEditor';
@import '../../../../ext/classic/theme-triton/sass/var/form/field/Tag';
@import '../../../../ext/classic/theme-triton/sass/var/view/Table';
@import '../../../../ext/classic/theme-triton/sass/var/grid/header/Container';
@import '../../../../ext/classic/theme-triton/sass/var/grid/column/Column';
@import '../../../../ext/classic/theme-triton/sass/var/grid/column/Action';
@import '../../../../ext/classic/theme-triton/sass/var/grid/feature/Grouping';
@import '../../../../ext/classic/theme-triton/sass/var/menu/Menu';
@import '../../../../ext/classic/theme-triton/sass/var/grid/filters/Filters';
@import '../../../../ext/classic/theme-triton/sass/var/grid/locking/Lockable';
@import '../../../../ext/classic/theme-triton/sass/var/grid/plugin/RowExpander';
@import '../../../../ext/classic/theme-triton/sass/var/layout/container/Accordion';
@import '../../../../ext/classic/theme-triton/sass/var/layout/container/Border';
@import '../../../../ext/classic/theme-triton/sass/var/resizer/Resizer';
@import '../../../../ext/classic/theme-triton/sass/var/selection/CheckboxModel';
@import '../../../../ext/classic/theme-triton/sass/var/slider/Multi';
@import '../../../../ext/classic/theme-triton/sass/var/tab/Tab';
@import '../../../../ext/classic/theme-triton/sass/var/tab/Bar';
@import '../../../../ext/classic/theme-triton/sass/var/tree/View';

/* including package sitemule-theme */
$sitemule-theme-resource-root: '' !default;
$sitemule-theme-resource-path: 'images' !default;
$current-package: 'sitemule-theme';
$current-resource-root: $sitemule-theme-resource-root;
$relative-image-path-for-uis: $sitemule-theme-resource-path;
@import '../../sitemule-theme/sass/var/Component';
@import '../../sitemule-theme/sass/var/LoadMask';
@import '../../sitemule-theme/sass/var/button/Button';
@import '../../sitemule-theme/sass/var/panel/Tool';
@import '../../sitemule-theme/sass/var/resizer/Splitter';
@import '../../sitemule-theme/sass/var/toolbar/Toolbar';
@import '../../sitemule-theme/sass/var/panel/Panel';
@import '../../sitemule-theme/sass/var/window/Window';
@import '../../sitemule-theme/sass/var/form/Labelable';
@import '../../sitemule-theme/sass/var/form/field/Base';
@import '../../sitemule-theme/sass/var/form/field/Text';
@import '../../sitemule-theme/sass/var/form/FieldContainer';
@import '../../sitemule-theme/sass/var/form/field/Checkbox';
@import '../../sitemule-theme/sass/var/form/FieldSet';
@import '../../sitemule-theme/sass/var/form/field/Radio';
@import '../../sitemule-theme/sass/var/toolbar/Paging';
@import '../../sitemule-theme/sass/var/view/BoundList';
@import '../../sitemule-theme/sass/var/grid/Panel';
@import '../../sitemule-theme/sass/var/grid/header/Container';
@import '../../sitemule-theme/sass/var/grid/column/Column';
@import '../../sitemule-theme/sass/var/grid/column/Action';
@import '../../sitemule-theme/sass/var/grid/column/Check';
@import '../../sitemule-theme/sass/var/grid/feature/Grouping';
@import '../../sitemule-theme/sass/var/menu/Menu';
@import '../../sitemule-theme/sass/var/layout/container/Accordion';
@import '../../sitemule-theme/sass/var/layout/container/Border';
@import '../../sitemule-theme/sass/var/tab/Tab';
@import '../../sitemule-theme/sass/var/tab/Bar';
@import '../../sitemule-theme/sass/var/tab/Panel';
@import '../../sitemule-theme/sass/var/tree/View';
@import '../../sitemule-theme/sass/var/tree/Panel';

/* including package icecap-theme */
$icecap-theme-resource-root: '' !default;
$icecap-theme-resource-path: 'images' !default;
$current-package: 'icecap-theme';
$current-resource-root: $icecap-theme-resource-root;
$relative-image-path-for-uis: $icecap-theme-resource-path;
@import '../sass/var/Component';
@import '../sass/var/button/Button';
@import '../sass/var/toolbar/Toolbar';
@import '../sass/var/panel/Panel';
@import '../sass/var/window/Window';
@import '../sass/var/form/field/Text';
@import '../sass/var/form/field/Display';


/* ======================== RULE ======================== */

/* including package core */
$core-resource-root: '' !default;
$core-resource-path: 'images' !default;
$current-package: 'core';
$current-resource-root: $core-resource-root;
$relative-image-path-for-uis: $core-resource-path;
@import '../../../../ext/packages/core/sass/src/util/SizeMonitor';
@import '../../../../ext/packages/core/sass/src/util/PaintMonitor';
@import '../../../../ext/packages/core/sass/src/dom/Element';
@import '../../../../ext/packages/core/sass/src/ProgressBase';
@import '../../../../ext/packages/core/sass/src/scroll/Scroller';
@import '../../../../ext/packages/core/sass/src/dom/TouchAction';
@import '../../../../ext/packages/core/sass/src/drag/Source';
@import '../../../../ext/packages/core/sass/src/list/TreeItem';

/* including package theme-base */
$theme-base-resource-root: '' !default;
$theme-base-resource-path: 'images' !default;
$current-package: 'theme-base';
$current-resource-root: $theme-base-resource-root;
$relative-image-path-for-uis: $theme-base-resource-path;
@import '../../../../ext/classic/theme-base/sass/src/rtl/util/Renderable';
@import '../../../../ext/classic/theme-base/sass/src/Component';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Container';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Auto';
@import '../../../../ext/classic/theme-base/sass/src/LoadMask';
@import '../../../../ext/classic/theme-base/sass/src/ProgressBar';
@import '../../../../ext/classic/theme-base/sass/src/button/Button';
@import '../../../../ext/classic/theme-base/sass/src/button/Segmented';
@import '../../../../ext/classic/theme-base/sass/src/panel/Title';
@import '../../../../ext/classic/theme-base/sass/src/panel/Tool';
@import '../../../../ext/classic/theme-base/sass/src/panel/Header';
@import '../../../../ext/classic/theme-base/sass/src/resizer/Splitter';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Box';
@import '../../../../ext/classic/theme-base/sass/src/toolbar/Toolbar';
@import '../../../../ext/classic/theme-base/sass/src/dd/DD';
@import '../../../../ext/classic/theme-base/sass/src/dd/StatusProxy';
@import '../../../../ext/classic/theme-base/sass/src/layout/component/Dock';
@import '../../../../ext/classic/theme-base/sass/src/panel/Panel';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Table';
@import '../../../../ext/classic/theme-base/sass/src/container/ButtonGroup';
@import '../../../../ext/classic/theme-base/sass/src/plugin/Viewport';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Column';
@import '../../../../ext/classic/theme-base/sass/src/resizer/SplitterTracker';
@import '../../../../ext/classic/theme-base/sass/src/window/Window';
@import '../../../../ext/classic/theme-base/sass/src/form/Labelable';
@import '../../../../ext/classic/theme-base/sass/src/form/field/Text';
@import '../../../../ext/classic/theme-base/sass/src/form/field/TextArea';
@import '../../../../ext/classic/theme-base/sass/src/window/MessageBox';
@import '../../../../ext/classic/theme-base/sass/src/form/FieldContainer';
@import '../../../../ext/classic/theme-base/sass/src/form/field/Checkbox';
@import '../../../../ext/classic/theme-base/sass/src/form/FieldSet';
@import '../../../../ext/classic/theme-base/sass/src/view/View';
@import '../../../../ext/classic/theme-base/sass/src/view/BoundList';
@import '../../../../ext/classic/theme-base/sass/src/picker/Date';
@import '../../../../ext/classic/theme-base/sass/src/form/field/Display';
@import '../../../../ext/classic/theme-base/sass/src/form/trigger/Component';
@import '../../../../ext/classic/theme-base/sass/src/form/field/File';
@import '../../../../ext/classic/theme-base/sass/src/form/field/Hidden';
@import '../../../../ext/classic/theme-base/sass/src/tip/Tip';
@import '../../../../ext/classic/theme-base/sass/src/picker/Color';
@import '../../../../ext/classic/theme-base/sass/src/form/field/HtmlEditor';
@import '../../../../ext/classic/theme-base/sass/src/form/field/Tag';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Fit';
@import '../../../../ext/classic/theme-base/sass/src/panel/Table';
@import '../../../../ext/classic/theme-base/sass/src/view/Table';
@import '../../../../ext/classic/theme-base/sass/src/grid/header/DropZone';
@import '../../../../ext/classic/theme-base/sass/src/grid/header/Container';
@import '../../../../ext/classic/theme-base/sass/src/grid/column/Column';
@import '../../../../ext/classic/theme-base/sass/src/grid/column/Action';
@import '../../../../ext/classic/theme-base/sass/src/grid/column/Check';
@import '../../../../ext/classic/theme-base/sass/src/grid/feature/Grouping';
@import '../../../../ext/classic/theme-base/sass/src/grid/feature/RowBody';
@import '../../../../ext/classic/theme-base/sass/src/menu/Menu';
@import '../../../../ext/classic/theme-base/sass/src/grid/locking/Lockable';
@import '../../../../ext/classic/theme-base/sass/src/grid/plugin/Editing';
@import '../../../../ext/classic/theme-base/sass/src/grid/plugin/RowEditing';
@import '../../../../ext/classic/theme-base/sass/src/grid/plugin/RowExpander';
@import '../../../../ext/classic/theme-base/sass/src/grid/selection/SpreadsheetModel';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Absolute';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Border';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Center';
@import '../../../../ext/classic/theme-base/sass/src/layout/container/Form';
@import '../../../../ext/classic/theme-base/sass/src/resizer/Resizer';
@import '../../../../ext/classic/theme-base/sass/src/slider/Multi';
@import '../../../../ext/classic/theme-base/sass/src/tab/Tab';
@import '../../../../ext/classic/theme-base/sass/src/tab/Bar';
@import '../../../../ext/classic/theme-base/sass/src/toolbar/Breadcrumb';
@import '../../../../ext/classic/theme-base/sass/src/tree/View';

/* including package theme-neutral */
$theme-neutral-resource-root: '' !default;
$theme-neutral-resource-path: 'images' !default;
$current-package: 'theme-neutral';
$current-resource-root: $theme-neutral-resource-root;
$relative-image-path-for-uis: $theme-neutral-resource-path;
@import '../../../../ext/classic/theme-neutral/sass/src/Component';
@import '../../../../ext/classic/theme-neutral/sass/src/Editor';
@import '../../../../ext/classic/theme-neutral/sass/src/LoadMask';
@import '../../../../ext/classic/theme-neutral/sass/src/ProgressBar';
@import '../../../../ext/classic/theme-neutral/sass/src/button/Button';
@import '../../../../ext/classic/theme-neutral/sass/src/panel/Tool';
@import '../../../../ext/classic/theme-neutral/sass/src/panel/Header';
@import '../../../../ext/classic/theme-neutral/sass/src/resizer/Splitter';
@import '../../../../ext/classic/theme-neutral/sass/src/toolbar/Toolbar';
@import '../../../../ext/classic/theme-neutral/sass/src/dd/StatusProxy';
@import '../../../../ext/classic/theme-neutral/sass/src/panel/Panel';
@import '../../../../ext/classic/theme-neutral/sass/src/container/ButtonGroup';
@import '../../../../ext/classic/theme-neutral/sass/src/dashboard/Dashboard';
@import '../../../../ext/classic/theme-neutral/sass/src/window/Window';
@import '../../../../ext/classic/theme-neutral/sass/src/form/Labelable';
@import '../../../../ext/classic/theme-neutral/sass/src/form/field/Text';
@import '../../../../ext/classic/theme-neutral/sass/src/window/MessageBox';
@import '../../../../ext/classic/theme-neutral/sass/src/form/field/Checkbox';
@import '../../../../ext/classic/theme-neutral/sass/src/form/CheckboxGroup';
@import '../../../../ext/classic/theme-neutral/sass/src/form/FieldSet';
@import '../../../../ext/classic/theme-neutral/sass/src/form/trigger/Spinner';
@import '../../../../ext/classic/theme-neutral/sass/src/toolbar/Paging';
@import '../../../../ext/classic/theme-neutral/sass/src/view/BoundList';
@import '../../../../ext/classic/theme-neutral/sass/src/picker/Date';
@import '../../../../ext/classic/theme-neutral/sass/src/form/field/Date';
@import '../../../../ext/classic/theme-neutral/sass/src/form/field/Display';
@import '../../../../ext/classic/theme-neutral/sass/src/tip/Tip';
@import '../../../../ext/classic/theme-neutral/sass/src/picker/Color';
@import '../../../../ext/classic/theme-neutral/sass/src/form/field/HtmlEditor';
@import '../../../../ext/classic/theme-neutral/sass/src/form/field/Tag';
@import '../../../../ext/classic/theme-neutral/sass/src/view/Table';
@import '../../../../ext/classic/theme-neutral/sass/src/view/DropZone';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/header/DropZone';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/header/Container';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/column/Column';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/column/Action';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/column/Check';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/column/RowNumberer';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/column/Widget';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/feature/Grouping';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/feature/RowBody';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/feature/Summary';
@import '../../../../ext/classic/theme-neutral/sass/src/menu/Menu';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/filters/Filters';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/locking/Lockable';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/plugin/Editing';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/plugin/CellEditing';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/plugin/RowExpander';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/property/Grid';
@import '../../../../ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel';
@import '../../../../ext/classic/theme-neutral/sass/src/layout/container/Accordion';
@import '../../../../ext/classic/theme-neutral/sass/src/layout/container/Border';
@import '../../../../ext/classic/theme-neutral/sass/src/layout/container/Form';
@import '../../../../ext/classic/theme-neutral/sass/src/resizer/Resizer';
@import '../../../../ext/classic/theme-neutral/sass/src/slider/Multi';
@import '../../../../ext/classic/theme-neutral/sass/src/tab/Bar';
@import '../../../../ext/classic/theme-neutral/sass/src/toolbar/Breadcrumb';
@import '../../../../ext/classic/theme-neutral/sass/src/tree/View';
@import '../../../../ext/classic/theme-neutral/sass/src/tree/ViewDropZone';
@import '../../../../ext/classic/theme-neutral/sass/src/view/MultiSelector';
@import '../../../../ext/classic/theme-neutral/sass/src/window/Toast';

/* including package theme-neptune */
$theme-neptune-resource-root: '' !default;
$theme-neptune-resource-path: 'images' !default;
$current-package: 'theme-neptune';
$current-resource-root: $theme-neptune-resource-root;
$relative-image-path-for-uis: $theme-neptune-resource-path;
@import '../../../../ext/classic/theme-neptune/sass/src/button/Button';
@import '../../../../ext/classic/theme-neptune/sass/src/panel/Panel';
@import '../../../../ext/classic/theme-neptune/sass/src/form/field/File';
@import '../../../../ext/classic/theme-neptune/sass/src/form/field/HtmlEditor';
@import '../../../../ext/classic/theme-neptune/sass/src/grid/header/Container';
@import '../../../../ext/classic/theme-neptune/sass/src/grid/column/Column';
@import '../../../../ext/classic/theme-neptune/sass/src/resizer/Resizer';

/* including package font-awesome */
$font-awesome-resource-root: 'font-awesome' !default;
$font-awesome-resource-path: 'font-awesome/images' !default;
$current-package: 'font-awesome';
$current-resource-root: $font-awesome-resource-root;
$relative-image-path-for-uis: $font-awesome-resource-path;
@import '../../../../ext/packages/font-awesome/sass/src/all';

/* including package font-ext */
$font-ext-resource-root: 'font-ext' !default;
$font-ext-resource-path: 'font-ext/images' !default;
$current-package: 'font-ext';
$current-resource-root: $font-ext-resource-root;
$relative-image-path-for-uis: $font-ext-resource-path;
@import '../../../../ext/packages/font-ext/sass/src/all';

/* including package theme-triton */
$theme-triton-resource-root: '' !default;
$theme-triton-resource-path: 'images' !default;
$current-package: 'theme-triton';
$current-resource-root: $theme-triton-resource-root;
$relative-image-path-for-uis: $theme-triton-resource-path;
@import '../../../../ext/classic/theme-triton/sass/src/Component';
@import '../../../../ext/classic/theme-triton/sass/src/form/FieldSet';
@import '../../../../ext/classic/theme-triton/sass/src/form/field/Tag';
@import '../../../../ext/classic/theme-triton/sass/src/menu/Menu';
@import '../../../../ext/classic/theme-triton/sass/src/tab/Tab';
@import '../../../../ext/classic/theme-triton/sass/src/toolbar/Breadcrumb';
@import '../../../../ext/classic/theme-triton/sass/src/window/Toast';
