.x-form-text-icecap-field.x-form-textarea {
  min-height: 0px !important;
}

.x-form-text-default {
  font-family: Lucida Console, Andale Mono, monospace;
	font-size: 14px;
	font-weight: 400;
	line-height: 22px !important;
	min-height: 22px !important;
  overflow: hidden;
  padding: 1px 1px 1px;
}

.x-form-text-icecap-field {
	font-family: Lucida Console, Andale Mono, monospace;
	font-size: 14px;
	font-weight: 400;
	line-height: 22px;
	min-height: 22px;
  white-space: pre;
}

.x-form-text-icecap-password-field {
	font-family: Lucida Console, Andale Mono, monospace;
	font-size: 14px;
	font-weight: 400;
	line-height: 24px;
	min-height: 24px;
}

.x-form-display-field-icecap-display {
	font-family: Lucida Console, Andale Mono, monospace;
	font-size: 14px;
	font-weight: 400;
	line-height: 24px;
	min-height: 24px;
}

.x-icecap-cursor {
  border: 1px solid #d81818;
  position: absolute;
}