
Ext.define("IceCap.util.Scale", {

	singleton: true,

	config: {
		fixed: null,
		free: null
	},

	constructor: function(o_config) {

		var i_self = this;
		i_self.initConfig(o_config);

		i_self.setFixed({
			"16": {
				"textSize": 16,
				"colSize": 9.7,
				"defaultWidth": 18,
				"defaultHeight": 24,
				"lineHeight": 28
			},
			"15": {
				"textSize": 15,
				"colSize": 9.1,
				"defaultWidth": 17,
				"defaultHeight": 22,
				"lineHeight": 26
			},
			"14": {
				"textSize": 14,
				"colSize": 8.45,
				"defaultWidth": 17,
				"defaultHeight": 20,
				"lineHeight": 24
			},
			"13": {
				"textSize": 13,
				"colSize": 7.9,
				"defaultWidth": 15,
				"defaultHeight": 19,
				"lineHeight": 22
			},
			"12": {
				"textSize": 12,
				"colSize": 7.4,
				"defaultWidth": 14,
				"defaultHeight": 17,
				"lineHeight": 20
			},
			"11": {
				"textSize": 11,
				"colSize": 6.8,
				"defaultWidth": 13,
				"defaultHeight": 15,
				"lineHeight": 18
			}
		});

		i_self.setFree({
			"14": {
				"textSize": 13,
				"colSize": 12.2,
				"defaultWidth": 20,
				"defaultHeight": 20,
				"lineHeight": 24
			}
		});
	}
});
