Ext.define("IceCap.view.Window", {

	xtype: "icecap-window",

	extend: "Ext.window.Window",

	layout: "fit",

	requires: [
		"IceCap.controller.Window"
	],

	alias: [
		"widget-icecap-view-window"
	],

	config: {
		inputData: null,
		lastTabIndex: 1,
		currentTabIndex: 1,
		content: null,
		keyArea: null,
		working: false,
		needFocus: 1,
		currentPosition: {
			col: 1,
			lin: 1
		},
		statusBar: null,
		main: null,
		sessionValue: "",
		cursor: null,
		timer: null,
		theme: "",
		requestCallBack: Ext.emptyFn,
		responseCallBack: Ext.emptyFn,
		enterOnDblClick: false,
		marker: null,
		markerActive: false,
		options: {},
		typeMode: 1,
		edit: false,
		level: 1,
		languages: [],
		translator: null,
		activeLanguage: "da",
		selector: null,
		viewArea: null,
		cssRules: null
	},

	closable: false,

	modal: false,

	controller: "icecap.view.window",

	listeners: {
		afterrender: {
			fn: function(i_panel) {

				var i_self = i_panel;

				i_self.addKeyEvents();

				var i_content = i_self.getContent();

				if (i_content) {

					var o_inputData = i_self.getInputData();

					var a_fields = IceCap.util.Handler.getInputFields(i_content);
					var b_found = false;
					var b_error = false;

					Ext.Array.each(a_fields, function(i_field) {
						if (i_field.getTabIndex() === i_self.getNeedFocus()) {
							if (!b_error) {
								setTimeout(function() {
									i_field.focus(false, 10);
								}, 10);
							}
							b_found = true;

							return false;
						}
					});

					if (!b_found) {

						i_self.setCurrentPosition({
							col: 2,
							lin: 1
						});

						if (!b_error) {
							i_self.findFocus();
						}
					}
				}
			},
			buffer: 100
		},
		dblclick: {
			fn: "onDblClick",
			element: "body"
		},
		click: {
			fn: "onClick",
			element: "body"
		},
		wheel: {
			fn: "onWheel",
			element: "body"
		},
		fieldoption: {
			fn: function(a_config) {

				var i_self = this;
				var i_controller = i_self.getController();

				var o_data = {};

				Ext.apply(o_data, {
					key: "ENTER"
				});

				Ext.Array.each(a_config, function(o_config) {

					var s_field = o_config.field;

					o_data[s_field] = o_config.option;

					Ext.apply(o_data, {
						csrCol: o_config.col,
						csrLin: o_config.lin
					});
				});

				i_self.setCurrentPosition({
					col: o_data.csrCol,
					lin: o_data.csrLin
				});

				i_controller.onSendData({
					func: ""
				}, o_data);
			}
		},
		key: {
			fn: function(s_value) {

				var i_self = this;
				var i_controller = i_self.getController();

				i_controller.doKeyEvent(s_value);
			}
		}

	},

	onKeyDown: Ext.emptyFn, // THIS IS NEEDED TO OVERRIDE Ext.util.Floating

	initComponent: function() {

		var i_self = this;

		var o_params = Ext.Object.fromQueryString(window.location.search);

		Ext.Object.each(o_params, function(s_key, value) {
			o_params[s_key] = Ext.decode(value, true) || value;
		});

		var o_options = Ext.apply(i_self.options, o_params.options || {});

		Ext.apply(i_self, {
			theme: i_self.theme || o_params.theme || ""
		});

		i_self.callParent(arguments);

		i_self.add(i_self.createLayout());

		i_self.enableBubble([
			"onAddWebContainer",
			"toWindow",
			"applicationClose"
		]);

		i_self.recreate();
	},

	createStatusBar: function () {

		var i_self = this;
		
		var o_rules = i_self.getCssRules();

		var i_translatorButton = Ext.widget("component", {
			itemId: "icecap-translator",
			cls: "pf-gearwheel",
			hidden: false,
			autoEl: {
				tab: "span",
				"data-qtip": "Toggle translation"
			},
			style: {
				"cursor": "pointer"
			},
			listeners: {
				afterrender: {
					fn: function(i_component) {

						var i_element = i_component.getEl();
						var b_edit = i_self.getEdit();

						if (b_edit) {
							i_element.addCls("x-base-color");
						}
						else {
							i_element.removeCls("x-base-color");
						}

						i_component.setStyle("font-size", "calc(1em * " + o_rules.fontScale + ")");

					}
				},
				click: {
					element: "el",
					fn: function () {

						var i_element = this;
						var b_edit = i_self.getEdit();

						b_edit = !b_edit;

						if (b_edit) {
							i_element.addCls("x-base-color");
						}
						else {
							i_element.removeCls("x-base-color");
						}

						i_self.setEdit(b_edit);
					}
				}
			}
		});

		var i_languageButton = Ext.widget("component", {
			itemId: "icecap-language",
			html: i_self.getActiveLanguage(),
			hidden: false,
			autoEl: {
				tab: "span",
				"data-qtip": "Toggle active language"
			},
			style: {
				"cursor": "pointer"
			},
			listeners: {
				afterrender: {
					fn: function (i_component) {

						i_component.setStyle("font-size", "calc(1em * " + o_rules.fontScale + ")");
					}
				},
				click: {
					element: "el",
					fn: function () {

						var i_menu = i_languageButton.menu;

						if (!i_menu) {

							var a_languages = i_self.getLanguages();

							var a_items = [];

							Ext.Array.each(a_languages, function (s_key) {

								var i_menuItem = Ext.widget("menuitem", {
									itemId: s_key,
									text: s_key,
									handler: function (i_item) {

										i_languageButton.setHtml(i_item.text);
										i_self.setActiveLanguage(i_item.text);
									}
								});

								a_items.push(i_menuItem);
							});

							i_menu = Ext.widget("menu", {
								items: a_items
							});

							i_languageButton.menu = i_menu;
						}

						i_menu.show();
						i_menu.alignTo(i_languageButton.getEl(), "bl-tr");

						i_menu.toFront();
					}
				}
			}
		});

		var i_statusbar = Ext.widget("toolbar", {
			ui: "statusbar",
			dock: "bottom",
			hidden: false,
			border: false,
			layout: {
				type: "hbox",
				align: "top"
			},
			defaults: {
				margin: "0 5 0 0"
			},
			height: 30,
			items: [
				{
					xtype: "label",
					itemId: "icecap-message",
					listeners: {
						afterrender: {
							fn: function (i_label) {

								i_label.setStyle("font-size", "calc(1em * " + o_rules.fontScale + ")");

								var i_tpl = Ext.create("Ext.XTemplate",
									"<ul style=\"list-style: none;",
									"margin:10px;",
									"padding:0;",
									"\">",
									"<tpl for=\".\">",
									"<li>{text}</li>",
									"</tpl>",
									"</ul>"
								);

								Ext.create("Ext.tip.ToolTip", {
									target: i_label.getEl(),
									html: "",
									anchor: true,
									defealtAlign: "b50-t50",
									listeners: {
										beforeshow: {
											fn: function (i_tip) {

												var b_hasError = i_label.hasCls("icecap-statusbar-error");

												var o_inputData = i_self.getInputData();

												var a_messages = Ext.Array.from(o_inputData.message);

												if (b_hasError && a_messages.length > 0) {
													var s_value = i_tpl.apply(a_messages);
													i_tip.update(s_value);
												}
												else {
													return b_hasError;
												}
											}
										}
									}
								});
							}
						},
						click: {
							element: "el",
							fn: function (i_event, i_element) {

								var o_input = {
									col: 3,
									lin: 24
								};

								i_self.setCurrentPosition(o_input);

								var i_cursor = i_self.getCursor();
								i_cursor.moveCursor(o_input);

								i_self.doKeyEvent("F1");
							}
						},
					}
				},
				{
					xtype: "tbfill"
				},
				i_languageButton,
				i_translatorButton,
				{
					xtype: "label",
					itemId: "icecap-position",
					listeners: {
						afterrender: {
							fn: function (i_label) {
	
								i_label.setStyle("font-size", "calc(1em * " + o_rules.fontScale + ")");
							}
						}
					}
				},
				{
					xtype: "component",
					autoEl: {
						tab: "span",
						"data-qtip": "Toggle input type"
					},
					style: {
						"cursor": "pointer"
					},
					html: "INS",
					itemId: "icecap-typemode",
					listeners: {
						afterrender: {
							fn: function (i_label) {
	
								i_label.setStyle("font-size", "calc(1em * " + o_rules.fontScale + ")");
							}
						},
						click: {
							element: "el",
							fn: function (i_element) {

								var n_type = i_self.getTypeMode();

								switch (n_type) {
									case IceCap.util.Handler.typeMode.OVERWRITE:
										n_type = IceCap.util.Handler.typeMode.FOCUS;
										break;
									case IceCap.util.Handler.typeMode.FOCUS:
										n_type = IceCap.util.Handler.typeMode.INSERT;
										break;
									default:
										n_type = IceCap.util.Handler.typeMode.OVERWRITE;
										break;
								}

								i_self.setTypeMode(n_type);
							}
						}
					}
				}
			],
			setText: function (s_text) {

				var i_toolbar = this;

				var i_message = i_toolbar.getComponent("icecap-message");

				if (i_message) {
					i_message.setText(s_text);
				}
			}
		});

		i_self.setTranslator(i_translatorButton);

		return i_statusbar;
	},

	createLayout: function() {

		var i_self = this;
		return i_self.createContent();
	},

	createContent: function() {

		var i_self = this;

		var i_panel = Ext.widget("panel", {
			layout: {
				type: "vbox",
				align: "stretch"
			},
			ui: "icecap",
			border: false,
			focusable: true,
			tabIndex: -1,
			items: i_self.createItems()
		});

		i_self.setMain(i_panel);

		var i_statusbar = i_self.createStatusBar();

		i_panel.addDocked(i_statusbar);

		i_self.setStatusBar(i_statusbar);

		var o_inputData = i_self.getInputData();

		i_self.updateMessage(o_inputData);

		return i_panel;
	},

	createItems: function() {

		var i_self = this;

		var a_items = [];

		var i_keyArea = Ext.widget("panel", {
			layout: {
				type: "column"
			},
			border: false,
			focusable: false,
			minHeight: 50,
			height: null,
			defaults: {
				margin: "5 5 0 5"
			},
			ui: "icecap-keyarea",
			cls: ["icecap-panel", i_self.getTheme()].join("-")
		});

		var i_center = Ext.widget("form", {
			border: false,
			layout: "absolute",
			flex: 1,
			ui: ["icecap", i_self.getTheme()].filter(Boolean).join("-"),
			style: {
				"margin-right": "10px"
			}
		});

		a_items.push(i_center);
		a_items.push(i_keyArea);

		i_self.setContent(i_center);
		i_self.setKeyArea(i_keyArea);

		return a_items;
	},

	createFields: function(a_created) {

		var i_self = this;
		var o_inputData = i_self.getInputData();

		var a_fields = [];

		var n_tabIndex = 1;
		var n_focus = o_inputData.focus;

		var n_inputWidth = o_inputData.width || 80;

		var a_sliced = Ext.Array.from(o_inputData.input || []);

		var o_rules = i_self.getCssRules();

		var n_elementWidth = IceCap.util.Handler.getWidth(1, o_rules.fontScale);

		Ext.Array.each(a_sliced, function(o_config, n_index) {

			var n_width = (n_elementWidth * o_config.len + (n_elementWidth / 2));

			var o_meta = o_config.metaData || {};

			var o_field = {
				xtype: "icecap-input",
				ui: "icecap-field"
			};

			var s_type = o_field.xtype || "icecap-input";
			var n_x = IceCap.util.Handler.getX(o_config.col, o_rules.fontScale) - 3;
			var n_y = IceCap.util.Handler.getY(o_config.lin, o_rules.lineScale);
			var b_password = o_config.atr == "27";
			var n_calc = 0;
			var n_height = null;

			if (o_config.len > (n_inputWidth + 1) || ((o_config.len + o_config.col) > (n_inputWidth + 1))) {
				n_calc = (n_inputWidth + 1) - o_config.col;
				n_width = (n_elementWidth * n_calc + (n_elementWidth / 2));
			}


			if (n_calc || (o_config.hasOwnProperty("colsize") && o_config.hasOwnProperty("rows") && o_config.rows > 1)) {

				var s_data = o_config.dta || "";

				var n_colSize = o_config.colsize || o_config.len;

				if (n_calc && n_colSize > n_calc) {
					o_config.rows = Math.ceil(n_colSize / n_calc);
				}

				var s_lineHeight = o_rules.sheet.rules[0].style.lineHeight;

				var n_parsed = parseFloat(s_lineHeight.replace("px"));

				n_height = n_parsed * o_config.rows;

				var o_box = {
					x: n_x,
					y: n_y,
					width: n_width,
					height: n_height,
					right: n_x + n_width,
					bottom: n_y + n_height
				};

				var i_region = Ext.util.Region.create({});

				Ext.apply(i_region, o_box);

				Ext.Array.each(a_created, function(i_label) {

					var o_rect = {
						x: i_label.x,
						y: i_label.y,
						width: i_label.html.length * n_elementWidth,
						height: n_parsed,
						right: i_label.x + (i_label.html.length * n_elementWidth),
						bottom: i_label.y + n_parsed
					};

					if (i_region.intersect(o_rect)) {

						o_config.rows = i_label.lin - o_config.lin;
						n_height = n_parsed * o_config.rows;

						if (o_config.len > (n_inputWidth + 1)) {
							var n_length = o_config.len /  o_config.rows;

							n_width = (n_elementWidth *n_length + (n_elementWidth / 2));
						}

						return false;
					}
				});

				s_type = "icecap-textarea";
				
				o_field.height = o_field.minHeight = n_height;

				var a_split = s_data.split("\n");

				var s_result = "";

				var n_split = a_split.length;

				Ext.Array.each(a_split, function(s_part, n_index) {

					var regex = new RegExp(".{" + n_colSize + "}", "g");

					var a_match = s_part.match(regex);

					if (a_match) {
						s_result += s_part;
					}
					else {
						if (n_index != n_split - 1) {
							s_result += s_part + "\n";
						}
						else {
							s_result += s_part;
						}
					}
				});

				o_config.dta = s_result;

				if (!b_password) {
					o_field.getSubmitValue = function() {

						var i_field = this;

						var s_value = i_field.stripReturns(i_field.getValue());

						var regex = new RegExp(".{1,"+ n_colSize +"}", "g");

						var a_split = s_value.match(regex) || [];

						return a_split.join("\n");
					};
				}
			}

			var o_listeners = Ext.apply({}, o_meta.listeners);
			delete o_meta.listeners;

			var a_field = ["icecap-field", i_self.getTheme()];

			var a_pass = [b_password ? "iceCap-input-password" : "iceCap-input-" + (o_config.atr || 20)];

			a_pass.push(i_self.getTheme());

			var a_cls = [a_field.filter(Boolean).join("-"), a_pass.filter(Boolean).join("-")];

			var s_cls = a_cls.join(" ");

			var s_name = IceCap.util.Handler.getRandomName();

			if (isNaN(n_x)) {
				n_x = IceCap.util.Handler.getWidth(1, o_rules.fontScale);
			}

			if (isNaN(n_y)) {
				n_y = IceCap.util.Handler.getHeight(1, o_rules.lineScale);
			}

			var s_ui = b_password ? "icecap-password-field" : "icecap-field";

			if (!o_meta.xtype) {
				Ext.apply(o_field, i_self.applyFFW(o_config));
				o_field.xtype = s_type;
			}

			var n_fieldIndex = n_tabIndex;

			if (o_field.unselected) {
				a_cls.push("x-unselectable-field");
				n_fieldIndex = -1;
			}

			s_cls = a_cls.join(" ");

			var i_field;

			if (b_password) {
				o_field.xtype = s_type = "icecap-input";
				o_field.height = o_field.minHeight = null;
				o_field.ui = "icecap-password-field";
			}

			if (s_type == "icecap-textarea") {
				s_ui = "icecap-textarea-field";
			}

			s_ui += o_rules.fieldCss;

			Ext.Object.merge(o_field, {
				width: n_width,
				enforceMaxLength: true,
				maxLength: o_config.len,
				minWidth: IceCap.util.Handler.getDefaultWidth(),
				tabIndex: n_fieldIndex,
				focusable: !o_field.readOnly,
				lin: o_config.lin,
				col: o_config.col,
				emuId: o_config.id,
				value: o_config.dta || "",
				itemId: o_config.id,
				name: s_name,
				inputAttrTpl: "tabindex=" + n_fieldIndex + " spellcheck=false autocomplete=\"new-password\" name=\"" + s_name + "\"",
				x: n_x,
				y: n_y,
				cls: s_cls,
				enableKeyEvents: true,
				selectOnFocus: false,
				ui: s_ui,
				listeners: {
					afterrender: {
						fn: function (i_field) {

							if (i_field.inputEl && !i_field.metaField) {
								if (i_field.xtype == "textarea" || i_field.xtype == "icecap-textarea") {
									i_field.inputEl.dom.setAttribute("rows", o_config.rows);
								}

								if (i_field.getTabIndex() === i_self.getNeedFocus()) {

									i_field.focus(false, 10, function () {
										var o_inputData = i_self.getInputData();

										var s_value = i_field.getValue();
										var n_col = i_field.col;
										var n_diff = 0;

										if (n_col < o_inputData.csrCol) {
											n_diff = o_inputData.csrCol - n_col;
											i_field.inputEl.el.dom.selectionEnd = i_field.inputEl.el.dom.selectionStart = i_field.inputEl.el.dom.selectionStart + n_diff;
										}

										var o_position = {
											col: o_inputData.csrCol,
											lin: o_inputData.csrLin
										};

										i_self.setCurrentPosition(o_position);

										var i_cursor = i_self.getCursor();
										i_cursor.moveCursor(o_position);
										i_cursor.hide();
									});
								}
							}
						}
					},
					change: {
						fn: function (i_field, value) {

							if (i_field.inputEl) {
								var s_direction = i_field.inputEl.el.dom.selectionDirection;

								var n_curpos = s_direction == "forward" ? i_field.inputEl.el.dom.selectionEnd : i_field.inputEl.el.dom.selectionStart;

								value = value || "";

								if (value.length == i_field.maxLength && n_curpos == i_field.maxLength) {
									i_self.doNavigationKey(1, true);
								}
							}
						}
					},
					focus: {
						fn: function (i_field) {

							var n_tabIndex = i_field.getTabIndex();
							i_self.setCurrentTabIndex(n_tabIndex);

							var o_position = {
								col: i_field.col,
								lin: i_field.lin
							};
							i_self.setCurrentPosition(o_position);

							var i_cursor = i_self.getCursor();
							i_cursor.moveCursor(o_position);
							i_cursor.hide();

							if (i_self.getTypeMode() == IceCap.util.Handler.typeMode.FOCUS) {
								var i_inputEl = i_field.inputEl;
								if (i_inputEl && i_inputEl.dom) {
									i_field.inputEl.dom.select();
								}
							}
						}
					},
					keyup: {
						fn: function (i_field, i_event) {

							var i_selector = i_self.getSelector();

							if (!i_selector.isHidden()) {
								return true;
							}

							if (i_field.xtype === "icecap-input") {

								var value = i_field.getValue();

								var s_direction = i_field.inputEl.el.dom.selectionDirection;

								var n_start = s_direction == "forward" ? i_field.inputEl.el.dom.selectionEnd : i_field.inputEl.el.dom.selectionStart;
								var n_add = n_start * IceCap.util.Handler.getWidth(1, o_rules.fontScale);

								if (n_start == i_field.maxLength) {
									n_add = n_add - IceCap.util.Handler.getWidth(1, o_rules.fontScale);
								}

								var o_input = Ext.apply({
									x: i_field.getLocalX() + n_add,
									y: i_field.lin * IceCap.util.Handler.getHeight(1, o_rules.lineScale)
								});

								var o_position = IceCap.util.Handler.toColAndLine(o_input, o_rules);
								i_self.setCurrentPosition(o_position);

								var i_cursor = i_self.getCursor();
								i_cursor.moveCursor(o_position);
							}
						}
					},
					keydown: {
						fn: function (i_field, i_event) {

							var i_selector = i_self.getSelector();

							if (!i_selector.isHidden()) {
								return true;
							}

							var i_regext = new RegExp("^.{1}$");

							var value = i_field.getValue();

							var n_selection = 0;

							var i_inputEl = i_field.inputEl;

							var o_input = {};
							var o_position = {};
							var o_box = {};

							var i_main = i_self.getMain();
							var i_cursor = i_self.getCursor();
							var a_inputs = IceCap.util.Handler.getInputFields(i_self);

							var b_intersect = false;

							var b_overshot = false;

							if (i_event.ctrlKey && !i_event.shiftKey) {

								if (i_event.keyCode == Ext.event.Event.DOWN ||
									i_event.keyCode == Ext.event.Event.UP) {

									n_selection = i_inputEl.dom.selectionEnd;

									i_event.stopEvent();

									o_position = {
										col: i_field.col + n_selection,
										lin: i_field.lin
									};

									if (i_event.keyCode == Ext.event.Event.DOWN) {

										var n_height = Math.ceil(i_field.getHeight() / IceCap.util.Handler.getHeight(1, o_rules.lineScale));

										n_height = (n_height > 1) ? n_height - 1 : n_height;

										o_position.lin = o_position.lin + n_height;

									}
									else {
										o_position.lin--;
									}

									if (n_selection !== i_field.maxLength) {
										o_position.col++;
									}

									i_self.setCurrentPosition(o_position);

									i_cursor.moveCursor(o_position);

									i_cursor.show();

									o_input = {
										x: i_cursor.getLocalX(),
										y: i_cursor.getLocalY()
									};

									Ext.apply(o_box, {
										width: i_cursor.getWidth(),
										height: i_cursor.getHeight(),
										right: i_cursor.getLocalX() + i_cursor.getWidth(),
										bottom: i_cursor.getLocalY() + i_cursor.getHeight()
									}, o_input);

									i_cursor.hide();

									Ext.Array.each(a_inputs, function (i_field) {

										var i_region = i_field.getRegion(false, true);

										if (i_region.intersect(o_box)) {
											b_intersect = true;
											i_field.focus(false, 10);
											return false;
										}
									});

									if (!b_intersect) {

										i_field.blur();
										i_cursor.show();

										i_main.focus(true, 10);
									}
								}
								if (i_event.keyCode == Ext.event.Event.LEFT ||
									i_event.keyCode == Ext.event.Event.RIGHT) {

									n_selection = i_event.keyCode == Ext.event.Event.LEFT ? i_inputEl.dom.selectionStart : i_inputEl.dom.selectionEnd;

									i_event.stopEvent();

									if (n_selection === 0 && i_event.keyCode === Ext.event.Event.LEFT) {

										o_position = {
											col: i_field.col,
											lin: i_field.lin
										};

										o_position.col--;

										o_input = {
											x: IceCap.util.Handler.getX(o_position.col, o_rules.fontScale),
											y: IceCap.util.Handler.getY(o_position.lin, o_rules.lineScale)
										};

										i_self.setCurrentPosition(o_position);

										i_cursor.moveCursor(o_position);

										Ext.apply(o_box, {
											width: i_cursor.getWidth(),
											height: i_cursor.getHeight(),
											right: o_input.x + i_cursor.getWidth(),
											bottom: o_input.x + IceCap.util.Handler.getHeight(1, o_rules.lineScale)
										}, o_input);

										Ext.Array.each(a_inputs, function (i_field) {

											var i_region = i_field.getRegion(false, true);

											if (i_region.intersect(o_box)) {
												b_intersect = true;
												i_field.focus(false, 10);
												return false;
											}
										});

										if (!b_intersect) {

											i_field.blur();
											i_cursor.show();

											i_main.focus(true, 10);
										}
									}
									else if (n_selection == value.length && i_event.keyCode == Ext.event.Event.RIGHT) {

										o_position = {
											col: i_field.col + i_field.maxLength,
											lin: i_field.lin
										};

										if (o_position.col > o_inputData.width) {
											o_position.col = o_inputData.width;
										}

										o_position.col = o_position.col + 2;

										o_input = {
											x: IceCap.util.Handler.getX(o_position.col, o_rules.fontScale),
											y: IceCap.util.Handler.getY(o_position.lin, o_rules.lineScale)
										};


										i_self.setCurrentPosition(o_position);
										i_cursor.moveCursor(o_position);

										Ext.apply(o_box, {
											width: i_cursor.getWidth(),
											height: i_cursor.getHeight(),
											right: o_input.x + i_cursor.getWidth(),
											bottom: o_input.x + IceCap.util.Handler.getHeight(1, o_rules.lineScale)
										}, o_input);

										Ext.Array.each(a_inputs, function (i_field) {

											var i_region = i_field.getRegion(false, true);

											if (i_region.intersect(o_box)) {
												b_intersect = true;
												i_field.focus(false, 10);
												return false;
											}
										});

										if (!b_intersect) {

											i_field.blur();
											i_cursor.show();

											i_main.focus(true, 10);
										}
									}
								}
							}
							else {

								if (i_field.xtype == "textarea" || i_field.xtype == "icecap-textarea") {

									if (i_event.keyCode == Ext.event.Event.ENTER) {
										i_event.preventDefault();
										i_self.doKeyEvent("ENTER");
										return false;
									}

									var n_row = 1;
									var n_char = 0;
									var n_left = 0;
									var n_current = 0;
									var n_nextLine = 0;
									var n_newPos = 0;

									if (i_event.keyCode == Ext.event.Event.UP && (!i_event.shiftKey && !i_event.ctrlKey)) {

										var s_value = i_field.stripReturns(i_field.getRawValue());

										var regex = new RegExp("^.*\n$|.{1," + n_colSize + "}", "gm");

										var a_lines = s_value.match(regex) || [];
										var a_newLines = s_value.split("\n");

										var n_start = i_field.inputEl.dom.selectionStart;

										if (a_lines.length > 0) {

											var s_first = a_lines[0];

											if (n_start > s_first.length) {
												i_event.stopPropagation();
											}
										}
										else {
											if (a_newLines.length > 0) {
												if (n_start > 0) {
													i_event.stopPropagation();
												}
											}
										}
									}

									if (i_event.keyCode == Ext.event.Event.DOWN && (!i_event.shiftKey && !i_event.ctrlKey)) {

										var s_value = i_field.stripReturns(i_field.getRawValue());
										var n_length = s_value.length;

										var regex = new RegExp("^.*\n$|.{1," + n_colSize + "}", "g");
										var n_start = i_field.inputEl.dom.selectionStart;

										var a_lines = s_value.match(regex) || [];
										var a_newLines = s_value.split("\n");

										if (a_lines.length < o_config.rows && a_newLines.length < o_config.rows) {

											i_event.stopEvent();

											s_value = s_value + "\n";

											i_field.setValue(s_value);

											i_field.inputEl.dom.setSelectionRange(s_value.length, s_value.length);
										}
										else {
											if (a_lines.length == o_config.rows) {

												var n_line = 0;

												Ext.Array.each(a_lines, function (s_line, n_index) {
													if (n_index < a_lines.length - 1) {
														n_line += s_line.length;
													}
												});

												n_line += a_newLines.length - 1;

												if (n_start < n_line) {
													i_event.stopPropagation();
												}
											}
											else {
												if (a_newLines.length > 0) {
													if (n_start < s_value.length) {
														i_event.stopPropagation();
													}
												}
											}
										}
									}
								}
								else if (i_field.xtype == "icecap-input") {

									var n_typeMode = i_self.getTypeMode();

									var s_direction = i_field.inputEl.el.dom.selectionDirection;

									var n_curpos = s_direction == "forward" ? i_field.inputEl.el.dom.selectionEnd : i_field.inputEl.el.dom.selectionStart;

									var s_key = i_event.event.key;

									var i_nearest;

									var n_temp;

									var n_valueTemp = 999;
									var n_curdiffCol = 999;

									if (i_regext.test(s_key)) {

										if (n_curpos < value.length && n_typeMode == IceCap.util.Handler.typeMode.OVERWRITE) {

											var a_values = value.split("");
											a_values[n_curpos] = i_event.event.key;
											value = a_values.join("");
											i_field.setValue(value);
											i_field.inputEl.el.dom.selectionEnd = i_field.inputEl.el.dom.selectionStart = n_curpos + 1;
											i_event.stopEvent();
										}
									}
									else {

										if (i_event.keyCode == Ext.event.Event.DOWN ||
											i_event.keyCode == Ext.event.Event.UP) {

											n_selection = i_inputEl.dom.selectionEnd;

											o_position = {
												col: i_field.col,
												lin: i_field.lin
											};

											if (i_event.keyCode === Ext.event.Event.UP) {

												Ext.Array.each(a_inputs, function (i_field) {

													if (i_field.col == o_position.col) {

														if (i_field.lin == (o_position.lin - 1)) {

															i_nearest = i_field;
														}
													}
												});

												if (!i_nearest) {

													n_posDiff = o_position.lin;

													n_valueTemp = 999;
													n_curdiffCol = 999;

													Ext.Array.each(a_inputs, function (i_field) {

														if (i_field.lin < o_position.lin) {

															var n_max = Math.max(i_field.lin, n_posDiff);
															var n_min = Math.min(i_field.lin, n_posDiff);

															var n_curDiff =  n_max - n_min;

															if (n_valueTemp >= n_curDiff) {

																n_max = Math.max(i_field.col, o_position.col);
																n_min = Math.min(i_field.col, o_position.col);

																var n_diff = n_max - n_min;

																if (n_valueTemp == n_curDiff) {

																	if (n_curdiffCol > n_diff) {
																		i_nearest = i_field;
																		n_valueTemp = n_curDiff;
																		n_curdiffCol = n_diff;
																	}
																}
																else {
																	i_nearest = i_field;
																	n_valueTemp = n_curDiff;
																	n_curdiffCol = n_diff;
																}
															}
														}
													});
												}

												if (i_nearest) {

													o_position.lin = i_nearest.lin;

													i_self.setCurrentPosition(o_position);

													i_cursor.moveCursor(o_position);

													i_nearest.focus(false, 10, function () {
														var i_element = i_nearest.inputEl;
														var value = i_nearest.getValue();
														if (i_self.getTypeMode() != IceCap.util.Handler.typeMode.FOCUS) {
															i_element.dom.selectionStart = i_element.dom.selectionEnd = n_selection;
														}
													});

													i_event.stopEvent();
												}
											}
											else if (i_event.keyCode == Ext.event.Event.DOWN) {

												Ext.Array.each(a_inputs, function (i_field) {

													if (i_field.col == o_position.col) {

														if (i_field.lin == (o_position.lin + 1)) {

															i_nearest = i_field;
														}
													}
												});

												if(!i_nearest) {

													n_posDiff = o_position.lin;
													n_tempCol = o_position.col;

													n_valueTemp = 999;
													n_curdiffCol = 999;

													Ext.Array.each(a_inputs, function (i_field) {

														if (i_field.lin > o_position.lin) {

															var n_max = Math.max(i_field.lin, n_posDiff);
															var n_min = Math.min(i_field.lin, n_posDiff);

															var n_diff = n_max - n_min;

															var n_curDiff =  n_max - n_min;

															if (n_valueTemp >= n_curDiff) {

																n_max = Math.max(i_field.col, o_position.col);
																n_min = Math.min(i_field.col, o_position.col);

																n_diff = n_max - n_min;

																if (n_curdiffCol > n_diff) {
																	i_nearest = i_field;
																	n_valueTemp = n_curDiff;
																	n_curdiffCol = n_diff;
																}
															}
														}
													});
												}

												if (i_nearest) {

													o_position.lin = i_nearest.lin;

													i_self.setCurrentPosition(o_position);

													i_cursor.moveCursor(o_position);

													i_nearest.focus(false, 10, function () {
														var i_element = i_nearest.inputEl;
														if (i_self.getTypeMode() != IceCap.util.Handler.typeMode.FOCUS) {
															i_element.dom.selectionStart = i_element.dom.selectionEnd = n_selection;
														}
													});

													i_event.stopEvent();
												}
											}
										}

										if (i_event.keyCode == Ext.event.Event.LEFT ||
											i_event.keyCode == Ext.event.Event.RIGHT) {

											var n_col = o_config.col;
											var n_tempCol = n_col;

											n_selection = i_event.keyCode == Ext.event.Event.LEFT ? i_inputEl.dom.selectionStart : i_inputEl.dom.selectionEnd;

											var a_selection = i_inputEl.getTextSelection();
											var n_selected = a_selection[2] == "forward" ? a_selection[1] - a_selection[0] : a_selection[2] - a_selection[1];

											if (n_selected == value.length && !Ext.isEmpty(value)) {

												if (i_event.keyCode == Ext.event.Event.LEFT) {
													i_inputEl.dom.selectionStart = i_inputEl.dom.selectionEnd = 0;
												}
												else {
													i_inputEl.dom.selectionStart = i_inputEl.dom.selectionEnd = n_selected;
												}

												i_event.stopEvent();

												return;
											}

											o_position = {
												col: i_field.col,
												lin: i_field.lin
											};

											n_posDiff = o_position.col + o_position.lin;

											if (n_selection === 0 && i_event.keyCode === Ext.event.Event.LEFT) {

												n_tempCol = o_position.col;

												Ext.Array.each(a_inputs, function (i_field) {

													if (i_field.lin == o_position.lin) {

														if (i_field.col < o_position.col) {

															i_nearest = i_field;
														}
													}
												});

												if (!i_nearest) {

													n_valueTemp = 999;

													n_posDiff = o_config.lin;


													Ext.Array.each(a_inputs, function (i_field) {

														if (i_field.lin < o_position.lin) {

															var n_curDiff = n_posDiff - i_field.lin;

															if (n_valueTemp > n_curDiff) {
																i_nearest = i_field;
																n_tempCol = i_field.col;
																n_valueTemp = n_curDiff;
															}
															else if (n_valueTemp == n_curDiff) {
																if (n_tempCol < i_field.col && i_field.col > o_position.col) {
																	i_nearest = i_field;
																	n_tempCol = i_field.col;
																}
															}
														}
													});
												}

												if (i_nearest) {

													o_position.col = i_nearest.col;

													i_self.setCurrentPosition(o_position);

													i_cursor.moveCursor(o_position);

													i_nearest.focus(false, 10, function () {
														var i_element = i_nearest.inputEl;
														var value = i_nearest.getValue();
														if (!b_overshot && i_self.getTypeMode() != IceCap.util.Handler.typeMode.FOCUS) {
															i_element.dom.selectionStart = i_element.dom.selectionEnd = value.length;
														}
													});
												}
											}
											else if (n_selection == value.length && i_event.keyCode == Ext.event.Event.RIGHT) {

												n_tempCol = i_field.col + i_field.maxLength;

												o_position = {
													col: i_field.col + i_field.maxLength,
													lin: i_field.lin
												};

												if (o_position.col > o_inputData.width) {
													o_position.col = n_tempCol = o_inputData.width;
												}

												Ext.Array.each(a_inputs, function (i_field) {

													if (i_field.lin == o_position.lin) {

														if (i_field.col > o_position.col) {

															i_nearest = i_field;
															return false;
														}
													}
												});

												if (!i_nearest) {

													n_valueTemp = 999;

													n_posDiff = o_config.lin;

													Ext.Array.each(a_inputs, function (i_field) {

														if (i_field.lin > o_position.lin) {

															var n_curDiff = i_field.lin - n_posDiff;

															if (n_valueTemp > n_curDiff) {
																if (n_tempCol >= i_field.col) {
																	i_nearest = i_field;
																	n_tempCol = i_field.col;
																}
																n_valueTemp = n_curDiff;
															}
															else if (n_valueTemp == n_curDiff) {
																if (n_tempCol > i_field.col && i_field.col < o_position.col) {
																	i_nearest = i_field;
																}
															}
														}
													});
												}

												if (i_nearest) {

													o_position.col = i_nearest.col;

													i_self.setCurrentPosition(o_position);

													i_cursor.moveCursor(o_position);

													i_nearest.focus(false, 10, function () {
														var i_element = i_nearest.inputEl;
														if (i_self.getTypeMode() != IceCap.util.Handler.typeMode.FOCUS) {
															i_element.dom.selectionStart = i_element.dom.selectionEnd = 0;
														}
													});

													i_event.stopEvent();
												}
											}
										}
									}
								}
							}
						}
					}
				}
			}, o_meta);

			var o_clone = Ext.clone(o_field);

			if (o_meta.xtype) {

				o_clone.metaField = true;

				o_clone.xtype = s_type = o_meta.xtype;

				delete o_clone.cls;
				delete o_clone.fieldStyle;
				delete o_clone.inputType;
				delete o_clone.ui;
			}

			if (o_config.type == "grid") {

				s_type = "iceCapGrid";

				Ext.apply(o_clone, {
					xtype: s_type,
					gridConfig: o_config.grid,
					width: IceCap.util.Handler.getWidth(n_inputWidth, o_rules.fontScale)
				});

				delete o_clone.cls;
				delete o_clone.fieldStyle;
				delete o_clone.inputType;
				delete o_clone.listeners;
				delete o_clone.grid;

				Ext.apply(o_clone, {
					listeners: {
						fieldoption: {
							fn: function (a_config) {
								i_self.fireEvent("fieldoption", a_config);
							}
						},
						key: {
							fn: function (s_key) {
								i_self.fireEvent("key", s_key);
							}
						}
					}
				});
			}

			i_field = Ext.widget(s_type, o_clone);

			var o_on = {};

			Ext.Object.each(o_listeners, function (s_key, value) {

				if (Ext.isFunction(value)) {
					o_on[s_key] = Ext.apply({}, {
						fn: value,
						scope: i_self
					});
				}
				else if (Ext.isObject(value)) {
					value.scope = i_self;
					o_on[s_key] = value;
				}
			});

			i_field.on(o_on);

			if (!i_field.unselected) {
				i_field.focusable = true;
				n_tabIndex++;
			}

			if (o_config.atr == 25) {

				if (o_field.readOnly) {
					i_field.addCls("icecap-invalid");
				}
				else {
					i_field.markInvalid(true);
				}
			}

			a_fields.push(i_field);
		});

		n_tabIndex = n_tabIndex - 1;
		i_self.setLastTabIndex(n_tabIndex);
		i_self.setCurrentTabIndex(o_inputData.focus);

		i_self.setNeedFocus(n_focus);

		return a_fields;
	},

	createLabels: function () {

		var i_self = this;
		var o_inputData = i_self.getInputData();

		var o_rules = i_self.getCssRules();

		var i_fieldRule = o_rules.sheet.rules.item(0);
		var o_style = i_fieldRule.style;

		var a_fields = [];
		var a_bold = [];

		if (!i_self.getEdit()) {

			var a_lines = [];
			var a_temp = [];

			Ext.Array.each(o_inputData.output, function (o_config) {

				var o_line = Ext.Array.findBy(a_lines, function (o_line) {
					return o_line.lin == o_config.lin;
				});

				if (o_line) {
					o_line.items.push(o_config);
				}
				else {
					o_line = {
						items: [o_config],
						lin: o_config.lin,
						col: o_config.col
					};

					a_lines.push(o_line);
				}
			});

			Ext.Array.each(a_lines, function (o_line) {

				var a_items = [];

				Ext.Array.each(o_line.items, function (o_item) {

					var o_atr = Ext.Array.findBy(a_items, function (o_atr) {
						return (o_atr.atr || "") == (o_item.atr || "");
					});

					if (!o_atr && o_item.atr != "22") {
						o_atr = {
							lin: o_item.lin,
							items: [o_item],
							atr: o_item.atr || ""
						};

						a_items.push(o_atr);
					}
					else {

						if (o_item.atr != "22") {
							o_atr.items.push(o_item);
						}
						else {
							a_bold.push(o_item);
						}
					}
				});

				o_line.atr = a_items;
			});

			Ext.Array.each(a_lines, function (o_line) {

				Ext.Array.each(o_line.atr, function (o_atr) {

					var n_col = 0;
					var n_current = 0;
					var s_value = "";

					var o_field = {
						value: ""
					};

					Ext.Array.each(o_atr.items, function (o_config) {

						var s_data = o_config.dta || o_config.label || o_config.text || "";

						if (o_config.off) {
							s_data = Ext.String.leftPad(s_data, s_data.length + o_config.off);
						}

						if (n_col === 0) {

							n_col = o_config.col;
							n_current = (n_col + s_data.length);
							s_value = s_data;
						}
						else {

							var n_diff = o_config.col - n_current;

							if (n_diff > 0) {
								s_data = Ext.String.leftPad(s_data, s_data.length + n_diff);
							}

							n_current = (n_current + s_data.length);

							s_value = s_value + s_data;
						}
					});

					Ext.apply(o_field, {
						col: n_col,
						lin: o_line.lin,
						value: s_value,
						atr: o_atr.atr
					});

					a_temp.push(o_field);
				});
			});

			var a_splitTemp = [];

			Ext.Array.each(a_bold, function (o_config) {

				var s_value = o_config.value || o_config.dta || "";

				if (o_config.off) {
					s_value = Ext.String.leftPad(s_value, s_value.length + o_config.off);
				}

				var a_matches = Array.from(s_value.matchAll(/\S+/g));

				Ext.Array.each(a_matches, function (i_match) {
					a_splitTemp.push({
						value: i_match[0],
						lin: o_config.lin,
						col: i_match.index + o_config.col,
						atr: "22"
					});
				});
			});

			a_temp = a_temp.concat(a_splitTemp);

			Ext.Array.each(a_temp, function (o_config) {

				var s_value = o_config.value || o_config.dta;

				if (s_value) {

					if (o_config.off) {
						s_value = Ext.String.leftPad(s_value, s_value.length + o_config.off);
					}

					var n_x = IceCap.util.Handler.getX(o_config.col, o_rules.fontScale);
					var n_y = IceCap.util.Handler.getY(o_config.lin, o_rules.lineScale);

					var s_cls = (["iceCap-output-" + (o_config.atr || 20), i_self.getTheme()].filter(Boolean).join("-"));

					var o_field = {
						autoEl: {
							tag: "span"
						},
						html: s_value,
						x: n_x,
						y: n_y,
						lin: o_config.lin,
						col: o_config.col,
						cls: ["x-form-display-field-icecap-display" + o_rules.fieldCss, s_cls].join(" "),
						originalValue: s_value,
						textID: o_config.txtId || 0,
						style: {
							"white-space": "pre",
							"pointer-events": "none"
						},
						listeners: {
							afterrender: {
								fn: function (i_field) {
									i_field.el.dom.setAttribute("draggable", false);
								}
							}
						}
					};


					if (o_config.atr == "27") {
						o_field.hidden = true;
					}

					if (o_config.atr == "22") {

						Ext.apply(o_field.style, {
							"font-size": IceCap.util.Handler.getFontSize(o_rules.fontScale),
							"font-weight": "bold;"
						});
					}

					var i_field = Ext.widget("component", o_field);
					a_fields.push(i_field);
				}
			});
		}
		else {

			Ext.Array.each(o_inputData.output, function (o_config) {

				var s_value = o_config.dta || o_config.label || o_config.text || "";

				if (s_value) {

					if (o_config.off) {
						s_value = Ext.String.leftPad(s_value, s_value.length + o_config.off);
					}

					var n_x = IceCap.util.Handler.getX(o_config.col, o_rules.fontScale);
					var n_y = IceCap.util.Handler.getY(o_config.lin, o_rules.lineScale);

					var s_cls = (["iceCap-output-" + (o_config.atr || 20), i_self.getTheme()].filter(Boolean).join("-"));

					var o_field = {
						autoEl: {
							tag: "span"
						},
						html: s_value,
						x: n_x,
						y: n_y,
						lin: o_config.lin,
						col: o_config.col,
						cls: ["x-form-display-field-icecap-display" + o_rules.fieldCss, s_cls].join(" "),
						originalValue: s_value,
						textID: o_config.txtId || 0,
						style: {
							"white-space": "pre"
						},
						listeners: {
							mouseover: {
								element: "el",
								fn: function () {

									var i_element = this;
									i_element.addCls("x-base-background-color");
								}
							},
							mouseout: {
								element: "el",
								fn: function () {

									var i_element = this;
									i_element.removeCls("x-base-background-color");
								}
							},
							afterrender: {
								fn: function (i_field) {
									i_field.el.dom.setAttribute("draggable", false);

									var i_tpl = Ext.create("Ext.XTemplate",
										"<div style=\"width: 300px; overflow:hidden;\">",
										"<div>Position: {lin} / {col}</div>",
										"<div>Length: {len}</div>",
										"<div>Color: {color}</div>",
										"<div style=\"overflow:hidden; white-space: nowrap; text-overflow:ellipsis;\">Font: {font}</div>",
										"</div>"
									);

									Ext.create("Ext.tip.ToolTip", {
										target: i_field.el,
										html: "",
										anchor: true,
										defealtAlign: "b0-t0",
										listeners: {
											beforeshow: {
												fn: function (i_tip) {

													var o_data = {
														lin: o_config.lin,
														col: o_config.col,
														color: o_style.color,
														len: o_config.len,
														font: [
															o_style.fontSize,
															o_style.fontFamily
														].join(" ")
													};

													var s_value = i_tpl.apply(o_data);
													i_tip.update(s_value);
												}
											}
										}
									});
								}
							}
						}
					};


					if (o_config.atr == "27") {
						o_field.hidden = true;
					}

					if (o_config.atr == "22") {

						Ext.apply(o_field.style, {
							"font-size": IceCap.util.Handler.getFontSize(o_rules.fontScale),
							"font-weight": "bold;"
						});
					}

					var i_field = Ext.widget("component", o_field);
					a_fields.push(i_field);

					i_field.on({
						afterrender: {
							fn: function (i_field) {
								i_field.el.on({
									click: {
										fn: function () {

											o_config.originalValue = o_config.dta;

											if (i_field.textID) {
												IceCap.util.Handler.getTranslation({
													textID: i_field.textID,
													languages: i_self.getLanguages()
												}, function (o_data) {

														o_config.originalValue = o_data.text;

														var i_editor = i_self.createEditor(o_config, o_data, function (o_values, o_translation) {

															var s_value = o_translation[i_self.getActiveLanguage()] || o_data.text;

															i_field.setHtml(s_value);

															i_field.textID = o_config.txtId = o_values.txtId;
														});

														var o_translation = o_data.translation || {};

														var s_value = o_translation[i_self.getActiveLanguage()] || i_field.originalValue;

														i_editor.startEdit(i_field.getEl(), s_value, false);
												});
											}
											else {

												o_config.dta = i_field.originalValue;

												var i_editor = i_self.createEditor(o_config, {}, function (o_values, o_translation) {

													i_field.textID = o_config.txtId = o_values.txtId;

													var s_value = o_translation[i_self.getActiveLanguage()] || o_config.text;

													i_field.setHtml(s_value);
												});

												i_editor.startEdit(i_field.getEl(), undefined, false);
											}
										}
									}
								});
							}
						}
					});
				}
			});
		}

		return a_fields;
	},

	createKeys: function () {

		var i_self = this;
		var o_rules = i_self.getCssRules();
		var o_inputData = i_self.getInputData();
		var a_disabledKey = o_inputData.disabledKeys || [];
		var a_buttons = [];

		var i_template = Ext.create("Ext.XTemplate",
			"{id}={text}"
		);

		Ext.Array.each(o_inputData.keys, function (o_config) {

			var s_template = i_template.apply(o_config);

			var o_found = Ext.Array.findBy(a_disabledKey, function (o_disabled) {
				return o_config.id == o_disabled.id;
			});

			o_found = o_found || {
				showKey: 1
			};

			var b_hidden = Number(o_found.showKey) < 1 || false;

			var i_button = Ext.widget("button", {
				text: s_template,
				key: o_config.id,
				len: o_config.len,
				focusable: false,
				textID: o_config.txtId || 0,
				hidden: b_hidden,
				originalValue: s_template,
				style: {
					maxHeight: 30 * o_rules.lineScale + "px",
					minHeight: 30 * o_rules.lineScale + "px",
					minWidth: 80 * o_rules.fontScale + "px"
				},
				listeners: {
					afterrender: {
						fn: function(i_button) {
							i_button.btnEl.setStyle("min-height", "inherit");
							i_button.btnInnerEl.setStyle("font-size", "calc(1em * " +  o_rules.fontScale + ")");
						}
					}
				}
			});

			if (i_self.getEdit()) {
				i_button.on({
					afterrender: {
						fn: function (i_button) {
							i_button.el.on({
								click: {
									fn: function (i_event) {

										o_config.dta = o_config.text;

										o_config.originalValue = i_template.apply({
											id: i_button.key,
											text: o_config.text
										});

										i_event.stopEvent();

										if (i_button.textID) {
											IceCap.util.Handler.getTranslation({
												textID: i_button.textID,
												languages: i_self.getLanguages()
											}, function (o_data) {

													o_config.originalValue = o_data.text;

													var i_editor = i_self.createEditor(o_config, o_data, function (o_values, o_translation) {

														var s_value = o_translation[i_self.getActiveLanguage()];

														if (s_value) {

															s_value = i_template.apply({
																id: i_button.key,
																text: s_value
															});
														}
														else {
															if (o_data.text) {
																s_value = o_data.text;
															}
															else {
																s_value = i_template.apply({
																	id: i_button.key,
																	text: o_config.text
																});
															}
														}

														i_button.setText(s_value);

														i_button.textID = o_config.txtId = o_values.txtId;

													}, true);

													var o_translation = o_data.translation || {};

													var s_value = o_translation[i_self.getActiveLanguage()] || o_config.text;

													i_editor.startEdit(i_button.getEl(), s_value, false);
											});
										}
										else {

											o_config.originalValue = i_template.apply({
												id: i_button.key,
												text: o_config.text
											});

											o_config.dta = o_config.text;

											var i_editor = i_self.createEditor(o_config, {}, function (o_values, o_translation) {

												i_button.textID = o_config.txtId =  o_values.txtId;

												var s_value = o_translation[i_self.getActiveLanguage()];

												if (s_value) {

													s_value = i_template.apply({
														id: i_button.key,
														text: s_value
													});
												}
												else {
													s_value = i_template.apply({
														id: i_button.key,
														text: o_config.text
													});
												}

												i_button.setText(s_value);

											}, true);

											i_editor.startEdit(i_button.getEl(), o_config.dta, false);
										}
									}
								}
							});
						}
					}
				});
			}
			else {
				i_button.on({
					click: {
						fn: function () {
							i_self.doKeyEvent(i_button.key);
						}
					}
				});
			}

			a_buttons.push(i_button);
		});

		return a_buttons;
	},

	createMetaFields: function() {

		var i_self = this;
		var o_inputData = i_self.getInputData();

		var a_fields = [];
		var n_tabIndex = i_self.getLastTabIndex() || 0;

		var a_sliced = Ext.Array.slice(o_inputData.metaFields || []);

		var o_rules = i_self.getCssRules();

		Ext.Array.each(a_sliced, function(o_config) {

			var n_x = o_config.x;
			var n_y = o_config.y;

			if (!o_config.x) {
				n_x = IceCap.util.Handler.getX(o_config.col, o_rules.fontScale);
			}

			if (!o_config.y) {
				n_y = IceCap.util.Handler.getY(o_config.lin, o_rules.lineScale);
			}

			if (isNaN(n_x)) {
				n_x = IceCap.util.Handler.getWidth(1, o_rules.fontScale);
			}

			if (isNaN(n_y)) {
				n_y = IceCap.util.Handler.getHeight(1, o_rules.lineScale);
			}

			var o_listeners = o_config.listeners || {};

			Ext.apply(o_config, {
				tabIndex: n_tabIndex + 1,
				keys: Ext.Array.slice(o_inputData.keys),
				theme: i_self.getTheme(),
				x: n_x,
				y: n_y,
				listeners: {
					fieldoption: {
						fn: function(a_config) {
							i_self.fireEvent("fieldoption", a_config);
						}
					},
					key: {
						fn: function(s_key) {
							i_self.fireEvent("key", s_key);
						}
					}
				}
			});

			o_config.xtype = o_config.xtype || o_config.type || "icecap-input";

			o_config.name = o_config.id;

			delete o_config.id;

			var i_field = Ext.widget(o_config.xtype, o_config);

			var o_on = {};

			if (!Ext.Object.isEmpty(o_listeners)) {

				Ext.Object.each(o_listeners, function(s_key, value) {

					if (Ext.isFunction(value)) {
						o_on[s_key] = Ext.apply({}, {
							fn: value,
							scope: i_self
						});
					}
					else if (Ext.isObject(value)) {
						value.scope = i_self;
						o_on[s_key] = value;
					}
				});
			}

			i_field.on(o_on);

			a_fields.push(i_field);

			n_tabIndex++;
		});

		i_self.setLastTabIndex(n_tabIndex);

		return a_fields;
	},

	doCreateFromData: function(o_inputData) {

		var i_self = this;
		i_self.fireEvent("toWindow", i_self, o_inputData);
	},

	recreate: function() {

		var i_self = this;

		var i_content = i_self.getContent();
		var i_keyArea = i_self.getKeyArea();
		var i_main = i_self.getMain();
		var o_inputData = i_self.getInputData();

		var b_fixed = o_inputData.hasOwnProperty("fixed") ? o_inputData.fixed : true;

		var s_languages = o_inputData.languages || "";

		var a_languagesSplit = s_languages.split(",").filter(function(value) {
			return value;
		});

		var a_languages = i_self.getLanguages();

		Ext.Array.each(a_languagesSplit, function (s_value) {
			s_value = s_value.trim();
			a_languages.push(s_value);
		});

		i_self.setLanguages(a_languages);

		IceCap.util.Handler.setFixed(b_fixed);

		i_self.suspendLayouts();

		if (o_inputData.title) {
			i_self.setTitle(o_inputData.title);
		}

		var a_created = [];
		a_created = a_created.concat(i_self.createLabels());
		a_created = a_created.concat(i_self.createFields(a_created));
		a_created = a_created.concat(i_self.createMetaFields());

		a_created.push(i_self.createCursor());
		a_created.push(i_self.createMarker());
		a_created.push(i_self.createSelector());

		i_content.removeAll(true);
		i_keyArea.removeAll(true);

		i_content.add(a_created);

		var a_keys = i_self.createKeys();
		i_keyArea.add(a_keys);

		i_keyArea[a_keys.length === 0 ? "hide" : "show"]();

		var i_marker = i_self.getMarker();
		i_marker.setInUse(i_self.getMarkerActive());

		i_self.updateMessage(o_inputData);


		IceCap.util.Handler.setFixed(true);

		i_self.resumeLayouts(true);

		if (i_content) {
			a_fields = IceCap.util.Handler.getInputFields(i_content);

			var b_found = false;
			var b_error = false;

			if (o_inputData.msgBox && o_inputData.msgBox.text) {
				b_error = true;
			}

			if (a_fields.length > 0) {

				b_found = Ext.Array.findBy(a_fields, function (i_field) {
					return i_field.getTabIndex() === i_self.getNeedFocus();
				});
			}

			if (!b_found) {

				i_self.setCurrentPosition({
					col: o_inputData.csrCol || 1,
					lin: o_inputData.csrLin || 1
				});
			}

			if (b_error) {
				i_self.onError(o_inputData);
			}
			else {
				if (i_self.rendered) {
					i_self.findFocus();
				}
			}
		}

		var b_translation = !Ext.isEmpty(o_inputData.isTranslator) ? o_inputData.isTranslator : false;

		var i_translatorButton = i_self.getTranslator();

		b_translation = i_self.getLanguages().length > 0;

		i_translatorButton[b_translation ? "show" : "hide"]();
	},

	getCurrentField: function() {

		var i_self = this;

		var a_fields = IceCap.util.Handler.getInputFields(i_self);
		var n_tabIndex = i_self.getCurrentTabIndex();
		var i_currentField;

		Ext.Array.each(a_fields, function(i_field) {
			if (i_field.getTabIndex() === n_tabIndex && i_field.hasFocus) {
				i_currentField = i_field;
				return false;
			}
		});

		return i_currentField;
	},

	doKeyEvent: function(s_value, i_event) {

		if (i_event) {
			i_event.stopEvent();
		}

		var i_self = this;

		var i_controller = i_self.getController();

		var o_inputData = i_self.getInputData() || {};

		var a_disabledKeys = Ext.Array.from(o_inputData.disabledKeys || []);

		var o_found = Ext.Array.findBy(a_disabledKeys, function (o_key) {
			return s_value == o_key.id;
		});

		if (!o_found) {
			i_controller.doKeyEvent(s_value);
		}
		else {

			IceCap.util.Handler.messageBox({
				title: "Error",
				message: "Funktionstasten er ikke tilladt",
				yesText: "Ok",
				yesFn: function () {
					i_self.findFocus();
				}
			});
		}
	},

	doNavigationKey: function(n_direction, b_tab, i_event) {

		if (i_event) {
			i_event.stopPropagation();
			i_event.preventDefault();
		}

		var i_self = this;
		var i_controller = i_self.getController();
		i_controller[b_tab ? "doTabKey" : "doArrowKeys"](n_direction);
	},

	addKeyEvents: function() {

		var i_self = this;

		var a_bindings = [
			{
				key: Ext.event.Event.PAGE_DOWN,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					i_self.doKeyEvent("ROLLUP");
				}
			},
			{
				key: Ext.event.Event.PAGE_UP,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					i_self.doKeyEvent("ROLLDOWN");
				}
			},
			{
				key: Ext.event.Event.ENTER,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					i_self.doKeyEvent("ENTER");
				}
			},
			{
				key: Ext.event.Event.ESC,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;

					var i_selector = i_self.getSelector();

					if (!i_selector.isHidden()) {
						i_event.stopEvent();
						i_selector.hide();
					}
					else {
						i_self.doKeyEvent("ATTN");
					}
				}
			},
			{
				key: Ext.event.Event.LEFT,
				shift: false,
				ctrl: true,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_selector.getLocalX(),
							y: i_selector.getLocalY()
						}, o_rules);

						var n_col = o_coords.col - 1;

						var n_x = IceCap.util.Handler.getX(n_col, o_rules.fontScale);

						if (n_x == i_selector.getLocalX()) {
							n_x = IceCap.util.Handler.getX(n_col - 1, o_rules.fontScale);
						}

						i_selector.setLeft(n_x);

						var i_region = i_selector.getRegion(false, true);

						i_selector.dragX = i_region.right;
						i_selector.setDragY(i_region.bottom);
					}
				}
			},
			{
				key: Ext.event.Event.RIGHT,
				shift: false,
				ctrl: true,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_selector.getLocalX(),
							y: i_selector.getLocalY()
						}, o_rules);

						var n_col = o_coords.col;

						var n_x = IceCap.util.Handler.getX(n_col, o_rules.fontScale);

						if (n_x == i_selector.getLocalX()) {
							n_x = IceCap.util.Handler.getX(n_col + 1, o_rules.fontScale);
						}

						i_selector.setLeft(n_x);

						var i_region = i_selector.getRegion(false, true);

						i_selector.dragX = i_region.right;
						i_selector.setDragY(i_region.bottom);
					}
				}
			},
			{
				key: Ext.event.Event.LEFT,
				shift: true,
				ctrl: false,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					var i_target = i_event.getTarget();
					var i_element = Ext.get(i_target);
					var i_component = i_element.component;

					if (!i_component) {
						i_component = i_element.getParent().component;
					}

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var i_region = i_selector.getRegion(false, true);

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_region.right,
							y: i_selector.getLocalY()
						}, o_rules);

						var n_col = o_coords.col - 1;

						var n_x = IceCap.util.Handler.getX(n_col, o_rules.fontScale);

						if (n_x == Math.floor(i_region.right)) {
							n_x = IceCap.util.Handler.getX(n_col - 1, o_rules.fontScale);
						}

						i_selector.setDragX(n_x);
					}
					else {
						if (!i_component.isXType("field")) {

							var i_cursor = i_self.getCursor();

							var o_click = Ext.apply({
								x: i_cursor.getLocalX(),
								y: i_cursor.getLocalY()
							});

							var o_position = IceCap.util.Handler.toColAndLine(o_click, o_rules);

							var n_x = IceCap.util.Handler.getX(o_position.col - 1, o_rules.fontScale);
							var n_y = IceCap.util.Handler.getY(o_position.lin, o_rules.lineScale);

							var n_dragX = IceCap.util.Handler.getX(o_position.col, o_rules.fontScale);
							var n_dragY = IceCap.util.Handler.getY(o_position.lin + 1, o_rules.lineScale);

							i_selector.resetPos(n_x, n_y);

							i_selector.show();

							i_selector.setSelecting(true);

							i_selector.setDragX(n_dragX);
							i_selector.setDragY(n_dragY);

							i_event.stopEvent();
						}
					}
				}
			},
			{
				key: Ext.event.Event.RIGHT,
				shift: true,
				ctrl: false,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					var i_target = i_event.getTarget();
					var i_element = Ext.get(i_target);
					var i_component = i_element.component;

					if (!i_component) {
						i_component = i_element.getParent().component;
					}

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var i_region = i_selector.getRegion(false, true);

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_region.right,
							y: i_selector.getLocalY()
						}, o_rules);

						var n_col = o_coords.col;

						var n_x = IceCap.util.Handler.getX(n_col, o_rules.fontScale);

						if (n_x == Math.floor(i_region.right)) {
							n_x = IceCap.util.Handler.getX(n_col + 1), o_rules.fontScale;
						}

						i_selector.setDragX(n_x);
					}
					else {
						if (!i_component.isXType("field")) {

							var i_cursor = i_self.getCursor();

							var o_click = Ext.apply({
								x: i_cursor.getLocalX(),
								y: i_cursor.getLocalY()
							});

							var o_position = IceCap.util.Handler.toColAndLine(o_click, o_rules);

							var n_x = IceCap.util.Handler.getX(o_position.col - 1, o_rules.fontScale);
							var n_y = IceCap.util.Handler.getY(o_position.lin, o_rules.lineScale);

							var n_dragX = IceCap.util.Handler.getX(o_position.col, o_rules.fontScale);
							var n_dragY = IceCap.util.Handler.getY(o_position.lin + 1, o_rules.lineScale);

							i_selector.resetPos(n_x, n_y);

							i_selector.show();

							i_selector.setSelecting(true);

							i_selector.setDragX(n_dragX);
							i_selector.setDragY(n_dragY);

							i_event.stopEvent();
						}
					}
				}
			},
			{
				key: Ext.event.Event.UP,
				shift: false,
				ctrl: true,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_selector.getLocalX(),
							y: i_selector.getLocalY()
						}, o_rules);

						var n_lin = o_coords.lin;

						var n_y = IceCap.util.Handler.getY(n_lin, o_rules.lineScale);

						if (n_y == i_selector.getLocalY()) {
							n_y = IceCap.util.Handler.getY(n_lin - 1, o_rules.lineScale);
						}

						i_selector.setTop(n_y);

						var i_region = i_selector.getRegion(false, true);

						i_selector.dragY = n_y;
						i_selector.setDragX(i_region.right);
					}
				}
			},
			{
				key: Ext.event.Event.DOWN,
				shift: false,
				ctrl: true,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_selector.getLocalX(),
							y: i_selector.getLocalY()
						}, o_rules);

						var n_lin = o_coords.lin + 1;

						var n_y = IceCap.util.Handler.getY(n_lin, o_rules.lineScale);

						if (n_y == i_selector.getLocalY()) {
							n_y = IceCap.util.Handler.getY(n_lin + 1, o_rules.lineScale);
						}

						i_selector.setTop(n_y);

						var i_region = i_selector.getRegion(false, true);

						i_selector.dragY = n_y;
						i_selector.setDragX(i_region.right);
					}
				}
			},
			{
				key: Ext.event.Event.UP,
				shift: true,
				ctrl: false,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					var i_target = i_event.getTarget();
					var i_element = Ext.get(i_target);
					var i_component = i_element.component;

					if (!i_component) {
						i_component = i_element.getParent().component;
					}

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var i_region = i_selector.getRegion(false, true);

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_selector.getLocalX(),
							y: i_region.bottom
						}, o_rules);

						var n_lin = o_coords.lin;

						var n_y = IceCap.util.Handler.getY(n_lin, o_rules.lineScale);

						if (n_y == Math.floor(i_region.bottom)) {
							n_y = IceCap.util.Handler.getY(n_lin - 1, o_rules.lineScale);
						}

						i_selector.setDragY(n_y);
					}
					else {
						if (!i_component.isXType("field")) {

							var i_cursor = i_self.getCursor();

							var o_click = Ext.apply({
								x: i_cursor.getLocalX(),
								y: i_cursor.getLocalY()
							});

							var o_position = IceCap.util.Handler.toColAndLine(o_click, o_rules);

							var n_x = IceCap.util.Handler.getX(o_position.col - 1, o_rules.fontScale);
							var n_y = IceCap.util.Handler.getY(o_position.lin, o_rules.lineScale);

							var n_dragX = IceCap.util.Handler.getX(o_position.col, o_rules.fontScale);
							var n_dragY = IceCap.util.Handler.getY(o_position.lin + 1, o_rules.lineScale);

							i_selector.resetPos(n_x, n_y);

							i_selector.show();

							i_selector.setSelecting(true);

							i_selector.setDragX(n_dragX);
							i_selector.setDragY(n_dragY);

							i_event.stopEvent();
						}
					}
				}
			},
			{
				key: Ext.event.Event.DOWN,
				shift: true,
				ctrl: false,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					var i_target = i_event.getTarget();
					var i_element = Ext.get(i_target);
					var i_component = i_element.component;

					if (!i_component) {
						i_component = i_element.getParent().component;
					}

					if (!i_selector.isHidden()) {

						i_event.stopEvent();

						var i_region = i_selector.getRegion(false, true);

						var o_coords = IceCap.util.Handler.toColAndLine({
							x: i_selector.getLocalX(),
							y: i_region.bottom
						}, o_rules);

						var n_lin = o_coords.lin + 1;

						var n_y = IceCap.util.Handler.getY(n_lin, o_rules.lineScale);

						if (n_y == Math.floor(i_region.bottom)) {
							n_y = IceCap.util.Handler.getY(n_lin + 1, o_rules.lineScale);
						}

						i_selector.setDragY(n_y);
					}
					else {
						if (!i_component.isXType("field")) {

							var i_cursor = i_self.getCursor();

							var o_click = Ext.apply({
								x: i_cursor.getLocalX(),
								y: i_cursor.getLocalY()
							});

							var o_position = IceCap.util.Handler.toColAndLine(o_click, o_rules);

							var n_x = IceCap.util.Handler.getX(o_position.col - 1, o_rules.fontScale);
							var n_y = IceCap.util.Handler.getY(o_position.lin, o_rules.lineScale);

							var n_dragX = IceCap.util.Handler.getX(o_position.col, o_rules.fontScale);
							var n_dragY = IceCap.util.Handler.getY(o_position.lin + 1, o_rules.lineScale);

							i_selector.resetPos(n_x, n_y);

							i_selector.show();

							i_selector.setSelecting(true);

							i_selector.setDragX(n_dragX);
							i_selector.setDragY(n_dragY);

							i_event.stopEvent();
						}
					}
				}
			},
			{
				key: Ext.event.Event.UP,
				shift: false,
				ctrl: false,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_activeComponent = Ext.ComponentManager.getActiveComponent();
					var i_content = i_self.getContent();

					if (i_content.contains(i_activeComponent) || i_content.ownerCt == i_activeComponent) {

						if (!i_event.target.type) {

							i_event.stopEvent();

							var i_cursor = i_self.getCursor();
							var o_position = i_self.getCurrentPosition();

							var a_inputs = IceCap.util.Handler.getInputFields(i_self);

							o_position.lin--;

							if (o_position.lin < 1) {
								o_position.lin = 1;
							}

							var o_box = {
								x: i_cursor.getLocalX(),
								y: i_cursor.getLocalY() - IceCap.util.Handler.getHeight(1, o_rules.lineScale),
								width: i_cursor.getWidth(),
								height: i_cursor.getHeight(),
								right: i_cursor.getLocalX() + i_cursor.getWidth(),
								bottom: i_cursor.getLocalY(),
								height: 1
							};


							Ext.Array.each(a_inputs, function (i_field) {

								var i_region = i_field.getRegion(false, true);

								if (i_region.intersect(o_box)) {
									b_intersect = true;
									i_field.focus(false, 10);
									return false;
								}
							});

							var b_intersect = false;

							Ext.Array.each(a_inputs, function(i_field) {

								var i_region = i_field.getRegion(false, true);

								if (i_region.intersect(o_box)) {

									b_intersect = true;
									i_field.focus(false, 10);

									var n_start = o_position.col - i_field.col;
									var i_inputEl = i_field.inputEl;
									i_inputEl.dom.selectionStart = i_inputEl.dom.selectionEnd = n_start;

									return false;
								}
							});

							if (!b_intersect) {
								i_cursor.moveCursor(o_position);
							}
							i_self.setCurrentPosition(o_position);
						}
						else {
							i_self.doNavigationKey(0);
						}
					}
				}
			},
			{
				key: Ext.event.Event.DOWN,
				shift: false,
				ctrl: false,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_activeComponent = Ext.ComponentManager.getActiveComponent();
					var i_content = i_self.getContent();

					if (i_content.contains(i_activeComponent) || i_content.ownerCt == i_activeComponent) {

						if (!i_event.target.type) {

							i_event.stopEvent();

							var i_cursor = i_self.getCursor();
							var o_position = i_self.getCurrentPosition();
							var o_inputData = i_self.getInputData();

							var a_inputs = IceCap.util.Handler.getInputFields(i_self);

							o_position.lin++;

							if (o_position.lin > o_inputData.height) {
								o_position.lin = o_inputData.height;
							}

							var o_box = {
								x: i_cursor.getLocalX(),
								y: i_cursor.getLocalY() + IceCap.util.Handler.getHeight(1, o_rules.lineScale),
								width: i_cursor.getWidth(),
								height: i_cursor.getHeight(),
								right: i_cursor.getLocalX() + i_cursor.getWidth(),
								bottom: i_cursor.getLocalY() + IceCap.util.Handler.getHeight(1, o_rules.lineScale) + i_cursor.getHeight(),
								height: 1
							};

							var b_intersect = false;

							Ext.Array.each(a_inputs, function(i_field) {

								var i_region = i_field.getRegion(false, true);

								if (i_region.intersect(o_box)) {

									b_intersect = true;
									i_field.focus(false, 10);

									var n_start = o_position.col - i_field.col;
									var i_inputEl = i_field.inputEl;
									i_inputEl.dom.selectionStart = i_inputEl.dom.selectionEnd = n_start;

									return false;
								}
							});

							if (!b_intersect) {
								i_cursor.moveCursor(o_position);
							}
							i_self.setCurrentPosition(o_position);
						}
						else {
							i_self.doNavigationKey(1);
						}
					}
				}
			},
			{
				key: Ext.event.Event.LEFT,
				shift: false,
				ctrl: false,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_activeComponent = Ext.ComponentManager.getActiveComponent();
					var i_content = i_self.getContent();

					if (i_content.contains(i_activeComponent) || i_content.ownerCt == i_activeComponent) {
						if (!i_event.target.type) {
							i_event.stopEvent();

							var i_cursor = i_self.getCursor();
							var o_position = i_self.getCurrentPosition();

							var a_inputs = IceCap.util.Handler.getInputFields(i_self);

							o_position.col--;

							if (o_position.col < 1) {
								o_position.col = 1;
							}

							var o_box = {
								x: i_cursor.getLocalX() - IceCap.util.Handler.getWidth(1, o_rules.fontScale),
								y: i_cursor.getLocalY(),
								width: i_cursor.getWidth(),
								height: i_cursor.getHeight(),
								right: (i_cursor.getLocalX() - IceCap.util.Handler.getWidth(1, o_rules.fontScale)) + i_cursor.getWidth(),
								bottom: i_cursor.getLocalY() + i_cursor.getHeight(),
								height: 1
							};


							var b_intersect = false;

							Ext.Array.each(a_inputs, function(i_field) {

								var i_region = i_field.getRegion(false, true);

								if (i_region.intersect(o_box)) {
									b_intersect = true;
									i_field.focus(false, 10);
									return false;
								}
							});

							if (!b_intersect) {
								i_cursor.moveCursor(o_position);
							}

							i_self.setCurrentPosition(o_position);
						}
					}
				}
			},
			{
				key: Ext.event.Event.RIGHT,
				shift: false,
				ctrl: false,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_activeComponent = Ext.ComponentManager.getActiveComponent();
					var i_content = i_self.getContent();

					if (i_content.contains(i_activeComponent) || i_content.ownerCt == i_activeComponent) {
						if (!i_event.target.type) {

							i_event.stopEvent();

							var i_cursor = i_self.getCursor();
							var o_position = i_self.getCurrentPosition();
							var o_inputData = i_self.getInputData();

							var a_inputs = IceCap.util.Handler.getInputFields(i_self);

							o_position.col++;

							if (o_position.col > o_inputData.width) {
								o_position.col = o_inputData.width;
							}

							var o_box = {
								x: i_cursor.getLocalX() + IceCap.util.Handler.getWidth(1, o_rules.fontScale),
								y: i_cursor.getLocalY(),
								width: i_cursor.getWidth(),
								height: i_cursor.getHeight(),
								right: i_cursor.getLocalX() + IceCap.util.Handler.getWidth(1, o_rules.fontScale) + i_cursor.getWidth(),
								bottom: i_cursor.getLocalY() + i_cursor.getHeight(),
								height: 1
							};

							var b_intersect = false;

							Ext.Array.each(a_inputs, function(i_field) {

								var i_region = i_field.getRegion(false, true);

								if (i_region.intersect(o_box)) {
									b_intersect = true;
									i_field.focus(false, 10);
									return false;
								}
							});

							if (!b_intersect) {
								i_cursor.moveCursor(o_position);
							}

							i_self.setCurrentPosition(o_position);
						}
					}
				}
			},
			{
				key: Ext.event.Event.TAB,
				shift: false,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;

					var i_activeComponent = Ext.ComponentManager.getActiveComponent();
					var i_content = i_self.getContent();

					if (i_content.contains(i_activeComponent) || i_content.ownerCt == i_activeComponent) {
						i_event.stopEvent();
						i_event.stopPropagation();

						i_self.doNavigationKey(1, true);
					}


				}
			},
			{
				key: Ext.event.Event.TAB,
				shift: true,
				fn: function(n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;

					var i_activeComponent = Ext.ComponentManager.getActiveComponent();
					var i_content = i_self.getContent();

					if (i_content.contains(i_activeComponent) || i_content.ownerCt == i_activeComponent) {
						i_event.stopEvent();
						i_event.stopPropagation();

						i_self.doNavigationKey(0, true);
					}
				}
			},
			{
				key: Ext.event.Event.NUM_PLUS,
				fn: function(n_key, i_event) {

					i_event.stopEvent();

					var i_key = this;
					var i_self = i_key.target.component;

					var i_field = i_self.getCurrentField();

					if (i_field) {

						var n_start = i_field.inputEl.el.dom.selectionStart;

						var s_text = i_field.getValue();

						s_text = s_text.substr(0, n_start);

						i_field.setValue(s_text);

						i_self.doNavigationKey(1, true);
					}
				}
			},
			{
				key: Ext.event.Event.HOME,
				ctrl: true,
				alt: false,
				fn: function(n_key, i_event) {

					i_event.stopEvent();

					var i_key = this;
					var i_self = i_key.target.component;

					var b_markerActive = i_self.getMarkerActive();
					var i_marker = i_self.getMarker();

					i_self.setMarkerActive(!b_markerActive);

					i_marker.toggle();
				}
			},
			{
				key: Ext.event.Event.INSERT,
				ctrl: false,
				alt: false,
				fn: function (n_key, i_event) {

					var n_type = i_self.getTypeMode();
					switch (n_type) {
						case IceCap.util.Handler.typeMode.OVERWRITE:
							n_type = IceCap.util.Handler.typeMode.FOCUS;
							break;
						case IceCap.util.Handler.typeMode.FOCUS:
							n_type = IceCap.util.Handler.typeMode.INSERT;
							break;
						default:
							n_type = IceCap.util.Handler.typeMode.OVERWRITE;
							break;
					}

					i_self.setTypeMode(n_type);
				}
			},
			{
				key: Ext.event.Event.A,
				ctrl: true,
				alt: false,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;

					var i_target = i_event.getTarget();

					var i_element = Ext.get(i_target);

					if (!i_element.isInputField()) {
						var i_selector = i_self.getSelector();

						var o_inputData = i_self.getInputData();

						i_event.stopEvent();

						i_selector.setSelecting(true);


						i_selector.setLeft(IceCap.util.Handler.getX(1));
						i_selector.setTop(IceCap.util.Handler.getY(1));

						i_selector.setDragX(IceCap.util.Handler.getX(o_inputData.width));
						i_selector.setDragY(IceCap.util.Handler.getY(o_inputData.height + 1));

						i_selector.setSelecting(false);
					}
				}
			},
			{
				key: Ext.event.Event.C,
				ctrl: true,
				shift: true,
				alt: false,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					if (i_selector.isVisible()) {
						i_event.stopEvent();

						var i_field  = IceCap.util.Handler.getCopyArea();

						var a_inputs = IceCap.util.Handler.getInputFields(i_self);
						var a_labels = IceCap.util.Handler.getLabels(i_self);

						var i_region = i_selector.getRegion(true, true);

						var n_rows = Math.round(i_region.height / IceCap.util.Handler.getHeight(1, o_rules.fontScale));
						var n_cols = Math.round(i_region.width / IceCap.util.Handler.getWidth(1, o_rules.lineScale));

						var a_copyLabels = IceCap.util.Handler.getCopyValues(a_labels, n_rows, n_cols, i_region, o_rules, 0);
						var a_copyFields = IceCap.util.Handler.getCopyValues(a_inputs, n_rows, n_cols, i_region, o_rules, 1);

						var a_result = [];

						Ext.Array.each(a_copyLabels, function (s_label, n_index) {

							var s_result = "";

							var s_field = a_copyFields[n_index];

							var a_splitLabel = s_label.split("");
							var a_splitField = s_field.split("");

							var n_copy = a_splitLabel.length;

							for (var n_copyIndex = 0; n_copyIndex < n_copy; n_copyIndex++) {

								var s_charLabel = a_splitLabel[n_copyIndex];
								var s_charField = a_splitField[n_copyIndex];

								s_result += !Ext.isEmpty(Ext.String.trim(s_charLabel)) ? s_charLabel : s_charField;

							}

							a_result.push(s_result);
						});

						var s_result = a_result.join("\n");

						i_self.fireEvent("copyplus", s_result);
					}
				}
			},
			{
				key: Ext.event.Event.C,
				ctrl: true,
				alt: false,
				fn: function (n_key, i_event) {

					var i_key = this;
					var i_self = i_key.target.component;
					var o_rules = i_self.getCssRules();

					var i_selector = i_self.getSelector();

					if (i_selector.isVisible()) {
						i_event.stopEvent();

						var i_field = IceCap.util.Handler.getCopyArea();

						i_field.setValue("");

						var a_inputs = IceCap.util.Handler.getInputFields(i_self);
						var a_labels = IceCap.util.Handler.getLabels(i_self);

						var i_region = i_selector.getRegion(true, true);

						var n_rows = Math.round(i_region.height / IceCap.util.Handler.getHeight(1, o_rules.lineScale));
						var n_cols = Math.round(i_region.width / IceCap.util.Handler.getWidth(1, o_rules.fontScale));

						var a_copyLabels = IceCap.util.Handler.getCopyValues(a_labels, n_rows, n_cols, i_region, o_rules, 0);
						var a_copyFields = IceCap.util.Handler.getCopyValues(a_inputs, n_rows, n_cols, i_region, o_rules, 1);

						var a_result = [];

						Ext.Array.each(a_copyLabels, function (s_label, n_index) {

							var s_result = "";

							var s_field = a_copyFields[n_index];

							var a_splitLabel = s_label.split("");
							var a_splitField = s_field.split("");

							var n_copy = a_splitLabel.length;

							for (var n_copyIndex = 0; n_copyIndex < n_copy; n_copyIndex++) {

								var s_charLabel = a_splitLabel[n_copyIndex];
								var s_charField = a_splitField[n_copyIndex];

								s_result += !Ext.isEmpty(Ext.String.trim(s_charLabel)) ? s_charLabel : s_charField;

							}

							a_result.push(s_result);
						});

						var s_result = a_result.join("\n");

						i_field.setValue(s_result);

						i_field.show();

						i_field.inputEl.dom.focus();

						i_field.inputEl.dom.select();

						document.execCommand("copy");

						i_selector.hide();

						i_field.hide();

						var i_main = i_self.getMain();
						i_main.focus();
					}
				}
			}
		];

		a_bindings = a_bindings.concat(i_self.getFKeys());

		var i_keyMap = Ext.create("Ext.util.KeyMap", {
			target: i_self.getEl(),
			binding: a_bindings
		});
	},

	getFKeys: function() {

		var i_self = this;

		var a_keys = [
			{
				key: Ext.event.Event.F1,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F1", i_event);
				}
			},
			{
				key: Ext.event.Event.F2,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F2", i_event);
				}
			},
			{
				key: Ext.event.Event.F3,
				shift: false,
				alt: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F3", i_event);
				}
			},
			{
				key: Ext.event.Event.F4,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F4", i_event);
				}
			},
			{
				key: Ext.event.Event.F5,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F5", i_event);
				}
			},
			{
				key: Ext.event.Event.F6,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F6", i_event);
				}
			},
			{
				key: Ext.event.Event.F7,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F7", i_event);
				}
			},
			{
				key: Ext.event.Event.F8,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F8", i_event);
				}
			},
			{
				key: Ext.event.Event.F9,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F9", i_event);
				}
			},
			{
				key: Ext.event.Event.F10,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F10", i_event);
				}
			},
			{
				key: Ext.event.Event.F11,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F11", i_event);
				}
			},
			{
				key: Ext.event.Event.F12,
				shift: false,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F12", i_event);
				}
			}
		];

		a_keys = a_keys.concat(i_self.getFShiftKeys());

		return a_keys;
	},

	getFShiftKeys: function() {

		var i_self = this;

		var a_keys = [
			{
				key: Ext.event.Event.F1,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F13", i_event);
				}
			},
			{
				key: Ext.event.Event.F2,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F14", i_event);
				}
			},
			{
				key: Ext.event.Event.F3,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F15", i_event);
				}
			},
			{
				key: Ext.event.Event.F4,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F16", i_event);
				}
			},
			{
				key: Ext.event.Event.F5,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F17", i_event);
				}
			},
			{
				key: Ext.event.Event.F6,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F18", i_event);
				}
			},
			{
				key: Ext.event.Event.F7,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F19", i_event);
				}
			},
			{
				key: Ext.event.Event.F8,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F20", i_event);
				}
			},
			{
				key: Ext.event.Event.F9,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F21", i_event);
				}
			},
			{
				key: Ext.event.Event.F10,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F22", i_event);
				}
			},
			{
				key: Ext.event.Event.F11,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F23", i_event);
				}
			},
			{
				key: Ext.event.Event.F12,
				shift: true,
				fn: function(n_key, i_event) {

					i_self.doKeyEvent("F24", i_event);
				}
			}
		];

		return a_keys;
	},

	createCursor: function() {

		var i_self = this;
		var o_inputData = i_self.getInputData();
		var o_rules = i_self.getCssRules();

		var i_cursor = Ext.widget("icecap-cursor", {
			theme: i_self.getTheme(),
			width: IceCap.util.Handler.getWidth(1, o_rules.fontScale),
			listeners: {
				show: {
					fn: function(i_cursor) {

						var i_marker = i_self.getMarker();
						var b_active = i_marker.getInUse();

						if (b_active) {
							i_marker.show();
						}
					}
				},
				render: {
					fn: function(i_item) {
						i_item.hide();
					}
				},
				afterrender: {
					fn: function(i_cursor) {

						var i_content = i_self.getContent();

						var a_fields = IceCap.util.Handler.getInputFields(i_content);

						if (a_fields.length === 0) {

							i_cursor.show();

							i_cursor.moveCursor({
								col: o_inputData.csrCol || 1,
								lin: o_inputData.csrLin || 1
							});
						}
					}
				}
			},
			moveCursor: function(o_position) {

				var i_cursor = this;
				var i_marker = i_self.getMarker();
				var o_rules = i_self.getCssRules();

				var n_x = IceCap.util.Handler.getX(o_position.col - 1);
				var n_y = IceCap.util.Handler.getY(o_position.lin + 1);

				i_cursor.move([
					(n_x * o_rules.fontScale) - (o_rules.fontScale < 1 ? (1/2) * o_rules.fontScale : 0),
					(n_y - 6) * o_rules.lineScale
				]);
				i_marker.move([
					n_x * o_rules.fontScale - (o_rules.fontScale < 1 ? (1/2) * o_rules.fontScale : 0),
					(n_y - 7) * o_rules.lineScale
				]);

				i_self.updateCurrentPosition(o_position);
			}
		});

		i_self.setCursor(i_cursor);

		return i_cursor;
	},

	createMarker: function() {

		var i_self = this;

		var i_marker = Ext.widget("icecap-marker", {
			hidden: true,
			active: false,
			inUse: false,
			ui: i_self.getTheme() || "default"
		});

		i_self.setMarker(i_marker);

		return i_marker;
	},

	findFocus: function() {

		var i_self = this;
		var i_main = i_self.getMain();
		var i_content = i_self.getContent();

		var a_fields = IceCap.util.Handler.getInputFields(i_content);

		if (a_fields.length > 0) {

			var i_field = a_fields[0];
			i_field.focus(true, 10);
		}
		else {
			i_main.focus(true, 10);
		}
	},

	doTimer: function() {

		var i_self = this;

		var i_timer = i_self.getTimer();
		if (!i_timer) {
			i_timer = new Ext.util.DelayedTask(function() {
				i_self.setLoading(true);
			});

			i_self.setTimer(i_timer);

			i_timer.delay(1000);
		}
	},

	cancelTimer: function() {

		var i_self = this;

		var i_timer = i_self.getTimer();

		if (i_timer) {
			i_timer.cancel();
			i_self.setTimer(null);
		}
	},

	onError: function(o_inputData) {

		var i_self = this;

		IceCap.util.Handler.messageBox({
			title: "Server Message",
			message: o_inputData.msgBox.text,
			yesText: "Ok",
			yesFn: function(btn) {
				i_self.findFocus();
			}
		});
	},

	updateMessage: function(o_inputData) {

		var i_self = this;
		var o_rules = i_self.getCssRules();
		var i_statusbar = i_self.getStatusBar();

		var a_messages = Ext.Array.from(o_inputData.message);

		var a_result = [];

		if (a_messages.length > 1) {

			a_result.push(a_messages[0].text);
		}
		else {
			Ext.Array.each(a_messages, function(o_message) {
				a_result.push(o_message.text);
			});
		}

		var i_messageLabel = i_statusbar.getComponent("icecap-message");
		var i_languageButton = i_statusbar.getComponent("icecap-language");
		var i_translatorButton = i_statusbar.getComponent("icecap-translator");
		var i_position = i_statusbar.getComponent("icecap-position");
		var i_type = i_statusbar.getComponent("icecap-typemode");

		var s_message = a_result.join(" ");

		if (Ext.String.startsWith(s_message.toLowerCase(), "(c)")) {
			i_messageLabel.removeCls("icecap-statusbar-error");

		}
		else {
			i_messageLabel.addCls("icecap-statusbar-error")
		}

		i_messageLabel.setText(s_message);

		i_messageLabel.setStyle("font-size", "calc(1em * " + o_rules.fontScale);
		i_languageButton.setStyle("font-size", "calc(1em * " + o_rules.fontScale);
		i_translatorButton.setStyle("font-size", "calc(1em * " + o_rules.fontScale);
		i_position.setStyle("font-size", "calc(1em * " + o_rules.fontScale);
		i_type.setStyle("font-size", "calc(1em * " + o_rules.fontScale);

	},

	applyFFW: function (o_config) {

		var i_self = this;
		var s_hex = o_config.ffw;
		var b_fixed = IceCap.util.Handler.getFixed();

		var o_field = {
			xtype: "icecap-input"
		};

		var o_fieldStyle = {
		};

		if (o_config.ta) {

			Ext.apply(o_fieldStyle, {
				"text-align": o_config.ta
			});
		}

		if (s_hex) {

			var n_hex = parseInt(s_hex);

			var n_sanHex = IceCap.util.Handler.createIndicators(s_hex);

			if (n_sanHex & IceCap.util.Handler.FFW.BYPASS) {

				Ext.apply(o_field, {
					readOnly: true,
					tabIndex: -1,
					unselected: true
				});
			}

			if (n_sanHex & IceCap.util.Handler.FFW.IO_FEATURE) {

				Ext.apply(o_field, {
					readOnly: true,
					selectOnFocus: true
				});
			}


			if (n_sanHex & IceCap.util.Handler.FFW.ALPHA_ONLY) {

				Ext.apply(o_field, {
					maskRe: new RegExp("[a-z A-Z ,\\.\\-]")
				});
			}

			if (n_sanHex & IceCap.util.Handler.FFW.NUMERIC_ONLY) {

				Ext.apply(o_field, {
					validator: function(value) {

						var b_valid = true;

						if (value) {
							var i_regex = new RegExp("^(?:\\+|\\-){0,1}[0-9]+(?:(,|\\.)[0-9]+){0,1}$");
							b_valid = i_regex.test(value);
						}
						
						return b_valid ? "" : "Must be pattern <strong>(+ or -) xxx ( , or . xxx)</strong> where x is <strong>0-9</strong><br>Anything in Parentheses is optinal";
					},
					maskRe: new RegExp("[\\+\\-,\\.0-9]")
				});
			}

			if (n_sanHex & IceCap.util.Handler.FFW.DIGITS_ONLY) {

				Ext.apply(o_field, {
					maskRe: new RegExp("[0-9]")
				});
			}

			if (n_sanHex & IceCap.util.Handler.FFW.MOD_DATA) {

				Ext.apply(o_field, {
					listeners: {
						afterrender: {
							fn: function (i_field) {

								i_field.originalValue = 0xFF;
							},
							single: true
						}
					}
				});
			}

			if (n_sanHex & IceCap.util.Handler.FFW.AUTO_ENTER) {

				// THIS WE DONT NEED IN THE MODERN WORLD...

				// Ext.apply(o_field, {
				// 	listeners: {
				// 		blur: {
				// 			fn: function(i_field) {
				// 				i_self.doKeyEvent("ENTER");
				// 			}
				// 		}
				// 	}
				// });
			}

			if (n_sanHex & IceCap.util.Handler.FFW.MONOCASE) {

				// Ext.apply(o_fieldStyle, {
				// 	"text-transform": "uppercase"
				// });
			}

			if (n_sanHex & IceCap.util.Handler.FFW.MAND_ENTER) {

				Ext.apply(o_field, {
					allowBlank: false
				});
			}

			if (n_sanHex & IceCap.util.Handler.FFW.RA_ZEROFILL ||
				n_sanHex & IceCap.util.Handler.FFW.RA_BLANKFILL ||
				n_sanHex & IceCap.util.Handler.FFW.RA_MANDATORY) {

				Ext.apply(o_fieldStyle, {
					"text-align": "right"
				});
			}

			if (o_config.atr == "27" && n_hex & (1 << 13)) {

				Ext.apply(o_field, {
					hidden: true,
					disabled: true
				});
			}
		}

		Ext.apply(o_field, {
			fieldStyle: o_fieldStyle
		});

		return o_field;
	},

	updateCurrentPosition: function (o_position) {

		var i_self = this;
		var i_statusbar = i_self.getStatusBar();

		if (i_statusbar) {
			var i_position = i_statusbar.getComponent("icecap-position");

			if (i_position) {

				var a_result = [
					o_position.lin,
					o_position.col
				];

				i_position.setText(a_result.join("/"));
			}

			i_self.updateTypeMode(i_self.getTypeMode())
		}
	},

	updateTypeMode: function (n_type) {

		var i_self = this;

		var i_statusbar = i_self.getStatusBar();

		if (i_statusbar) {

			var i_typeLabel = i_statusbar.getComponent("icecap-typemode");

			var a_mode = [
			];

			if (i_typeLabel) {

				switch (n_type) {
					case IceCap.util.Handler.typeMode.OVERWRITE:
						a_mode.push("DEL");
						break;
					case IceCap.util.Handler.typeMode.FOCUS:
						a_mode.push("WEB");
						break;

					default:
						a_mode.push("INS");
						break;
				}

				i_typeLabel.setHtml(a_mode.join(" "));
			}
		}
	},

	updateEdit: function (value) {

		var i_self = this;

		if (i_self.rendered) {

			IceCap.util.Handler.getData({
				func: "",
				i18nLearning: false,
				session: i_self.getSessionValue(),
				translateMode: value
			}, {}, function (o_inputData) {

				o_inputData = o_inputData || {};

				i_self.setInputData(o_inputData);

				i_self.recreate();
			});
		}
	},

	updateActiveLanguage: function (value) {

		var i_self = this;

		if (i_self.rendered) {

			IceCap.util.Handler.getData({
				func: "",
				i18nLearning: false,
				session: i_self.getSessionValue(),
				translateMode: value,
				language: value,
			}, {}, function (o_inputData) {

				o_inputData = o_inputData || {};

				i_self.setInputData(o_inputData);

					i_self.recreate();
			});
		}
	},

	createEditor: function(o_config, o_data, f_callback, b_split) {

		var i_self = this;
		var o_rules = i_self.getCssRules();

		var s_active = i_self.getActiveLanguage();

		f_callback = f_callback || Ext.emptyFn;

		var o_value = o_data.translation || {};

		var s_original = o_data.text || o_config.dta;
		var s_dta = s_original;

		var a_split = s_original.split("=");

		if (a_split.length > 1 && b_split) {
			s_dta = a_split.pop();
		}

		var i_editor = new Ext.Editor({
			updateEl: false,
			alignment: "l-l",
			hideEl: false,
			ignoreNoChange: true,
			allowBlur: true,
			field: {
				xtype: "icecap-i18n-textfield",
				ui: "icecap-field",
				enforceMaxLength: true,
				languages: i_self.getLanguages(),
				languageActive: s_active ? true : false,
				language: s_active,
				value: o_value,
				global: o_data.general,
				originalText: s_dta
			},
			getValue: function () {

				var i_editor = this;
				var i_field = i_editor.field;
				var value = i_field.getValue();

				return value;
			},
			listeners: {
				beforecomplete: {
					fn: function (i_editor) {

						var i_field = i_editor.field;
						var s_value = i_field.getValue();

						if (Ext.isObject(s_value)) {

							Ext.Object.each(s_value, function (s_key, value) {
								value = value.padEnd(i_field.maxLength);
								s_value[s_key] = value;
							});
						}
						else {
							s_value = s_value.padEnd(i_field.maxLength);
							i_field.setValue(s_value);
						}

						return !Ext.isEmpty(s_value);
					}
				},
				complete: {
					fn: function (i_editor, i_element) {

						var i_editorField = i_editor.field;
						var value = i_editorField.getValue();

						if (i_editorField.isDirty()) {

							var i_menu = i_editorField.getSelections();
							var i_check = i_menu.items.get("check-global");
							var b_check = i_check.checked;

							IceCap.util.Handler.doUpsertTranslation({
								screen_id: i_self.getOriginalTitle(),
								linno: o_config.lin,
								colno: o_config.col,
								maxLen: i_editorField.maxLength,
								tolinno: o_config.lin,
								text: o_config.originalValue,
								txtId: o_config.txtId || 0,
								general: b_check,
								translation: i_editorField.getValue()
							}, f_callback);
						}
					}
				},
				globalchange: {
					fn: function(i_editorField, b_checked) {

						if (i_editorField.isDirty()) {

							var i_menu = i_editorField.getSelections();
							var i_check = i_menu.items.get("check-global");
							var b_check = b_checked;

							IceCap.util.Handler.doUpsertTranslation({
								screen_id: i_self.getOriginalTitle(),
								linno: o_config.lin,
								colno: o_config.col,
								maxLen: i_editorField.maxLength,
								tolinno: o_config.lin,
								text: o_config.originalValue,
								txtId: o_config.txtId || 0,
								general: b_check,
								translation: i_editorField.getValue()
							}, Ext.emptyFn);
						}
					}
				},
				selectionopen: {
					fn: function(i_editorField) {
						i_editor.allowBlur = false;
					}
				},
				selectionclose: {
					fn: function(i_editorField) {
						i_editor.allowBlur = true;
					}
				},
				canceledit: {
					fn: function (i_editor) {
						var i_field = i_editor.field;
						var i_menu = i_field.getSelections();
						i_menu.hide();
					}
				}
			}
		});


		var n_width = (IceCap.util.Handler.getWidth(o_config.len, o_rules.fontScale) + (IceCap.util.Handler.getWidth(1, o_rules.fontScale) / 2)) + 45;
		var i_editorField = i_editor.field;
		i_editor.setWidth(n_width);
		i_editorField.setWidth(n_width);
		i_editorField.maxLength = o_config.len;
		i_editorField.focus(false, 50);

		return i_editor;
	},

	createSelector: function () {

		var i_self = this;

		var i_content = i_self.getContent();

		var i_selector

		if (i_content.rendered) {

			var i_region = i_content.getRegion(true);

			var o_inputData = i_self.getInputData();

			var i_selector = Ext.widget("icecap-selector", {
				left: 0,
				top: 0,
				dragX: 0,
				dragY: 0,
				selecting: false,
				renderTo: i_content.getEl(),
				shadow: false
			});

			i_self.setSelector(i_selector);
		}
		else {
			i_content.on({
				afterrender: {
					fn: function() {

						i_selector = i_self.createSelector();
						i_content.add(i_selector);

						i_content.on({
							mousedown: {
								element: "el",
								fn: function (i_event) {

									var i_selector = i_self.getSelector();

									var i_box = i_content.getRegion(true, false);

									var i_target = Ext.get(i_event.getTarget());

									if (i_box.contains(i_event.browserEvent) &&
										!i_target.isFocusable() &&
										!i_event.within(i_selector.getEl())) {

										var o_click = Ext.apply({
											x: i_event.pageX - i_box.x,
											y: i_event.pageY - i_box.y
										});

										var o_position = IceCap.util.Handler.toColAndLine(o_click);

										var n_x = IceCap.util.Handler.getX(o_position.col);
										var n_y = IceCap.util.Handler.getY(o_position.lin);

										i_selector.resetPos(n_x, n_y);

										i_selector.mouseDown = true;

										if (i_selector.isVisible()) {
											i_selector.setVisible(false);
										}
									}
								}
							},
							mousemove: {
								element: "el",
								fn: function (i_event) {

									var i_selector = i_self.getSelector();

									if (i_selector && i_selector.mouseDown) {

										var i_box = i_content.getRegion(true, false);

										var o_click = Ext.apply({
											x: i_event.pageX - i_box.x,
											y: i_event.pageY - i_box.y
										});

										var o_position = IceCap.util.Handler.toColAndLine(o_click);

										var n_x = IceCap.util.Handler.getX(o_position.col);
										var n_y = IceCap.util.Handler.getY(o_position.lin);


										i_selector.setDragX(n_x);
										i_selector.setDragY(n_y);

										i_selector.setSelecting(true);
									}
								}
							},
							mouseup: {
								element: "el",
								fn: function (i_event) {

									var i_selector = i_self.getSelector();

									if(i_selector) {
										i_selector.mouseDown = false;
										i_selector.setSelecting(false);
										i_selector.fireEvent("dragcomplete", i_selector);
									}
								}
							}
						});
					}
				}
			})
		}

		return i_selector;
	}
});
