Ext.define("IceCap.ux.container.Column", {
	
	extend: "Ext.Container",

	alias: [
		"widget.iColumn"
	],

	defaults: {
		xtype: "container",
		layout: {
			type: "form"
		},
		defaults: {
			autoEl: {},
			style: "padding:8px 0 0 5px"
		}
	},

	layout: {
		type: "column"
	},

	flex: 1,
	focusable: false,

  	constructor: function(o_config) {

		var i_self = this;

		i_self.name = i_self.id || o_config.id;

		delete i_self.id;
		delete o_config.id;

		i_self.callParent([o_config]);
	},

 	initComponent: function() {

 		var i_self = this;

 		i_self.callParent(arguments);
 	}
});