.x-panel[id^=iceCapPanel4Area-] {
  background-color: black !important;
}

.x-window-icecap-window .x-panel-body{
	background-color: black !important;
}
/* line 21, ../sass/5250c.scss */
.x-panel-body-icecap-5250c {
  background-color: black !important;
}

.x-panel-icecap-keyarea .x-panel-body {
   background-color: white !important;
}

/* line 25, ../sass/5250c.scss */
.iceCap-cursor-5250c {
  border: 1px solid white !important;
}

/* line 33, ../sass/5250c.scss */
.icecap-field-5250c
input:-webkit-autofill,
input:-webkit-autofill:hover,
input:-webkit-autofill:focus,
input:-webkit-autofill:active {
  -moz-transition: none;
  -webkit-transition: none;
  -o-transition: color 0 ease-in;
  transition: none;
}

/* line 42, ../sass/5250c.scss */
.icecap-field-5250c .x-form-display-field {
  background: transparent;
  color: #53e700 !important;
}
/* line 47, ../sass/5250c.scss */
.icecap-field-5250c .x-form-trigger-wrap {
  border-bottom: 1px solid #53e700 !important;
  border-top: transparent !important;
  border-left: transparent !important;
  border-right: transparent !important;
  border-radius: 0px !important;
}
/* line 53, ../sass/5250c.scss */
.icecap-field-5250c input {
  background-color: black !important;
  color: #53e700 !important;
  caret-color: white !important;
}
/* line 57, ../sass/5250c.scss */
.icecap-field-5250c input::selection {
  color: black !important;
  background-color: #53e700 !important;
}

/* line 65, ../sass/5250c.scss */
.iceCap-input-password-5250c .x-form-trigger-wrap {
  background-color: transparent !important;
  border: none !important;
}
/* line 69, ../sass/5250c.scss */
.iceCap-input-password-5250c input {
  caret-color: #53e700 !important;
  color: transparent !important;
  background-color: transparent !important;
  border-radius: 0px !important;;
}
/* line 73, ../sass/5250c.scss */
.iceCap-input-password-5250c input::selection {
  color: transparent !important;
}

/* line 79, ../sass/5250c.scss */
.iceCap-row-5250c {
  background-color: black;
  color: #53e700;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-20-5250c {
  background: transparent !important;
  color: #53e700 !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-20-5250c input {
  background: black !important;
  color: #53e700 !important;
  border-radius: 0px !important;;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-20-5250c-protected input {
  background: black !important;
  color: #53e700 !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-21-5250c {
  background: #53e700 !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-21-5250c input {
  background: #53e700 !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-21-5250c-protected input {
  background: #53e700 !important;
  color: black !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-22-5250c {
  background: transparent !important;
  color: white !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-22-5250c input {
  background: black !important;
  color: white !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-22-5250c-protected input {
  background: black !important;
  color: white !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-23-5250c {
  background: white !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-23-5250c input {
  background: white !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-23-5250c-protected input {
  background: white !important;
  color: black !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-24-5250c {
  background: transparent !important;
  color: #53e700 !important;
  text-decoration: underline;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-24-5250c input {
  background: black !important;
  color: #53e700 !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-24-5250c-protected input {
  background: black !important;
  color: #53e700 !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-25-5250c {
  background: #53e700 !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-25-5250c input {
  background: #53e700 !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-25-5250c-protected input {
  background: #53e700 !important;
  color: black !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-26-5250c {
  background: transparent !important;
  color: white !important;
  text-decoration: underline;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-26-5250c input {
  background: black !important;
  color: white !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-26-5250c-protected input {
  background: black !important;
  color: white !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-27-5250c {
  background: transparent !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-27-5250c input {
  background: black !important;
  color: #53e700 !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-27-5250c-protected input {
  background: black !important;
  color: #53e700 !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-28-5250c {
  background: transparent !important;
  color: #f01818 !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-28-5250c input {
  background: black !important;
  color: #f01818 !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-28-5250c-protected input {
  background: black !important;
  color: #f01818 !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-29-5250c {
  background: #f01818 !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-29-5250c input {
  background: #f01818 !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-29-5250c-protected input {
  background: #f01818 !important;
  color: black !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-2A-5250c {
  background: transparent !important;
  color: #f01818 !important;
  text-decoration: blink;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-2A-5250c input {
  background: black !important;
  color: #f01818 !important;
  text-decoration: blink;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-2A-5250c-protected input {
  background: black !important;
  color: #f01818 !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-2B-5250c {
  background: #f01818 !important;
  color: black !important;
  text-decoration: blink;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-2B-5250c input {
  background: #f01818 !important;
  color: black !important;
  text-decoration: blink;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-2B-5250c-protected input {
  background: #f01818 !important;
  color: black !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-2C-5250c {
  background: transparent !important;
  color: #f01818 !important;
  text-decoration: none;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-2C-5250c input {
  background: black !important;
  color: #f01818 !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-2C-5250c-protected input {
  background: black !important;
  color: #f01818 !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-2D-5250c {
  background: #f01818 !important;
  color: black !important;
  text-decoration: none;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-2D-5250c input {
  background: #f01818 !important;
  color: black !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-2D-5250c-protected input {
  background: #f01818 !important;
  color: black !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-2E-5250c {
  background: transparent !important;
  color: #f01818 !important;
  text-decoration: blink;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-2E-5250c input {
  background: black !important;
  color: #f01818 !important;
  text-decoration: blink;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-2E-5250c-protected input {
  background: black !important;
  color: #f01818 !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-2F-5250c {
  background: transparent !important;
  color: black !important;
  text-decoration: none;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-2F-5250c input {
  background: black !important;
  color: #f01818 !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-2F-5250c-protected input {
  background: black !important;
  color: #f01818 !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-30-5250c {
  background: transparent !important;
  color: #58f0f0 !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-30-5250c input {
  background: black !important;
  color: #58f0f0 !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-30-5250c-protected input {
  background: black !important;
  color: #58f0f0 !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-31-5250c {
  background: #58f0f0 !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-31-5250c input {
  background: #58f0f0 !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-31-5250c-protected input {
  background: #58f0f0 !important;
  color: black !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-32-5250c {
  background: transparent !important;
  color: white !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-32-5250c input {
  background: black !important;
  color: white !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-32-5250c-protected input {
  background: black !important;
  color: white !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-33-5250c {
  background: yellow !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-33-5250c input {
  background: yellow !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-33-5250c-protected input {
  background: yellow !important;
  color: black !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-34-5250c {
  background: transparent !important;
  color: #58f0f0 !important;
  text-decoration: underline;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-34-5250c input {
  background: black !important;
  color: #58f0f0 !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-34-5250c-protected input {
  background: black !important;
  color: #58f0f0 !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-35-5250c {
  background: #58f0f0 !important;
  color: black !important;
  text-decoration: underline;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-35-5250c input {
  background: #58f0f0 !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-35-5250c-protected input {
  background: #58f0f0 !important;
  color: black !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-36-5250c {
  background: transparent !important;
  color: yellow !important;
  text-decoration: underline;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-36-5250c input {
  background: black !important;
  color: yellow !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-36-5250c-protected input {
  background: black !important;
  color: yellow !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-37-5250c {
  background: transparent !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-37-5250c input {
  background: black !important;
  color: yellow !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-37-5250c-protected input {
  background: black !important;
  color: yellow !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-38-5250c {
  background: transparent !important;
  color: fuchsia !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-38-5250c input {
  background: black !important;
  color: fuchsia !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-38-5250c-protected input {
  background: black !important;
  color: fuchsia !important;
}

/* line 287, ../sass/5250c.scss */
.iceCap-output-39-5250c {
  background: fuchsia !important;
  color: black !important;
  text-decoration: none;
}

/* line 294, ../sass/5250c.scss */
.iceCap-input-39-5250c input {
  background: fuchsia !important;
  color: black !important;
}
/* line 299, ../sass/5250c.scss */
.iceCap-input-39-5250c-protected input {
  background: fuchsia !important;
  color: black !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-3A-5250c {
  background: transparent !important;
  color: #7890f0 !important;
  text-decoration: none;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-3A-5250c input {
  background: black !important;
  color: #7890f0 !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-3A-5250c-protected input {
  background: black !important;
  color: #7890f0 !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-3B-5250c {
  background: #7890f0 !important;
  color: black !important;
  text-decoration: none;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-3B-5250c input {
  background: black !important;
  color: black !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-3B-5250c-protected input {
  background: black !important;
  color: black !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-3C-5250c {
  background: transparent !important;
  color: fuchsia !important;
  text-decoration: underline;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-3C-5250c input {
  background: black !important;
  color: fuchsia !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-3C-5250c-protected input {
  background: black !important;
  color: fuchsia !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-3D-5250c {
  background: fuchsia !important;
  color: black !important;
  text-decoration: underline;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-3D-5250c input {
  background: fuchsia !important;
  color: black !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-3D-5250c-protected input {
  background: fuchsia !important;
  color: black !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-3E-5250c {
  background: transparent !important;
  color: #7890f0 !important;
  text-decoration: underline;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-3E-5250c input {
  background: black !important;
  color: #7890f0 !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-3E-5250c-protected input {
  background: black !important;
  color: #7890f0 !important;
}

/* line 448, ../sass/5250c.scss */
.iceCap-output-3F-5250c {
  background: transparent !important;
  color: #7890f0 !important;
  text-decoration: none;
}

/* line 455, ../sass/5250c.scss */
.iceCap-input-3F-5250c input {
  background: black !important;
  color: #7890f0 !important;
  text-decoration: none;
}
/* line 461, ../sass/5250c.scss */
.iceCap-input-3F-5250c-protected input {
  background: black !important;
  color: #7890f0 !important;
}
