/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-bottom-tl,
.x-window-header-icecap-window-bottom-bl,
.x-window-header-icecap-window-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-bottom-tl,
.x-window-header-icecap-window-bottom-bl,
.x-window-header-icecap-window-bottom-tr,
.x-window-header-icecap-window-bottom-br,
.x-window-header-icecap-window-bottom-tc,
.x-window-header-icecap-window-bottom-bc,
.x-window-header-icecap-window-bottom-ml,
.x-window-header-icecap-window-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-window-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-bottom-ml,
.x-window-header-icecap-window-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-window-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-left-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-left-tr,
.x-window-header-icecap-window-left-br,
.x-window-header-icecap-window-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-left-tl,
.x-window-header-icecap-window-left-bl,
.x-window-header-icecap-window-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-left-tl,
.x-window-header-icecap-window-left-bl,
.x-window-header-icecap-window-left-tr,
.x-window-header-icecap-window-left-br,
.x-window-header-icecap-window-left-tc,
.x-window-header-icecap-window-left-bc,
.x-window-header-icecap-window-left-ml,
.x-window-header-icecap-window-left-mr {
    background-image: url(images/window-header/window-header-icecap-window-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-left-ml,
.x-window-header-icecap-window-left-mr {
    background-image: url(images/window-header/window-header-icecap-window-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-collapsed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-collapsed-top-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-collapsed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-collapsed-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-collapsed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-collapsed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-collapsed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-collapsed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-collapsed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-collapsed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-collapsed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-collapsed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-collapsed-top-tr,
.x-window-header-icecap-window-collapsed-top-br,
.x-window-header-icecap-window-collapsed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-collapsed-top-tl,
.x-window-header-icecap-window-collapsed-top-bl,
.x-window-header-icecap-window-collapsed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-collapsed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-collapsed-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-collapsed-top-tl,
.x-window-header-icecap-window-collapsed-top-bl,
.x-window-header-icecap-window-collapsed-top-tr,
.x-window-header-icecap-window-collapsed-top-br,
.x-window-header-icecap-window-collapsed-top-tc,
.x-window-header-icecap-window-collapsed-top-bc,
.x-window-header-icecap-window-collapsed-top-ml,
.x-window-header-icecap-window-collapsed-top-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-collapsed-top-ml,
.x-window-header-icecap-window-collapsed-top-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-collapsed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-collapsed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-collapsed-right-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-collapsed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-collapsed-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-collapsed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-collapsed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-collapsed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-collapsed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-collapsed-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-collapsed-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-collapsed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-collapsed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-collapsed-right-tr,
.x-window-header-icecap-window-collapsed-right-br,
.x-window-header-icecap-window-collapsed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-collapsed-right-tl,
.x-window-header-icecap-window-collapsed-right-bl,
.x-window-header-icecap-window-collapsed-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-collapsed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-collapsed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-collapsed-right-tl,
.x-window-header-icecap-window-collapsed-right-bl,
.x-window-header-icecap-window-collapsed-right-tr,
.x-window-header-icecap-window-collapsed-right-br,
.x-window-header-icecap-window-collapsed-right-tc,
.x-window-header-icecap-window-collapsed-right-bc,
.x-window-header-icecap-window-collapsed-right-ml,
.x-window-header-icecap-window-collapsed-right-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-collapsed-right-ml,
.x-window-header-icecap-window-collapsed-right-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-collapsed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-collapsed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-collapsed-bottom-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-collapsed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-collapsed-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-collapsed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-collapsed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-collapsed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-collapsed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-collapsed-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-collapsed-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-collapsed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-collapsed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-collapsed-bottom-tr,
.x-window-header-icecap-window-collapsed-bottom-br,
.x-window-header-icecap-window-collapsed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-collapsed-bottom-tl,
.x-window-header-icecap-window-collapsed-bottom-bl,
.x-window-header-icecap-window-collapsed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-collapsed-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-collapsed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-collapsed-bottom-tl,
.x-window-header-icecap-window-collapsed-bottom-bl,
.x-window-header-icecap-window-collapsed-bottom-tr,
.x-window-header-icecap-window-collapsed-bottom-br,
.x-window-header-icecap-window-collapsed-bottom-tc,
.x-window-header-icecap-window-collapsed-bottom-bc,
.x-window-header-icecap-window-collapsed-bottom-ml,
.x-window-header-icecap-window-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-collapsed-bottom-ml,
.x-window-header-icecap-window-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-collapsed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-collapsed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-collapsed-left-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-collapsed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-collapsed-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-collapsed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-collapsed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-collapsed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-collapsed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-collapsed-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-collapsed-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-collapsed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-collapsed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-collapsed-left-tr,
.x-window-header-icecap-window-collapsed-left-br,
.x-window-header-icecap-window-collapsed-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-collapsed-left-tl,
.x-window-header-icecap-window-collapsed-left-bl,
.x-window-header-icecap-window-collapsed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-collapsed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-collapsed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-collapsed-left-tl,
.x-window-header-icecap-window-collapsed-left-bl,
.x-window-header-icecap-window-collapsed-left-tr,
.x-window-header-icecap-window-collapsed-left-br,
.x-window-header-icecap-window-collapsed-left-tc,
.x-window-header-icecap-window-collapsed-left-bc,
.x-window-header-icecap-window-collapsed-left-ml,
.x-window-header-icecap-window-collapsed-left-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-collapsed-left-ml,
.x-window-header-icecap-window-collapsed-left-mr {
    background-image: url(images/window-header/window-header-icecap-window-collapsed-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-collapsed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:857 */
.x-window-header-icecap-window .x-window-header-icon {
    width: 16px;
    height: 16px;
    color: #fff;
    font-size: 16px;
    line-height: 16px;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:866 */
.x-window-header-icecap-window .x-window-header-glyph {
    color: #fff;
    font-size: 16px;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:883 */
.x-ie8 .x-window-header-icecap-window .x-window-header-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:892 */
.x-window-header-icecap-window-horizontal .x-tool-after-title {
    margin: 0 0 0 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:902 */
.x-window-header-icecap-window-horizontal .x-tool-before-title {
    margin: 0 30px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:914 */
.x-window-header-icecap-window-vertical .x-tool-after-title {
    margin: 30px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:924 */
.x-window-header-icecap-window-vertical .x-tool-before-title {
    margin: 0 0 30px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:937 */
.x-keyboard-mode .x-window-header-icecap-window .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-window-header-icecap-window .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-window-header-icecap-window .x-tool-focus,
.x-edge .x-keyboard-mode .x-window-header-icecap-window .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-window-header-icecap-window .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-window-header-icecap-window .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-window-header-icecap-window .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:951 */
.x-window-header-icecap-window {
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:961 */
.x-nbr .x-window-icecap-window-collapsed .x-window-header {
    border-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-window-icecap-window-outer-border-l {
    border-left-color: #00adee !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-window-icecap-window-outer-border-b {
    border-bottom-color: #00adee !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-window-icecap-window-outer-border-bl {
    border-bottom-color: #00adee !important;
    border-bottom-width: 2px !important;
    border-left-color: #00adee !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-window-icecap-window-outer-border-r {
    border-right-color: #00adee !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-window-icecap-window-outer-border-rl {
    border-right-color: #00adee !important;
    border-right-width: 2px !important;
    border-left-color: #00adee !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-window-icecap-window-outer-border-rb {
    border-right-color: #00adee !important;
    border-right-width: 2px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-window-icecap-window-outer-border-rbl {
    border-right-color: #00adee !important;
    border-right-width: 2px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 2px !important;
    border-left-color: #00adee !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-window-icecap-window-outer-border-t {
    border-top-color: #00adee !important;
    border-top-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-window-icecap-window-outer-border-tl {
    border-top-color: #00adee !important;
    border-top-width: 2px !important;
    border-left-color: #00adee !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-window-icecap-window-outer-border-tb {
    border-top-color: #00adee !important;
    border-top-width: 2px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-window-icecap-window-outer-border-tbl {
    border-top-color: #00adee !important;
    border-top-width: 2px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 2px !important;
    border-left-color: #00adee !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-window-icecap-window-outer-border-tr {
    border-top-color: #00adee !important;
    border-top-width: 2px !important;
    border-right-color: #00adee !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-window-icecap-window-outer-border-trl {
    border-top-color: #00adee !important;
    border-top-width: 2px !important;
    border-right-color: #00adee !important;
    border-right-width: 2px !important;
    border-left-color: #00adee !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-window-icecap-window-outer-border-trb {
    border-top-color: #00adee !important;
    border-top-width: 2px !important;
    border-right-color: #00adee !important;
    border-right-width: 2px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-window-icecap-window-outer-border-trbl {
    border-color: #00adee !important;
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/window/Window.scss:20 */
.x-window-icecap-message {
    box-shadow: 0px 7px 9px -2px rgba(0, 0, 0, 0.28) !important;
    border-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/window/Window.scss:24 */
.x-window-icecap-message .x-panel-body {
    background-color: white;
    padding: 20px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/window/Window.scss:30 */
.x-window-icecap-message .x-toolbar-footer {
    border-top: 1px solid transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/window/Window.scss:35 */
.x-window-icecap-window {
    box-shadow: 0px 7px 9px -2px rgba(0, 0, 0, 0.28) !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/window/Window.scss:38 */
.x-window-icecap-window .x-panel-body {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/window/Window.scss:43 */
.x-window-icecap-window .x-toolbar-footer {
    border-top: 1px solid transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:201 */
.x-form-text-field-body-icecap-field {
    min-width: 170px;
    max-width: 170px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:221 */
.x-form-trigger-wrap-icecap-field {
    border-width: 1px;
    border-style: solid;
    border-color: #d0d0d0;
    border-radius: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:229 */
.x-form-trigger-wrap-icecap-field.x-form-trigger-wrap-focus {
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:233 */
.x-form-trigger-wrap-icecap-field.x-form-trigger-wrap-invalid {
    border-color: #d81818;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:258 */
.x-form-text-icecap-field {
    color: #000;
    padding: 1px 1px 1px;
    background-color: white !important;
    border-radius: 3px;
    font: 400 14px/20px Lucida Console, Andale Mono, monospace;
    min-height: 22px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:272 */
.x-ie8 .x-form-text-icecap-field {
    min-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:278 */
.x-form-text-icecap-field.x-form-textarea {
    line-height: 21px;
    min-height: 84px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:283 */
.x-ie8 .x-form-text-icecap-field.x-form-textarea {
    min-height: 82px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:290 */
.x-form-text-icecap-field.x-form-text-file {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:294 */
.x-form-text-icecap-field.x-webkit-border-box-bug {
    height: calc(100% + 2px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:300 */
.x-placeholder-label-icecap-field {
    padding: 1px 1px 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:304 */
.x-form-empty-field-icecap-field + .x-placeholder-label-icecap-field {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:309 */
.x-form-text-icecap-field:-ms-input-placeholder {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:313 */
.x-form-invalid-field-icecap-field {
    background-color: #fceded;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:324 */
.x-form-trigger-icecap-field {
    width: 40px;
    font: 16px/22px Portfolio, FontAwesome, Extjs;
    background: #fff;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-trigger-icecap-field:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:347 */
.x-form-trigger-icecap-field.x-form-trigger-over {
    background-position: -40px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:353 */
.x-form-trigger-icecap-field.x-form-trigger-over.x-form-trigger-focus {
    background-position: -160px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:358 */
.x-form-trigger-icecap-field.x-form-trigger-focus {
    background-position: -120px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:367 */
.x-form-trigger.x-form-trigger-icecap-field.x-form-trigger-click {
    background-position: -80px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:376 */
.x-textfield-icecap-field-cell > .x-grid-cell-inner {
    padding-top: 5px;
    padding-bottom: 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:201 */
.x-form-text-field-body-icecap-password-field {
    min-width: 170px;
    max-width: 170px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:221 */
.x-form-trigger-wrap-icecap-password-field {
    border-width: 0px;
    border-style: solid;
    border-radius: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:229 */
.x-form-trigger-wrap-icecap-password-field.x-form-trigger-wrap-focus {
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:233 */
.x-form-trigger-wrap-icecap-password-field.x-form-trigger-wrap-invalid {
    border-color: #d81818;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:258 */
.x-form-text-icecap-password-field {
    color: #000;
    padding: 1px 1px 1px;
    background-color: #fff;
    border-radius: 3px;
    font: 400 14px/22px Lucida Console, Andale Mono, monospace;
    min-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:272 */
.x-ie8 .x-form-text-icecap-password-field {
    min-height: 22px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:278 */
.x-form-text-icecap-password-field.x-form-textarea {
    line-height: 21px;
    min-height: 84px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:283 */
.x-ie8 .x-form-text-icecap-password-field.x-form-textarea {
    min-height: 82px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:290 */
.x-form-text-icecap-password-field.x-form-text-file {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:294 */
.x-form-text-icecap-password-field.x-webkit-border-box-bug {
    height: calc(100% + 2px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:300 */
.x-placeholder-label-icecap-password-field {
    padding: 1px 1px 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:304 */
.x-form-empty-field-icecap-password-field + .x-placeholder-label-icecap-password-field {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:309 */
.x-form-text-icecap-password-field:-ms-input-placeholder {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:313 */
.x-form-invalid-field-icecap-password-field {
    background-color: #fceded;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:324 */
.x-form-trigger-icecap-password-field {
    width: 40px;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
    background: #fff;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-trigger-icecap-password-field:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:347 */
.x-form-trigger-icecap-password-field.x-form-trigger-over {
    background-position: -40px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:353 */
.x-form-trigger-icecap-password-field.x-form-trigger-over.x-form-trigger-focus {
    background-position: -160px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:358 */
.x-form-trigger-icecap-password-field.x-form-trigger-focus {
    background-position: -120px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:367 */
.x-form-trigger.x-form-trigger-icecap-password-field.x-form-trigger-click {
    background-position: -80px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:376 */
.x-textfield-icecap-password-field-cell > .x-grid-cell-inner {
    padding-top: 5px;
    padding-bottom: 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/form/field/Text.scss:29 */
.x-form-trigger-icecap-field {
    border-left: 1px solid #d0d0d0;
    vertical-align: middle !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/form/field/Text.scss:34 */
.x-form-trigger-icecap-field.x-form-trigger-focus {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/form/field/Text.scss:45 */
.x-field-icecap {
    white-space: pre;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/form/field/Text.scss:48 */
.x-field-icecap-password-field {
    margin-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/form/field/Text.scss:52 */
.x-field-icecap-field {
    margin-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Display.scss:52 */
.x-form-display-field-icecap-display {
    min-height: 24px;
    font: 400 14px/24px Lucida Console, Andale Mono, monospace;
    color: #000;
    margin-top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Display.scss:60 */
.x-keyboard-mode .x-form-display-field-icecap-display.x-field-form-focus {
    outline: 1px solid #00adee;
    outline-offset: -1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-form-display-field-icecap-display.x-field-form-focus,
.x-ie10p .x-keyboard-mode .x-form-display-field-icecap-display.x-field-form-focus,
.x-edge .x-keyboard-mode .x-form-display-field-icecap-display.x-field-form-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-form-display-field-icecap-display.x-field-form-focus:after,
.x-ie10p .x-keyboard-mode .x-form-display-field-icecap-display.x-field-form-focus:after,
.x-edge .x-keyboard-mode .x-form-display-field-icecap-display.x-field-form-focus:after {
    position: absolute;
    content: ' ';
    top: 0px;
    right: 0px;
    bottom: 0px;
    left: 0px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Display.scss:71 */
.x-ie8 .x-form-display-field-icecap-display.x-field-form-focus {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/form/field/Display.scss:9 */
.x-field-icecap-display {
    margin-left: 1px;
    margin-bottom: 0px;
    white-space: pre;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:5 */
.x-size-monitored {
    /**
 * @class Ext.util.SizeMonitor
 */
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:9 */
.x-size-monitors {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    visibility: hidden;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:18 */
.x-size-monitors > * {
    width: 100%;
    height: 100%;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:25 */
.x-size-monitors.scroll > *.shrink::after {
    content: '';
    display: block;
    width: 200%;
    height: 200%;
    min-width: 1px;
    min-height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:34 */
.x-size-monitors.scroll > *.expand::after {
    content: '';
    display: block;
    width: 100000px;
    height: 100000px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:44 */
.x-size-monitors.overflowchanged > *.shrink > * {
    width: 100%;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:51 */
.x-size-monitors.overflowchanged > *.expand > * {
    width: 200%;
    height: 200%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:59 */
.x-size-change-detector {
    visibility: hidden;
    position: absolute;
    left: 0;
    top: 0;
    z-index: -1;
    width: 100%;
    height: 100%;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:70 */
.x-size-change-detector > * {
    visibility: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:74 */
.x-size-change-detector-shrink > * {
    width: 200%;
    height: 200%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/SizeMonitor.scss:79 */
.x-size-change-detector-expand > * {
    width: 100000px;
    height: 100000px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:5 */
@-webkit-keyframes x-paint-monitor-helper {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:6 */
    from {
        /**
 * @class Ext.util.PaintMonitor
 */
        /**
 * @class Ext.util.PaintMonitor
 */
        zoom: 1;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:9 */
    to {
        zoom: 1;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:14 */
@keyframes x-paint-monitor-helper {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:15 */
    from {
        zoom: 1;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:18 */
    to {
        zoom: 1;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:23 */
.x-paint-monitored {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:27 */
.x-paint-monitor {
    width: 0 !important;
    height: 0 !important;
    visibility: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:32 */
.x-paint-monitor.cssanimation {
    -webkit-animation-duration: 0.0001ms;
    -webkit-animation-name: x-paint-monitor-helper;
    animation-duration: 0.0001ms;
    animation-name: x-paint-monitor-helper;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:39 */
.x-paint-monitor.overflowchange {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/util/PaintMonitor.scss:42 */
.x-paint-monitor.overflowchange::after {
    content: '';
    display: block;
    width: 1px !important;
    height: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:2 */
.x-unselectable {
    user-select: none;
    -o-user-select: none;
    -ms-user-select: none;
    -moz-user-select: -moz-none;
    -webkit-user-select: none;
    -webkit-tap-highlight-color: transparent;
    -webkit-user-drag: none;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:7 */
.x-hidden-clip {
    position: absolute !important;
    clip: rect(0, 0, 0, 0);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:12 */
.x-hidden-display {
    display: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:16 */
.x-hidden-offsets,
.x-hidden {
    display: block !important;
    visibility: hidden !important;
    position: absolute !important;
    top: -10000px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:26 */
.x-hidden-opacity {
    opacity: 0 !important;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:31 */
.x-hidden-visibility {
    visibility: hidden !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:36 */
.x-pressed .x-ripple-transition,
.x-pressing .x-ripple-transition {
    transition: background-color 0.15s 0.2s cubic-bezier(0.4, 0, 0.2, 1), color 0.15s 0.2s cubic-bezier(0.4, 0, 0.2, 1);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:40 */
.x-pressed .x-ripple-transition .x-icon-el,
.x-pressed .x-ripple-transition .x-arrow-el,
.x-pressing .x-ripple-transition .x-icon-el,
.x-pressing .x-ripple-transition .x-arrow-el {
    transition: background-color 0.15s 0.2s cubic-bezier(0.4, 0, 0.2, 1), color 0.15s 0.2s cubic-bezier(0.4, 0, 0.2, 1);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:45 */
.x-rippling {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:48 */
.x-rippling.x-component-confirm .x-ripple {
    background-color: green;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:52 */
.x-rippling.x-component-decline .x-ripple {
    background-color: red;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:57 */
.x-rippling.x-rippling-unbound {
    overflow: visible !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:59 */
.x-rippling.x-rippling-unbound .x-ripple-container {
    overflow: visible;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:68 */
.x-safari .x-rippling:not(.x-rippling-unbound) .x-ripple-container {
    -webkit-transform: rotate(0);
    -moz-transform: rotate(0);
    -ms-transform: rotate(0);
    -o-transform: rotate(0);
    transform: rotate(0);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:72 */
.x-ripple-container {
    overflow: hidden;
    position: absolute;
    top: 0;
    bottom: 0;
    left: 0;
    right: 0;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:83 */
.x-ripple-wrapper {
    z-index: 1000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:88 */
.x-button-fab .x-ripple-container,
.x-button-round .x-ripple-container {
    border-radius: 10000px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:93 */
.x-splitButton-fab .x-ripple-container,
.x-splitButton-round .x-ripple-container {
    border-radius: 10000px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:97 */
.x-ripple {
    position: absolute;
    border-radius: 50%;
    background-color: white;
    -webkit-transform: scale(1, 1);
    -moz-transform: scale(1, 1);
    -ms-transform: scale(1, 1);
    -o-transform: scale(1, 1);
    transform: scale(1, 1);
    opacity: 0.4;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:106 */
.x-rippling.x-rippling-unbound .x-ripple {
    -webkit-animation: x-ripple-unbound-animation 0.3s ease-out forwards;
    animation: x-ripple-unbound-animation 0.3s ease-out forwards;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:110 */
.x-rippling:not(.x-rippling-unbound) .x-ripple {
    -webkit-animation: x-ripple-animation 0.35s ease-out forwards;
    animation: x-ripple-animation 0.35s ease-out forwards;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/etc/mixins/animation.scss:17 */
@-webkit-keyframes x-ripple-animation {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:115 */
    0% {
        -webkit-transform: scale(0, 0);
        -moz-transform: scale(0, 0);
        -ms-transform: scale(0, 0);
        -o-transform: scale(0, 0);
        transform: scale(0, 0);
        opacity: 0.4;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:119 */
    75% {
        -webkit-transform: scale(2, 2);
        -moz-transform: scale(2, 2);
        -ms-transform: scale(2, 2);
        -o-transform: scale(2, 2);
        transform: scale(2, 2);
        opacity: 0.2;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:123 */
    100% {
        -webkit-transform: scale(2.35, 2.35);
        -moz-transform: scale(2.35, 2.35);
        -ms-transform: scale(2.35, 2.35);
        -o-transform: scale(2.35, 2.35);
        transform: scale(2.35, 2.35);
        opacity: 0;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/etc/mixins/animation.scss:20 */
@keyframes x-ripple-animation {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:115 */
    0% {
        -webkit-transform: scale(0, 0);
        -moz-transform: scale(0, 0);
        -ms-transform: scale(0, 0);
        -o-transform: scale(0, 0);
        transform: scale(0, 0);
        opacity: 0.4;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:119 */
    75% {
        -webkit-transform: scale(2, 2);
        -moz-transform: scale(2, 2);
        -ms-transform: scale(2, 2);
        -o-transform: scale(2, 2);
        transform: scale(2, 2);
        opacity: 0.2;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:123 */
    100% {
        -webkit-transform: scale(2.35, 2.35);
        -moz-transform: scale(2.35, 2.35);
        -ms-transform: scale(2.35, 2.35);
        -o-transform: scale(2.35, 2.35);
        transform: scale(2.35, 2.35);
        opacity: 0;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/etc/mixins/animation.scss:17 */
@-webkit-keyframes x-ripple-unbound-animation {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:130 */
    0% {
        -webkit-transform: scale(0, 0);
        -moz-transform: scale(0, 0);
        -ms-transform: scale(0, 0);
        -o-transform: scale(0, 0);
        transform: scale(0, 0);
        opacity: 0.4;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:134 */
    75% {
        -webkit-transform: scale(1.75, 1.75);
        -moz-transform: scale(1.75, 1.75);
        -ms-transform: scale(1.75, 1.75);
        -o-transform: scale(1.75, 1.75);
        transform: scale(1.75, 1.75);
        opacity: 0.2;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:138 */
    100% {
        -webkit-transform: scale(2, 2);
        -moz-transform: scale(2, 2);
        -ms-transform: scale(2, 2);
        -o-transform: scale(2, 2);
        transform: scale(2, 2);
        opacity: 0;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/etc/mixins/animation.scss:20 */
@keyframes x-ripple-unbound-animation {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:130 */
    0% {
        -webkit-transform: scale(0, 0);
        -moz-transform: scale(0, 0);
        -ms-transform: scale(0, 0);
        -o-transform: scale(0, 0);
        transform: scale(0, 0);
        opacity: 0.4;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:134 */
    75% {
        -webkit-transform: scale(1.75, 1.75);
        -moz-transform: scale(1.75, 1.75);
        -ms-transform: scale(1.75, 1.75);
        -o-transform: scale(1.75, 1.75);
        transform: scale(1.75, 1.75);
        opacity: 0.2;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/Element.scss:138 */
    100% {
        -webkit-transform: scale(2, 2);
        -moz-transform: scale(2, 2);
        -ms-transform: scale(2, 2);
        -o-transform: scale(2, 2);
        transform: scale(2, 2);
        opacity: 0;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/ProgressBase.scss:1 */
.x-progress {
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/ProgressBase.scss:6 */
.x-progress-bar {
    height: 100%;
    width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/ProgressBase.scss:11 */
.x-progress-text {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/ProgressBase.scss:15 */
.x-progress-bar {
    overflow: hidden;
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/scroll/Scroller.scss:1 */
.x-scroller {
    -webkit-overflow-scrolling: touch;
    overflow-anchor: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/scroll/Scroller.scss:6 */
.x-scroller-spacer {
    position: absolute;
    top: 0;
    overflow: hidden;
    height: 1px;
    width: 1px;
    font-size: 0;
    line-height: 0;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/scroll/Scroller.scss:17 */
.x-scroller-snappable {
    -ms-scroll-snap-type: mandatory;
    -webkit-scroll-snap-type: mandatory;
    scroll-snap-type: mandatory;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/scroll/Scroller.scss:23 */
.x-no-scrollbars {
    -ms-overflow-style: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/scroll/Scroller.scss:26 */
.x-no-scrollbars::-webkit-scrollbar {
    width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/TouchAction.scss:1 */
.x-touch-action-pan-y {
    overflow-x: hidden !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/dom/TouchAction.scss:5 */
.x-touch-action-pan-x {
    overflow-y: hidden !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/drag/Source.scss:4 */
.x-drag-body {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/drag/Source.scss:6 */
.x-drag-body * {
    -webkit-user-select: none;
    -moz-user-select: none;
    user-select: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/drag/Source.scss:11 */
.x-drag-dragging {
    z-index: 1000000!important;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:576 */
.x-treelist {
    background-color: #fff;
    background-position: 16px 0%;
    overflow: hidden;
    padding: 0 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:589 */
.x-treelist-container,
.x-treelist-root-container {
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:594 */
.x-treelist-toolstrip {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:599 */
.x-treelist-micro > .x-treelist-toolstrip {
    display: inline-block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:602 */
.x-treelist-micro > .x-treelist-root-container {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:607 */
.x-treelist-item,
.x-treelist-container,
.x-treelist-root-container {
    position: relative;
    overflow: hidden;
    list-style: none;
    padding: 0;
    margin: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:617 */
.x-treelist-item-tool,
.x-treelist-row,
.x-treelist-item-wrap {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:623 */
.x-treelist-item-icon,
.x-treelist-item-expander {
    display: none;
    position: absolute;
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:630 */
.x-treelist-item-expander {
    right: 0;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:635 */
.x-treelist-expander-only .x-treelist-item-expandable > * > .x-treelist-item-wrap > * {
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:639 */
.x-treelist-item-text {
    cursor: pointer;
    white-space: nowrap;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:645 */
.x-treelist-item-collapsed > .x-treelist-container {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:649 */
.x-treelist-item-expandable > * > * > .x-treelist-item-expander,
.x-treelist-item-icon {
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:654 */
.x-treelist-item-floated > * > * > .x-treelist-item-expander,
.x-treelist-item-floated > * > * > .x-treelist-item-icon {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:659 */
.x-treelist-expander-first .x-treelist-item-expander {
    left: 0;
    right: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:103 */
.x-treelist-toolstrip {
    background-color: #f8f8f8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:134 */
.x-treelist-item-selected > .x-treelist-row {
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:138 */
.x-treelist-item-selected > .x-treelist-row-over {
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:143 */
.x-treelist-item-tool {
    padding-left: 6px;
    padding-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:166 */
.x-treelist-item-icon:before,
.x-treelist-item-tool:before,
.x-treelist-item-expander {
    line-height: 33px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:178 */
.x-treelist-item-icon,
.x-treelist-item-tool,
.x-treelist-item-expander {
    text-align: center;
    background-repeat: no-repeat;
    background-position: 0 center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:188 */
.x-treelist-item-loading .x-treelist-item-icon {
    background-image: url(images/tree/loading.gif);
    color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:193 */
.x-treelist-item-icon,
.x-treelist-item-tool {
    color: #000;
    font-size: 16px;
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:206 */
.x-treelist-item-tool {
    width: 32px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:216 */
.x-treelist-item-expander {
    color: #000;
    font-size: 16px;
    width: 18px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:232 */
.x-treelist-item-expander:after {
    content: "\ed21";
    font: 16px/33px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:240 */
.x-treelist-item-expanded > * > * > .x-treelist-item-expander:after {
    content: "\ed1b";
    font: 16px/33px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:253 */
.x-treelist-item-text {
    color: #000;
    margin-left: 22px;
    margin-right: 18px;
    font-size: 14px;
    line-height: 33px;
    text-overflow: ellipsis;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:270 */
.x-treelist-row {
    padding-left: 6px;
    padding-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:301 */
.x-treelist-item-floated .x-treelist-container {
    width: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:304 */
.x-treelist-item-floated > .x-treelist-row {
    background-color: #f8f8f8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:308 */
.x-treelist-item-floated > .x-treelist-container {
    margin-left: -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:311 */
.x-big .x-treelist-item-floated > .x-treelist-container {
    margin-left: -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:317 */
.x-treelist-item-floated > * > * > .x-treelist-item-text {
    margin-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:321 */
.x-treelist-item-floated > * .x-treelist-row {
    cursor: pointer;
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:326 */
.x-treelist-item-floated .x-treelist-row:before {
    width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:330 */
.x-treelist-item-floated > .x-treelist-row-over {
    background-color: #f8f8f8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:333 */
.x-treelist-item-floated > .x-treelist-row-over > * > .x-treelist-item-text {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:346 */
.x-treelist-item-expanded > .x-treelist-item-expander:after {
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:351 */
.x-treelist-item-collapsed > * > .x-treelist-item-expander:after {
    content: "\ed21";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:357 */
.x-treelist-highlight-path .x-treelist-item-over > * > * > .x-treelist-item-icon {
    color: #000;
    transition: color 0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:361 */
.x-treelist-highlight-path .x-treelist-item-over > * > * > .x-treelist-item-text {
    color: #000;
    transition: color 0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:365 */
.x-treelist-highlight-path .x-treelist-item-over > * > * > .x-treelist-item-expander {
    color: #000;
    transition: color 0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:372 */
.x-treelist-row-over {
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:376 */
.x-treelist-row-over > * > .x-treelist-item-icon {
    color: #000;
    transition: color 0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:380 */
.x-treelist-row-over > * > .x-treelist-item-text {
    color: #000;
    transition: color 0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:384 */
.x-treelist-row-over > * > .x-treelist-item-expander {
    color: #000;
    transition: color 0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:391 */
.x-treelist-expander-first .x-treelist-item-icon {
    left: 18px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:400 */
.x-treelist-expander-first .x-treelist-item-text {
    margin-left: 40px;
    margin-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:410 */
.x-treelist-expander-first .x-treelist-item-hide-icon > * > * > .x-treelist-item-text {
    margin-left: 21px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:420 */
.x-treelist-item-hide-icon > * > * > .x-treelist-item-text {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:495 */
.x-treelist-nav {
    background-color: #32404e;
    background-position: 24px 0%;
    padding: 0 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:103 */
.x-treelist-nav .x-treelist-toolstrip {
    background-color: #32404e;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:112 */
.x-treelist-nav .x-treelist-item-selected.x-treelist-item-tool {
    color: #f0f0f0;
    background-color: #5fa2dd;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:134 */
.x-treelist-nav .x-treelist-item-selected > .x-treelist-row {
    background-color: #3f505f;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:143 */
.x-treelist-nav .x-treelist-item-tool {
    padding-left: 10px;
    padding-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:150 */
.x-treelist-nav .x-treelist-item-tool-floated:after {
    height: 44px;
    position: absolute;
    top: 0;
    left: 0;
    content: " ";
    width: 4px;
    background-color: #5fa2dd;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:166 */
.x-treelist-nav .x-treelist-item-icon:before,
.x-treelist-nav .x-treelist-item-tool:before,
.x-treelist-nav .x-treelist-item-expander {
    line-height: 44px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:178 */
.x-treelist-nav .x-treelist-item-icon,
.x-treelist-nav .x-treelist-item-tool,
.x-treelist-nav .x-treelist-item-expander {
    text-align: center;
    background-repeat: no-repeat;
    background-position: 0 center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:188 */
.x-treelist-nav .x-treelist-item-loading .x-treelist-item-icon {
    background-image: url(images/tree/loading.gif);
    color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:193 */
.x-treelist-nav .x-treelist-item-icon,
.x-treelist-nav .x-treelist-item-tool {
    color: #adb3b8;
    font-size: 18px;
    width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:206 */
.x-treelist-nav .x-treelist-item-tool {
    width: 44px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:216 */
.x-treelist-nav .x-treelist-item-expander {
    color: #adb3b8;
    font-size: 16px;
    width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:253 */
.x-treelist-nav .x-treelist-item-text {
    color: #adb3b8;
    margin-left: 30px;
    margin-right: 24px;
    font-size: 16px;
    line-height: 44px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:270 */
.x-treelist-nav .x-treelist-row {
    padding-left: 10px;
    padding-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:276 */
.x-treelist-nav .x-treelist-row-over:before,
.x-treelist-nav .x-treelist-item-selected > .x-treelist-row:before {
    content: " ";
    position: absolute;
    display: block;
    left: 0;
    top: 0;
    width: 6px;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:287 */
.x-treelist-nav .x-treelist-row-over:before {
    background-color: #22c3ff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:291 */
.x-treelist-nav .x-treelist-item-selected > .x-treelist-row-over:before {
    background-color: #22c3ff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:295 */
.x-treelist-nav .x-treelist-item-selected > .x-treelist-row:before {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:301 */
.x-treelist-nav .x-treelist-item-floated .x-treelist-container {
    width: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:304 */
.x-treelist-nav .x-treelist-item-floated > .x-treelist-row {
    background-color: #32404e;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:308 */
.x-treelist-nav .x-treelist-item-floated > .x-treelist-container {
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:311 */
.x-big .x-treelist-nav .x-treelist-item-floated > .x-treelist-container {
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:317 */
.x-treelist-nav .x-treelist-item-floated > * > * > .x-treelist-item-text {
    margin-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:321 */
.x-treelist-nav .x-treelist-item-floated > * .x-treelist-row {
    cursor: pointer;
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:326 */
.x-treelist-nav .x-treelist-item-floated .x-treelist-row:before {
    width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:330 */
.x-treelist-nav .x-treelist-item-floated > .x-treelist-row-over {
    background-color: #32404e;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:333 */
.x-treelist-nav .x-treelist-item-floated > .x-treelist-row-over > * > .x-treelist-item-text {
    color: #adb3b8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:339 */
.x-treelist-nav .x-treelist-item-expanded {
    background-color: #2c3845;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:357 */
.x-treelist-nav .x-treelist-highlight-path .x-treelist-item-over > * > * > .x-treelist-item-icon {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:361 */
.x-treelist-nav .x-treelist-highlight-path .x-treelist-item-over > * > * > .x-treelist-item-text {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:365 */
.x-treelist-nav .x-treelist-highlight-path .x-treelist-item-over > * > * > .x-treelist-item-expander {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:372 */
.x-treelist-nav .x-treelist-row-over {
    background-color: #4f606f;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:376 */
.x-treelist-nav .x-treelist-row-over > * > .x-treelist-item-icon {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:380 */
.x-treelist-nav .x-treelist-row-over > * > .x-treelist-item-text {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:384 */
.x-treelist-nav .x-treelist-row-over > * > .x-treelist-item-expander {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:391 */
.x-treelist-nav .x-treelist-expander-first .x-treelist-item-icon {
    left: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:400 */
.x-treelist-nav .x-treelist-expander-first .x-treelist-item-text {
    margin-left: 54px;
    margin-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:410 */
.x-treelist-nav .x-treelist-expander-first .x-treelist-item-hide-icon > * > * > .x-treelist-item-text {
    margin-left: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/core/sass/src/list/TreeItem.scss:420 */
.x-treelist-nav .x-treelist-item-hide-icon > * > * > .x-treelist-item-text {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:14 */
.x-body {
    margin: 0;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:23 */
@-ms-viewport {
    width: device-width;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:28 */
img {
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:32 */
.x-border-box,
.x-border-box * {
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -ms-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:46 */
.x-ltr {
    direction: ltr;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:50 */
.x-clear {
    overflow: hidden;
    clear: both;
    font-size: 0;
    line-height: 0;
    display: table;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:58 */
.x-layer {
    position: absolute !important;
    top: 0;
    left: 0;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:72 */
.x-fixed-layer {
    position: fixed !important;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:77 */
.x-shim {
    position: absolute;
    left: 0;
    top: 0;
    overflow: hidden;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:90 */
.x-hidden-clip {
    position: absolute !important;
    clip: rect(0, 0, 0, 0);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:95 */
.x-masked-relative {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:101 */
.x-ie-shadow {
    background-color: #777;
    position: absolute;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:108 */
.x-selectable {
    cursor: auto;
    -moz-user-select: text;
    -webkit-user-select: text;
    -ms-user-select: text;
    user-select: text;
    -o-user-select: text;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:123 */
.x-list-plain {
    list-style-type: none;
    margin: 0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:130 */
.x-table-plain {
    border-collapse: collapse;
    border-spacing: 0;
    font-size: 1em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:138 */
.x-frame-tl,
.x-frame-tr,
.x-frame-tc,
.x-frame-bl,
.x-frame-br,
.x-frame-bc {
    overflow: hidden;
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:148 */
.x-frame-tc,
.x-frame-bc {
    background-repeat: repeat-x;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:157 */
td.x-frame-tl,
td.x-frame-tr,
td.x-frame-bl,
td.x-frame-br {
    width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:164 */
.x-frame-mc {
    background-repeat: repeat-x;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:169 */
.x-proxy-el {
    position: absolute;
    background: #b4b4b4;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:176 */
.x-css-shadow {
    position: absolute;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    -ms-border-radius: 5px;
    -o-border-radius: 5px;
    border-radius: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:181 */
.x-item-disabled,
.x-item-disabled * {
    cursor: default;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:187 */
.x-component,
.x-container {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:197 */
:focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:206 */
.x-body .x-sync-repaint:before,
.x-body .x-sync-repaint:after {
    content: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:215 */
.x-position-relative {
    position: relative !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/Component.scss:221 */
.x-tab-guard {
    position: absolute;
    clip: rect(0, 0, 0, 0);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Container.scss:3 */
.x-box-item {
    position: absolute !important;
    left: 0;
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Auto.scss:1 */
.x-autocontainer-outerCt {
    display: table;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Auto.scss:4 */
.x-mobile-safari .x-autocontainer-outerCt {
    transform: translateZ(0);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Auto.scss:14 */
.x-clipped .x-autocontainer-outerCt {
    transform: initial;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Auto.scss:18 */
.x-autocontainer-innerCt {
    display: table-cell;
    height: 100%;
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/LoadMask.scss:1 */
.x-mask {
    z-index: 100;
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    /*
     * IE and FF will add an outline to focused elements,
     * which we don't want when using our own focus treatment
     */
    outline: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/LoadMask.scss:21 */
.x-ie8 .x-mask {
    /*
 * IE8 will treat partially transparent divs as invalid click targets,
 * allowing mouse events to reach elements beneath the mask. Placing
 * a 1x1 transparent gif as the link el background will cure this.
 */
    background-image: url(data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/LoadMask.scss:27 */
.x-mask-fixed {
    position: fixed;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/LoadMask.scss:31 */
.x-mask-msg {
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/ProgressBar.scss:1 */
.x-progress {
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:21 */
.x-btn {
    display: inline-block;
    outline: 0;
    cursor: pointer;
    white-space: nowrap;
    text-decoration: none;
    vertical-align: top;
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:33 */
.x-btn > .x-frame {
    height: 100%;
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:39 */
.x-btn-wrap {
    height: 100%;
    width: 100%;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: stretch;
    -ms-flex-align: stretch;
    align-items: stretch;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:47 */
.x-btn-wrap.x-btn-arrow-bottom,
.x-btn-wrap.x-btn-split-bottom {
    -webkit-box-orient: vertical;
    -ms-flex-direction: column;
    flex-direction: column;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:53 */
.x-ie9m .x-btn-wrap {
    display: table;
    border-spacing: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:64 */
.x-btn-button {
    white-space: nowrap;
    line-height: 0;
    position: relative;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-flex: 1;
    -ms-flex: 1 1 auto;
    flex: 1 1 auto;
    min-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:76 */
.x-btn-button.x-btn-icon-top,
.x-btn-button.x-btn-icon-bottom {
    -webkit-box-orient: vertical;
    -ms-flex-direction: column;
    flex-direction: column;
    -webkit-box-align: stretch;
    -ms-flex-align: stretch;
    align-items: stretch;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:85 */
.x-ie10p .x-btn-button.x-btn-icon-top,
.x-ie10p .x-btn-button.x-btn-icon-bottom {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:92 */
.x-ie9m .x-btn-button {
    display: table-cell;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:103 */
.x-btn-inner {
    overflow: hidden;
    text-overflow: ellipsis;
    -ms-flex-negative: 1;
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:112 */
.x-ie9m .x-btn-inner {
    display: inline-block;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:122 */
.x-btn-icon.x-btn-no-text > .x-btn-inner {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:127 */
.x-btn-icon-el {
    display: none;
    vertical-align: middle;
    text-align: center;
    background-position: center center;
    background-repeat: no-repeat;
    flex-shrink: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:137 */
.x-btn-icon > .x-btn-icon-el {
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:142 */
.x-ie9m .x-btn-icon-left > .x-btn-icon-el,
.x-ie9m .x-btn-icon-right > .x-btn-icon-el {
    display: inline-block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:159 */
.x-btn-button-center {
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:161 */
.x-ie9m .x-btn-button-center {
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:169 */
.x-btn-button-center.x-btn-icon-top,
.x-btn-button-center.x-btn-icon-bottom {
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:175 */
.x-btn-button-left {
    text-align: left;
    -webkit-box-pack: start;
    -ms-flex-pack: start;
    justify-content: flex-start;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:188 */
.x-btn-button-right {
    text-align: right;
    -webkit-box-pack: end;
    -ms-flex-pack: end;
    justify-content: flex-end;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:202 */
.x-btn-arrow:after,
.x-btn-split:after {
    display: block;
    background-repeat: no-repeat;
    content: '';
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -ms-box-sizing: border-box;
    -webkit-box-sizing: border-box;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:216 */
.x-btn-arrow-right:after,
.x-btn-split-right:after {
    background-position: right center;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
    -ms-flex-align: center;
    align-items: center;
    -webkit-box-pack: center;
    -ms-flex-pack: center;
    justify-content: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:226 */
.x-ie9m .x-btn-arrow-right:after,
.x-ie9m .x-btn-split-right:after {
    display: table-cell;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:246 */
.x-btn-arrow-bottom:after,
.x-btn-split-bottom:after {
    background-position: center bottom;
    content: '\00a0';
    line-height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:259 */
.x-ie9m .x-btn-arrow-bottom:after,
.x-ie9m .x-btn-split-bottom:after {
    display: table-row;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:269 */
.x-btn-split-right > .x-btn-button:after {
    position: absolute;
    display: block;
    top: -100%;
    right: 0;
    height: 300%;
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:286 */
.x-btn-split-bottom > .x-btn-button:after {
    position: absolute;
    display: block;
    bottom: 0;
    left: -100%;
    font-size: 0;
    width: 300%;
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:297 */
.x-btn-mc {
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:1 */
.x-segmented-button {
    display: table;
    table-layout: fixed;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:6 */
.x-segmented-button-item {
    display: table-cell;
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:10 */
.x-segmented-button-item > .x-frame {
    width: 100%;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:17 */
.x-segmented-button-item .x-btn-mc {
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:23 */
.x-segmented-button-item-horizontal {
    display: table-cell;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:30 */
.x-segmented-button-item-horizontal.x-segmented-button-first {
    border-top-right-radius: 0;
    border-bottom-right-radius: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:35 */
.x-segmented-button-item-horizontal.x-segmented-button-first .x-btn-tr,
.x-segmented-button-item-horizontal.x-segmented-button-first .x-btn-mr,
.x-segmented-button-item-horizontal.x-segmented-button-first .x-btn-br {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:43 */
.x-segmented-button-item-horizontal.x-segmented-button-middle {
    border-radius: 0;
    border-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:48 */
.x-segmented-button-item-horizontal.x-segmented-button-middle .x-btn-tl,
.x-segmented-button-item-horizontal.x-segmented-button-middle .x-btn-tr,
.x-segmented-button-item-horizontal.x-segmented-button-middle .x-btn-ml,
.x-segmented-button-item-horizontal.x-segmented-button-middle .x-btn-mr,
.x-segmented-button-item-horizontal.x-segmented-button-middle .x-btn-bl,
.x-segmented-button-item-horizontal.x-segmented-button-middle .x-btn-br {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:59 */
.x-segmented-button-item-horizontal.x-segmented-button-last {
    border-left: 0;
    border-top-left-radius: 0;
    border-bottom-left-radius: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:65 */
.x-segmented-button-item-horizontal.x-segmented-button-last .x-btn-tl,
.x-segmented-button-item-horizontal.x-segmented-button-last .x-btn-ml,
.x-segmented-button-item-horizontal.x-segmented-button-last .x-btn-bl {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:74 */
.x-segmented-button-row {
    display: table-row;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:79 */
.x-segmented-button-item-vertical.x-segmented-button-first {
    border-bottom-right-radius: 0;
    border-bottom-left-radius: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:84 */
.x-segmented-button-item-vertical.x-segmented-button-first .x-btn-bl,
.x-segmented-button-item-vertical.x-segmented-button-first .x-btn-bc,
.x-segmented-button-item-vertical.x-segmented-button-first .x-btn-br {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:92 */
.x-segmented-button-item-vertical.x-segmented-button-middle {
    border-radius: 0;
    border-top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:97 */
.x-segmented-button-item-vertical.x-segmented-button-middle .x-btn-tl,
.x-segmented-button-item-vertical.x-segmented-button-middle .x-btn-tc,
.x-segmented-button-item-vertical.x-segmented-button-middle .x-btn-tr,
.x-segmented-button-item-vertical.x-segmented-button-middle .x-btn-bl,
.x-segmented-button-item-vertical.x-segmented-button-middle .x-btn-bc,
.x-segmented-button-item-vertical.x-segmented-button-middle .x-btn-br {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:108 */
.x-segmented-button-item-vertical.x-segmented-button-last {
    border-top: 0;
    border-top-right-radius: 0;
    border-top-left-radius: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/button/Segmented.scss:114 */
.x-segmented-button-item-vertical.x-segmented-button-last .x-btn-tl,
.x-segmented-button-item-vertical.x-segmented-button-last .x-btn-tc,
.x-segmented-button-item-vertical.x-segmented-button-last .x-btn-tr {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:1 */
.x-title-icon {
    background-repeat: no-repeat;
    background-position: 0 0;
    vertical-align: middle;
    line-height: 1;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:9 */
.x-title {
    display: table;
    table-layout: fixed;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:21 */
.x-title-text {
    display: table-cell;
    overflow: hidden;
    white-space: nowrap;
    -o-text-overflow: ellipsis;
    text-overflow: ellipsis;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:30 */
.x-title-align-left {
    text-align: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:39 */
.x-title-align-center {
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:43 */
.x-title-align-right {
    text-align: right;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:52 */
.x-title-rotate-right {
    -webkit-transform: rotate(90deg);
    -webkit-transform-origin: 0 0;
    -moz-transform: rotate(90deg);
    -moz-transform-origin: 0 0;
    -ms-transform: rotate(90deg);
    -ms-transform-origin: 0 0;
    transform: rotate(90deg);
    transform-origin: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/rotate-element.scss:41 */
.x-ie8 .x-title-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:62 */
.x-title-rotate-left {
    -webkit-transform: rotate(270deg);
    -webkit-transform-origin: 100% 0;
    -moz-transform: rotate(270deg);
    -moz-transform-origin: 100% 0;
    -ms-transform: rotate(270deg);
    -ms-transform-origin: 100% 0;
    transform: rotate(270deg);
    transform-origin: 100% 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/rotate-element.scss:41 */
.x-ie8 .x-title-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:75 */
.x-horizontal.x-header .x-title-rotate-right.x-title-align-left > .x-title-item {
    vertical-align: bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:79 */
.x-horizontal.x-header .x-title-rotate-right.x-title-align-center > .x-title-item {
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:83 */
.x-horizontal.x-header .x-title-rotate-right.x-title-align-right > .x-title-item {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:89 */
.x-horizontal.x-header .x-title-rotate-left.x-title-align-left > .x-title-item {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:93 */
.x-horizontal.x-header .x-title-rotate-left.x-title-align-center > .x-title-item {
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:97 */
.x-horizontal.x-header .x-title-rotate-left.x-title-align-right > .x-title-item {
    vertical-align: bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:105 */
.x-vertical.x-header .x-title-rotate-none.x-title-align-left > .x-title-item {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:109 */
.x-vertical.x-header .x-title-rotate-none.x-title-align-center > .x-title-item {
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:113 */
.x-vertical.x-header .x-title-rotate-none.x-title-align-right > .x-title-item {
    vertical-align: bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:120 */
.x-title-icon-wrap {
    display: table-cell;
    text-align: center;
    vertical-align: middle;
    line-height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:125 */
.x-title-icon-wrap.x-title-icon-top,
.x-title-icon-wrap.x-title-icon-bottom {
    display: table-row;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Title.scss:131 */
.x-title-icon {
    display: inline-block;
    vertical-align: middle;
    background-position: center;
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Tool.scss:1 */
.x-tool {
    font-size: 16px;
    line-height: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Header.scss:4 */
.x-header > .x-box-inner,
.x-panel-header-mc > .x-box-inner,
.x-window-header-mc > .x-box-inner {
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Splitter.scss:1 */
.x-splitter {
    font-size: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Splitter.scss:5 */
.x-splitter-horizontal {
    cursor: e-resize;
    cursor: row-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Splitter.scss:10 */
.x-splitter-vertical {
    cursor: e-resize;
    cursor: col-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Splitter.scss:15 */
.x-splitter-collapsed,
.x-splitter-horizontal-noresize,
.x-splitter-vertical-noresize {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Splitter.scss:21 */
.x-splitter-active {
    z-index: 4;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Splitter.scss:25 */
.x-collapse-el {
    position: absolute;
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Splitter.scss:30 */
.x-splitter-focus {
    z-index: 4;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:1 */
.x-box-layout-ct {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:5 */
.x-box-target {
    position: absolute;
    width: 20000px;
    top: 0;
    left: 0;
    min-height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:32 */
.x-box-inner {
    overflow: hidden;
    position: relative;
    left: 0;
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:39 */
.x-box-scroller {
    position: absolute;
    background-repeat: no-repeat;
    background-position: center;
    line-height: 0;
    font-size: 0;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:48 */
.x-box-scroller-top {
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:52 */
.x-box-scroller-right {
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:56 */
.x-box-scroller-bottom {
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:60 */
.x-box-scroller-left {
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:64 */
.x-box-menu-body-horizontal {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:68 */
.x-box-menu-after {
    position: relative;
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:75 */
.x-box-scroller-body-vertical,
.x-box-scroller-body-horizontal {
    -ms-overflow-style: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:78 */
.x-box-scroller-body-vertical .x-scroller,
.x-box-scroller-body-horizontal .x-scroller {
    -ms-overflow-style: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Box.scss:81 */
.x-box-scroller-body-vertical :not(.x-scroller)::-webkit-scrollbar,
.x-box-scroller-body-horizontal :not(.x-scroller)::-webkit-scrollbar {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/toolbar/Toolbar.scss:1 */
.x-toolbar-text {
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/toolbar/Toolbar.scss:5 */
.x-toolbar-separator {
    display: block;
    font-size: 1px;
    overflow: hidden;
    cursor: default;
    border: 0;
    width: 0;
    height: 0;
    line-height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/toolbar/Toolbar.scss:16 */
.x-toolbar-scroller {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/toolbar/Toolbar.scss:23 */
.x-toolbar-plain {
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/dd/DD.scss:3 */
.x-dd-drag-proxy,
.x-dd-drag-current {
    z-index: 1000000!important;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/dd/StatusProxy.scss:1 */
.x-dd-drag-proxy {
    display: table;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/dd/StatusProxy.scss:6 */
.x-dd-drag-repair .x-dd-drag-ghost {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/dd/StatusProxy.scss:10 */
.x-dd-drag-repair .x-dd-drop-icon {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/dd/StatusProxy.scss:15 */
.x-dd-drag-ghost,
.x-dd-drop-icon {
    display: table-cell;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/dd/StatusProxy.scss:21 */
.x-dd-drag-ghost {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=85)";
    opacity: 0.85;
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/dd/StatusProxy.scss:26 */
.x-dd-drop-icon {
    height: 26px;
    width: 26px;
    background-color: transparent;
    background-position: center;
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:1 */
.x-docked {
    position: absolute !important;
    z-index: 2;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:7 */
.x-docked-vertical {
    position: static;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:11 */
.x-docked-top {
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:15 */
.x-docked-bottom {
    border-top-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:19 */
.x-docked-left {
    border-right-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:23 */
.x-docked-right {
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:27 */
.x-docked-noborder-top {
    border-top-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:31 */
.x-docked-noborder-right {
    border-right-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:35 */
.x-docked-noborder-bottom {
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:39 */
.x-docked-noborder-left {
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:45 */
.x-noborder-l {
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:48 */
.x-noborder-b {
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:51 */
.x-noborder-bl {
    border-bottom-width: 0 !important;
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:55 */
.x-noborder-r {
    border-right-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:58 */
.x-noborder-rl {
    border-right-width: 0 !important;
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:62 */
.x-noborder-rb {
    border-right-width: 0 !important;
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:66 */
.x-noborder-rbl {
    border-right-width: 0 !important;
    border-bottom-width: 0 !important;
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:71 */
.x-noborder-t {
    border-top-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:74 */
.x-noborder-tl {
    border-top-width: 0 !important;
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:78 */
.x-noborder-tb {
    border-top-width: 0 !important;
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:82 */
.x-noborder-tbl {
    border-top-width: 0 !important;
    border-bottom-width: 0 !important;
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:87 */
.x-noborder-tr {
    border-top-width: 0 !important;
    border-right-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:91 */
.x-noborder-trl {
    border-top-width: 0 !important;
    border-right-width: 0 !important;
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:96 */
.x-noborder-trb {
    border-top-width: 0 !important;
    border-right-width: 0 !important;
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/component/Dock.scss:101 */
.x-noborder-trbl {
    border-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:1 */
.x-panel,
.x-plain {
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:7 */
.x-panel {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:13 */
td.x-frame-mc {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:18 */
.x-panel-bodyWrap {
    overflow: hidden;
    position: static;
    height: 100%;
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:25 */
.x-panel-body {
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:30 */
.x-panel-header-plain,
.x-panel-body-plain {
    border: 0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:40 */
.x-panel-collapsed-mini {
    visibility: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Panel.scss:50 */
.x-viewport > .x-body.x-panel > .x-panel-bodyWrap {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Table.scss:1 */
.x-table-layout {
    font-size: 1em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/container/ButtonGroup.scss:1 */
.x-btn-group {
    position: relative;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/container/ButtonGroup.scss:6 */
.x-btn-group-body {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/container/ButtonGroup.scss:8 */
.x-btn-group-body .x-table-layout-cell {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/plugin/Viewport.scss:1 */
.x-viewport,
.x-viewport > .x-body {
    margin: 0;
    padding: 0;
    border: 0 none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/plugin/Viewport.scss:8 */
.x-viewport {
    width: 100%;
    height: 100%;
    position: static;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/plugin/Viewport.scss:16 */
.x-viewport > .x-body {
    position: fixed;
    top: 0;
    left: 0;
    min-width: 100%;
    min-height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/plugin/Viewport.scss:30 */
@media print {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/plugin/Viewport.scss:33 */
    .x-viewport > .x-body {
        position: static;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Column.scss:1 */
.x-column {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/SplitterTracker.scss:1 */
.x-resizable-overlay {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    display: none;
    z-index: 200000;
    background-color: #fff;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/window/Window.scss:1 */
.x-window {
    outline: none;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/window/Window.scss:5 */
.x-window .x-window-wrap {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/window/Window.scss:10 */
.x-window-body {
    position: relative;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:1 */
.x-form-item {
    display: table;
    table-layout: fixed;
    border-spacing: 0;
    border-collapse: separate;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:10 */
.x-form-item-label {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:14 */
.x-form-item.x-form-item-no-label > .x-form-item-label {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:18 */
.x-form-item-label,
.x-form-item-body {
    display: table-cell;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:23 */
.x-form-item-body {
    vertical-align: middle;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:28 */
.x-form-item-label-inner {
    display: inline-block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:32 */
.x-form-item-label-top {
    display: table-row;
    height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:35 */
.x-form-item-label-top > .x-form-item-label-inner {
    display: table-cell;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:39 */
.x-form-item-label-top-side-error:after {
    display: table-cell;
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:44 */
.x-form-item-label-right {
    text-align: right;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:53 */
.x-form-error-wrap-side {
    display: table-cell;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:58 */
.x-form-error-wrap-under {
    display: table-row;
    height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:61 */
.x-form-error-wrap-under > .x-form-error-msg {
    display: table-cell;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:66 */
.x-form-error-wrap-under-side-label:before {
    display: table-cell;
    content: '';
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:72 */
.x-form-invalid-icon {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/Labelable.scss:74 */
.x-form-invalid-icon ul {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:1 */
.x-form-trigger-wrap {
    display: table;
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:6 */
.x-form-text-heighted .x-form-trigger-wrap {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:17 */
.x-gecko .x-form-trigger-wrap {
    display: -moz-inline-box;
    display: inline-flex;
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:27 */
.x-form-type-text.x-has-min-height {
    height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:32 */
.x-form-type-text.x-has-min-height .x-form-text-field-body,
.x-form-type-text.x-has-min-height .x-form-trigger-wrap,
.x-form-type-text.x-has-min-height .x-form-text-wrap {
    min-height: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:40 */
.x-ie8 .x-form-type-text.x-has-min-height .x-form-text-field-body,
.x-ie8 .x-form-type-text.x-has-min-height .x-form-trigger-wrap,
.x-ie8 .x-form-type-text.x-has-min-height .x-form-text-wrap {
    min-height: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:47 */
.x-ie8 .x-form-type-text.x-has-min-height .x-form-text {
    min-height: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:52 */
.x-form-type-text.x-has-min-height .x-form-text {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:57 */
.x-form-text-wrap {
    display: table-cell;
    overflow: hidden;
    height: 100%;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:65 */
.x-gecko .x-form-text-wrap {
    display: block;
    -moz-box-flex: 1;
    flex: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:72 */
.x-form-text-wrap .x-placeholder-label {
    position: absolute;
    top: 0;
    left: 0;
    cursor: text;
    white-space: nowrap;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:84 */
.x-form-item-body.x-form-text-grow {
    min-width: inherit;
    max-width: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:89 */
.x-form-text {
    border: 0;
    margin: 0;
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
    display: block;
    background: repeat-x 0 0;
    width: 100%;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:99 */
.x-form-trigger {
    display: table-cell;
    vertical-align: top;
    cursor: pointer;
    overflow: hidden;
    background-repeat: no-repeat;
    text-align: center;
    line-height: 0;
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:111 */
.x-item-disabled .x-form-trigger {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:114 */
.x-form-trigger.x-form-trigger-cmp {
    background: none;
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Text.scss:131 */
.x-gecko .x-form-trigger {
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/TextArea.scss:2 */
.x-form-textarea-body.x-form-text-grow > .x-form-trigger-wrap {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/TextArea.scss:7 */
.x-form-textarea {
    overflow: auto;
    resize: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/TextArea.scss:12 */
div.x-form-text-grow .x-form-textarea {
    min-height: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/window/MessageBox.scss:2 */
.x-message-box .x-form-display-field {
    height: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldContainer.scss:4 */
.x-safari .x-form-fieldcontainer {
    table-layout: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldContainer.scss:12 */
.x-ie8 .x-form-fieldcontainer > .x-form-item-body.x-field-container-body-vertical {
    display: table-row;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:1 */
.x-form-cb-wrap {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:5 */
.x-form-cb-wrap-inner {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:9 */
.x-form-cb {
    position: absolute;
    left: 0;
    right: auto;
    vertical-align: top;
    overflow: hidden;
    padding: 0;
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:17 */
.x-form-cb::-moz-focus-inner {
    padding: 0;
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:23 */
.x-form-cb-input {
    position: absolute;
    margin: 0;
    padding: 0;
    border: 0;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:43 */
.x-form-cb-after {
    /* allow for the component to be positioned after the label */
    left: auto;
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:57 */
.x-form-cb-label {
    /* some browsers like IE 10 need a block element to be able to measure
the height of a multi-line element */
    display: inline-block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Checkbox.scss:60 */
.x-form-cb-label.x-form-cb-no-box-label {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:1 */
.x-fieldset {
    display: block;
    /* preserve margins in IE */
    position: relative;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:7 */
.x-safari11 .x-fieldset {
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:12 */
.x-fieldset-header {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:15 */
.x-fieldset-header .x-form-item,
.x-fieldset-header .x-tool {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:20 */
.x-fieldset-header .x-fieldset-header-text {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:24 */
.x-fieldset-header .x-form-cb-wrap {
    font-size: 0;
    line-height: 0;
    min-height: 0;
    height: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:31 */
.x-fieldset-header .x-form-cb {
    margin: 0;
    position: static;
    display: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:40 */
.x-fieldset-body {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:44 */
.x-fieldset-collapsed {
    padding-bottom: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:47 */
.x-fieldset-collapsed > .x-fieldset-body {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/FieldSet.scss:52 */
.x-fieldset-header-text-collapsible {
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/view/View.scss:2 */
.x-keyboard-mode .x-view-item-focused {
    outline: 1px dashed #00adee !important;
    outline-offset: -1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/view/BoundList.scss:8 */
.x-ie9 .x-boundlist-list-ct {
    min-height: 0%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:1 */
.x-datepicker {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:4 */
.x-datepicker .x-monthpicker {
    left: 0;
    top: 0;
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:10 */
.x-datepicker .x-monthpicker-months,
.x-datepicker .x-monthpicker-years {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:16 */
.x-datepicker-inner {
    table-layout: fixed;
    width: 100%;
    border-collapse: separate;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:22 */
.x-datepicker-cell {
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:26 */
.x-datepicker-header {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:30 */
.x-datepicker-arrow {
    position: absolute;
    outline: none;
    font-size: 0;
    display: table;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:37 */
.x-datepicker-arrow:before {
    display: table-cell;
    text-align: center;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:45 */
.x-datepicker-column-header {
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:49 */
.x-datepicker-date {
    display: block;
    text-decoration: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:54 */
.x-monthpicker {
    display: table;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:57 */
.x-monthpicker-body {
    height: 100%;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:62 */
.x-monthpicker-months,
.x-monthpicker-years {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:67 */
.x-monthpicker-item {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:71 */
.x-monthpicker-item-inner {
    display: block;
    text-decoration: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:76 */
.x-monthpicker-yearnav-button-ct {
    float: left;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:81 */
.x-monthpicker-yearnav-button {
    display: inline-block;
    outline: none;
    font-size: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:87 */
.x-monthpicker-buttons {
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:91 */
.x-datepicker .x-monthpicker-buttons {
    position: absolute;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Date.scss:96 */
.x-datepicker-month .x-btn-split > .x-btn-button:after {
    content: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Display.scss:1 */
.x-form-display-field-body {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Display.scss:3 */
.x-form-display-field-body .x-form-display-field {
    overflow-wrap: break-word;
    word-wrap: break-word;
    -ms-word-break: break-all;
    /* This is dangerous in WebKit as it breaks things at random points */
    word-break: break-all;
    /* Use this non-standard instead */
    word-break: break-word;
    /* Adds a hyphen where the word breaks, if supported (No Blink) */
    -ms-hyphens: auto;
    -moz-hyphens: auto;
    -webkit-hyphens: auto;
    hyphens: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/trigger/Component.scss:3 */
.x-form-trigger.x-form-trigger-cmp:before {
    content: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/File.scss:1 */
.x-form-file-btn {
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/File.scss:6 */
.x-form-file-input {
    border: 0;
    position: absolute;
    cursor: pointer;
    top: 0;
    right: 0;
    width: 100%;
    height: 100%;
    overflow: hidden;
    text-indent: -10000px;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
    /* Yes, there's actually a good reason for this...
      * If the configured buttonText is set to something longer than the default,
      * then it will quickly exceed the width of the hidden file input's "Browse..."
      * button, so part of the custom button's clickable area will be covered by
      * the hidden file input's text box instead. This results in a text-selection
      * mouse cursor over that part of the button, at least in Firefox, which is
      * confusing to a user. Giving the hidden file input a huge font-size makes
      * the native button part very large so it will cover the whole clickable area.
      */
    font-size: 1000px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Hidden.scss:1 */
.x-form-item-hidden {
    margin: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tip/Tip.scss:1 */
.x-tip {
    position: absolute;
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tip/Tip.scss:6 */
.x-tip-body {
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tip/Tip.scss:11 */
.x-tip-anchor {
    position: absolute;
    border-style: solid;
    height: 0;
    width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Color.scss:1 */
.x-color-picker-item {
    float: left;
    text-decoration: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/picker/Color.scss:6 */
.x-color-picker-item-inner {
    display: block;
    font-size: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/HtmlEditor.scss:1 */
.x-html-editor-tb .x-toolbar {
    position: static !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/HtmlEditor.scss:5 */
.x-htmleditor-iframe,
.x-htmleditor-textarea {
    display: block;
    overflow: auto;
    width: 100%;
    height: 100%;
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:1 */
.x-tagfield-body {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:5 */
.x-tagfield {
    height: auto!important;
    /* The wrap has to accommodate the list, so override the .x-form-text height rule */
    cursor: text;
    overflow-y: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:11 */
.x-tagfield .x-tagfield-list {
    padding: 0;
    margin: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:16 */
.x-tagfield-list.x-tagfield-singleselect {
    white-space: nowrap;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:21 */
.x-tagfield-input,
.x-tagfield-item {
    vertical-align: top;
    display: inline-block;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:27 */
.x-tagfield-input-field {
    font: inherit;
    border: 0;
    margin: 0;
    background: none;
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:35 */
.x-tagfield-stacked .x-tagfield-item {
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:39 */
.x-tagfield-item {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:43 */
.x-tagfield-item-close {
    cursor: pointer;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:48 */
.x-tagfield-arialist {
    list-style-type: none;
    position: absolute;
    clip: rect(0, 0, 0, 0);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/form/field/Tag.scss:54 */
.x-tagfield-arialist-item {
    list-style-type: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Fit.scss:1 */
.x-fit-item {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:1 */
.x-grid-view {
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:11 */
.x-grid-row-table {
    /* A grid *item* is a dataview item. It is encapsulated by a <table class="x-grid-item">.
 * One item always corresponds to one store record
 * But an item may contain more than one <tr>.
 * ONE child row, <tr class="x-grid-row"> will be the grid-row and will contain record data
 */
    width: 0;
    table-layout: fixed;
    border: 0 none;
    border-collapse: separate;
    border-spacing: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:25 */
.x-grid-item {
    table-layout: fixed;
    outline: none;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:34 */
.x-ie10 .x-grid-item {
    transform: translateZ(0);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:39 */
.x-grid-row {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:43 */
.x-grid-td {
    overflow: hidden;
    border-width: 0;
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:49 */
.x-grid-cell-inner {
    overflow: hidden;
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:55 */
.x-wrap-cell .x-grid-cell-inner {
    white-space: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/panel/Table.scss:60 */
.x-grid-resize-marker {
    position: absolute;
    z-index: 5;
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/view/Table.scss:3 */
.x-grid-item-container {
    min-height: 1px;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/header/DropZone.scss:1 */
.x-col-move-top,
.x-col-move-bottom {
    position: absolute;
    top: 0;
    line-height: 0;
    font-size: 0;
    overflow: hidden;
    z-index: 20000;
    background: no-repeat center top transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/header/Container.scss:1 */
.x-grid-header-ct {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:1 */
.x-column-header {
    position: absolute;
    overflow: hidden;
    background-repeat: repeat-x;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:11 */
.x-column-header-inner {
    /*
 * TODO:
 * When IE8 retires, revisit https://jsbin.com/honawo/quiet for better way to center header text
 */
    white-space: nowrap;
    position: relative;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:17 */
.x-leaf-column-header {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:19 */
.x-leaf-column-header .x-column-header-text-container {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:26 */
.x-column-header-text-container {
    width: 100%;
    display: table;
    table-layout: fixed;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:31 */
.x-column-header-text-container.x-column-header-text-container-auto {
    table-layout: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:36 */
.x-column-header-text-wrapper {
    display: table-cell;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:41 */
.x-column-header-text {
    display: block;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:50 */
.x-column-header-sort-DESC .x-column-header-text,
.x-column-header-sort-ASC .x-column-header-text {
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:57 */
.x-column-header-text-inner {
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:60 */
.x-column-header-inner-empty .x-column-header-text-inner {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:63 */
.x-column-header-inner-empty .x-column-header-text-container {
    line-height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:76 */
.x-column-header-trigger {
    display: none;
    height: 100%;
    background-repeat: no-repeat;
    position: absolute;
    right: 0;
    top: 0;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:86 */
.x-ie9m .x-column-header-trigger {
    z-index: 6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:101 */
.x-column-header-over .x-column-header-trigger,
.x-column-header-open .x-column-header-trigger {
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:106 */
.x-column-header-align-right {
    text-align: right;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:116 */
.x-column-header-align-left {
    text-align: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Column.scss:126 */
.x-column-header-align-center {
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Action.scss:1 */
.x-grid-cell-inner-action-col {
    line-height: 0;
    font-size: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Action.scss:6 */
.x-keyboard-mode .x-grid-cell-inner-action-col :focus {
    outline: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Action.scss:12 */
.x-action-col-icon {
    display: inline-block;
    line-height: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Check.scss:4 */
.x-column-header-checkbox .x-column-header-text {
    margin-bottom: 0.4em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Check.scss:9 */
.x-column-header-checkbox .x-column-header-inner-empty .x-column-header-text {
    margin-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Check.scss:15 */
.x-grid-checkcolumn-cell-inner {
    line-height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/column/Check.scss:19 */
.x-keyboard-mode .x-grid-checkcolumn-cell-inner :focus {
    outline: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/feature/Grouping.scss:1 */
.x-group-hd-container {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/feature/Grouping.scss:5 */
.x-grid-group-hd {
    white-space: nowrap;
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/feature/Grouping.scss:10 */
.x-grid-group-title {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/feature/Grouping.scss:14 */
.x-grid-group-title:before {
    position: absolute;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/feature/Grouping.scss:29 */
.x-grid-row-body-hidden,
.x-grid-group-collapsed {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/feature/RowBody.scss:1 */
.x-grid-row-body-hidden {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:1 */
.x-menu {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:5 */
.x-menu-body {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:9 */
.x-menu-item {
    white-space: nowrap;
    overflow: hidden;
    border-color: transparent;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:17 */
.x-menu-item-cmp {
    margin: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:20 */
.x-menu-item-cmp .x-field-label-cell {
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:28 */
.x-menu-icon-separator {
    position: absolute;
    top: 0px;
    z-index: 0;
    height: 100%;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:34 */
.x-menu-plain .x-menu-icon-separator {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:39 */
.x-menu-item-link {
    -webkit-tap-highlight-color: transparent;
    -webkit-touch-callout: none;
    text-decoration: none;
    outline: 0;
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:54 */
.x-menu-item-link-href {
    -webkit-touch-callout: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:58 */
.x-menu-item-text {
    display: inline-block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/menu/Menu.scss:62 */
.x-menu-item-icon,
.x-menu-item-icon-right,
.x-menu-item-arrow {
    font-size: 0;
    position: absolute;
    text-align: center;
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:1 */
.x-grid-scroll-container {
    position: absolute;
    z-index: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:7 */
.x-grid-scrollbar-clipper-floated,
.x-grid-scrollbar-floated {
    z-index: 2;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:12 */
.x-grid-scroll-body {
    width: 100%;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:17 */
.x-grid-scrollbar-clipper {
    overflow: hidden;
    position: absolute;
    top: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:23 */
.x-grid-scrollbar-clipper > .x-grid-view,
.x-grid-scrollbar-clipper > .x-tree-view {
    overflow-y: hidden !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:29 */
.x-grid-with-col-lines .x-grid-scrollbar-clipper-locked .x-grid-cell-last {
    border-right-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:43 */
.x-grid-scrollbar {
    position: absolute;
    bottom: 0;
    left: 0;
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:56 */
.x-grid-scrollbar-visible {
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:61 */
.x-grid-locking-body > .x-grid {
    z-index: 2;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:65 */
.x-grid-locking-body > .x-grid .x-docked {
    pointer-events: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:70 */
.x-grid-locking-body .x-grid-body {
    background: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:74 */
.x-grid-locking-body > .x-splitter {
    z-index: 2;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:80 */
.x-grid-locking-body > .x-splitter-active {
    z-index: 4;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:84 */
.x-grid-locking-body > .x-splitter-focus {
    z-index: 4;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:90 */
.x-grid-inner-locked.x-border-region-slide-in {
    z-index: 3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/locking/Lockable.scss:92 */
.x-grid-inner-locked.x-border-region-slide-in > .x-panel-bodyWrap > .x-grid-body > .x-grid-view,
.x-grid-inner-locked.x-border-region-slide-in > .x-panel-bodyWrap > .x-grid-body > .x-tree-view {
    overflow-y: hidden !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/Editing.scss:7 */
.x-grid-editor .x-form-cb-wrap {
    /*
 * Rules for fields which are rendered to fit inside grid cells.
 * This includes cell and row editor fields and fields in widget columns.
 */
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/Editing.scss:12 */
.x-grid-editor .x-form-cb {
    position: static;
    display: inline-block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/Editing.scss:20 */
.x-grid-editor .x-form-display-field {
    margin: 0;
    white-space: nowrap;
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/Editing.scss:28 */
.x-grid-editor div.x-form-action-col-field {
    line-height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/RowEditing.scss:1 */
.x-grid-row-editor-wrap {
    position: absolute;
    overflow: visible;
    z-index: 2;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/RowEditing.scss:8 */
.x-grid-row-editor {
    position: absolute;
    z-index: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/RowEditing.scss:15 */
.x-grid-row-editor-buttons {
    position: absolute;
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/RowExpander.scss:1 */
.x-grid-row-expander {
    font-size: 0;
    line-height: 0;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/RowExpander.scss:8 */
.x-keyboard-mode .x-grid-row-expander:focus {
    outline: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/RowExpander.scss:13 */
.x-grid-hide-row-expander-spacer .x-grid-row-expander-spacer {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/plugin/RowExpander.scss:17 */
.x-grid-row-expander-spacer {
    border: 0 none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/selection/SpreadsheetModel.scss:1 */
.x-ssm-row-numberer-hd {
    cursor: se-resize!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/selection/SpreadsheetModel.scss:6 */
.x-ssm-row-numberer-cell {
    cursor: e-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/selection/SpreadsheetModel.scss:11 */
.x-ssm-column-select .x-column-header {
    cursor: s-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/selection/SpreadsheetModel.scss:16 */
.x-ssm-extender-drag-handle {
    position: absolute;
    z-index: 1;
    cursor: crosshair;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/grid/selection/SpreadsheetModel.scss:22 */
.x-ssm-extender-mask {
    position: absolute;
    z-index: 1;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Absolute.scss:1 */
.x-abs-layout-ct {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Absolute.scss:5 */
.x-abs-layout-item {
    position: absolute !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Border.scss:1 */
.x-border-layout-ct {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Border.scss:5 */
.x-border-layout-ct {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Border.scss:9 */
.x-border-region-slide-in {
    z-index: 6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Border.scss:13 */
.x-region-collapsed-placeholder {
    z-index: 4;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Center.scss:1 */
.x-center-layout-item {
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Center.scss:5 */
.x-center-target {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:1 */
.x-form-layout-wrap {
    display: table;
    width: 100%;
    border-collapse: separate;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:7 */
.x-form-layout-colgroup {
    display: table-column-group;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:11 */
.x-form-layout-column {
    display: table-column;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:16 */
.x-form-layout-auto-label > * > .x-form-item-label {
    width: auto !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:20 */
.x-form-layout-auto-label > * > .x-form-item-label > .x-form-item-label-inner {
    width: auto !important;
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:26 */
.x-form-layout-auto-label > * > .x-form-layout-label-column {
    width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:33 */
.x-form-layout-sized-label > * > .x-form-item-label {
    width: auto !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:40 */
.x-form-form-item {
    display: table-row;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:43 */
.x-form-form-item > .x-form-item-label {
    padding-left: 0 !important;
    padding-right: 0 !important;
    padding-bottom: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:51 */
.x-form-form-item > .x-form-item-body {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/layout/container/Form.scss:60 */
.x-form-form-item.x-form-item-no-label:before {
    content: ' ';
    display: table-cell;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/resizer/Resizer.scss:2 */
.x-resizable-wrapped {
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -ms-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/slider/Multi.scss:1 */
.x-slider {
    outline: none;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/slider/Multi.scss:6 */
.x-slider-inner {
    position: relative;
    left: 0;
    top: 0;
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/slider/Multi.scss:11 */
.x-slider-vert .x-slider-inner {
    background: repeat-y 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/slider/Multi.scss:16 */
.x-slider-thumb {
    position: absolute;
    background: no-repeat 0 0;
    cursor: default;
    -webkit-user-callout: none;
    display: table;
    table-layout: fixed;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/slider/Multi.scss:19 */
.x-slider-horz .x-slider-thumb {
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/slider/Multi.scss:22 */
.x-slider-vert .x-slider-thumb {
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/slider/Multi.scss:35 */
.x-slider-thumb:before {
    display: table-cell;
    vertical-align: middle;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:21 */
.x-tab {
    display: block;
    outline: 0;
    cursor: pointer;
    white-space: nowrap;
    text-decoration: none;
    vertical-align: top;
    overflow: hidden;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:33 */
.x-tab > .x-frame {
    height: 100%;
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:39 */
.x-tab-wrap {
    height: 100%;
    width: 100%;
    display: table;
    border-spacing: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:64 */
.x-tab-button {
    white-space: nowrap;
    line-height: 0;
    position: relative;
    display: table-cell;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:103 */
.x-tab-inner {
    overflow: hidden;
    text-overflow: ellipsis;
    display: inline-block;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:122 */
.x-tab-icon.x-tab-no-text > .x-tab-inner {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:127 */
.x-tab-icon-el {
    display: none;
    vertical-align: middle;
    text-align: center;
    background-position: center center;
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:148 */
.x-tab-icon > .x-tab-icon-el {
    display: inline-block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:152 */
.x-tab-icon-top > .x-tab-icon-el,
.x-tab-icon-bottom > .x-tab-icon-el {
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:161 */
.x-ie9m .x-tab-button-center {
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:169 */
.x-tab-button-center.x-tab-icon-top,
.x-tab-button-center.x-tab-icon-bottom {
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:175 */
.x-tab-button-left {
    text-align: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:188 */
.x-tab-button-right {
    text-align: right;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/var/button/Button.scss:297 */
.x-tab-mc {
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Tab.scss:13 */
.x-tab {
    z-index: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Tab.scss:17 */
.x-tab-active {
    z-index: 3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Tab.scss:21 */
.x-tab-button {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Tab.scss:27 */
.x-tab-close-btn {
    display: block;
    position: absolute;
    overflow: hidden;
    font-size: 0;
    line-height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Tab.scss:35 */
.x-tab-rotate-left {
    -webkit-transform: rotate(270deg);
    -webkit-transform-origin: 100% 0;
    -moz-transform: rotate(270deg);
    -moz-transform-origin: 100% 0;
    -ms-transform: rotate(270deg);
    -ms-transform-origin: 100% 0;
    transform: rotate(270deg);
    transform-origin: 100% 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/rotate-element.scss:41 */
.x-ie8 .x-tab-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Tab.scss:45 */
.x-tab-rotate-right {
    -webkit-transform: rotate(90deg);
    -webkit-transform-origin: 0 0;
    -moz-transform: rotate(90deg);
    -moz-transform-origin: 0 0;
    -ms-transform: rotate(90deg);
    -ms-transform-origin: 0 0;
    transform: rotate(90deg);
    transform-origin: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/rotate-element.scss:41 */
.x-ie8 .x-tab-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Tab.scss:57 */
.x-tab-tr,
.x-tab-br,
.x-tab-mr,
.x-tab-tl,
.x-tab-bl,
.x-tab-ml {
    width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:1 */
.x-tab-bar {
    z-index: 0;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:6 */
.x-tab-bar-strip {
    position: absolute;
    line-height: 0;
    font-size: 0;
    z-index: 2;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:12 */
.x-tab-bar-top > .x-tab-bar-strip {
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:16 */
.x-tab-bar-bottom > .x-tab-bar-strip {
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:20 */
.x-tab-bar-left > .x-tab-bar-strip {
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:31 */
.x-tab-bar-right > .x-tab-bar-strip {
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:43 */
.x-tab-bar-horizontal .x-tab-bar-strip {
    width: 100%;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:48 */
.x-tab-bar-vertical {
    display: table-cell;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:54 */
.x-tab-bar-vertical .x-tab-bar-strip {
    height: 100%;
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:60 */
.x-tab-bar-plain {
    background: transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tab/Bar.scss:64 */
.x-box-scroller-plain {
    background-color: transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/toolbar/Breadcrumb.scss:1 */
.x-breadcrumb-btn .x-box-target:first-child {
    margin: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/toolbar/Breadcrumb.scss:7 */
.x-breadcrumb-btn > .x-btn-split-right > .x-btn-button:after {
    content: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/toolbar/Breadcrumb.scss:12 */
.x-breadcrumb-btn.x-btn-over > .x-btn-split-right > .x-btn-button:after,
.x-breadcrumb-btn.x-btn-menu-active > .x-btn-split-right > .x-btn-button:after {
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tree/View.scss:4 */
.x-autowidth-table .x-grid-item-container {
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tree/View.scss:8 */
.x-autowidth-table .x-grid-item {
    table-layout: auto;
    width: auto !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tree/View.scss:14 */
.x-tree-view {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tree/View.scss:18 */
.x-tree-elbow-img,
.x-tree-icon {
    display: inline-block;
    text-align: center;
    background-repeat: no-repeat;
    background-position: 0 center;
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tree/View.scss:27 */
.x-tree-checkbox {
    display: inline-block;
    vertical-align: top;
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/src/tree/View.scss:33 */
.x-tree-animator-wrap {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/Component.scss:1 */
.x-body {
    color: black;
    font-size: 14px;
    line-height: 24px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    background: #f6f6f6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/Component.scss:18 */
.x-animating-size,
.x-collapsed {
    overflow: hidden!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/Component.scss:25 */
.x-animating-size {
    z-index: 10000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/Editor.scss:2 */
.x-editor .x-form-item-body {
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/LoadMask.scss:1 */
.x-mask {
    background-image: none;
    background-color: rgba(208, 208, 208, 0.5);
    cursor: default;
    border-style: solid;
    border-width: 1px;
    border-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/background-opacity.scss:19 */
.x-ie8 .x-mask {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#80d0d0d0, endColorstr=#80d0d0d0)";
    zoom: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/LoadMask.scss:16 */
body > .x-mask {
    background-image: none;
    background-color: rgba(0, 0, 0, 0.55);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/background-opacity.scss:19 */
.x-ie8 body > .x-mask {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#8c000000, endColorstr=#8c000000)";
    zoom: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/LoadMask.scss:23 */
.x-keyboard-mode .x-mask.x-focus {
    border-style: solid;
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/LoadMask.scss:31 */
.x-mask-msg {
    padding: 10px;
    background: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/LoadMask.scss:49 */
.x-mask-msg-inner {
    padding: 0;
    background-color: transparent;
    color: #000;
    font: 400 14px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/LoadMask.scss:61 */
.x-mask-msg-text {
    padding: 25px 0 0;
    background-image: url(images/loadmask/loading.gif);
    background-repeat: no-repeat;
    background-position: center 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/ProgressBar.scss:219 */
.x-progress-default {
    background-color: #ececec;
    border-width: 0;
    height: 24px;
    border-color: #00adee;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/ProgressBar.scss:234 */
.x-progress-default .x-progress-bar-default {
    background-image: none;
    background-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/ProgressBar.scss:249 */
.x-progress-default .x-progress-text {
    color: #fff;
    font-weight: 400;
    font-size: 14px;
    font-family: Open Sans, sans-serif;
    text-align: center;
    line-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/ProgressBar.scss:258 */
.x-progress-default .x-progress-text-back {
    color: #000;
    line-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-keyboard-mode .x-progress-default.x-progress-focus:after {
    position: absolute;
    content: ' ';
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    border: 0 solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/ProgressBar.scss:285 */
.x-progressbar-default-cell > .x-grid-cell-inner,
.x-progress-default-cell > .x-grid-cell-inner,
.x-progressbarwidget-default-cell > .x-grid-cell-inner {
    padding-top: 5px;
    padding-bottom: 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/ProgressBar.scss:288 */
.x-progressbar-default-cell > .x-grid-cell-inner .x-progress-default,
.x-progress-default-cell > .x-grid-cell-inner .x-progress-default,
.x-progressbarwidget-default-cell > .x-grid-cell-inner .x-progress-default {
    height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-default-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-default-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-default-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-default-small-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-default-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-default-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-default-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-default-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-default-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-default-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-default-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-default-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-default-small-tr,
.x-btn-default-small-br,
.x-btn-default-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-default-small-tl,
.x-btn-default-small-bl,
.x-btn-default-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-default-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-default-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-default-small-tl,
.x-btn-default-small-bl,
.x-btn-default-small-tr,
.x-btn-default-small-br,
.x-btn-default-small-tc,
.x-btn-default-small-bc,
.x-btn-default-small-ml,
.x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-default-small-ml,
.x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-default-small-mc {
    padding: 5px 5px 5px 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-default-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-default-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-default-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-default-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-default-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-default-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-default-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-default-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-default-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-default-small {
    font-size: 16px;
    height: 16px;
    color: #000;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-default-small,
.x-btn-icon-right > .x-btn-icon-el-default-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-default-small,
.x-btn-icon-bottom > .x-btn-icon-el-default-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-default-small.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-default-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-default-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-default-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-default-small,
.x-btn-split-bottom > .x-btn-button-default-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-default-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-default-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-default-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-default-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-default-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-default-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-default-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-default-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-default-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-default-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-default-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-default-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-default-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-default-small,
.x-btn.x-btn-pressed.x-btn-default-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-default-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-default-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-default-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-default-small {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-default-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-default-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-default-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-default-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-default-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-default-small-bc {
    background-image: url(images/btn/btn-default-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-default-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-default-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-default-small-tl,
.x-btn-over .x-btn-default-small-bl,
.x-btn-over .x-btn-default-small-tr,
.x-btn-over .x-btn-default-small-br,
.x-btn-over .x-btn-default-small-tc,
.x-btn-over .x-btn-default-small-bc {
    background-image: url(images/btn/btn-default-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-default-small-ml,
.x-btn-over .x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-default-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-bc {
    background-image: url(images/btn/btn-default-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-default-small-tl,
.x-btn.x-btn-menu-active .x-btn-default-small-bl,
.x-btn.x-btn-menu-active .x-btn-default-small-tr,
.x-btn.x-btn-menu-active .x-btn-default-small-br,
.x-btn.x-btn-menu-active .x-btn-default-small-tc,
.x-btn.x-btn-menu-active .x-btn-default-small-bc,
.x-btn.x-btn-pressed .x-btn-default-small-tl,
.x-btn.x-btn-pressed .x-btn-default-small-bl,
.x-btn.x-btn-pressed .x-btn-default-small-tr,
.x-btn.x-btn-pressed .x-btn-default-small-br,
.x-btn.x-btn-pressed .x-btn-default-small-tc,
.x-btn.x-btn-pressed .x-btn-default-small-bc {
    background-image: url(images/btn/btn-default-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-default-small-ml,
.x-btn.x-btn-menu-active .x-btn-default-small-mr,
.x-btn.x-btn-pressed .x-btn-default-small-ml,
.x-btn.x-btn-pressed .x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-default-small-mc,
.x-btn.x-btn-pressed .x-btn-default-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-bc {
    background-image: url(images/btn/btn-default-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-default-small-tl,
.x-btn.x-btn-disabled .x-btn-default-small-bl,
.x-btn.x-btn-disabled .x-btn-default-small-tr,
.x-btn.x-btn-disabled .x-btn-default-small-br,
.x-btn.x-btn-disabled .x-btn-default-small-tc,
.x-btn.x-btn-disabled .x-btn-default-small-bc {
    background-image: url(images/btn/btn-default-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-default-small-ml,
.x-btn.x-btn-disabled .x-btn-default-small-mr {
    background-image: url(images/btn/btn-default-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-default-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-default-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-default-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small.x-segmented-button-first .x-btn-default-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small.x-segmented-button-middle .x-btn-default-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small.x-segmented-button-last .x-btn-default-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small.x-segmented-button-first .x-btn-default-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small.x-segmented-button-middle .x-btn-default-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small.x-segmented-button-last .x-btn-default-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-default-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-small.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-small.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-default-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-default-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-default-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-default-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-default-small-cell > .x-grid-cell-inner {
    padding-top: 1px;
    padding-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-default-small-cell > .x-grid-cell-inner >.x-btn-default-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-default-medium {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 8px 8px 8px 8px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-default-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-default-medium {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-default-medium-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-8-8-8-8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-default-medium-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-default-medium-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-default-medium-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-default-medium-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-default-medium-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-default-medium-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-default-medium-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-default-medium-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-default-medium-tr,
.x-btn-default-medium-br,
.x-btn-default-medium-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-default-medium-tl,
.x-btn-default-medium-bl,
.x-btn-default-medium-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-default-medium-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-default-medium-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-default-medium-tl,
.x-btn-default-medium-bl,
.x-btn-default-medium-tr,
.x-btn-default-medium-br,
.x-btn-default-medium-tc,
.x-btn-default-medium-bc,
.x-btn-default-medium-ml,
.x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-default-medium-ml,
.x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-default-medium-mc {
    padding: 6px 6px 6px 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-default-medium {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-default-medium {
    min-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-default-medium {
    min-height: auto;
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-default-medium {
    font: 400 14px/18px Open Sans, sans-serif;
    color: #000;
    padding: 0 8px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-default-medium,
.x-ie9 .x-btn-icon-left > .x-btn-inner-default-medium {
    max-width: calc(100% - 20px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-default-medium,
.x-safari8m .x-btn-icon-left > .x-btn-inner-default-medium {
    max-width: calc(100% - 19px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-default-medium {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-default-medium {
    font-size: 20px;
    height: 20px;
    color: #000;
    line-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-default-medium,
.x-btn-icon-right > .x-btn-icon-el-default-medium {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-default-medium,
.x-btn-icon-bottom > .x-btn-icon-el-default-medium {
    min-width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-default-medium.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-default-medium {
    margin-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-medium {
    margin-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-default-medium {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-default-medium {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-medium {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-medium {
    margin-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-default-medium,
.x-btn-split-bottom > .x-btn-button-default-medium {
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-default-medium.x-btn-arrow-right:after {
    width: 20px;
    content: "\f0d7";
    font: 20px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-default-medium.x-btn-arrow-bottom:after {
    height: 14px;
    content: "\f0d7";
    font: 20px/14px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-default-medium.x-btn-split-right > .x-btn-button {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-default-medium.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-default-medium.x-btn-split-right:after {
    width: 26px;
    content: "\f0d7";
    font: 20px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-default-medium.x-btn-split-bottom {
    margin-bottom: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-default-medium.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-default-medium.x-btn-split-bottom:after {
    height: 24px;
    content: "\f0d7";
    font: 20px/24px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-medium {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-medium {
    margin-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-default-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-default-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-default-medium .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 34px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-default-medium.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-default-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-default-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-default-medium {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-default-medium,
.x-btn.x-btn-pressed.x-btn-default-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-default-medium .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-default-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-default-medium,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-default-medium {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-default-medium {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-tl,
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-bl,
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-tr,
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-br,
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-tc,
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-bc {
    background-image: url(images/btn/btn-default-medium-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-ml,
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-default-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-default-medium-tl,
.x-btn-over .x-btn-default-medium-bl,
.x-btn-over .x-btn-default-medium-tr,
.x-btn-over .x-btn-default-medium-br,
.x-btn-over .x-btn-default-medium-tc,
.x-btn-over .x-btn-default-medium-bc {
    background-image: url(images/btn/btn-default-medium-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-default-medium-ml,
.x-btn-over .x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-default-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-bc {
    background-image: url(images/btn/btn-default-medium-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-default-medium-tl,
.x-btn.x-btn-menu-active .x-btn-default-medium-bl,
.x-btn.x-btn-menu-active .x-btn-default-medium-tr,
.x-btn.x-btn-menu-active .x-btn-default-medium-br,
.x-btn.x-btn-menu-active .x-btn-default-medium-tc,
.x-btn.x-btn-menu-active .x-btn-default-medium-bc,
.x-btn.x-btn-pressed .x-btn-default-medium-tl,
.x-btn.x-btn-pressed .x-btn-default-medium-bl,
.x-btn.x-btn-pressed .x-btn-default-medium-tr,
.x-btn.x-btn-pressed .x-btn-default-medium-br,
.x-btn.x-btn-pressed .x-btn-default-medium-tc,
.x-btn.x-btn-pressed .x-btn-default-medium-bc {
    background-image: url(images/btn/btn-default-medium-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-default-medium-ml,
.x-btn.x-btn-menu-active .x-btn-default-medium-mr,
.x-btn.x-btn-pressed .x-btn-default-medium-ml,
.x-btn.x-btn-pressed .x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-default-medium-mc,
.x-btn.x-btn-pressed .x-btn-default-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-bc {
    background-image: url(images/btn/btn-default-medium-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-medium-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-default-medium-tl,
.x-btn.x-btn-disabled .x-btn-default-medium-bl,
.x-btn.x-btn-disabled .x-btn-default-medium-tr,
.x-btn.x-btn-disabled .x-btn-default-medium-br,
.x-btn.x-btn-disabled .x-btn-default-medium-tc,
.x-btn.x-btn-disabled .x-btn-default-medium-bc {
    background-image: url(images/btn/btn-default-medium-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-default-medium-ml,
.x-btn.x-btn-disabled .x-btn-default-medium-mr {
    background-image: url(images/btn/btn-default-medium-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-default-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-default-medium {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-default-medium {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium.x-segmented-button-first .x-btn-default-medium-mc {
    padding-right: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium.x-segmented-button-middle .x-btn-default-medium-mc {
    padding-right: 8px !important;
    padding-left: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium.x-segmented-button-last .x-btn-default-medium-mc {
    padding-left: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium.x-segmented-button-first .x-btn-default-medium-mc {
    padding-bottom: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium.x-segmented-button-middle .x-btn-default-medium-mc {
    padding-top: 8px !important;
    padding-bottom: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium.x-segmented-button-last .x-btn-default-medium-mc {
    padding-top: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-default-medium:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-medium.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-medium.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-default-medium:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-default-medium:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-default-medium:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-default-medium:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-default-medium-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-default-medium-cell > .x-grid-cell-inner >.x-btn-default-medium {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-default-large {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 9px 9px 9px 9px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-default-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-default-large {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-default-large-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-9-9-9-9;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-default-large-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-default-large-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-default-large-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-default-large-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-default-large-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-default-large-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-default-large-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-default-large-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-default-large-tr,
.x-btn-default-large-br,
.x-btn-default-large-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-default-large-tl,
.x-btn-default-large-bl,
.x-btn-default-large-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-default-large-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-default-large-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-default-large-tl,
.x-btn-default-large-bl,
.x-btn-default-large-tr,
.x-btn-default-large-br,
.x-btn-default-large-tc,
.x-btn-default-large-bc,
.x-btn-default-large-ml,
.x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-default-large-ml,
.x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-default-large-mc {
    padding: 7px 7px 7px 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-default-large {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-default-large {
    min-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-default-large {
    min-height: auto;
    height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-default-large {
    font: 400 16px/20px Open Sans, sans-serif;
    color: #000;
    padding: 0 10px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-default-large,
.x-ie9 .x-btn-icon-left > .x-btn-inner-default-large {
    max-width: calc(100% - 24px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-default-large,
.x-safari8m .x-btn-icon-left > .x-btn-inner-default-large {
    max-width: calc(100% - 23px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-default-large {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-default-large {
    font-size: 24px;
    height: 24px;
    color: #000;
    line-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-default-large,
.x-btn-icon-right > .x-btn-icon-el-default-large {
    width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-default-large,
.x-btn-icon-bottom > .x-btn-icon-el-default-large {
    min-width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-default-large.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-default-large {
    margin-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-large {
    margin-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-default-large {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-default-large {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-large {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-large {
    margin-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-default-large,
.x-btn-split-bottom > .x-btn-button-default-large {
    padding-bottom: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-default-large.x-btn-arrow-right:after {
    width: 22px;
    content: "\f0d7";
    font: 24px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-default-large.x-btn-arrow-bottom:after {
    height: 16px;
    content: "\f0d7";
    font: 24px/16px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-default-large.x-btn-split-right > .x-btn-button {
    padding-right: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-default-large.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-default-large.x-btn-split-right:after {
    width: 32px;
    content: "\f0d7";
    font: 24px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-default-large.x-btn-split-bottom {
    margin-bottom: -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-default-large.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-default-large.x-btn-split-bottom:after {
    height: 28px;
    content: "\f0d7";
    font: 24px/28px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-large {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-large {
    margin-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-default-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-default-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-default-large .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 41px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-default-large.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-default-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-default-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-default-large {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-default-large,
.x-btn.x-btn-pressed.x-btn-default-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-default-large .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-default-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-default-large,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-default-large {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-default-large {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-default-large-tl,
.x-keyboard-mode .x-btn-focus .x-btn-default-large-bl,
.x-keyboard-mode .x-btn-focus .x-btn-default-large-tr,
.x-keyboard-mode .x-btn-focus .x-btn-default-large-br,
.x-keyboard-mode .x-btn-focus .x-btn-default-large-tc,
.x-keyboard-mode .x-btn-focus .x-btn-default-large-bc {
    background-image: url(images/btn/btn-default-large-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-default-large-ml,
.x-keyboard-mode .x-btn-focus .x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-default-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-default-large-tl,
.x-btn-over .x-btn-default-large-bl,
.x-btn-over .x-btn-default-large-tr,
.x-btn-over .x-btn-default-large-br,
.x-btn-over .x-btn-default-large-tc,
.x-btn-over .x-btn-default-large-bc {
    background-image: url(images/btn/btn-default-large-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-default-large-ml,
.x-btn-over .x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-default-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-bc {
    background-image: url(images/btn/btn-default-large-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-default-large-tl,
.x-btn.x-btn-menu-active .x-btn-default-large-bl,
.x-btn.x-btn-menu-active .x-btn-default-large-tr,
.x-btn.x-btn-menu-active .x-btn-default-large-br,
.x-btn.x-btn-menu-active .x-btn-default-large-tc,
.x-btn.x-btn-menu-active .x-btn-default-large-bc,
.x-btn.x-btn-pressed .x-btn-default-large-tl,
.x-btn.x-btn-pressed .x-btn-default-large-bl,
.x-btn.x-btn-pressed .x-btn-default-large-tr,
.x-btn.x-btn-pressed .x-btn-default-large-br,
.x-btn.x-btn-pressed .x-btn-default-large-tc,
.x-btn.x-btn-pressed .x-btn-default-large-bc {
    background-image: url(images/btn/btn-default-large-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-default-large-ml,
.x-btn.x-btn-menu-active .x-btn-default-large-mr,
.x-btn.x-btn-pressed .x-btn-default-large-ml,
.x-btn.x-btn-pressed .x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-default-large-mc,
.x-btn.x-btn-pressed .x-btn-default-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-bc {
    background-image: url(images/btn/btn-default-large-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-large-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-default-large-tl,
.x-btn.x-btn-disabled .x-btn-default-large-bl,
.x-btn.x-btn-disabled .x-btn-default-large-tr,
.x-btn.x-btn-disabled .x-btn-default-large-br,
.x-btn.x-btn-disabled .x-btn-default-large-tc,
.x-btn.x-btn-disabled .x-btn-default-large-bc {
    background-image: url(images/btn/btn-default-large-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-default-large-ml,
.x-btn.x-btn-disabled .x-btn-default-large-mr {
    background-image: url(images/btn/btn-default-large-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-default-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-default-large {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-default-large {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large.x-segmented-button-first .x-btn-default-large-mc {
    padding-right: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large.x-segmented-button-middle .x-btn-default-large-mc {
    padding-right: 9px !important;
    padding-left: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large.x-segmented-button-last .x-btn-default-large-mc {
    padding-left: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large.x-segmented-button-first .x-btn-default-large-mc {
    padding-bottom: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large.x-segmented-button-middle .x-btn-default-large-mc {
    padding-top: 9px !important;
    padding-bottom: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large.x-segmented-button-last .x-btn-default-large-mc {
    padding-top: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-default-large:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-large.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-large.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-default-large:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-default-large:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-default-large:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-default-large:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-default-large-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-default-large-cell > .x-grid-cell-inner >.x-btn-default-large {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-default-toolbar-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-default-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-default-toolbar-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-default-toolbar-small-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-default-toolbar-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-default-toolbar-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-default-toolbar-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-default-toolbar-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-default-toolbar-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-default-toolbar-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-default-toolbar-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-default-toolbar-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-default-toolbar-small-tr,
.x-btn-default-toolbar-small-br,
.x-btn-default-toolbar-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-default-toolbar-small-tl,
.x-btn-default-toolbar-small-bl,
.x-btn-default-toolbar-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-default-toolbar-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-default-toolbar-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-default-toolbar-small-tl,
.x-btn-default-toolbar-small-bl,
.x-btn-default-toolbar-small-tr,
.x-btn-default-toolbar-small-br,
.x-btn-default-toolbar-small-tc,
.x-btn-default-toolbar-small-bc,
.x-btn-default-toolbar-small-ml,
.x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-default-toolbar-small-ml,
.x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-default-toolbar-small-mc {
    padding: 5px 5px 5px 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-default-toolbar-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-default-toolbar-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-default-toolbar-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-default-toolbar-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-default-toolbar-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-default-toolbar-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-default-toolbar-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-default-toolbar-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-default-toolbar-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-default-toolbar-small {
    font-size: 16px;
    height: 16px;
    color: #919191;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-default-toolbar-small,
.x-btn-icon-right > .x-btn-icon-el-default-toolbar-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-default-toolbar-small,
.x-btn-icon-bottom > .x-btn-icon-el-default-toolbar-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-default-toolbar-small.x-btn-glyph {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-default-toolbar-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-default-toolbar-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-default-toolbar-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-toolbar-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-default-toolbar-small,
.x-btn-split-bottom > .x-btn-button-default-toolbar-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-default-toolbar-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-default-toolbar-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-default-toolbar-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-default-toolbar-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-default-toolbar-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-toolbar-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-default-toolbar-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-default-toolbar-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-default-toolbar-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-default-toolbar-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-default-toolbar-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-default-toolbar-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-default-toolbar-small {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-default-toolbar-small,
.x-btn.x-btn-pressed.x-btn-default-toolbar-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-default-toolbar-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-default-toolbar-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-default-toolbar-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-default-toolbar-small {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-default-toolbar-small {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-bc {
    background-image: url(images/btn/btn-default-toolbar-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-default-toolbar-small-tl,
.x-btn-over .x-btn-default-toolbar-small-bl,
.x-btn-over .x-btn-default-toolbar-small-tr,
.x-btn-over .x-btn-default-toolbar-small-br,
.x-btn-over .x-btn-default-toolbar-small-tc,
.x-btn-over .x-btn-default-toolbar-small-bc {
    background-image: url(images/btn/btn-default-toolbar-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-default-toolbar-small-ml,
.x-btn-over .x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-default-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-bc {
    background-image: url(images/btn/btn-default-toolbar-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-tl,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-bl,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-tr,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-br,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-tc,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-bc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-tl,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-bl,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-tr,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-br,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-tc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-bc {
    background-image: url(images/btn/btn-default-toolbar-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-ml,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-mr,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-ml,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-small-mc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-bc {
    background-image: url(images/btn/btn-default-toolbar-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-tl,
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-bl,
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-tr,
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-br,
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-tc,
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-bc {
    background-image: url(images/btn/btn-default-toolbar-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-ml,
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-mr {
    background-image: url(images/btn/btn-default-toolbar-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-default-toolbar-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-default-toolbar-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small.x-segmented-button-first .x-btn-default-toolbar-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small.x-segmented-button-middle .x-btn-default-toolbar-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small.x-segmented-button-last .x-btn-default-toolbar-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small.x-segmented-button-first .x-btn-default-toolbar-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small.x-segmented-button-middle .x-btn-default-toolbar-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small.x-segmented-button-last .x-btn-default-toolbar-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-default-toolbar-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-small.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-small.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-default-toolbar-small:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-default-toolbar-small:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-default-toolbar-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-default-toolbar-small:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-default-toolbar-small-cell > .x-grid-cell-inner {
    padding-top: 1px;
    padding-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-default-toolbar-small-cell > .x-grid-cell-inner >.x-btn-default-toolbar-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-default-toolbar-medium {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 8px 8px 8px 8px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-default-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-default-toolbar-medium {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-default-toolbar-medium-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-8-8-8-8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-default-toolbar-medium-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-default-toolbar-medium-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-default-toolbar-medium-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-default-toolbar-medium-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-default-toolbar-medium-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-default-toolbar-medium-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-default-toolbar-medium-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-default-toolbar-medium-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-default-toolbar-medium-tr,
.x-btn-default-toolbar-medium-br,
.x-btn-default-toolbar-medium-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-default-toolbar-medium-tl,
.x-btn-default-toolbar-medium-bl,
.x-btn-default-toolbar-medium-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-default-toolbar-medium-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-default-toolbar-medium-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-default-toolbar-medium-tl,
.x-btn-default-toolbar-medium-bl,
.x-btn-default-toolbar-medium-tr,
.x-btn-default-toolbar-medium-br,
.x-btn-default-toolbar-medium-tc,
.x-btn-default-toolbar-medium-bc,
.x-btn-default-toolbar-medium-ml,
.x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-default-toolbar-medium-ml,
.x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-default-toolbar-medium-mc {
    padding: 6px 6px 6px 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-default-toolbar-medium {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-default-toolbar-medium {
    min-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-default-toolbar-medium {
    min-height: auto;
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-default-toolbar-medium {
    font: 400 14px/18px Open Sans, sans-serif;
    color: #000;
    padding: 0 8px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-default-toolbar-medium,
.x-ie9 .x-btn-icon-left > .x-btn-inner-default-toolbar-medium {
    max-width: calc(100% - 20px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-default-toolbar-medium,
.x-safari8m .x-btn-icon-left > .x-btn-inner-default-toolbar-medium {
    max-width: calc(100% - 19px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-default-toolbar-medium {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-default-toolbar-medium {
    font-size: 20px;
    height: 20px;
    color: #919191;
    line-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-default-toolbar-medium,
.x-btn-icon-right > .x-btn-icon-el-default-toolbar-medium {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-default-toolbar-medium,
.x-btn-icon-bottom > .x-btn-icon-el-default-toolbar-medium {
    min-width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-default-toolbar-medium.x-btn-glyph {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-default-toolbar-medium {
    margin-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-medium {
    margin-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-default-toolbar-medium {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-default-toolbar-medium {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-toolbar-medium {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-medium {
    margin-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-default-toolbar-medium,
.x-btn-split-bottom > .x-btn-button-default-toolbar-medium {
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-default-toolbar-medium.x-btn-arrow-right:after {
    width: 20px;
    content: "\f0d7";
    font: 20px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-default-toolbar-medium.x-btn-arrow-bottom:after {
    height: 14px;
    content: "\f0d7";
    font: 20px/14px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-default-toolbar-medium.x-btn-split-right > .x-btn-button {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-default-toolbar-medium.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-default-toolbar-medium.x-btn-split-right:after {
    width: 26px;
    content: "\f0d7";
    font: 20px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-default-toolbar-medium.x-btn-split-bottom {
    margin-bottom: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-default-toolbar-medium.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-default-toolbar-medium.x-btn-split-bottom:after {
    height: 24px;
    content: "\f0d7";
    font: 20px/24px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-toolbar-medium {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-medium {
    margin-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-default-toolbar-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-default-toolbar-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-default-toolbar-medium .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 34px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-default-toolbar-medium.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-default-toolbar-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-default-toolbar-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-default-toolbar-medium {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-default-toolbar-medium,
.x-btn.x-btn-pressed.x-btn-default-toolbar-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-default-toolbar-medium .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-default-toolbar-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-default-toolbar-medium,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-default-toolbar-medium {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-default-toolbar-medium {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-bc {
    background-image: url(images/btn/btn-default-toolbar-medium-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-default-toolbar-medium-tl,
.x-btn-over .x-btn-default-toolbar-medium-bl,
.x-btn-over .x-btn-default-toolbar-medium-tr,
.x-btn-over .x-btn-default-toolbar-medium-br,
.x-btn-over .x-btn-default-toolbar-medium-tc,
.x-btn-over .x-btn-default-toolbar-medium-bc {
    background-image: url(images/btn/btn-default-toolbar-medium-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-default-toolbar-medium-ml,
.x-btn-over .x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-default-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-bc {
    background-image: url(images/btn/btn-default-toolbar-medium-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-tl,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-bl,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-tr,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-br,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-tc,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-bc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-tl,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-bl,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-tr,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-br,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-tc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-bc {
    background-image: url(images/btn/btn-default-toolbar-medium-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-ml,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-mr,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-ml,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-medium-mc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-bc {
    background-image: url(images/btn/btn-default-toolbar-medium-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-medium-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-tl,
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-bl,
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-tr,
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-br,
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-tc,
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-bc {
    background-image: url(images/btn/btn-default-toolbar-medium-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-ml,
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-mr {
    background-image: url(images/btn/btn-default-toolbar-medium-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-default-toolbar-medium {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-default-toolbar-medium {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium.x-segmented-button-first .x-btn-default-toolbar-medium-mc {
    padding-right: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium.x-segmented-button-middle .x-btn-default-toolbar-medium-mc {
    padding-right: 8px !important;
    padding-left: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium.x-segmented-button-last .x-btn-default-toolbar-medium-mc {
    padding-left: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium.x-segmented-button-first .x-btn-default-toolbar-medium-mc {
    padding-bottom: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium.x-segmented-button-middle .x-btn-default-toolbar-medium-mc {
    padding-top: 8px !important;
    padding-bottom: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium.x-segmented-button-last .x-btn-default-toolbar-medium-mc {
    padding-top: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-default-toolbar-medium:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-medium.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-medium.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-default-toolbar-medium:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-default-toolbar-medium:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-default-toolbar-medium:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-default-toolbar-medium:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-default-toolbar-medium-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-default-toolbar-medium-cell > .x-grid-cell-inner >.x-btn-default-toolbar-medium {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-default-toolbar-large {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 9px 9px 9px 9px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-default-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-default-toolbar-large {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-default-toolbar-large-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-9-9-9-9;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-default-toolbar-large-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-default-toolbar-large-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-default-toolbar-large-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-default-toolbar-large-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-default-toolbar-large-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-default-toolbar-large-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-default-toolbar-large-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-default-toolbar-large-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-default-toolbar-large-tr,
.x-btn-default-toolbar-large-br,
.x-btn-default-toolbar-large-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-default-toolbar-large-tl,
.x-btn-default-toolbar-large-bl,
.x-btn-default-toolbar-large-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-default-toolbar-large-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-default-toolbar-large-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-default-toolbar-large-tl,
.x-btn-default-toolbar-large-bl,
.x-btn-default-toolbar-large-tr,
.x-btn-default-toolbar-large-br,
.x-btn-default-toolbar-large-tc,
.x-btn-default-toolbar-large-bc,
.x-btn-default-toolbar-large-ml,
.x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-default-toolbar-large-ml,
.x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-default-toolbar-large-mc {
    padding: 7px 7px 7px 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-default-toolbar-large {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-default-toolbar-large {
    min-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-default-toolbar-large {
    min-height: auto;
    height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-default-toolbar-large {
    font: 400 16px/20px Open Sans, sans-serif;
    color: #000;
    padding: 0 10px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-default-toolbar-large,
.x-ie9 .x-btn-icon-left > .x-btn-inner-default-toolbar-large {
    max-width: calc(100% - 24px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-default-toolbar-large,
.x-safari8m .x-btn-icon-left > .x-btn-inner-default-toolbar-large {
    max-width: calc(100% - 23px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-default-toolbar-large {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-default-toolbar-large {
    font-size: 24px;
    height: 24px;
    color: #919191;
    line-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-default-toolbar-large,
.x-btn-icon-right > .x-btn-icon-el-default-toolbar-large {
    width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-default-toolbar-large,
.x-btn-icon-bottom > .x-btn-icon-el-default-toolbar-large {
    min-width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-default-toolbar-large.x-btn-glyph {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-default-toolbar-large {
    margin-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-large {
    margin-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-default-toolbar-large {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-default-toolbar-large {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-toolbar-large {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-large {
    margin-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-default-toolbar-large,
.x-btn-split-bottom > .x-btn-button-default-toolbar-large {
    padding-bottom: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-default-toolbar-large.x-btn-arrow-right:after {
    width: 22px;
    content: "\f0d7";
    font: 24px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-default-toolbar-large.x-btn-arrow-bottom:after {
    height: 16px;
    content: "\f0d7";
    font: 24px/16px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-default-toolbar-large.x-btn-split-right > .x-btn-button {
    padding-right: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-default-toolbar-large.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-default-toolbar-large.x-btn-split-right:after {
    width: 32px;
    content: "\f0d7";
    font: 24px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-default-toolbar-large.x-btn-split-bottom {
    margin-bottom: -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-default-toolbar-large.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-default-toolbar-large.x-btn-split-bottom:after {
    height: 28px;
    content: "\f0d7";
    font: 24px/28px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-default-toolbar-large {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-default-toolbar-large {
    margin-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-default-toolbar-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-default-toolbar-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-default-toolbar-large .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 41px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-default-toolbar-large.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-default-toolbar-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-default-toolbar-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-default-toolbar-large {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-default-toolbar-large,
.x-btn.x-btn-pressed.x-btn-default-toolbar-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-default-toolbar-large .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-default-toolbar-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-default-toolbar-large,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-default-toolbar-large {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-default-toolbar-large {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-br,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-bc {
    background-image: url(images/btn/btn-default-toolbar-large-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-default-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-default-toolbar-large-tl,
.x-btn-over .x-btn-default-toolbar-large-bl,
.x-btn-over .x-btn-default-toolbar-large-tr,
.x-btn-over .x-btn-default-toolbar-large-br,
.x-btn-over .x-btn-default-toolbar-large-tc,
.x-btn-over .x-btn-default-toolbar-large-bc {
    background-image: url(images/btn/btn-default-toolbar-large-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-default-toolbar-large-ml,
.x-btn-over .x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-default-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-bc {
    background-image: url(images/btn/btn-default-toolbar-large-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-default-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-tl,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-bl,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-tr,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-br,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-tc,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-bc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-tl,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-bl,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-tr,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-br,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-tc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-bc {
    background-image: url(images/btn/btn-default-toolbar-large-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-ml,
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-mr,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-ml,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-default-toolbar-large-mc,
.x-btn.x-btn-pressed .x-btn-default-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-bc {
    background-image: url(images/btn/btn-default-toolbar-large-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-default-toolbar-large-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-default-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-tl,
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-bl,
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-tr,
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-br,
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-tc,
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-bc {
    background-image: url(images/btn/btn-default-toolbar-large-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-ml,
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-mr {
    background-image: url(images/btn/btn-default-toolbar-large-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-default-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-default-toolbar-large {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-default-toolbar-large {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large.x-segmented-button-first .x-btn-default-toolbar-large-mc {
    padding-right: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large.x-segmented-button-middle .x-btn-default-toolbar-large-mc {
    padding-right: 9px !important;
    padding-left: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large.x-segmented-button-last .x-btn-default-toolbar-large-mc {
    padding-left: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large.x-segmented-button-first .x-btn-default-toolbar-large-mc {
    padding-bottom: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large.x-segmented-button-middle .x-btn-default-toolbar-large-mc {
    padding-top: 9px !important;
    padding-bottom: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large.x-segmented-button-last .x-btn-default-toolbar-large-mc {
    padding-top: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-default-toolbar-large:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-default-toolbar-large.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-default-toolbar-large.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-default-toolbar-large:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-default-toolbar-large:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-default-toolbar-large:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-default-toolbar-large:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-default-toolbar-large-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-default-toolbar-large-cell > .x-grid-cell-inner >.x-btn-default-toolbar-large {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:1 */
.x-tool {
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:5 */
.x-tool-tool-el {
    overflow: hidden;
    width: 16px;
    height: 16px;
    margin: 0;
    color: #000;
    text-align: center;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:16 */
.x-tool-over .x-tool-tool-el {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:21 */
.x-tool-pressed .x-tool-tool-el {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:30 */
.x-keyboard-mode .x-tool-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-tool-focus,
.x-edge .x-keyboard-mode .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:40 */
.x-tool-img {
    background-image: url(images/tools/tool-sprites.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:44 */
.x-tool-placeholder {
    visibility: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:48 */
.x-tool-close {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-close:before {
    content: "\ed1d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:57 */
.x-tool-minimize {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-minimize:before {
    content: "\ed24";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:66 */
.x-tool-maximize {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-maximize:before {
    content: "\ea14";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:75 */
.x-tool-restore {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-restore:before {
    content: "\efc8";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:84 */
.x-tool-toggle {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-toggle:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:92 */
.x-panel-collapsed .x-tool-toggle {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-panel-collapsed .x-tool-toggle:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:102 */
.x-tool-gear {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-gear:before {
    content: "\f013";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:111 */
.x-tool-prev {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-prev:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:120 */
.x-tool-next {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-next:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:129 */
.x-tool-pin {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-pin:before {
    content: "\f08d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:138 */
.x-tool-unpin {
    font: 16px/1 ExtJS;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-unpin:before {
    content: "\e611";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:147 */
.x-tool-right {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-right:before {
    content: "\f0da";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:156 */
.x-tool-left {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-left:before {
    content: "\f0d9";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:165 */
.x-tool-down {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-down:before {
    content: "\f0d7";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:174 */
.x-tool-up {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-up:before {
    content: "\f0d8";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:183 */
.x-tool-refresh {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-refresh:before {
    content: "\e91a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:192 */
.x-tool-plus {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-plus:before {
    content: "\f067";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:201 */
.x-tool-minus {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-minus:before {
    content: "\f068";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:210 */
.x-tool-search {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-search:before {
    content: "\f002";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:219 */
.x-tool-save {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-save:before {
    content: "\f00c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:228 */
.x-tool-help {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-help:before {
    content: "\f128";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:237 */
.x-tool-print {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-print:before {
    content: "\f02f";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:246 */
.x-tool-expand {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-expand:before {
    content: "";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:255 */
.x-tool-collapse {
    font-family: Portfolio, FontAwesome, Extjs;
    line-height: 1;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-collapse:before {
    content: "";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:264 */
.x-tool-resize {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-resize:before {
    content: "\f07e";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:273 */
.x-tool-move {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-move:before {
    content: "\f047";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:282 */
.x-tool-expand-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-expand-bottom:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:291 */
.x-tool-collapse-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-collapse-bottom:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:300 */
.x-tool-expand-top {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-expand-top:before {
    content: "\ed25";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:309 */
.x-tool-collapse-top {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-collapse-top:before {
    content: "\ed25";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:318 */
.x-tool-expand-left {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-expand-left:before {
    content: "\ed1c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:327 */
.x-tool-collapse-left {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-collapse-left:before {
    content: "\ed1c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:336 */
.x-tool-expand-right {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-expand-right:before {
    content: "\ed21";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Tool.scss:345 */
.x-tool-collapse-right {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tool-collapse-right:before {
    content: "\ed21";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Header.scss:1 */
.x-header-draggable,
.x-header-ghost {
    cursor: move;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Header.scss:6 */
.x-header-text {
    white-space: nowrap;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:22 */
.x-collapse-el {
    cursor: pointer;
    color: #919191;
    display: table;
    table-layout: fixed;
    background-color: rgba(0, 0, 0, 0.05);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:31 */
.x-collapse-el:before {
    display: table-cell;
    vertical-align: middle;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:46 */
.x-layout-split-left {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-layout-split-left:before {
    content: "\ed1c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:55 */
.x-layout-split-right {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    padding: 0 0 0 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-layout-split-right:before {
    content: "\ed21";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:86 */
.x-layout-split-top {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    padding: 0 0 2px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-layout-split-top:before {
    content: "\ed25";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:95 */
.x-layout-split-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-layout-split-bottom:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:105 */
.x-splitter-collapsed .x-layout-split-left {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    padding: 0 0 0 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-splitter-collapsed .x-layout-split-left:before {
    content: "\ed21";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:114 */
.x-splitter-collapsed .x-layout-split-right {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-splitter-collapsed .x-layout-split-right:before {
    content: "\ed1c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:145 */
.x-splitter-collapsed .x-layout-split-top {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-splitter-collapsed .x-layout-split-top:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:154 */
.x-splitter-collapsed .x-layout-split-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    padding: 0 0 2px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-splitter-collapsed .x-layout-split-bottom:before {
    content: "\ed25";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:164 */
.x-splitter-active {
    background-color: #b4b4b4;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:168 */
.x-splitter-active .x-collapse-el {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:173 */
.x-layout-split-left,
.x-layout-split-right {
    top: 50%;
    margin-top: -24px;
    width: 100%;
    height: 48px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:184 */
.x-layout-split-top,
.x-layout-split-bottom {
    left: 50%;
    width: 48px;
    height: 100%;
    margin-left: -24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Splitter.scss:199 */
.x-layout-split-top:before,
.x-layout-split-bottom:before {
    width: 100%;
    line-height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-keyboard-mode .x-splitter-focus:after {
    position: absolute;
    content: ' ';
    top: 0px;
    right: 0px;
    bottom: 0px;
    left: 0px;
    border: 0px solid #008abe;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:598 */
.x-toolbar-default {
    padding: 6px 0 6px 8px;
    border-style: solid;
    border-color: #d0d0d0;
    border-width: 1px;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:614 */
.x-toolbar-default .x-tool-img {
    color: #919191;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:629 */
.x-toolbar-default .x-toolbar-item {
    margin: 0 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:639 */
.x-toolbar-default .x-toolbar-separator-horizontal {
    margin: 0 8px 0 0;
    height: 14px;
    border-style: solid;
    border-width: 0 0 0 1px;
    border-left-color: #d0d0d0;
    border-right-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:648 */
.x-toolbar-default .x-box-menu-after {
    margin: 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:653 */
.x-toolbar-default-vertical {
    padding: 6px 8px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:662 */
.x-toolbar-default-vertical .x-toolbar-item {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:671 */
.x-toolbar-default-vertical .x-toolbar-separator-vertical {
    margin: 0 5px 6px;
    border-style: solid none;
    border-width: 1px 0 0;
    border-top-color: #d0d0d0;
    border-bottom-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:679 */
.x-toolbar-default-vertical .x-box-menu-after {
    margin: 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:694 */
.x-toolbar-text-default {
    padding: 0 4px;
    color: #34454c;
    font: 400 14px/16px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:700 */
.x-toolbar-spacer-default {
    width: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-toolbar-default-scroller .x-box-scroller-body-horizontal {
    margin-left: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-toolbar-default-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-toolbar-default {
    cursor: pointer;
    color: #919191;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-toolbar-default.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-toolbar-default.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-toolbar-default.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-toolbar-default.x-box-scroller-left,
.x-box-scroller-toolbar-default.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-toolbar-default.x-box-scroller-left {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-default.x-box-scroller-left:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-toolbar-default.x-box-scroller-right {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-default.x-box-scroller-right:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-toolbar-default.x-box-scroller-top,
.x-box-scroller-toolbar-default.x-box-scroller-bottom {
    height: 24px;
    width: 24px;
    left: 50%;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-toolbar-default.x-box-scroller-top {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-default.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-toolbar-default.x-box-scroller-bottom {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-default.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:742 */
.x-ie8 .x-box-scroller-toolbar-default {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:748 */
.x-toolbar-more-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-toolbar-more-icon:before {
    content: "\f0c9";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:598 */
.x-toolbar-footer {
    padding: 6px 0 6px 6px;
    border-style: solid;
    border-color: #d0d0d0;
    border-width: 0;
    background-image: none;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:614 */
.x-toolbar-footer .x-tool-img {
    color: #919191;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:629 */
.x-toolbar-footer .x-toolbar-item {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:639 */
.x-toolbar-footer .x-toolbar-separator-horizontal {
    margin: 0 8px 0 0;
    height: 14px;
    border-style: solid;
    border-width: 0 0 0 1px;
    border-left-color: #d0d0d0;
    border-right-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:648 */
.x-toolbar-footer .x-box-menu-after {
    margin: 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:653 */
.x-toolbar-footer-vertical {
    padding: 6px 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:662 */
.x-toolbar-footer-vertical .x-toolbar-item {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:671 */
.x-toolbar-footer-vertical .x-toolbar-separator-vertical {
    margin: 0 5px 6px;
    border-style: solid none;
    border-width: 1px 0 0;
    border-top-color: #d0d0d0;
    border-bottom-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:679 */
.x-toolbar-footer-vertical .x-box-menu-after {
    margin: 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:694 */
.x-toolbar-text-footer {
    padding: 0 4px;
    color: #34454c;
    font: 400 14px/16px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:700 */
.x-toolbar-spacer-footer {
    width: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-toolbar-footer-scroller .x-box-scroller-body-horizontal {
    margin-left: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-toolbar-footer-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-toolbar-footer {
    cursor: pointer;
    color: #919191;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-toolbar-footer.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-toolbar-footer.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-toolbar-footer.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-toolbar-footer.x-box-scroller-left,
.x-box-scroller-toolbar-footer.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-toolbar-footer.x-box-scroller-left {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-footer.x-box-scroller-left:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-toolbar-footer.x-box-scroller-right {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-footer.x-box-scroller-right:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:742 */
.x-ie8 .x-box-scroller-toolbar-footer {
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:748 */
.x-toolbar-more-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-toolbar-more-icon:before {
    content: "\f0c9";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dd/StatusProxy.scss:1 */
.x-dd-drag-proxy {
    color: #000;
    font: 400 14px/24px Open Sans, sans-serif;
    border: 1px solid #d0d0d0;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dd/StatusProxy.scss:8 */
.x-dd-drag-ghost,
.x-dd-drop-icon {
    padding: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dd/StatusProxy.scss:19 */
.x-dd-drag-ghost {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dd/StatusProxy.scss:30 */
.x-dd-drop-ok .x-dd-drop-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #a4cf6d;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-dd-drop-ok .x-dd-drop-icon:before {
    content: "\f058";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dd/StatusProxy.scss:38 */
.x-dd-drop-ok-add .x-dd-drop-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #a4cf6d;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-dd-drop-ok-add .x-dd-drop-icon:before {
    content: "\f058";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dd/StatusProxy.scss:47 */
.x-dd-drop-nodrop div.x-dd-drop-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #d9705d;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-dd-drop-nodrop div.x-dd-drop-icon:before {
    content: "\f057";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/panel/Panel.scss:1 */
.x-panel-ghost {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:799 */
.x-panel-default {
    border-color: #d0d0d0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:802 */
.x-panel-default.x-masked {
    border-color: #e8e8e8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:810 */
.x-panel-header-default {
    font-size: 14px;
    border: 1px solid transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:836 */
.x-panel-header-default .x-tool-tool-el {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:842 */
.x-panel-header-default-horizontal {
    padding: 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:846 */
.x-panel-header-default-horizontal .x-panel-header-default-tab-bar {
    margin-top: -11px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:854 */
.x-panel-header-default-horizontal.x-header-noborder {
    padding: 12px 16px 12px 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:858 */
.x-panel-header-default-horizontal.x-header-noborder .x-panel-header-default-tab-bar {
    margin-top: -12px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:866 */
.x-panel-header-default-vertical {
    padding: 15px 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:870 */
.x-panel-header-default-vertical .x-panel-header-default-tab-bar {
    margin-right: -11px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:878 */
.x-panel-header-default-vertical.x-header-noborder {
    padding: 16px 12px 16px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:882 */
.x-panel-header-default-vertical.x-header-noborder .x-panel-header-default-tab-bar {
    margin-right: -12px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:916 */
.x-panel-header-title-default {
    color: #000;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:929 */
.x-keyboard-mode .x-panel-header-title-default.x-title-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-title-default.x-title-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-title-default.x-title-focus,
.x-edge .x-keyboard-mode .x-panel-header-title-default.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-title-default.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-title-default.x-title-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-title-default.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:950 */
.x-panel-header-title-default > .x-title-text-default {
    text-transform: none;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:997 */
.x-panel-header-title-default > .x-title-icon-wrap-default.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1002 */
.x-panel-header-title-default > .x-title-icon-wrap-default.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1014 */
.x-panel-header-title-default > .x-title-icon-wrap-default.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1019 */
.x-panel-header-title-default > .x-title-icon-wrap-default.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1031 */
.x-panel-header-title-default > .x-title-icon-wrap-default > .x-title-icon-default {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #000;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1051 */
.x-ie8 .x-panel-header-title-default > .x-title-icon-wrap-default > .x-title-icon-default.x-title-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1062 */
.x-panel-body-default {
    background: #fff;
    border-color: #d0d0d0;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1226 */
.x-panel-header-default {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1230 */
.x-panel-header-default-vertical {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1288 */
.x-panel .x-panel-header-default-collapsed-border-top {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1292 */
.x-panel .x-panel-header-default-collapsed-border-right {
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1296 */
.x-panel .x-panel-header-default-collapsed-border-bottom {
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1300 */
.x-panel .x-panel-header-default-collapsed-border-left {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1336 */
.x-panel-header-default-horizontal .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1346 */
.x-panel-header-default-horizontal .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1358 */
.x-panel-header-default-vertical .x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1368 */
.x-panel-header-default-vertical .x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1381 */
.x-keyboard-mode .x-panel-header-default .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-default .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-default .x-tool-focus,
.x-edge .x-keyboard-mode .x-panel-header-default .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-default .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-default .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-default .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1429 */
.x-panel-default-resizable .x-panel-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-panel-default-outer-border-l {
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-panel-default-outer-border-b {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-panel-default-outer-border-bl {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-panel-default-outer-border-r {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-panel-default-outer-border-rl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-panel-default-outer-border-rb {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-panel-default-outer-border-rbl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-panel-default-outer-border-t {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-panel-default-outer-border-tl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-panel-default-outer-border-tb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-panel-default-outer-border-tbl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-panel-default-outer-border-tr {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-panel-default-outer-border-trl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-panel-default-outer-border-trb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-panel-default-outer-border-trbl {
    border-color: #d0d0d0 !important;
    border-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:799 */
.x-panel-default-framed {
    border-color: #d0d0d0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:802 */
.x-panel-default-framed.x-masked {
    border-color: #e8e8e8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:810 */
.x-panel-header-default-framed {
    font-size: 14px;
    border: 2px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:836 */
.x-panel-header-default-framed .x-tool-tool-el {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:842 */
.x-panel-header-default-framed-horizontal {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:846 */
.x-panel-header-default-framed-horizontal .x-panel-header-default-framed-tab-bar {
    margin-top: -10px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:854 */
.x-panel-header-default-framed-horizontal.x-header-noborder {
    padding: 12px 16px 10px 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:858 */
.x-panel-header-default-framed-horizontal.x-header-noborder .x-panel-header-default-framed-tab-bar {
    margin-top: -12px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:866 */
.x-panel-header-default-framed-vertical {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:870 */
.x-panel-header-default-framed-vertical .x-panel-header-default-framed-tab-bar {
    margin-right: -10px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:878 */
.x-panel-header-default-framed-vertical.x-header-noborder {
    padding: 16px 12px 16px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:882 */
.x-panel-header-default-framed-vertical.x-header-noborder .x-panel-header-default-framed-tab-bar {
    margin-right: -12px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:916 */
.x-panel-header-title-default-framed {
    color: #000;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:929 */
.x-keyboard-mode .x-panel-header-title-default-framed.x-title-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-title-default-framed.x-title-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-title-default-framed.x-title-focus,
.x-edge .x-keyboard-mode .x-panel-header-title-default-framed.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-title-default-framed.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-title-default-framed.x-title-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-title-default-framed.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:950 */
.x-panel-header-title-default-framed > .x-title-text-default-framed {
    text-transform: none;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:997 */
.x-panel-header-title-default-framed > .x-title-icon-wrap-default-framed.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1002 */
.x-panel-header-title-default-framed > .x-title-icon-wrap-default-framed.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1014 */
.x-panel-header-title-default-framed > .x-title-icon-wrap-default-framed.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1019 */
.x-panel-header-title-default-framed > .x-title-icon-wrap-default-framed.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1031 */
.x-panel-header-title-default-framed > .x-title-icon-wrap-default-framed > .x-title-icon-default-framed {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #000;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1051 */
.x-ie8 .x-panel-header-title-default-framed > .x-title-icon-wrap-default-framed > .x-title-icon-default-framed.x-title-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1062 */
.x-panel-body-default-framed {
    background: #fff;
    border-color: #d0d0d0;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-default-framed {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 0 0 0 0;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-default-framed-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-default-framed {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-default-framed-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-0px-0px-0px-0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-default-framed-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-default-framed-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-default-framed-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-default-framed-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-default-framed-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-default-framed-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-default-framed-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-default-framed-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-default-framed-tr,
.x-panel-default-framed-br,
.x-panel-default-framed-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-default-framed-tl,
.x-panel-default-framed-bl,
.x-panel-default-framed-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-default-framed-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-default-framed-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-default-framed-tl,
.x-panel-default-framed-bl,
.x-panel-default-framed-tr,
.x-panel-default-framed-br,
.x-panel-default-framed-tc,
.x-panel-default-framed-bc,
.x-panel-default-framed-ml,
.x-panel-default-framed-mr {
    background-image: url(images/panel/panel-default-framed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-default-framed-ml,
.x-panel-default-framed-mr {
    background-image: url(images/panel/panel-default-framed-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-default-framed-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 0 2px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-top-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-top-frameInfo {
    font-family: dh-2-2-0-2-2-2-0-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-top-tr,
.x-panel-header-default-framed-top-br,
.x-panel-header-default-framed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-top-tl,
.x-panel-header-default-framed-top-bl,
.x-panel-header-default-framed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-top-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 0;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-right-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-right-frameInfo {
    font-family: dh-2-2-2-0-2-2-2-0-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-right-ml {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-right-mr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-right-tr,
.x-panel-header-default-framed-right-br,
.x-panel-header-default-framed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-right-tl,
.x-panel-header-default-framed-right-bl,
.x-panel-header-default-framed-right-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 0 2px 2px 2px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-bottom-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-bottom-frameInfo {
    font-family: dh-0-2-2-2-0-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-bottom-tr,
.x-panel-header-default-framed-bottom-br,
.x-panel-header-default-framed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-bottom-tl,
.x-panel-header-default-framed-bottom-bl,
.x-panel-header-default-framed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-bottom-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 0 2px 2px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-left-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-left-frameInfo {
    font-family: dh-2-0-2-2-2-0-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-left-ml {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-left-mr {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-left-tr,
.x-panel-header-default-framed-left-br,
.x-panel-header-default-framed-left-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-left-tl,
.x-panel-header-default-framed-left-bl,
.x-panel-header-default-framed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-collapsed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-collapsed-top-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-collapsed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-collapsed-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-collapsed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-collapsed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-collapsed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-collapsed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-collapsed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-collapsed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-collapsed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-collapsed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-collapsed-top-tr,
.x-panel-header-default-framed-collapsed-top-br,
.x-panel-header-default-framed-collapsed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-collapsed-top-tl,
.x-panel-header-default-framed-collapsed-top-bl,
.x-panel-header-default-framed-collapsed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-collapsed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-collapsed-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-collapsed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-collapsed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-collapsed-right-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-collapsed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-collapsed-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-collapsed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-collapsed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-collapsed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-collapsed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-collapsed-right-ml {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-collapsed-right-mr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-collapsed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-collapsed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-collapsed-right-tr,
.x-panel-header-default-framed-collapsed-right-br,
.x-panel-header-default-framed-collapsed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-collapsed-right-tl,
.x-panel-header-default-framed-collapsed-right-bl,
.x-panel-header-default-framed-collapsed-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-collapsed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-collapsed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-collapsed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-collapsed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-collapsed-bottom-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-collapsed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-collapsed-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-collapsed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-collapsed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-collapsed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-collapsed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-collapsed-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-collapsed-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-collapsed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-collapsed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-collapsed-bottom-tr,
.x-panel-header-default-framed-collapsed-bottom-br,
.x-panel-header-default-framed-collapsed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-collapsed-bottom-tl,
.x-panel-header-default-framed-collapsed-bottom-bl,
.x-panel-header-default-framed-collapsed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-collapsed-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-collapsed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-collapsed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-default-framed-collapsed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-default-framed-collapsed-left-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-default-framed-collapsed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-default-framed-collapsed-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-default-framed-collapsed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-default-framed-collapsed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-default-framed-collapsed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-default-framed-collapsed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-default-framed-collapsed-left-ml {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-default-framed-collapsed-left-mr {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-default-framed-collapsed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-default-framed-collapsed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-default-framed-collapsed-left-tr,
.x-panel-header-default-framed-collapsed-left-br,
.x-panel-header-default-framed-collapsed-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-default-framed-collapsed-left-tl,
.x-panel-header-default-framed-collapsed-left-bl,
.x-panel-header-default-framed-collapsed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-default-framed-collapsed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-default-framed-collapsed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-default-framed-collapsed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1188 */
.x-panel .x-panel-header-default-framed-top {
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1192 */
.x-panel .x-panel-header-default-framed-right {
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1196 */
.x-panel .x-panel-header-default-framed-bottom {
    border-top-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1200 */
.x-panel .x-panel-header-default-framed-left {
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1206 */
.x-nbr .x-panel-header-default-framed-collapsed-top {
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1210 */
.x-nbr .x-panel-header-default-framed-collapsed-right {
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1214 */
.x-nbr .x-panel-header-default-framed-collapsed-bottom {
    border-top-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1218 */
.x-nbr .x-panel-header-default-framed-collapsed-left {
    border-right-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1336 */
.x-panel-header-default-framed-horizontal .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1346 */
.x-panel-header-default-framed-horizontal .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1358 */
.x-panel-header-default-framed-vertical .x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1368 */
.x-panel-header-default-framed-vertical .x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1381 */
.x-keyboard-mode .x-panel-header-default-framed .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-default-framed .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-default-framed .x-tool-focus,
.x-edge .x-keyboard-mode .x-panel-header-default-framed .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-default-framed .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-default-framed .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-default-framed .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1429 */
.x-panel-default-framed-resizable .x-panel-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-panel-default-framed-outer-border-l {
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-panel-default-framed-outer-border-b {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-panel-default-framed-outer-border-bl {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-panel-default-framed-outer-border-r {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-panel-default-framed-outer-border-rl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-panel-default-framed-outer-border-rb {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-panel-default-framed-outer-border-rbl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-panel-default-framed-outer-border-t {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-panel-default-framed-outer-border-tl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-panel-default-framed-outer-border-tb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-panel-default-framed-outer-border-tbl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-panel-default-framed-outer-border-tr {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-panel-default-framed-outer-border-trl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-panel-default-framed-outer-border-trb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-panel-default-framed-outer-border-trbl {
    border-color: #d0d0d0 !important;
    border-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:243 */
.x-btn-group-default {
    border-color: #d0d0d0;
    -webkit-box-shadow: #fff 0 1px 0px 0 inset, #fff 0 -1px 0px 0 inset, #fff -1px 0 0px 0 inset, #fff 1px 0 0px 0 inset;
    -moz-box-shadow: #fff 0 1px 0px 0 inset, #fff 0 -1px 0px 0 inset, #fff -1px 0 0px 0 inset, #fff 1px 0 0px 0 inset;
    box-shadow: #fff 0 1px 0px 0 inset, #fff 0 -1px 0px 0 inset, #fff -1px 0 0px 0 inset, #fff 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:252 */
.x-btn-group-header-default {
    padding: 8px 8px 7px;
    line-height: 16px;
    background: #fff;
    -moz-border-radius-topleft: 0px;
    -webkit-border-top-left-radius: 0px;
    border-top-left-radius: 0px;
    -moz-border-radius-topright: 0px;
    -webkit-border-top-right-radius: 0px;
    border-top-right-radius: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:263 */
.x-btn-group-header-default .x-tool-img {
    background-image: url(images/tools/tool-sprites-dark.png);
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:274 */
.x-btn-group-header-title-default {
    font: 400 15px Open Sans, sans-serif;
    line-height: 16px;
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:280 */
.x-btn-group-body-default {
    padding: 0 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:282 */
.x-btn-group-body-default .x-table-layout {
    border-spacing: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-group-default-framed {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    -ms-border-radius: 2px;
    -o-border-radius: 2px;
    border-radius: 2px;
    padding: 1px 1px 1px 1px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-group-default-framed-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-group-default-framed {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-group-default-framed-frameInfo {
    font-family: dh-2-2-2-2-1-1-1-1-1-1-1-1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-group-default-framed-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-group-default-framed-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-group-default-framed-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-group-default-framed-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-group-default-framed-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-group-default-framed-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-group-default-framed-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-group-default-framed-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-group-default-framed-tr,
.x-btn-group-default-framed-br,
.x-btn-group-default-framed-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-group-default-framed-tl,
.x-btn-group-default-framed-bl,
.x-btn-group-default-framed-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-group-default-framed-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-group-default-framed-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-group-default-framed-tl,
.x-btn-group-default-framed-bl,
.x-btn-group-default-framed-tr,
.x-btn-group-default-framed-br,
.x-btn-group-default-framed-tc,
.x-btn-group-default-framed-bc,
.x-btn-group-default-framed-ml,
.x-btn-group-default-framed-mr {
    background-image: url(images/btn-group/btn-group-default-framed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-group-default-framed-ml,
.x-btn-group-default-framed-mr {
    background-image: url(images/btn-group/btn-group-default-framed-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-group-default-framed-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-group-default-framed-notitle {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    -ms-border-radius: 2px;
    -o-border-radius: 2px;
    border-radius: 2px;
    padding: 1px 1px 1px 1px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-group-default-framed-notitle-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-group-default-framed-notitle {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-group-default-framed-notitle-frameInfo {
    font-family: dh-2-2-2-2-1-1-1-1-1-1-1-1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-group-default-framed-notitle-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-group-default-framed-notitle-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-group-default-framed-notitle-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-group-default-framed-notitle-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-group-default-framed-notitle-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-group-default-framed-notitle-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-group-default-framed-notitle-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-group-default-framed-notitle-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-group-default-framed-notitle-tr,
.x-btn-group-default-framed-notitle-br,
.x-btn-group-default-framed-notitle-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-group-default-framed-notitle-tl,
.x-btn-group-default-framed-notitle-bl,
.x-btn-group-default-framed-notitle-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-group-default-framed-notitle-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-group-default-framed-notitle-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-group-default-framed-notitle-tl,
.x-btn-group-default-framed-notitle-bl,
.x-btn-group-default-framed-notitle-tr,
.x-btn-group-default-framed-notitle-br,
.x-btn-group-default-framed-notitle-tc,
.x-btn-group-default-framed-notitle-bc,
.x-btn-group-default-framed-notitle-ml,
.x-btn-group-default-framed-notitle-mr {
    background-image: url(images/btn-group/btn-group-default-framed-notitle-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-group-default-framed-notitle-ml,
.x-btn-group-default-framed-notitle-mr {
    background-image: url(images/btn-group/btn-group-default-framed-notitle-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-group-default-framed-notitle-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:243 */
.x-btn-group-default-framed {
    border-color: #d0d0d0;
    -webkit-box-shadow: #fff 0 1px 0px 0 inset, #fff 0 -1px 0px 0 inset, #fff -1px 0 0px 0 inset, #fff 1px 0 0px 0 inset;
    -moz-box-shadow: #fff 0 1px 0px 0 inset, #fff 0 -1px 0px 0 inset, #fff -1px 0 0px 0 inset, #fff 1px 0 0px 0 inset;
    box-shadow: #fff 0 1px 0px 0 inset, #fff 0 -1px 0px 0 inset, #fff -1px 0 0px 0 inset, #fff 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:252 */
.x-btn-group-header-default-framed {
    padding: 8px 8px 7px;
    line-height: 16px;
    background: #fff;
    -moz-border-radius-topleft: 2px;
    -webkit-border-top-left-radius: 2px;
    border-top-left-radius: 2px;
    -moz-border-radius-topright: 2px;
    -webkit-border-top-right-radius: 2px;
    border-top-right-radius: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:263 */
.x-btn-group-header-default-framed .x-tool-img {
    background-image: url(images/tools/tool-sprites-dark.png);
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:274 */
.x-btn-group-header-title-default-framed {
    font: 400 15px Open Sans, sans-serif;
    line-height: 16px;
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:280 */
.x-btn-group-body-default-framed {
    padding: 0 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/container/ButtonGroup.scss:282 */
.x-btn-group-body-default-framed .x-table-layout {
    border-spacing: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dashboard/Dashboard.scss:1 */
.x-dashboard-column {
    padding: 0 0 7px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dashboard/Dashboard.scss:5 */
.x-dashboard-panel {
    margin-top: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dashboard/Dashboard.scss:9 */
.x-dashboard-column-first {
    padding-left: 7px;
    clear: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dashboard/Dashboard.scss:14 */
.x-dashboard-column-last {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dashboard/Dashboard.scss:18 */
.x-dashboard .x-panel-dd-spacer {
    border: 2px dashed #99bbe8;
    background: #f6f6f6;
    border-radius: 4px;
    -moz-border-radius: 4px;
    margin-top: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/dashboard/Dashboard.scss:28 */
.x-dashboard-dd-over {
    overflow: hidden !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Window.scss:1 */
.x-window-ghost {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:545 */
.x-window-default {
    border-color: #00adee;
    -webkit-border-radius: 0 0 0 0;
    -moz-border-radius: 0 0 0 0;
    -ms-border-radius: 0 0 0 0;
    -o-border-radius: 0 0 0 0;
    border-radius: 0 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-default {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 0 0 0 0;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-default-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-default {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-default-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-0px-0px-0px-0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-default-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-default-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-default-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-default-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-default-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-default-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-default-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-default-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-default-tr,
.x-window-default-br,
.x-window-default-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-default-tl,
.x-window-default-bl,
.x-window-default-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-default-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-default-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-default-tl,
.x-window-default-bl,
.x-window-default-tr,
.x-window-default-br,
.x-window-default-tc,
.x-window-default-bc,
.x-window-default-ml,
.x-window-default-mr {
    background-image: url(images/window/window-default-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-default-ml,
.x-window-default-mr {
    background-image: url(images/window/window-default-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-default-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:567 */
.x-window-body-default {
    border-color: #00adee;
    border-width: 1px;
    border-style: solid;
    background: #fff;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:581 */
.x-window-header-default {
    font-size: 14px;
    border-color: #00adee;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:586 */
.x-window-header-default .x-tool-img {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:599 */
.x-window-header-default-horizontal .x-window-header-default-tab-bar {
    margin-top: -10px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:606 */
.x-window-header-default-vertical .x-window-header-default-tab-bar {
    margin-right: -10px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:622 */
.x-window-header-title-default {
    color: #fff;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:631 */
.x-window-header-title-default > .x-title-text-default {
    padding: 0;
    text-transform: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:678 */
.x-window-header-title-default > .x-title-icon-wrap-default.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:683 */
.x-window-header-title-default > .x-title-icon-wrap-default.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:695 */
.x-window-header-title-default > .x-title-icon-wrap-default.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:700 */
.x-window-header-title-default > .x-title-icon-wrap-default.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:712 */
.x-window-header-title-default > .x-title-icon-wrap-default > .x-title-icon-default {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #fff;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:732 */
.x-ie8 .x-window-header-title-default > .x-title-icon-wrap-default > .x-title-icon-default.x-title-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-top-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-top-tr,
.x-window-header-default-top-br,
.x-window-header-default-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-top-tl,
.x-window-header-default-top-bl,
.x-window-header-default-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-top-tl,
.x-window-header-default-top-bl,
.x-window-header-default-top-tr,
.x-window-header-default-top-br,
.x-window-header-default-top-tc,
.x-window-header-default-top-bc,
.x-window-header-default-top-ml,
.x-window-header-default-top-mr {
    background-image: url(images/window-header/window-header-default-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-top-ml,
.x-window-header-default-top-mr {
    background-image: url(images/window-header/window-header-default-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-right-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-right-tr,
.x-window-header-default-right-br,
.x-window-header-default-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-right-tl,
.x-window-header-default-right-bl,
.x-window-header-default-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-right-tl,
.x-window-header-default-right-bl,
.x-window-header-default-right-tr,
.x-window-header-default-right-br,
.x-window-header-default-right-tc,
.x-window-header-default-right-bc,
.x-window-header-default-right-ml,
.x-window-header-default-right-mr {
    background-image: url(images/window-header/window-header-default-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-right-ml,
.x-window-header-default-right-mr {
    background-image: url(images/window-header/window-header-default-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-bottom-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-bottom-tr,
.x-window-header-default-bottom-br,
.x-window-header-default-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-bottom-tl,
.x-window-header-default-bottom-bl,
.x-window-header-default-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-bottom-tl,
.x-window-header-default-bottom-bl,
.x-window-header-default-bottom-tr,
.x-window-header-default-bottom-br,
.x-window-header-default-bottom-tc,
.x-window-header-default-bottom-bc,
.x-window-header-default-bottom-ml,
.x-window-header-default-bottom-mr {
    background-image: url(images/window-header/window-header-default-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-bottom-ml,
.x-window-header-default-bottom-mr {
    background-image: url(images/window-header/window-header-default-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-left-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-left-tr,
.x-window-header-default-left-br,
.x-window-header-default-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-left-tl,
.x-window-header-default-left-bl,
.x-window-header-default-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-left-tl,
.x-window-header-default-left-bl,
.x-window-header-default-left-tr,
.x-window-header-default-left-br,
.x-window-header-default-left-tc,
.x-window-header-default-left-bc,
.x-window-header-default-left-ml,
.x-window-header-default-left-mr {
    background-image: url(images/window-header/window-header-default-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-left-ml,
.x-window-header-default-left-mr {
    background-image: url(images/window-header/window-header-default-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-collapsed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-collapsed-top-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-collapsed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-collapsed-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-collapsed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-collapsed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-collapsed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-collapsed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-collapsed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-collapsed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-collapsed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-collapsed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-collapsed-top-tr,
.x-window-header-default-collapsed-top-br,
.x-window-header-default-collapsed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-collapsed-top-tl,
.x-window-header-default-collapsed-top-bl,
.x-window-header-default-collapsed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-collapsed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-collapsed-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-collapsed-top-tl,
.x-window-header-default-collapsed-top-bl,
.x-window-header-default-collapsed-top-tr,
.x-window-header-default-collapsed-top-br,
.x-window-header-default-collapsed-top-tc,
.x-window-header-default-collapsed-top-bc,
.x-window-header-default-collapsed-top-ml,
.x-window-header-default-collapsed-top-mr {
    background-image: url(images/window-header/window-header-default-collapsed-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-collapsed-top-ml,
.x-window-header-default-collapsed-top-mr {
    background-image: url(images/window-header/window-header-default-collapsed-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-collapsed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-collapsed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-collapsed-right-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-collapsed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-collapsed-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-collapsed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-collapsed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-collapsed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-collapsed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-collapsed-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-collapsed-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-collapsed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-collapsed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-collapsed-right-tr,
.x-window-header-default-collapsed-right-br,
.x-window-header-default-collapsed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-collapsed-right-tl,
.x-window-header-default-collapsed-right-bl,
.x-window-header-default-collapsed-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-collapsed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-collapsed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-collapsed-right-tl,
.x-window-header-default-collapsed-right-bl,
.x-window-header-default-collapsed-right-tr,
.x-window-header-default-collapsed-right-br,
.x-window-header-default-collapsed-right-tc,
.x-window-header-default-collapsed-right-bc,
.x-window-header-default-collapsed-right-ml,
.x-window-header-default-collapsed-right-mr {
    background-image: url(images/window-header/window-header-default-collapsed-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-collapsed-right-ml,
.x-window-header-default-collapsed-right-mr {
    background-image: url(images/window-header/window-header-default-collapsed-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-collapsed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-collapsed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-collapsed-bottom-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-collapsed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-collapsed-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-collapsed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-collapsed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-collapsed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-collapsed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-collapsed-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-collapsed-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-collapsed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-collapsed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-collapsed-bottom-tr,
.x-window-header-default-collapsed-bottom-br,
.x-window-header-default-collapsed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-collapsed-bottom-tl,
.x-window-header-default-collapsed-bottom-bl,
.x-window-header-default-collapsed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-collapsed-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-collapsed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-collapsed-bottom-tl,
.x-window-header-default-collapsed-bottom-bl,
.x-window-header-default-collapsed-bottom-tr,
.x-window-header-default-collapsed-bottom-br,
.x-window-header-default-collapsed-bottom-tc,
.x-window-header-default-collapsed-bottom-bc,
.x-window-header-default-collapsed-bottom-ml,
.x-window-header-default-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-default-collapsed-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-collapsed-bottom-ml,
.x-window-header-default-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-default-collapsed-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-collapsed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-default-collapsed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-default-collapsed-left-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-default-collapsed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-default-collapsed-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-default-collapsed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-default-collapsed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-default-collapsed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-default-collapsed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-default-collapsed-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-default-collapsed-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-default-collapsed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-default-collapsed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-default-collapsed-left-tr,
.x-window-header-default-collapsed-left-br,
.x-window-header-default-collapsed-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-default-collapsed-left-tl,
.x-window-header-default-collapsed-left-bl,
.x-window-header-default-collapsed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-default-collapsed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-default-collapsed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-default-collapsed-left-tl,
.x-window-header-default-collapsed-left-bl,
.x-window-header-default-collapsed-left-tr,
.x-window-header-default-collapsed-left-br,
.x-window-header-default-collapsed-left-tc,
.x-window-header-default-collapsed-left-bc,
.x-window-header-default-collapsed-left-ml,
.x-window-header-default-collapsed-left-mr {
    background-image: url(images/window-header/window-header-default-collapsed-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-default-collapsed-left-ml,
.x-window-header-default-collapsed-left-mr {
    background-image: url(images/window-header/window-header-default-collapsed-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-default-collapsed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:857 */
.x-window-header-default .x-window-header-icon {
    width: 16px;
    height: 16px;
    color: #fff;
    font-size: 16px;
    line-height: 16px;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:866 */
.x-window-header-default .x-window-header-glyph {
    color: #fff;
    font-size: 16px;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:883 */
.x-ie8 .x-window-header-default .x-window-header-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:892 */
.x-window-header-default-horizontal .x-tool-after-title {
    margin: 0 0 0 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:902 */
.x-window-header-default-horizontal .x-tool-before-title {
    margin: 0 30px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:914 */
.x-window-header-default-vertical .x-tool-after-title {
    margin: 30px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:924 */
.x-window-header-default-vertical .x-tool-before-title {
    margin: 0 0 30px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:937 */
.x-keyboard-mode .x-window-header-default .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-window-header-default .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-window-header-default .x-tool-focus,
.x-edge .x-keyboard-mode .x-window-header-default .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-window-header-default .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-window-header-default .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-window-header-default .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:951 */
.x-window-header-default {
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:961 */
.x-nbr .x-window-default-collapsed .x-window-header {
    border-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-window-default-outer-border-l {
    border-left-color: #00adee !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-window-default-outer-border-b {
    border-bottom-color: #00adee !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-window-default-outer-border-bl {
    border-bottom-color: #00adee !important;
    border-bottom-width: 1px !important;
    border-left-color: #00adee !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-window-default-outer-border-r {
    border-right-color: #00adee !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-window-default-outer-border-rl {
    border-right-color: #00adee !important;
    border-right-width: 1px !important;
    border-left-color: #00adee !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-window-default-outer-border-rb {
    border-right-color: #00adee !important;
    border-right-width: 1px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-window-default-outer-border-rbl {
    border-right-color: #00adee !important;
    border-right-width: 1px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 1px !important;
    border-left-color: #00adee !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-window-default-outer-border-t {
    border-top-color: #00adee !important;
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-window-default-outer-border-tl {
    border-top-color: #00adee !important;
    border-top-width: 1px !important;
    border-left-color: #00adee !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-window-default-outer-border-tb {
    border-top-color: #00adee !important;
    border-top-width: 1px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-window-default-outer-border-tbl {
    border-top-color: #00adee !important;
    border-top-width: 1px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 1px !important;
    border-left-color: #00adee !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-window-default-outer-border-tr {
    border-top-color: #00adee !important;
    border-top-width: 1px !important;
    border-right-color: #00adee !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-window-default-outer-border-trl {
    border-top-color: #00adee !important;
    border-top-width: 1px !important;
    border-right-color: #00adee !important;
    border-right-width: 1px !important;
    border-left-color: #00adee !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-window-default-outer-border-trb {
    border-top-color: #00adee !important;
    border-top-width: 1px !important;
    border-right-color: #00adee !important;
    border-right-width: 1px !important;
    border-bottom-color: #00adee !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-window-default-outer-border-trbl {
    border-color: #00adee !important;
    border-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Window.scss:11 */
.x-window-body-plain {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:97 */
.x-form-item-label-default {
    color: #000;
    font: 400 14px/17px Open Sans, sans-serif;
    min-height: 40px;
    padding-top: 12px;
    padding-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:113 */
.x-ie8 .x-form-item-label-default {
    min-height: 28px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:119 */
.x-form-item-label-default.x-form-item-label-top {
    height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:121 */
.x-form-item-label-default.x-form-item-label-top > .x-form-item-label-inner {
    padding-top: 12px;
    padding-bottom: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:127 */
.x-form-item-label-default.x-form-item-label-top-side-error:after {
    width: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:132 */
.x-form-item-body-default {
    min-height: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:136 */
.x-form-invalid-icon-default {
    width: 16px;
    height: 16px;
    margin: 0 5px;
    background: url(images/form/exclamation.png) no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:143 */
.x-form-invalid-under-default {
    padding: 2px 2px 2px 20px;
    color: #d81818;
    font: 400 14px/16px Open Sans, sans-serif;
    background: no-repeat 0 2px;
    background-image: url(images/form/exclamation.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/Labelable.scss:151 */
.x-form-error-wrap-default.x-form-error-wrap-side {
    width: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/Labelable.scss:33 */
.x-autocontainer-form-item,
.x-anchor-form-item,
.x-vbox-form-item,
.x-table-form-item {
    margin-bottom: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:201 */
.x-form-text-field-body-default {
    min-width: 170px;
    max-width: 170px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:221 */
.x-form-trigger-wrap-default {
    border-width: 1px;
    border-style: solid;
    border-color: #d0d0d0;
    border-radius: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:229 */
.x-form-trigger-wrap-default.x-form-trigger-wrap-focus {
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:233 */
.x-form-trigger-wrap-default.x-form-trigger-wrap-invalid {
    border-color: #d81818;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:258 */
.x-form-text-default {
    color: #000;
    padding: 5px 10px 4px;
    background-color: #fff;
    border-radius: 3px;
    font: 400 14px/29px Open Sans, sans-serif;
    min-height: 38px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:272 */
.x-ie8 .x-form-text-default {
    min-height: 29px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:278 */
.x-form-text-default.x-form-textarea {
    line-height: 21px;
    min-height: 84px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:283 */
.x-ie8 .x-form-text-default.x-form-textarea {
    min-height: 75px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:290 */
.x-form-text-default.x-form-text-file {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:294 */
.x-form-text-default.x-webkit-border-box-bug {
    height: calc(100% + 9px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:300 */
.x-placeholder-label-default {
    padding: 5px 10px 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:304 */
.x-form-empty-field-default + .x-placeholder-label-default {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:309 */
.x-form-text-default:-ms-input-placeholder {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:313 */
.x-form-invalid-field-default {
    background-color: #fceded;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:324 */
.x-form-trigger-default {
    width: 40px;
    font: 16px/38px Portfolio, FontAwesome, Extjs;
    background: #fff;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-trigger-default:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:347 */
.x-form-trigger-default.x-form-trigger-over {
    background-position: -40px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:353 */
.x-form-trigger-default.x-form-trigger-over.x-form-trigger-focus {
    background-position: -160px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:358 */
.x-form-trigger-default.x-form-trigger-focus {
    background-position: -120px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:367 */
.x-form-trigger.x-form-trigger-default.x-form-trigger-click {
    background-position: -80px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:376 */
.x-textfield-default-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/Text.scss:54 */
.x-form-clear-trigger {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-clear-trigger:before {
    content: "\ed1d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/Text.scss:67 */
.x-form-search-trigger {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-search-trigger:before {
    content: "\ec8e";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/MessageBox.scss:1 */
.x-message-box .x-window-body {
    background-color: #fff;
    border-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/MessageBox.scss:10 */
.x-message-box-info,
.x-message-box-warning,
.x-message-box-question,
.x-message-box-error {
    background-position: left top;
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/MessageBox.scss:29 */
.x-message-box-icon {
    height: 44px;
    width: 44px;
    margin-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/MessageBox.scss:35 */
.x-message-box-info {
    font: 44px/1 Portfolio, FontAwesome, Extjs;
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-message-box-info:before {
    content: "\f05a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/MessageBox.scss:44 */
.x-message-box-warning {
    font: 44px/1 Portfolio, FontAwesome, Extjs;
    color: #f8d400;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-message-box-warning:before {
    content: "\f071";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/MessageBox.scss:53 */
.x-message-box-question {
    font: 44px/1 Portfolio, FontAwesome, Extjs;
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-message-box-question:before {
    content: "\f059";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/MessageBox.scss:62 */
.x-message-box-error {
    font: 44px/1 Portfolio, FontAwesome, Extjs;
    color: #ee611f;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-message-box-error:before {
    content: "\f057";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:89 */
.x-form-cb-wrap-default {
    height: 40px;
    min-width: 18px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:98 */
.x-form-cb-default {
    margin-top: 11px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:103 */
.x-form-checkbox-default,
.x-form-radio-default {
    width: 18px;
    height: 18px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:109 */
.x-form-radio-default {
    font: 18px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-radio-default:before {
    content: "\efbd";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:114 */
.x-form-cb-checked .x-form-radio-default {
    font: 18px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-cb-checked .x-form-radio-default:before {
    content: "\efbc";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:126 */
.x-form-checkbox-default {
    font: 18px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-checkbox-default:before {
    content: "\ea14";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:131 */
.x-form-cb-checked .x-form-checkbox-default {
    font: 18px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-cb-checked .x-form-checkbox-default:before {
    content: "\ea16";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:145 */
.x-keyboard-mode .x-form-checkbox-focus.x-form-radio-default {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:154 */
.x-keyboard-mode .x-form-checkbox-focus.x-form-checkbox-default {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:165 */
.x-keyboard-mode .x-form-cb-checked .x-form-checkbox-focus.x-form-radio-default {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:174 */
.x-keyboard-mode .x-form-cb-checked .x-form-checkbox-focus.x-form-checkbox-default {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:185 */
.x-form-cb-label-default {
    margin-top: 12px;
    font: 400 14px/17px Open Sans, sans-serif;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:190 */
.x-form-cb-label-default.x-form-cb-label-before {
    padding-right: 22px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:201 */
.x-form-cb-label-default.x-form-cb-label-after {
    padding-left: 22px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Checkbox.scss:215 */
.x-checkbox-default-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/CheckboxGroup.scss:96 */
.x-form-item-body-default.x-form-checkboxgroup-body {
    padding: 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/CheckboxGroup.scss:99 */
.x-form-invalid .x-form-item-body-default.x-form-checkboxgroup-body {
    border-width: 1px;
    border-style: solid;
    border-color: #d81818;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:282 */
.x-fieldset-default {
    border: 1px solid transparent;
    padding: 0px;
    margin: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:295 */
.x-ie8 .x-fieldset-default {
    padding-top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:298 */
.x-ie8 .x-fieldset-body-default {
    padding-top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:304 */
.x-fieldset-header-default {
    padding: 0px;
    line-height: 50px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:308 */
.x-fieldset-header-default > .x-fieldset-header-text {
    font: 700 14px/50px Open Sans, sans-serif;
    color: #000;
    padding: 1px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:315 */
.x-fieldset-header-checkbox-default {
    margin: 0px;
    line-height: 50px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:325 */
.x-fieldset-header-tool-default {
    margin: 0px;
    padding: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:334 */
.x-fieldset-header-tool-default > .x-tool-img {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
    height: 15px;
    width: 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:341 */
.x-fieldset-header-tool-default.x-tool-over > .x-tool-img {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=90)";
    opacity: 0.9;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:347 */
.x-fieldset-header-tool-default.x-tool-pressed > .x-tool-img {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:353 */
.x-fieldset-header-tool-default > .x-tool-toggle {
    font: 14px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-fieldset-header-tool-default > .x-tool-toggle:before {
    content: "\f146";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:373 */
.x-keyboard-mode .x-fieldset-header-tool-default.x-focus {
    outline: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:380 */
.x-fieldset-default.x-fieldset-collapsed {
    border-width: 1px 1px 0 1px;
    border-left-color: transparent;
    border-right-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/FieldSet.scss:389 */
.x-fieldset-default.x-fieldset-collapsed .x-tool-toggle {
    font: 14px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-fieldset-default.x-fieldset-collapsed .x-tool-toggle:before {
    content: "\f0fe";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:71 */
.x-form-trigger-spinner-default {
    width: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:79 */
.x-form-trigger-spinner-default:before {
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:85 */
.x-form-spinner-default {
    background-color: #fff;
    width: 40px;
    height: 19px;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:131 */
.x-form-spinner-up-default {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-spinner-up-default:before {
    content: "\e61c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:137 */
.x-form-spinner-down-default {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-spinner-down-default:before {
    content: "\e61b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:143 */
.x-form-spinner-up-default {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:146 */
.x-form-spinner-up-default.x-form-spinner-over {
    background-position: -40px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:148 */
.x-form-spinner-up-default.x-form-spinner-over.x-form-spinner-focus {
    background-position: -160px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:153 */
.x-form-spinner-up-default.x-form-spinner-focus {
    background-position: -120px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:158 */
.x-form-spinner-up-default.x-form-spinner.x-form-spinner-click {
    background-position: -80px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:163 */
.x-form-spinner-down-default {
    background-position: 0 -19px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:166 */
.x-form-spinner-down-default.x-form-spinner-over {
    background-position: -40px -19px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:168 */
.x-form-spinner-down-default.x-form-spinner-over.x-form-spinner-focus {
    background-position: -160px -19px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:173 */
.x-form-spinner-down-default.x-form-spinner-focus {
    background-position: -120px -19px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/trigger/Spinner.scss:178 */
.x-form-spinner-down-default.x-form-spinner.x-form-spinner-click {
    background-position: -80px -19px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/toolbar/Paging.scss:1 */
.x-tbar-page-number {
    width: 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/toolbar/Paging.scss:10 */
.x-btn-icon-el.x-tbar-page-first {
    font: 16px/16px Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-btn-icon-el.x-tbar-page-first:before {
    content: "\ed23";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/toolbar/Paging.scss:19 */
.x-btn-icon-el.x-tbar-page-prev {
    font: 16px/16px Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-btn-icon-el.x-tbar-page-prev:before {
    content: "\ed22";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/toolbar/Paging.scss:28 */
.x-btn-icon-el.x-tbar-page-next {
    font: 16px/16px Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-btn-icon-el.x-tbar-page-next:before {
    content: "\ed27";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/toolbar/Paging.scss:37 */
.x-btn-icon-el.x-tbar-page-last {
    font: 16px/16px Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-btn-icon-el.x-tbar-page-last:before {
    content: "\ed28";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/toolbar/Paging.scss:46 */
.x-btn-icon-el.x-tbar-loading {
    font: 16px/16px Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-btn-icon-el.x-tbar-loading:before {
    content: "\e91a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/BoundList.scss:1 */
.x-boundlist {
    border-width: 1px;
    border-style: solid;
    border-color: #d0d0d0;
    background: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/BoundList.scss:8 */
.x-boundlist-item {
    padding: 0 10px;
    font: 400 14px Open Sans, sans-serif;
    line-height: 30px;
    cursor: pointer;
    cursor: hand;
    position: relative;
    /*allow hover in IE on empty items*/
    border-width: 1px;
    border-style: dotted;
    border-color: #fff;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/BoundList.scss:25 */
.x-boundlist-selected {
    color: #fff;
    background: #00adee;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/BoundList.scss:33 */
.x-boundlist-item-over {
    color: #fff;
    background: #33bdf1;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/BoundList.scss:42 */
.x-boundlist-floating {
    border-top-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/BoundList.scss:46 */
.x-boundlist-above {
    border-top-width: 1px;
    border-bottom-width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:9 */
.x-datepicker {
    border-width: 1px;
    border-style: solid;
    border-color: #d0d0d0;
    background-color: #fff;
    width: 310px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:19 */
.x-datepicker-header {
    padding: 0;
    text-align: center;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:29 */
.x-datepicker-arrow {
    width: 32px;
    height: 44px;
    top: 0px;
    cursor: pointer;
    -webkit-touch-callout: none;
    color: #919191;
    background-color: #ececec;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:51 */
div.x-datepicker-arrow:hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:56 */
.x-datepicker-next {
    right: 0;
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-datepicker-next:before {
    content: "\f101";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:65 */
.x-datepicker-prev {
    left: 0;
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-datepicker-prev:before {
    content: "\f100";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:74 */
.x-datepicker-month {
    background: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:77 */
.x-datepicker-month .x-btn,
.x-datepicker-month .x-btn .x-btn-tc,
.x-datepicker-month .x-btn .x-btn-tl,
.x-datepicker-month .x-btn .x-btn-tr,
.x-datepicker-month .x-btn .x-btn-mc,
.x-datepicker-month .x-btn .x-btn-ml,
.x-datepicker-month .x-btn .x-btn-mr,
.x-datepicker-month .x-btn .x-btn-bc,
.x-datepicker-month .x-btn .x-btn-bl,
.x-datepicker-month .x-btn .x-btn-br {
    background: transparent;
    border-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:93 */
.x-datepicker-month .x-btn-inner {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:98 */
.x-datepicker-month .x-btn-split-right:after,
.x-datepicker-month .x-btn-over .x-btn-split-right:after {
    content: "\f107";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    background: none;
    padding: 0;
    text-align: right;
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:111 */
.x-datepicker-month .x-btn {
    padding: 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:115 */
.x-datepicker-month .x-btn-over {
    border-color: transparent;
    background: #dfdfdf;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:120 */
.x-datepicker-month .x-btn.x-btn-pressed {
    border-color: transparent;
    background: #d3d3d3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:125 */
.x-datepicker-month .x-btn-inner {
    font-size: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:130 */
.x-datepicker-column-header {
    width: 44px;
    color: #000;
    font: 400 14px Open Sans, sans-serif;
    text-align: right;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:149 */
.x-datepicker-column-header-inner {
    line-height: 36px;
    padding: 0 15px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:154 */
.x-datepicker-cell {
    text-align: right;
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:163 */
.x-datepicker-date {
    padding: 0 15px 0 0;
    font: 400 14px Open Sans, sans-serif;
    color: #000;
    cursor: pointer;
    line-height: 36px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:173 */
div.x-datepicker-date:hover {
    color: #000;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:178 */
.x-datepicker-selected {
    border-style: solid;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:181 */
.x-datepicker-selected div.x-datepicker-date {
    background-color: #00adee;
    color: #fff;
    font-weight: 400;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:188 */
.x-datepicker-today {
    border-color: darkred;
    border-style: solid;
    background-color: #99def8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:199 */
.x-datepicker-prevday .x-datepicker-date,
.x-datepicker-nextday .x-datepicker-date {
    color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:206 */
.x-datepicker-disabled .x-datepicker-date {
    background-color: #eee;
    cursor: default;
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:214 */
.x-datepicker-disabled div.x-datepicker-date:hover {
    background-color: #eee;
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:219 */
.x-datepicker-footer,
.x-monthpicker-buttons {
    padding: 6px 0;
    background-color: #fff;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:236 */
.x-datepicker-footer .x-btn,
.x-monthpicker-buttons .x-btn {
    margin: 0 3px 0 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:242 */
.x-monthpicker {
    width: 310px;
    border-width: 1px;
    border-style: solid;
    border-color: #d0d0d0;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:252 */
.x-monthpicker-months {
    border-width: 0 1px 0 0;
    border-color: #d0d0d0;
    border-style: solid;
    width: 154px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:261 */
.x-monthpicker-months .x-monthpicker-item {
    width: 76px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:266 */
.x-monthpicker-years {
    width: 154px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:269 */
.x-monthpicker-years .x-monthpicker-item {
    width: 77px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:274 */
.x-monthpicker-item {
    margin: 5px 0 5px;
    font: 400 14px Open Sans, sans-serif;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:280 */
.x-monthpicker-item-inner {
    margin: 0 5px 0 5px;
    color: #000;
    border: 0;
    line-height: 37px;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:295 */
a.x-monthpicker-item-inner:hover {
    color: #000;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:301 */
.x-monthpicker-item a.x-monthpicker-selected {
    background-color: #00adee;
    color: #fff;
    border-style: solid;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:308 */
.x-monthpicker-yearnav {
    height: 47px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:312 */
.x-monthpicker-yearnav-button-ct {
    width: 77px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:316 */
.x-monthpicker-yearnav-button {
    height: 16px;
    width: 16px;
    cursor: pointer;
    margin-top: 15px;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    opacity: 0.7;
    -webkit-touch-callout: none;
    color: #919191;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:337 */
a.x-monthpicker-yearnav-button:hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:342 */
.x-monthpicker-yearnav-next {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-monthpicker-yearnav-next:before {
    content: "\f101";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:356 */
.x-monthpicker-yearnav-prev {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-monthpicker-yearnav-prev:before {
    content: "\f100";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:371 */
.x-monthpicker-small .x-monthpicker-item {
    margin: 2px 0 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:375 */
.x-monthpicker-small .x-monthpicker-item-inner {
    margin: 0 5px 0 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:379 */
.x-monthpicker-small .x-monthpicker-yearnav {
    height: 41px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Date.scss:383 */
.x-monthpicker-small .x-monthpicker-yearnav-button {
    margin-top: 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/Date.scss:2 */
.x-form-field-date .x-form-date-trigger {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-field-date .x-form-date-trigger:before {
    content: "\f073";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Display.scss:52 */
.x-form-display-field-default {
    min-height: 40px;
    font: 400 14px/17px Open Sans, sans-serif;
    color: #000;
    margin-top: 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Display.scss:60 */
.x-keyboard-mode .x-form-display-field-default.x-field-form-focus {
    outline: 1px solid #00adee;
    outline-offset: -1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-form-display-field-default.x-field-form-focus,
.x-ie10p .x-keyboard-mode .x-form-display-field-default.x-field-form-focus,
.x-edge .x-keyboard-mode .x-form-display-field-default.x-field-form-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-form-display-field-default.x-field-form-focus:after,
.x-ie10p .x-keyboard-mode .x-form-display-field-default.x-field-form-focus:after,
.x-edge .x-keyboard-mode .x-form-display-field-default.x-field-form-focus:after {
    position: absolute;
    content: ' ';
    top: 0px;
    right: 0px;
    bottom: 0px;
    left: 0px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Display.scss:71 */
.x-ie8 .x-form-display-field-default.x-field-form-focus {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tip-default {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    -ms-border-radius: 2px;
    -o-border-radius: 2px;
    border-radius: 2px;
    padding: 1px 1px 1px 1px;
    border-width: 1px;
    border-style: solid;
    background-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tip-default-mc {
    background-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tip-default {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tip-default-frameInfo {
    font-family: th-2-2-2-2-1-1-1-1-1-1-1-1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tip-default-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tip-default-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tip-default-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tip-default-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tip-default-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tip-default-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tip-default-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tip-default-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tip-default-tr,
.x-tip-default-br,
.x-tip-default-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tip-default-tl,
.x-tip-default-bl,
.x-tip-default-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tip-default-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tip-default-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tip-default-tl,
.x-tip-default-bl,
.x-tip-default-tr,
.x-tip-default-br,
.x-tip-default-tc,
.x-tip-default-bc,
.x-tip-default-ml,
.x-tip-default-mr {
    background-image: url(images/tip/tip-default-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tip-default-ml,
.x-tip-default-mr {
    background-image: url(images/tip/tip-default-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tip-default-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:318 */
.x-tip-default {
    background-color: #747474;
    border-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:328 */
.x-tip-default .x-tool-img {
    background-image: url(images/tools/tool-sprites-dark.png);
    background-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:343 */
.x-tip-header-default .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:353 */
.x-tip-header-default .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:364 */
.x-tip-header-default {
    padding: 3px 3px 0 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:368 */
.x-tip-header-title-default {
    color: #f0f0f0;
    font-size: 14px;
    font-weight: bold;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:374 */
.x-tip-body-default {
    padding: 6px 8px;
    color: #f0f0f0;
    font-size: 14px;
    font-weight: 400;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:379 */
.x-tip-body-default a {
    color: #f0f0f0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:390 */
.x-tip-default .x-tip-anchor {
    border: 10px solid transparent;
    _border-color: pink;
    _filter: chroma(color=pink);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:467 */
.x-tip-default .x-tip-anchor-top {
    border-top-width: 0;
    border-bottom: 10px solid #747474;
    top: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:473 */
.x-tip-default .x-tip-anchor-bottom {
    border-bottom-width: 0;
    border-top: 10px solid #747474;
    bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:479 */
.x-tip-default .x-tip-anchor-left {
    border-left-width: 0;
    border-right: 10px solid #747474;
    left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:485 */
.x-tip-default .x-tip-anchor-right {
    border-right-width: 0;
    border-left: 10px solid #747474;
    right: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tip-form-invalid {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    -ms-border-radius: 2px;
    -o-border-radius: 2px;
    border-radius: 2px;
    padding: 1px 1px 1px 1px;
    border-width: 1px;
    border-style: solid;
    background-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tip-form-invalid-mc {
    background-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tip-form-invalid {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tip-form-invalid-frameInfo {
    font-family: th-2-2-2-2-1-1-1-1-1-1-1-1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tip-form-invalid-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tip-form-invalid-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tip-form-invalid-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tip-form-invalid-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tip-form-invalid-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tip-form-invalid-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tip-form-invalid-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tip-form-invalid-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tip-form-invalid-tr,
.x-tip-form-invalid-br,
.x-tip-form-invalid-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tip-form-invalid-tl,
.x-tip-form-invalid-bl,
.x-tip-form-invalid-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tip-form-invalid-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tip-form-invalid-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tip-form-invalid-tl,
.x-tip-form-invalid-bl,
.x-tip-form-invalid-tr,
.x-tip-form-invalid-br,
.x-tip-form-invalid-tc,
.x-tip-form-invalid-bc,
.x-tip-form-invalid-ml,
.x-tip-form-invalid-mr {
    background-image: url(images/tip/tip-form-invalid-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tip-form-invalid-ml,
.x-tip-form-invalid-mr {
    background-image: url(images/tip/tip-form-invalid-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tip-form-invalid-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:318 */
.x-tip-form-invalid {
    background-color: #747474;
    border-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:328 */
.x-tip-form-invalid .x-tool-img {
    background-image: url(images/tools/tool-sprites-dark.png);
    background-color: #747474;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:343 */
.x-tip-header-form-invalid .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:353 */
.x-tip-header-form-invalid .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:364 */
.x-tip-header-form-invalid {
    padding: 3px 3px 0 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:368 */
.x-tip-header-title-form-invalid {
    color: #f0f0f0;
    font-size: 14px;
    font-weight: bold;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:374 */
.x-tip-body-form-invalid {
    padding: 3px 3px 3px 22px;
    color: #f0f0f0;
    font-size: 14px;
    font-weight: 400;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:379 */
.x-tip-body-form-invalid a {
    color: #f0f0f0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:390 */
.x-tip-form-invalid .x-tip-anchor {
    border: 10px solid transparent;
    _border-color: pink;
    _filter: chroma(color=pink);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:467 */
.x-tip-form-invalid .x-tip-anchor-top {
    border-top-width: 0;
    border-bottom: 10px solid #747474;
    top: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:473 */
.x-tip-form-invalid .x-tip-anchor-bottom {
    border-bottom-width: 0;
    border-top: 10px solid #747474;
    bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:479 */
.x-tip-form-invalid .x-tip-anchor-left {
    border-left-width: 0;
    border-right: 10px solid #747474;
    left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tip/Tip.scss:485 */
.x-tip-form-invalid .x-tip-anchor-right {
    border-right-width: 0;
    border-left: 10px solid #747474;
    right: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tip/Tip.scss:25 */
.x-tip-body-form-invalid {
    background: 1px 1px no-repeat;
    background-image: url(images/form/exclamation.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tip/Tip.scss:28 */
.x-tip-body-form-invalid li {
    margin-bottom: 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tip/Tip.scss:30 */
.x-tip-body-form-invalid li.last {
    margin-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Color.scss:1 */
.x-color-picker {
    width: 192px;
    height: 120px;
    background-color: #fff;
    border-color: #fff;
    border-width: 0;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Color.scss:10 */
.x-color-picker-item {
    width: 24px;
    height: 24px;
    border-width: 1px;
    border-color: #fff;
    border-style: solid;
    background-color: #fff;
    cursor: pointer;
    padding: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Color.scss:22 */
a.x-color-picker-item:hover {
    border-color: #8bb8f3;
    background-color: #d9d9d9;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Color.scss:27 */
.x-color-picker-selected {
    border-color: #8bb8f3;
    background-color: #d9d9d9;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/picker/Color.scss:32 */
.x-color-picker-item-inner {
    line-height: 16px;
    border-color: #d0d0d0;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:1 */
.x-html-editor-tb .x-btn-icon-el {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:7 */
.x-html-editor-tb .x-edit-bold,
.x-menu-item div.x-edit-bold {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-bold:before,
.x-menu-item div.x-edit-bold:before {
    content: "\f032";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:18 */
.x-html-editor-tb .x-edit-italic,
.x-menu-item div.x-edit-italic {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-italic:before,
.x-menu-item div.x-edit-italic:before {
    content: "\f033";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:29 */
.x-html-editor-tb .x-edit-underline,
.x-menu-item div.x-edit-underline {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-underline:before,
.x-menu-item div.x-edit-underline:before {
    content: "\f0cd";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:40 */
.x-html-editor-tb .x-edit-forecolor,
.x-menu-item div.x-edit-forecolor {
    font: 16px/1 ExtJS;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-forecolor:before,
.x-menu-item div.x-edit-forecolor:before {
    content: "\e60e";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:51 */
.x-html-editor-tb .x-edit-backcolor,
.x-menu-item div.x-edit-backcolor {
    font: 16px/1 ExtJS;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-backcolor:before,
.x-menu-item div.x-edit-backcolor:before {
    content: "\e60d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:62 */
.x-html-editor-tb .x-edit-justifyleft,
.x-menu-item div.x-edit-justifyleft {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-justifyleft:before,
.x-menu-item div.x-edit-justifyleft:before {
    content: "\f036";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:73 */
.x-html-editor-tb .x-edit-justifycenter,
.x-menu-item div.x-edit-justifycenter {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-justifycenter:before,
.x-menu-item div.x-edit-justifycenter:before {
    content: "\f037";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:84 */
.x-html-editor-tb .x-edit-justifyright,
.x-menu-item div.x-edit-justifyright {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-justifyright:before,
.x-menu-item div.x-edit-justifyright:before {
    content: "\f038";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:95 */
.x-html-editor-tb .x-edit-insertorderedlist,
.x-menu-item div.x-edit-insertorderedlist {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-insertorderedlist:before,
.x-menu-item div.x-edit-insertorderedlist:before {
    content: "\f0cb";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:106 */
.x-html-editor-tb .x-edit-insertunorderedlist,
.x-menu-item div.x-edit-insertunorderedlist {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-insertunorderedlist:before,
.x-menu-item div.x-edit-insertunorderedlist:before {
    content: "\f0ca";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:117 */
.x-html-editor-tb .x-edit-increasefontsize,
.x-menu-item div.x-edit-increasefontsize {
    font: 16px/1 ExtJS;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-increasefontsize:before,
.x-menu-item div.x-edit-increasefontsize:before {
    content: "\e610";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:128 */
.x-html-editor-tb .x-edit-decreasefontsize,
.x-menu-item div.x-edit-decreasefontsize {
    font: 16px/1 ExtJS;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-decreasefontsize:before,
.x-menu-item div.x-edit-decreasefontsize:before {
    content: "\e60f";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:139 */
.x-html-editor-tb .x-edit-sourceedit,
.x-menu-item div.x-edit-sourceedit {
    font: 16px/1 ExtJS;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-sourceedit:before,
.x-menu-item div.x-edit-sourceedit:before {
    content: "\e604";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:150 */
.x-html-editor-tb .x-edit-createlink,
.x-menu-item div.x-edit-createlink {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-html-editor-tb .x-edit-createlink:before,
.x-menu-item div.x-edit-createlink:before {
    content: "\f0c1";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:161 */
.x-html-editor-tip .x-tip-bd .x-tip-bd-inner {
    padding: 5px;
    padding-bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:166 */
.x-html-editor-tb .x-font-select {
    font-size: 14px;
    font-family: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:171 */
.x-html-editor-wrap textarea {
    font: 400 14px Open Sans, sans-serif;
    background-color: #fff;
    resize: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/form/field/HtmlEditor.scss:177 */
.x-htmleditor-iframe {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:320 */
.x-form-text-default.x-tagfield {
    padding: 3px 0 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:324 */
.x-form-text-default .x-tagfield-input {
    margin: 0 4px 3px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:328 */
.x-form-text-default .x-tagfield-input-field {
    height: 24px;
    line-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:333 */
.x-form-text-default .x-tagfield-item {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
    background-color: #ececec;
    border: 1px solid #ececec;
    padding: 0 21px 0 5px;
    margin: 0 4px 3px 0;
    color: #000;
    line-height: 22px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:344 */
.x-form-text-default .x-tagfield-item:hover {
    background-color: #e5e5e5;
    border-color: #e5e5e5;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:352 */
.x-form-text-default .x-tagfield-item.x-tagfield-item-selected {
    background-color: #33bdf1;
    border-color: #33bdf1;
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:367 */
.x-form-text-default .x-tagfield-item-close {
    width: 12px;
    height: 12px;
    top: 5px;
    right: 3px;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=85)";
    opacity: 0.85;
    font: 12px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-text-default .x-tagfield-item-close:before {
    content: "\f00d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:384 */
.x-form-text-default .x-tagfield-item-close:hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=93)";
    opacity: 0.93;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:395 */
.x-form-text-default .x-tagfield-item-close:active {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:412 */
.x-form-text-default .x-tagfield-item-selected .x-tagfield-item-close {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Tag.scss:416 */
.x-form-text-default .x-tagfield-item-selected .x-tagfield-item-close:hover {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:5 */
.x-grid-view,
.x-tree-view {
    z-index: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:11 */
.x-theme-row-height-el {
    height: 33px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:15 */
.x-grid-body {
    background: #fff;
    border-width: 2px 1px 1px;
    border-style: solid;
    border-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:22 */
.x-grid-empty {
    padding: 10px;
    color: grey;
    background-color: #fff;
    font: 400 14px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:30 */
.x-grid-item {
    color: #000;
    font: 400 14px/20px Open Sans, sans-serif;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:36 */
.x-grid-item-alt {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:40 */
.x-grid-item-over {
    color: #000;
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:47 */
.x-grid-item-focused {
    outline: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:51 */
.x-grid-item-focused .x-grid-cell-inner {
    z-index: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:57 */
.x-keyboard-mode .x-grid-item-focused {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:60 */
.x-keyboard-mode .x-grid-item-focused .x-grid-cell-inner:before {
    content: "";
    position: absolute;
    z-index: -1;
    top: 0px;
    right: 0px;
    bottom: 0px;
    left: 0px;
    pointer-events: none;
    border: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:83 */
.x-grid-item-selected {
    color: #000;
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:89 */
.x-grid-with-row-lines .x-grid-item {
    border-style: solid;
    border-width: 1px 0 0;
    border-color: #e9e9e9;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:95 */
.x-grid-with-row-lines .x-grid-item:first-child {
    border-top-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:101 */
.x-grid-with-row-lines .x-grid-item.x-grid-item-over {
    border-style: solid;
    border-color: rgba(0, 76, 105, 0.126);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:106 */
.x-grid-with-row-lines .x-grid-item-over + .x-grid-item {
    border-top-style: solid;
    border-top-color: rgba(0, 76, 105, 0.126);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:111 */
.x-grid-with-row-lines .x-grid-item.x-grid-item-selected {
    border-style: solid;
    border-color: rgba(0, 76, 105, 0.126);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:116 */
.x-grid-with-row-lines .x-grid-item-selected + .x-grid-item {
    border-top-style: solid;
    border-top-color: rgba(0, 76, 105, 0.126);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:121 */
.x-grid-with-row-lines .x-grid-item:last-child {
    border-bottom-width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:131 */
.x-ie8 .x-grid-with-row-lines .x-grid-item {
    border-width: 1px 0;
    margin-top: -1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:136 */
.x-ie8 .x-grid-with-row-lines .x-grid-item:first-child {
    margin-top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:142 */
.x-grid-cell-inner {
    position: relative;
    text-overflow: ellipsis;
    padding: 7px 10px 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:158 */
.x-grid-cell-special {
    border-color: #e9e9e9;
    border-style: solid;
    border-right-width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:210 */
.x-grid-dirty-cell > .x-grid-cell-inner:after {
    content: "\e602";
    font: 14px/1 ExtJS;
    color: #cf4c35;
    position: absolute;
    top: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:238 */
.x-grid-row .x-grid-cell-selected {
    color: #000;
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:245 */
.x-grid-with-col-lines .x-grid-cell {
    border-style: solid;
    border-color: #e9e9e9;
    border-width: 0 1px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:251 */
.x-grid-with-col-lines .x-grid-item-over .x-grid-cell {
    border-color: rgba(0, 76, 105, 0.126);
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:256 */
.x-grid-with-col-lines .x-grid-item-selected .x-grid-cell {
    border-color: rgba(0, 76, 105, 0.126);
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/Table.scss:269 */
.x-grid-resize-marker {
    width: 1px;
    background-color: #0f0f0f;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/DropZone.scss:1 */
.x-grid-drop-indicator {
    position: absolute;
    height: 1px;
    line-height: 0px;
    background-color: #77bc71;
    overflow: visible;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/DropZone.scss:9 */
.x-grid-drop-indicator .x-grid-drop-indicator-left {
    position: absolute;
    top: -8px;
    left: -12px;
    background-image: url(images/grid/dd-insert-arrow-right.png);
    height: 16px;
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/DropZone.scss:18 */
.x-grid-drop-indicator .x-grid-drop-indicator-right {
    position: absolute;
    top: -8px;
    right: -11px;
    background-image: url(images/grid/dd-insert-arrow-left.png);
    height: 16px;
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/DropZone.scss:1 */
.x-col-move-top,
.x-col-move-bottom {
    width: 9px;
    height: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/DropZone.scss:7 */
.x-col-move-top {
    background-image: url(images/grid/col-move-top.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/DropZone.scss:11 */
.x-col-move-bottom {
    background-image: url(images/grid/col-move-bottom.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/Container.scss:1 */
.x-grid-header-ct {
    border: 1px solid #d0d0d0;
    border-bottom-color: #ececec;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/Container.scss:14 */
.x-accordion-item .x-grid-header-ct {
    border-width: 0 0 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/Container.scss:21 */
.x-grid-header-ct-hidden {
    border-top: 0 !important;
    border-bottom: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/Container.scss:31 */
.x-grid-body {
    border-top-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/Container.scss:35 */
.x-hmenu-sort-asc {
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-hmenu-sort-asc:before {
    content: "\ee97";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/Container.scss:46 */
.x-hmenu-sort-desc {
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-hmenu-sort-desc:before {
    content: "\ee94";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/header/Container.scss:57 */
.x-cols-icon {
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-cols-icon:before {
    content: "\efc7";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:1 */
.x-column-header {
    border-right: 1px solid #d0d0d0;
    color: #000;
    font: bold 14px/20px Open Sans, sans-serif;
    outline: 0;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:27 */
.x-group-sub-header {
    background: transparent;
    border-top: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:32 */
.x-group-sub-header .x-column-header-inner {
    padding: -1px 10px 0px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:37 */
.x-column-header-inner {
    padding: 0px 10px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:41 */
.x-column-header-inner-empty {
    text-overflow: clip;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:50 */
.x-keyboard-mode .x-column-header.x-column-header-focus {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:51 */
.x-keyboard-mode .x-column-header.x-column-header-focus .x-column-header-inner:after {
    content: "";
    position: absolute;
    z-index: 5;
    top: 0px;
    right: 0px;
    bottom: 0px;
    left: 0px;
    border: 1px solid #2fbaee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:65 */
.x-keyboard-mode .x-column-header.x-column-header-focus.x-group-sub-header .x-column-header-inner:before {
    bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:79 */
.x-column-header-over {
    background-image: none;
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:83 */
.x-column-header-sort-ASC,
.x-column-header-sort-DESC {
    background-image: none;
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:111 */
.x-column-header-open {
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:114 */
.x-column-header-open .x-column-header-trigger {
    background-color: rgba(0, 76, 105, 0.126);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:119 */
.x-column-header-over .x-column-header-trigger,
.x-column-header-open .x-column-header-trigger {
    width: 24px;
    cursor: pointer;
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-column-header-over .x-column-header-trigger:before,
.x-column-header-open .x-column-header-trigger:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:127 */
.x-column-header-over .x-column-header-trigger:before,
.x-column-header-open .x-column-header-trigger:before {
    top: 50%;
    margin-top: -8px;
    text-align: center;
    position: relative;
    display: block;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:151 */
.x-column-header-align-right .x-column-header-text {
    margin-right: 18px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:165 */
.x-column-header-sort-ASC .x-column-header-text-inner,
.x-column-header-sort-DESC .x-column-header-text-inner {
    background-position: right center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:167 */
.x-column-header-sort-ASC .x-column-header-text-inner:after,
.x-column-header-sort-DESC .x-column-header-text-inner:after {
    display: inline-block;
    text-align: center;
    margin-left: 5px;
    width: 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:139 */
.x-column-header-sort-ASC .x-column-header-text-inner:after {
    content: "\ee97";
    font-family: Portfolio, FontAwesome, Extjs;
    line-height: 1;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:139 */
.x-column-header-sort-DESC .x-column-header-text-inner:after {
    content: "\ee94";
    font-family: Portfolio, FontAwesome, Extjs;
    line-height: 1;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:224 */
.x-no-header-borders .x-column-header {
    border: 0 none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Column.scss:227 */
.x-no-header-borders .x-column-header .x-column-header-inner {
    padding-top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Action.scss:1 */
.x-grid-cell-inner-action-col {
    padding: 8px 4px 7px 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Action.scss:14 */
.x-action-col-cell .x-item-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Action.scss:18 */
.x-action-col-icon {
    color: #000;
    font-size: 18px;
    height: 18px;
    width: 18px;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Check.scss:2 */
.x-column-header-checkbox .x-column-header-inner,
.x-grid-checkcolumn-cell-inner {
    padding: 8px 4px 7px 4px;
    text-overflow: clip;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Check.scss:20 */
.x-column-header-checkbox {
    border-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Check.scss:22 */
.x-column-header-checkbox .x-column-header-text {
    overflow: visible;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:139 */
.x-column-header-checkbox .x-column-header-checkbox:after,
.x-grid-checkcolumn:after {
    content: "\ea14";
    font: 18px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Check.scss:42 */
.x-item-disabled .x-column-header-checkbox .x-column-header-checkbox,
.x-item-disabled .x-grid-checkcolumn {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:139 */
.x-grid-hd-checker-on .x-column-header-checkbox:after,
.x-grid-checkcolumn-checked:after {
    content: "\ea16";
    font: 18px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:139 */
.x-grid-item-selected .x-selmodel-column .x-grid-checkcolumn:after {
    content: "\ea16";
    font: 18px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Check.scss:79 */
.x-gecko .x-selmodel-checkbox .x-grid-checkcolumn {
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/RowNumberer.scss:1 */
.x-grid-cell-row-numberer {
    background-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/RowNumberer.scss:10 */
.x-grid-cell-inner-row-numberer {
    padding: 7px 5px 6px 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-grid-cell-small {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
    padding: 7px 7px 7px 7px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-grid-cell-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-grid-cell-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-grid-cell-small-frameInfo {
    font-family: th-1-1-1-1-1-1-1-1-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-grid-cell-small-tl {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-grid-cell-small-tr {
    background-position: right -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-grid-cell-small-bl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-grid-cell-small-br {
    background-position: right -5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-grid-cell-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-grid-cell-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-grid-cell-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-grid-cell-small-bc {
    background-position: 0 -1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-grid-cell-small-tr,
.x-btn-grid-cell-small-br,
.x-btn-grid-cell-small-mr {
    padding-right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-grid-cell-small-tl,
.x-btn-grid-cell-small-bl,
.x-btn-grid-cell-small-ml {
    padding-left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-grid-cell-small-tc {
    height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-grid-cell-small-bc {
    height: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-grid-cell-small-tl,
.x-btn-grid-cell-small-bl,
.x-btn-grid-cell-small-tr,
.x-btn-grid-cell-small-br,
.x-btn-grid-cell-small-tc,
.x-btn-grid-cell-small-bc,
.x-btn-grid-cell-small-ml,
.x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-grid-cell-small-ml,
.x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-grid-cell-small-mc {
    padding: 7px 7px 7px 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-grid-cell-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-grid-cell-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-grid-cell-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-grid-cell-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-grid-cell-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-grid-cell-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-grid-cell-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-grid-cell-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-grid-cell-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-grid-cell-small {
    font-size: 16px;
    height: 16px;
    color: #000;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-grid-cell-small,
.x-btn-icon-right > .x-btn-icon-el-grid-cell-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-grid-cell-small,
.x-btn-icon-bottom > .x-btn-icon-el-grid-cell-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-grid-cell-small.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-grid-cell-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-grid-cell-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-grid-cell-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-grid-cell-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-grid-cell-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-grid-cell-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-grid-cell-small,
.x-btn-split-bottom > .x-btn-button-grid-cell-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-grid-cell-small.x-btn-arrow-right:after {
    width: 8px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-grid-cell-small.x-btn-arrow-bottom:after {
    height: 8px;
    content: "\ed1b";
    font: 16px/8px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-grid-cell-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-grid-cell-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-grid-cell-small.x-btn-split-right:after {
    width: 14px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-grid-cell-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-grid-cell-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-grid-cell-small.x-btn-split-bottom:after {
    height: 14px;
    content: "\ed1b";
    font: 16px/14px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-grid-cell-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-grid-cell-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-grid-cell-small {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-grid-cell-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 21px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-grid-cell-small {
    border-color: #343434;
    background-image: none;
    background-color: #ebebeb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-grid-cell-small,
.x-btn.x-btn-pressed.x-btn-grid-cell-small {
    border-color: #2b2b2b;
    background-image: none;
    background-color: #bfbfbf;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-grid-cell-small {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-bc {
    background-image: url(images/btn/btn-grid-cell-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-grid-cell-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-grid-cell-small-tl,
.x-btn-over .x-btn-grid-cell-small-bl,
.x-btn-over .x-btn-grid-cell-small-tr,
.x-btn-over .x-btn-grid-cell-small-br,
.x-btn-over .x-btn-grid-cell-small-tc,
.x-btn-over .x-btn-grid-cell-small-bc {
    background-image: url(images/btn/btn-grid-cell-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-grid-cell-small-ml,
.x-btn-over .x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-grid-cell-small-mc {
    background-color: #ebebeb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-bc {
    background-image: url(images/btn/btn-grid-cell-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-grid-cell-small-mc {
    background-color: #ebebeb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-tl,
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-bl,
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-tr,
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-br,
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-tc,
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-bc,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-tl,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-bl,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-tr,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-br,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-tc,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-bc {
    background-image: url(images/btn/btn-grid-cell-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-ml,
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-mr,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-ml,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-grid-cell-small-mc,
.x-btn.x-btn-pressed .x-btn-grid-cell-small-mc {
    background-color: #bfbfbf;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-bc {
    background-image: url(images/btn/btn-grid-cell-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-grid-cell-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-grid-cell-small-mc {
    background-color: #bfbfbf;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-grid-cell-small-tl,
.x-btn.x-btn-disabled .x-btn-grid-cell-small-bl,
.x-btn.x-btn-disabled .x-btn-grid-cell-small-tr,
.x-btn.x-btn-disabled .x-btn-grid-cell-small-br,
.x-btn.x-btn-disabled .x-btn-grid-cell-small-tc,
.x-btn.x-btn-disabled .x-btn-grid-cell-small-bc {
    background-image: url(images/btn/btn-grid-cell-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-grid-cell-small-ml,
.x-btn.x-btn-disabled .x-btn-grid-cell-small-mr {
    background-image: url(images/btn/btn-grid-cell-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-grid-cell-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-grid-cell-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-grid-cell-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small.x-segmented-button-first .x-btn-grid-cell-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small.x-segmented-button-middle .x-btn-grid-cell-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small.x-segmented-button-last .x-btn-grid-cell-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small.x-segmented-button-first .x-btn-grid-cell-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small.x-segmented-button-middle .x-btn-grid-cell-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small.x-segmented-button-last .x-btn-grid-cell-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-grid-cell-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-grid-cell-small.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-grid-cell-small.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-grid-cell-small-cell > .x-grid-cell-inner {
    padding-top: 1px;
    padding-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-grid-cell-small-cell > .x-grid-cell-inner >.x-btn-grid-cell-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/column/Widget.scss:110 */
.x-grid-widgetcolumn-cell-inner {
    text-overflow: clip;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Grouping.scss:1 */
.x-grid-group-hd {
    border-width: 0 0 1px 0;
    border-style: solid;
    border-color: #d0d0d0;
    padding: 8px 10px;
    background: #fff;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Grouping.scss:10 */
.x-grid-group-hd-not-collapsible {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Grouping.scss:14 */
.x-grid-group-hd-collapsible .x-grid-group-title {
    padding: 0 0 0 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-group-hd-collapsible .x-grid-group-title:before {
    content: "\ed1e";
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Grouping.scss:36 */
.x-grid-group-title {
    color: #000;
    font: bold 14px/16px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-group-hd-collapsed .x-grid-group-title:before {
    content: "\ed27";
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Grouping.scss:54 */
.x-group-by-icon {
    font-family: Portfolio, FontAwesome, Extjs;
    line-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-group-by-icon:before {
    content: "\efcc";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/RowBody.scss:1 */
.x-grid-rowbody {
    font: 400 14px/20px Open Sans, sans-serif;
    padding: 5px 10px 5px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Summary.scss:1 */
.x-docked-summary {
    border-width: 1px;
    border-color: #d0d0d0;
    border-style: solid;
    background: #fff!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Summary.scss:6 */
.x-docked-summary .x-grid-table {
    border: 0 none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Summary.scss:14 */
.x-grid-row-summary .x-grid-cell,
.x-grid-row-summary .x-grid-rowwrap,
.x-grid-row-summary .x-grid-cell-rowbody {
    border-color: #e9e9e9;
    background-color: #fff !important;
    border-top: 1px solid #e9e9e9;
    font: 400 14px/20px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Summary.scss:26 */
.x-docked-summary .x-grid-item,
.x-docked-summary .x-grid-row-summary .x-grid-cell {
    border-bottom: 0 none;
    border-top: 0 none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Summary.scss:34 */
.x-docked-summary > :first-child {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/feature/Summary.scss:40 */
.x-grid-row-summary .x-grid-cell-inner-row-expander {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:818 */
.x-menu-default {
    border-style: solid;
    border-width: 1px;
    border-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:824 */
.x-menu-body-default {
    background: #fff;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:829 */
.x-menu-icon-separator-default {
    left: 32px;
    border-left: solid 1px #d0d0d0;
    background-color: #fff;
    width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:843 */
.x-menu-item-default {
    border-width: 0;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:849 */
.x-menu-item-default.x-menu-item-focus,
.x-menu-item-default.x-menu-item-active {
    background-image: none;
    background-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:862 */
.x-nlg .x-menu-item-default.x-menu-item-focus,
.x-nlg .x-menu-item-default.x-menu-item-active {
    background: #33bdf1 repeat-x left top;
    background-image: url(images/menu/menu-item-default-active-bg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:869 */
.x-menu-item-default.x-menu-item-disabled {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:872 */
.x-menu-item-default.x-menu-item-disabled a {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:877 */
.x-menu-item-default.x-menu-item-separator {
    height: 1px;
    border-top: solid 1px #d0d0d0;
    background-color: #fff;
    margin: 2px 0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:885 */
.x-menu-item-default.x-menu-item-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:890 */
.x-ie9m .x-menu-item-default.x-menu-item-disabled .x-menu-item-icon-ui {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:894 */
.x-ie9m .x-menu-item-default.x-menu-item-disabled .x-menu-item-text-default {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:904 */
.x-menu-item-default .x-form-item-label {
    font-size: 14px;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:911 */
.x-menu-item-text-default,
.x-menu-item-cmp-default {
    margin: 0 8px 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:916 */
.x-menu-item-text-default {
    font: 400 14px Open Sans, sans-serif;
    line-height: 31px;
    padding-top: 1px;
    color: #000;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:928 */
.x-menu-item-focus .x-menu-item-text-default,
.x-menu-item-active .x-menu-item-text-default {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:934 */
.x-menu-item-text-default.x-menu-item-indent {
    margin-left: 41px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:938 */
.x-menu-item-text-default.x-menu-item-indent-no-separator {
    margin-left: 36px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:942 */
.x-menu-item-text-default.x-menu-item-indent-right-icon {
    margin-right: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:946 */
.x-menu-item-text-default.x-menu-item-indent-right-arrow {
    margin-right: 29px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:950 */
.x-menu-item-disabled .x-menu-item-text-default {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:982 */
.x-menu-item-indent-default {
    margin-left: 41px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:992 */
.x-menu-item-icon-default {
    width: 24px;
    height: 24px;
    top: 4px;
    left: 4px;
    line-height: 24px;
    font-size: 16px;
    color: #000;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1041 */
.x-ie8 .x-menu-item-icon-default.x-menu-item-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1049 */
.x-menu-item-icon-default.x-menu-item-icon-right {
    width: 24px;
    height: 24px;
    top: 4px;
    right: 4px;
    left: auto;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1070 */
.x-menu-item-icon-default.x-menu-item-checkbox {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1080 */
.x-menu-item-focus .x-menu-item-icon-default.x-menu-item-checkbox,
.x-menu-item-active .x-menu-item-icon-default.x-menu-item-checkbox {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1087 */
.x-menu-item-checked .x-menu-item-icon-default.x-menu-item-checkbox {
    font: 18px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-checked .x-menu-item-icon-default.x-menu-item-checkbox:before {
    content: "\ea16";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1095 */
.x-menu-item-unchecked .x-menu-item-icon-default.x-menu-item-checkbox {
    font: 18px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-unchecked .x-menu-item-icon-default.x-menu-item-checkbox:before {
    content: "\ea14";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1110 */
.x-menu-item-focus .x-menu-item-icon-default.x-menu-group-icon,
.x-menu-item-active .x-menu-item-icon-default.x-menu-group-icon {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1117 */
.x-menu-item-checked .x-menu-item-icon-default.x-menu-group-icon {
    font: 18px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-checked .x-menu-item-icon-default.x-menu-group-icon:before {
    content: "\f00c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1125 */
.x-menu-item-unchecked .x-menu-item-icon-default.x-menu-group-icon {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1130 */
.x-menu-item-unchecked .x-menu-item-icon-default.x-menu-group-icon:before {
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1140 */
.x-menu-item-arrow-default {
    width: 16px;
    height: 16px;
    top: 8px;
    right: 0;
    margin: 0 4px 0;
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-arrow-default:before {
    content: "\ed21";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1152 */
.x-menu-item-focus .x-menu-item-arrow-default,
.x-menu-item-active .x-menu-item-arrow-default {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1161 */
.x-menu-item-focus .x-menu-item-arrow-default,
.x-menu-item-active .x-menu-item-arrow-default {
    top: 8px;
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-menu-default-scroller .x-box-scroller-body-horizontal {
    margin-left: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-menu-default-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-menu-default {
    cursor: pointer;
    color: #919191;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-menu-default.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-menu-default.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-menu-default.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-menu-default.x-box-scroller-top,
.x-box-scroller-menu-default.x-box-scroller-bottom {
    height: 16px;
    width: 16px;
    left: 50%;
    margin-left: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-menu-default.x-box-scroller-top {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/16px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-menu-default.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-menu-default.x-box-scroller-bottom {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/16px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-menu-default.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1217 */
.x-ie8 .x-box-scroller-menu-default {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:818 */
.x-menu-default-menubar {
    border-style: solid;
    border-width: 1px;
    border-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:824 */
.x-menu-body-default-menubar {
    background: #fff;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:829 */
.x-menu-icon-separator-default-menubar {
    left: 32px;
    border-left: solid 1px #d0d0d0;
    background-color: #fff;
    width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:843 */
.x-menu-item-default-menubar {
    border-width: 0;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:849 */
.x-menu-item-default-menubar.x-menu-item-focus,
.x-menu-item-default-menubar.x-menu-item-active {
    background-image: none;
    background-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:862 */
.x-nlg .x-menu-item-default-menubar.x-menu-item-focus,
.x-nlg .x-menu-item-default-menubar.x-menu-item-active {
    background: #33bdf1 repeat-x left top;
    background-image: url(images/menu/menu-item-default-menubar-active-bg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:869 */
.x-menu-item-default-menubar.x-menu-item-disabled {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:872 */
.x-menu-item-default-menubar.x-menu-item-disabled a {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:877 */
.x-menu-item-default-menubar.x-menu-item-separator {
    height: 1px;
    border-top: solid 1px #d0d0d0;
    background-color: #fff;
    margin: 2px 0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:885 */
.x-menu-item-default-menubar.x-menu-item-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:890 */
.x-ie9m .x-menu-item-default-menubar.x-menu-item-disabled .x-menu-item-icon-ui {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:894 */
.x-ie9m .x-menu-item-default-menubar.x-menu-item-disabled .x-menu-item-text-default-menubar {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:904 */
.x-menu-item-default-menubar .x-form-item-label {
    font-size: 14px;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:911 */
.x-menu-item-text-default-menubar,
.x-menu-item-cmp-default-menubar {
    margin: 0 8px 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:916 */
.x-menu-item-text-default-menubar {
    font: 400 14px Open Sans, sans-serif;
    line-height: 31px;
    padding-top: 1px;
    color: #000;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:928 */
.x-menu-item-focus .x-menu-item-text-default-menubar,
.x-menu-item-active .x-menu-item-text-default-menubar {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:934 */
.x-menu-item-text-default-menubar.x-menu-item-indent {
    margin-left: 41px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:938 */
.x-menu-item-text-default-menubar.x-menu-item-indent-no-separator {
    margin-left: 36px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:942 */
.x-menu-item-text-default-menubar.x-menu-item-indent-right-icon {
    margin-right: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:946 */
.x-menu-item-text-default-menubar.x-menu-item-indent-right-arrow {
    margin-right: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:950 */
.x-menu-item-disabled .x-menu-item-text-default-menubar {
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:982 */
.x-menu-item-indent-default-menubar {
    margin-left: 41px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:992 */
.x-menu-item-icon-default-menubar {
    width: 24px;
    height: 24px;
    top: 4px;
    left: 4px;
    line-height: 24px;
    font-size: 16px;
    color: #000;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1041 */
.x-ie8 .x-menu-item-icon-default-menubar.x-menu-item-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1049 */
.x-menu-item-icon-default-menubar.x-menu-item-icon-right {
    width: 24px;
    height: 24px;
    top: 4px;
    right: 4px;
    left: auto;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1070 */
.x-menu-item-icon-default-menubar.x-menu-item-checkbox {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1080 */
.x-menu-item-focus .x-menu-item-icon-default-menubar.x-menu-item-checkbox,
.x-menu-item-active .x-menu-item-icon-default-menubar.x-menu-item-checkbox {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1087 */
.x-menu-item-checked .x-menu-item-icon-default-menubar.x-menu-item-checkbox {
    font: 18px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-checked .x-menu-item-icon-default-menubar.x-menu-item-checkbox:before {
    content: "\ea16";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1095 */
.x-menu-item-unchecked .x-menu-item-icon-default-menubar.x-menu-item-checkbox {
    font: 18px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-unchecked .x-menu-item-icon-default-menubar.x-menu-item-checkbox:before {
    content: "\ea14";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1110 */
.x-menu-item-focus .x-menu-item-icon-default-menubar.x-menu-group-icon,
.x-menu-item-active .x-menu-item-icon-default-menubar.x-menu-group-icon {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1117 */
.x-menu-item-checked .x-menu-item-icon-default-menubar.x-menu-group-icon {
    font: 18px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-checked .x-menu-item-icon-default-menubar.x-menu-group-icon:before {
    content: "\f00c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1125 */
.x-menu-item-unchecked .x-menu-item-icon-default-menubar.x-menu-group-icon {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1130 */
.x-menu-item-unchecked .x-menu-item-icon-default-menubar.x-menu-group-icon:before {
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1140 */
.x-menu-item-arrow-default-menubar {
    width: 9px;
    height: 6px;
    top: 9px;
    right: 5px;
    margin: 0 4px 0;
    font-family: menu-item-arrow-glyph-font-size;
    line-height: 1;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-menu-item-arrow-default-menubar:before {
    content: "\ed1b";
    display: inline-block;
    -webkit-transform: rotate(Portfolio, FontAwesome, Extjsdeg);
    -webkit-transform-origin: 50% 50%;
    -moz-transform: rotate(Portfolio, FontAwesome, Extjsdeg);
    -moz-transform-origin: 50% 50%;
    -ms-transform: rotate(Portfolio, FontAwesome, Extjsdeg);
    -ms-transform-origin: 50% 50%;
    transform: rotate(Portfolio, FontAwesome, Extjsdeg);
    transform-origin: 50% 50%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:151 */
.x-ie8 .x-menu-item-arrow-default-menubar {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1152 */
.x-menu-item-focus .x-menu-item-arrow-default-menubar,
.x-menu-item-active .x-menu-item-arrow-default-menubar {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1161 */
.x-menu-item-focus .x-menu-item-arrow-default-menubar,
.x-menu-item-active .x-menu-item-arrow-default-menubar {
    top: 9px;
    right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-menu-default-menubar-scroller .x-box-scroller-body-horizontal {
    margin-left: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-menu-default-menubar-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-menu-default-menubar {
    cursor: pointer;
    color: #919191;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-menu-default-menubar.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-menu-default-menubar.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-menu-default-menubar.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-menu-default-menubar.x-box-scroller-top,
.x-box-scroller-menu-default-menubar.x-box-scroller-bottom {
    height: 16px;
    width: 16px;
    left: 50%;
    margin-left: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-menu-default-menubar.x-box-scroller-top {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/16px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-menu-default-menubar.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-menu-default-menubar.x-box-scroller-bottom {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/16px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-menu-default-menubar.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/menu/Menu.scss:1217 */
.x-ie8 .x-box-scroller-menu-default-menubar {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/filters/Filters.scss:1 */
.x-grid-filters-filtered-column {
    font-style: italic;
    font-weight: 600;
    text-decoration: underline;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/filters/Filters.scss:7 */
.x-grid-filters-icon {
    background-repeat: no-repeat;
    background-position: center center;
    color: #000;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/filters/Filters.scss:16 */
.x-grid-filters-find .x-form-item-label-inner {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-filters-find .x-form-item-label-inner:before {
    content: "\f002";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/filters/Filters.scss:26 */
.x-grid-filters-gt .x-form-item-label-inner {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-filters-gt .x-form-item-label-inner:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/filters/Filters.scss:36 */
.x-grid-filters-lt .x-form-item-label-inner {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-filters-lt .x-form-item-label-inner:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/filters/Filters.scss:46 */
.x-grid-filters-eq .x-form-item-label-inner {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-filters-eq .x-form-item-label-inner:before {
    content: "\e605";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:1 */
.x-grid-locked .x-grid-inner-locked {
    border-width: 0 2px 0 0;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:12 */
.x-grid-locked-split .x-grid-inner-normal {
    border-width: 0 0 0 2px;
    border-style: solid;
    border-left-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:24 */
.x-grid-locking-body {
    border-width: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:31 */
.x-grid-locking-body > .x-splitter {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:35 */
.x-grid-locking-body > .x-splitter-active {
    background-color: #b4b4b4;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:40 */
.x-grid-inner-locked {
    border-right-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:45 */
.x-grid-inner-locked .x-column-header-last,
.x-grid-inner-locked .x-grid-cell-last {
    border-right-width: 0!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:75 */
.x-hmenu-lock {
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-hmenu-lock:before {
    content: "\f023";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:86 */
.x-hmenu-unlock {
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-hmenu-unlock:before {
    content: "\f09c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:101 */
.x-grid-scrollbar-clipper > .x-grid-view,
.x-grid-scrollbar-clipper > .x-tree-view {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:108 */
.x-grid-scrollbar-clipper-locked,
.x-grid-scrollbar-locked {
    border-width: 0 2px 0 0;
    border-style: solid;
    border-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/locking/Lockable.scss:123 */
.x-grid-scroll-container {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/Editing.scss:18 */
.x-grid-editor .x-form-display-field {
    text-overflow: ellipsis;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/Editing.scss:24 */
.x-grid-editor .x-form-action-col-field {
    padding: 8px 4px 7px 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/Editing.scss:30 */
.x-grid-editor .x-form-text {
    padding-left: 9px;
    padding-right: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/CellEditing.scss:3 */
.x-tree-cell-editor .x-form-text {
    padding-left: 5px;
    padding-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:2 */
.x-grid-row-editor .x-field {
    margin: 0 3px 0 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:7 */
.x-grid-row-editor .x-form-display-field {
    padding: 7px 8px 6px 8px;
    line-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:18 */
.x-ie9m .x-grid-row-editor .x-form-display-field {
    min-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:26 */
.x-grid-row-editor .x-form-action-col-field {
    padding: 8px 1px 7px 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:37 */
.x-grid-row-editor .x-form-text {
    padding: 5px 6px 4px 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:41 */
.x-gecko .x-grid-row-editor .x-form-text {
    padding-left: 6px;
    padding-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:50 */
.x-grid-row-editor .x-panel-body {
    border-top: 1px solid #d0d0d0 !important;
    border-bottom: 1px solid #d0d0d0 !important;
    padding: 5px 0 5px 0;
    background-color: #daeff6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:60 */
.x-grid-with-col-lines .x-grid-row-editor .x-form-cb {
    margin-right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-grid-row-editor-buttons-default-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 5px;
    -webkit-border-bottom-right-radius: 5px;
    border-bottom-right-radius: 5px;
    -moz-border-radius-bottomleft: 5px;
    -webkit-border-bottom-left-radius: 5px;
    border-bottom-left-radius: 5px;
    padding: 5px 5px 5px 5px;
    border-width: 0 1px 1px 1px;
    border-style: solid;
    background-color: #daeff6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-grid-row-editor-buttons-default-bottom-mc {
    background-color: #daeff6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-grid-row-editor-buttons-default-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-grid-row-editor-buttons-default-bottom-frameInfo {
    font-family: th-0-5-5-5-0-1-1-1-5-5-5-5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-grid-row-editor-buttons-default-bottom-tl {
    background-position: 0 -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-grid-row-editor-buttons-default-bottom-tr {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-grid-row-editor-buttons-default-bottom-bl {
    background-position: 0 -20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-grid-row-editor-buttons-default-bottom-br {
    background-position: right -25px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-grid-row-editor-buttons-default-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-grid-row-editor-buttons-default-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-grid-row-editor-buttons-default-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-grid-row-editor-buttons-default-bottom-bc {
    background-position: 0 -5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-grid-row-editor-buttons-default-bottom-tr,
.x-grid-row-editor-buttons-default-bottom-br,
.x-grid-row-editor-buttons-default-bottom-mr {
    padding-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-grid-row-editor-buttons-default-bottom-tl,
.x-grid-row-editor-buttons-default-bottom-bl,
.x-grid-row-editor-buttons-default-bottom-ml {
    padding-left: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-grid-row-editor-buttons-default-bottom-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-grid-row-editor-buttons-default-bottom-bc {
    height: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-grid-row-editor-buttons-default-bottom-tl,
.x-grid-row-editor-buttons-default-bottom-bl,
.x-grid-row-editor-buttons-default-bottom-tr,
.x-grid-row-editor-buttons-default-bottom-br,
.x-grid-row-editor-buttons-default-bottom-tc,
.x-grid-row-editor-buttons-default-bottom-bc,
.x-grid-row-editor-buttons-default-bottom-ml,
.x-grid-row-editor-buttons-default-bottom-mr {
    background-image: url(images/grid-row-editor-buttons/grid-row-editor-buttons-default-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-grid-row-editor-buttons-default-bottom-ml,
.x-grid-row-editor-buttons-default-bottom-mr {
    background-image: url(images/grid-row-editor-buttons/grid-row-editor-buttons-default-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-grid-row-editor-buttons-default-bottom-mc {
    padding: 5px 1px 1px 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-grid-row-editor-buttons-default-top {
    -moz-border-radius-topleft: 5px;
    -webkit-border-top-left-radius: 5px;
    border-top-left-radius: 5px;
    -moz-border-radius-topright: 5px;
    -webkit-border-top-right-radius: 5px;
    border-top-right-radius: 5px;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 5px 5px 5px 5px;
    border-width: 1px 1px 0 1px;
    border-style: solid;
    background-color: #daeff6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-grid-row-editor-buttons-default-top-mc {
    background-color: #daeff6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-grid-row-editor-buttons-default-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-grid-row-editor-buttons-default-top-frameInfo {
    font-family: th-5-5-0-5-1-1-0-1-5-5-5-5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-grid-row-editor-buttons-default-top-tl {
    background-position: 0 -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-grid-row-editor-buttons-default-top-tr {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-grid-row-editor-buttons-default-top-bl {
    background-position: 0 -20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-grid-row-editor-buttons-default-top-br {
    background-position: right -25px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-grid-row-editor-buttons-default-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-grid-row-editor-buttons-default-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-grid-row-editor-buttons-default-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-grid-row-editor-buttons-default-top-bc {
    background-position: 0 -5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-grid-row-editor-buttons-default-top-tr,
.x-grid-row-editor-buttons-default-top-br,
.x-grid-row-editor-buttons-default-top-mr {
    padding-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-grid-row-editor-buttons-default-top-tl,
.x-grid-row-editor-buttons-default-top-bl,
.x-grid-row-editor-buttons-default-top-ml {
    padding-left: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-grid-row-editor-buttons-default-top-tc {
    height: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-grid-row-editor-buttons-default-top-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-grid-row-editor-buttons-default-top-tl,
.x-grid-row-editor-buttons-default-top-bl,
.x-grid-row-editor-buttons-default-top-tr,
.x-grid-row-editor-buttons-default-top-br,
.x-grid-row-editor-buttons-default-top-tc,
.x-grid-row-editor-buttons-default-top-bc,
.x-grid-row-editor-buttons-default-top-ml,
.x-grid-row-editor-buttons-default-top-mr {
    background-image: url(images/grid-row-editor-buttons/grid-row-editor-buttons-default-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-grid-row-editor-buttons-default-top-ml,
.x-grid-row-editor-buttons-default-top-mr {
    background-image: url(images/grid-row-editor-buttons/grid-row-editor-buttons-default-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-grid-row-editor-buttons-default-top-mc {
    padding: 1px 1px 5px 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:108 */
.x-grid-row-editor-buttons {
    border-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:112 */
.x-row-editor-update-button {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:115 */
.x-row-editor-cancel-button {
    margin-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:131 */
.x-grid-row-editor-errors .x-tip-body {
    padding: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:136 */
.x-grid-row-editor-errors-item {
    list-style: disc;
    margin-left: 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowExpander.scss:1 */
.x-grid-cell-inner-row-expander {
    padding: 9px 8px 8px 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowExpander.scss:16 */
.x-grid-row-expander {
    width: 16px;
    height: 16px;
    cursor: pointer;
    color: #919191;
    font: 14px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-row-expander:before {
    content: "\f146";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowExpander.scss:31 */
.x-grid-row-collapsed .x-grid-row-expander {
    font: 14px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-row-collapsed .x-grid-row-expander:before {
    content: "\f0fe";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:1 */
.x-ssm-row-numberer-hd {
    cursor: se-resize!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:6 */
.x-ssm-row-numberer-cell {
    cursor: e-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:11 */
.x-ssm-column-select .x-column-header {
    cursor: s-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:16 */
.x-ssm-extender-drag-handle {
    height: 7px;
    width: 7px;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:22 */
.x-ssm-extender-mask {
    border: 1px dotted #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:1 */
.x-accordion-layout-ct {
    background-color: #fff;
    padding: 5px 5px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:6 */
.x-accordion-hd .x-panel-header-title {
    color: #000;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    text-transform: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:13 */
.x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus,
.x-edge .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus:after,
.x-edge .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:34 */
.x-accordion-item {
    margin: 0 0 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:37 */
.x-accordion-item .x-accordion-hd {
    background: #ececec;
    border-width: 0;
    border-color: transparent;
    padding: 12px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:45 */
.x-accordion-item .x-accordion-hd-over {
    background-color: #f6f6f6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:48 */
.x-accordion-item .x-accordion-hd-over .x-tool-tool-el {
    background-color: #f6f6f6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:54 */
.x-accordion-item .x-accordion-hd-sibling-expanded {
    border-top-color: transparent;
    border-top-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:59 */
.x-accordion-item .x-accordion-hd-last-collapsed {
    border-bottom-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:63 */
.x-accordion-item .x-accordion-body {
    border-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:72 */
.x-accordion-hd .x-tool-tool-el {
    background-color: #ececec;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:77 */
.x-accordion-hd .x-tool-img {
    background-image: url(images/tools/tool-sprites-dark.png);
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:87 */
.x-accordion-hd .x-tool-collapse-top,
.x-accordion-hd .x-tool-collapse-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-accordion-hd .x-tool-collapse-top:before,
.x-accordion-hd .x-tool-collapse-bottom:before {
    content: "\ecce";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:106 */
.x-accordion-hd .x-tool-expand-top,
.x-accordion-hd .x-tool-expand-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-accordion-hd .x-tool-expand-top:before,
.x-accordion-hd .x-tool-expand-bottom:before {
    content: "\edac";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:126 */
.x-keyboard-mode .x-accordion-hd .x-tool-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-tool-focus,
.x-edge .x-keyboard-mode .x-accordion-hd .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-accordion-hd .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Border.scss:5 */
body.x-border-layout-ct,
div.x-border-layout-ct {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Form.scss:1 */
.x-form-layout-wrap {
    border-spacing: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:1 */
.x-resizable-handle {
    position: absolute;
    z-index: 100;
    font-size: 1px;
    line-height: 10px;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
    background-color: #ececec;
    color: #919191;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:20 */
.x-collapsed .x-resizable-handle {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:24 */
.x-resizable-handle-southeast {
    cursor: se-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:27 */
.x-resizable-handle-southeast:before {
    position: absolute;
    bottom: 0;
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:34 */
.x-resizable-handle-northwest {
    cursor: nw-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:37 */
.x-resizable-handle-northwest:before {
    position: absolute;
    top: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:44 */
.x-resizable-handle-northeast {
    cursor: ne-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:47 */
.x-resizable-handle-northeast:before {
    position: absolute;
    top: 0;
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:54 */
.x-resizable-handle-southwest {
    cursor: sw-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:57 */
.x-resizable-handle-southwest:before {
    position: absolute;
    bottom: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:68 */
.x-resizable-handle-east:before,
.x-resizable-handle-west:before {
    display: block;
    position: absolute;
    top: 50%;
    margin-top: -0.5em;
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:78 */
.x-resizable-handle-east {
    cursor: e-resize;
    width: 10px;
    right: 0;
    top: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:86 */
.x-resizable-handle-south {
    cursor: s-resize;
    height: 10px;
    left: 0;
    right: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:94 */
.x-resizable-handle-west {
    cursor: w-resize;
    width: 10px;
    left: 0;
    top: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:102 */
.x-resizable-handle-north {
    cursor: n-resize;
    height: 10px;
    left: 0;
    right: 0;
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:110 */
.x-resizable-handle-southeast {
    width: 10px;
    height: 10px;
    right: 0;
    bottom: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:118 */
.x-resizable-handle-northwest {
    width: 10px;
    height: 10px;
    left: 0;
    top: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:126 */
.x-resizable-handle-northeast {
    width: 10px;
    height: 10px;
    right: 0;
    top: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:134 */
.x-resizable-handle-southwest {
    width: 10px;
    height: 10px;
    left: 0;
    bottom: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:145 */
.x-tablet .x-resizable-handle-north,
.x-tablet .x-resizable-handle-south {
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:149 */
.x-tablet .x-resizable-handle-east,
.x-tablet .x-resizable-handle-west {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:153 */
.x-tablet .x-resizable-handle-northwest,
.x-tablet .x-resizable-handle-northeast,
.x-tablet .x-resizable-handle-southwest,
.x-tablet .x-resizable-handle-southeast {
    width: 20px;
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:163 */
.x-window .x-window-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:167 */
.x-window-collapsed .x-window-handle {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:172 */
.x-resizable-proxy {
    border: 1px dashed #3b5a82;
    position: absolute;
    overflow: hidden;
    z-index: 50000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:180 */
.x-resizable-handle-over,
.x-resizable-pinned .x-resizable-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:186 */
.x-resizable-handle-east-over,
.x-resizable-handle-west-over,
.x-resizable-pinned > .x-resizable-handle-east,
.x-resizable-pinned > .x-resizable-handle-west {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-east-over:before,
.x-resizable-handle-west-over:before,
.x-resizable-pinned > .x-resizable-handle-east:before,
.x-resizable-pinned > .x-resizable-handle-west:before {
    content: "\f142";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:198 */
.x-resizable-handle-south-over,
.x-resizable-handle-north-over,
.x-resizable-pinned > .x-resizable-handle-south,
.x-resizable-pinned > .x-resizable-handle-north {
    font: 16px/10px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-south-over:before,
.x-resizable-handle-north-over:before,
.x-resizable-pinned > .x-resizable-handle-south:before,
.x-resizable-pinned > .x-resizable-handle-north:before {
    content: "\f141";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:210 */
.x-resizable-handle-southeast-over,
.x-resizable-pinned > .x-resizable-handle-southeast {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-southeast-over:before,
.x-resizable-pinned > .x-resizable-handle-southeast:before {
    content: "\e60c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:220 */
.x-resizable-handle-northwest-over,
.x-resizable-pinned > .x-resizable-handle-northwest {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-northwest-over:before,
.x-resizable-pinned > .x-resizable-handle-northwest:before {
    content: "\e609";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:230 */
.x-resizable-handle-northeast-over,
.x-resizable-pinned > .x-resizable-handle-northeast {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-northeast-over:before,
.x-resizable-pinned > .x-resizable-handle-northeast:before {
    content: "\e60a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:240 */
.x-resizable-handle-southwest-over,
.x-resizable-pinned > .x-resizable-handle-southwest {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-southwest-over:before,
.x-resizable-pinned > .x-resizable-handle-southwest:before {
    content: "\e60b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:2 */
.x-slider:before {
    border: 1px solid #d0d0d0;
    content: '';
    position: absolute;
    border-radius: 2px;
    background-color: #eee;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -ms-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:20 */
.x-slider-thumb {
    background-color: #f6f6f6;
    border: 1px solid #d0d0d0;
    border-radius: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:28 */
.x-slider-thumb:before {
    color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:33 */
.x-slider-thumb-over {
    background-color: #fcfcfc;
    border-color: #c0ced3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:36 */
.x-slider-thumb-over:before {
    color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:42 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb {
    background-color: #f6f6f6;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:45 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb:before {
    color: #76cded;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:52 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb-over {
    background-color: #fcfcfc;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:57 */
.x-slider-thumb-drag {
    background-color: #f1f1f1;
    border-color: #b5c9d1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:60 */
.x-slider-thumb-drag:before {
    color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:66 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb-drag {
    background-color: #f1f1f1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:79 */
.x-slider-horz {
    padding-left: 10px;
    background: no-repeat 0 -20px;
    margin: 10px 0 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:86 */
.x-slider-horz .x-slider-end {
    padding-right: 10px;
    background: no-repeat right -40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:91 */
.x-slider-horz .x-slider-inner {
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:96 */
.x-slider-horz:before {
    height: 10px;
    width: 100%;
    top: 50%;
    left: 0;
    margin-top: -5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:106 */
.x-slider-horz .x-slider-thumb {
    width: 20px;
    height: 20px;
    margin-left: -10px;
    font: 12px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-slider-horz .x-slider-thumb:before {
    content: "\e612";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:170 */
.x-slider-ct-vert {
    /* Vertical styles */
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:174 */
.x-slider-vert {
    padding-top: 10px;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:181 */
.x-slider-vert > .x-slider-end {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:183 */
.x-slider-vert > .x-slider-end > .x-slider-inner {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:189 */
.x-slider-vert:before {
    width: 10px;
    height: 100%;
    left: 10px;
    top: 0;
    margin-left: -5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:199 */
.x-slider-vert .x-slider-end {
    padding-bottom: 10px;
    background: no-repeat -20px bottom;
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:205 */
.x-slider-vert .x-slider-inner {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:209 */
.x-slider-vert .x-slider-thumb {
    width: 20px;
    height: 20px;
    margin-bottom: -10px;
    font: 12px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-slider-vert .x-slider-thumb:before {
    content: "\e605";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:262 */
.x-slider-default-cell > .x-grid-cell-inner,
.x-sliderwidget-default-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-top {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-top-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-top-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-top-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-top-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-top-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-top-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-top-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-default-top-tr,
.x-tab-default-top-br,
.x-tab-default-top-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-default-top-tl,
.x-tab-default-top-bl,
.x-tab-default-top-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-default-top-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-default-top-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-default-top-tl,
.x-tab-default-top-bl,
.x-tab-default-top-tr,
.x-tab-default-top-br,
.x-tab-default-top-tc,
.x-tab-default-top-bc,
.x-tab-default-top-ml,
.x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-default-top-ml,
.x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-default-top-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 6px 15px 10px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-bottom-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-bottom-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-6-15-10-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-bottom-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-bottom-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-bottom-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-bottom-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-bottom-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-default-bottom-tr,
.x-tab-default-bottom-br,
.x-tab-default-bottom-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-default-bottom-tl,
.x-tab-default-bottom-bl,
.x-tab-default-bottom-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-default-bottom-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-default-bottom-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-default-bottom-tl,
.x-tab-default-bottom-bl,
.x-tab-default-bottom-tr,
.x-tab-default-bottom-br,
.x-tab-default-bottom-tc,
.x-tab-default-bottom-bc,
.x-tab-default-bottom-ml,
.x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-default-bottom-ml,
.x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-default-bottom-mc {
    padding: 6px 15px 10px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-left-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-left-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-left-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-left-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-left-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-left-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-left-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-default-left-tr,
.x-tab-default-left-br,
.x-tab-default-left-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-default-left-tl,
.x-tab-default-left-bl,
.x-tab-default-left-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-default-left-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-default-left-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-default-left-tl,
.x-tab-default-left-bl,
.x-tab-default-left-tr,
.x-tab-default-left-br,
.x-tab-default-left-tc,
.x-tab-default-left-bc,
.x-tab-default-left-ml,
.x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-default-left-ml,
.x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-default-left-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-right-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-right-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-right-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-right-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-right-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-right-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-right-bc {
    background-position: 0 0;
}