/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/etc/all.scss:3 */
.x-region-collapsed-placeholder {
    border-right-width: 0 !important;
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/etc/all.scss:10 */
.x-collapse-el {
    display: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/_config.scss:19 */
.x-ux-admin-top-container {
    -webkit-box-shadow: 0px 7px 9px -2px rgba(0, 0, 0, 0.28);
    -moz-box-shadow: 0px 7px 9px -2px rgba(0, 0, 0, 0.28);
    box-shadow: 0px 7px 9px -2px rgba(0, 0, 0, 0.28);
    z-index: 10;
    border: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/_config.scss:28 */
.x-site-icon {
    line-height: 32px;
    font-size: 32px;
    color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/_config.scss:34 */
.x-site-user-icon {
    border-radius: 50%;
    line-height: 32px;
    font-size: 32px;
    color: white;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/_config.scss:44 */
.x-ux-treeIcon-bg {
    background-position: 0 center !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/_config.scss:48 */
.x-tree-no-icon {
    display: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/_config.scss:52 */
.x-plugin-charcount {
    color: black;
    font-size: 11px;
    right: 5px;
    position: absolute;
    display: inline-block;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:1 */
.splashsvg {
    height: auto;
    max-width: 40%;
    max-height: 40%;
    display: block;
    position: fixed;
    margin: auto;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    box-sizing: border-box;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:15 */
#loadingSplash {
    z-index: 99999999;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    position: absolute;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:25 */
.loadingSplashTop {
    background-color: #00adee;
    left: 0;
    right: 0;
    top: 0;
    position: absolute;
    height: 51%;
    transition: all 500ms;
    transition-delay: 200ms;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:36 */
.loadingSplashBottom {
    background-color: #00adee;
    left: 0;
    right: 0;
    bottom: 0;
    position: absolute;
    height: 51%;
    transition: all 500ms;
    transition-delay: 200ms;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:47 */
.loadingSplashMessage {
    margin: auto;
    width: 60px;
    height: 60px;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:59 */
.loading-circle {
    width: 100%;
    height: 100%;
    position: absolute;
    top: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:65 */
.loading-circle:before {
    content: '';
    display: block;
    margin: 0 auto;
    width: 15%;
    height: 15%;
    background-color: #fff;
    border-radius: 100%;
    animation: loading-circleFadeDelay 1.2s infinite ease-in-out both;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:75 */
.loading-circle-2 {
    transform: rotate(30deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:77 */
.loading-circle-2:before {
    animation-delay: -1.1s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:81 */
.loading-circle-3 {
    transform: rotate(60deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:83 */
.loading-circle-3:before {
    animation-delay: -1s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:87 */
.loading-circle-4 {
    transform: rotate(90deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:89 */
.loading-circle-4:before {
    animation-delay: -0.9s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:93 */
.loading-circle-5 {
    transform: rotate(120deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:95 */
.loading-circle-5:before {
    animation-delay: -0.8s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:99 */
.loading-circle-6 {
    transform: rotate(150deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:101 */
.loading-circle-6:before {
    animation-delay: -0.7s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:105 */
.loading-circle-7 {
    transform: rotate(180deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:107 */
.loading-circle-7:before {
    animation-delay: -0.6s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:111 */
.loading-circle-8 {
    transform: rotate(210deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:113 */
.loading-circle-8:before {
    animation-delay: -0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:117 */
.loading-circle-9 {
    transform: rotate(240deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:119 */
.loading-circle-9:before {
    animation-delay: -0.4s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:123 */
.loading-circle-10 {
    transform: rotate(270deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:125 */
.loading-circle-10:before {
    animation-delay: -0.3s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:129 */
.loading-circle-11 {
    transform: rotate(300deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:131 */
.loading-circle-11:before {
    animation-delay: -0.2s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:135 */
.loading-circle-12 {
    transform: rotate(330deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:137 */
.loading-circle-12:before {
    animation-delay: -0.1s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:143 */
.x-spinner {
    position: relative;
    background-color: transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:148 */
.x-page-spinner {
    width: 200px;
    height: 200px;
    background-color: transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:154 */
.x-loadspinner {
    margin: auto;
    width: 60px;
    height: 60px;
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:165 */
.x-msg-spinner {
    margin: auto;
    width: 30px;
    height: 30px;
    position: relative;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:176 */
.x-loading-circle {
    width: 100%;
    height: 100%;
    position: absolute;
    top: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:182 */
.x-loading-circle:before {
    content: '';
    display: block;
    margin: 0 auto;
    width: 15%;
    height: 15%;
    background-color: #000;
    border-radius: 100%;
    animation: loading-circleFadeDelay 1.2s infinite ease-in-out both;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:192 */
.x-loading-circle-2 {
    transform: rotate(30deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:194 */
.x-loading-circle-2:before {
    animation-delay: -1.1s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:198 */
.x-loading-circle-3 {
    transform: rotate(60deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:200 */
.x-loading-circle-3:before {
    animation-delay: -1s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:204 */
.x-loading-circle-4 {
    transform: rotate(90deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:206 */
.x-loading-circle-4:before {
    animation-delay: -0.9s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:210 */
.x-loading-circle-5 {
    transform: rotate(120deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:212 */
.x-loading-circle-5:before {
    animation-delay: -0.8s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:216 */
.x-loading-circle-6 {
    transform: rotate(150deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:218 */
.x-loading-circle-6:before {
    animation-delay: -0.7s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:222 */
.x-loading-circle-7 {
    transform: rotate(180deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:224 */
.x-loading-circle-7:before {
    animation-delay: -0.6s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:228 */
.x-loading-circle-8 {
    transform: rotate(210deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:230 */
.x-loading-circle-8:before {
    animation-delay: -0.5s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:234 */
.x-loading-circle-9 {
    transform: rotate(240deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:236 */
.x-loading-circle-9:before {
    animation-delay: -0.4s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:240 */
.x-loading-circle-10 {
    transform: rotate(270deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:242 */
.x-loading-circle-10:before {
    animation-delay: -0.3s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:246 */
.x-loading-circle-11 {
    transform: rotate(300deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:248 */
.x-loading-circle-11:before {
    animation-delay: -0.2s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:252 */
.x-loading-circle-12 {
    transform: rotate(330deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:254 */
.x-loading-circle-12:before {
    animation-delay: -0.1s;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:260 */
.loading-done {
    height: 0%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:264 */
@-webkit-keyframes loading-circleFadeDelay {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:265 */
    0%,
    39%,
    100% {
        opacity: 0;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:268 */
    40% {
        opacity: 1;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:273 */
@keyframes loading-circleFadeDelay {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:274 */
    0%,
    39%,
    100% {
        opacity: 0;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/siteloader.scss:277 */
    40% {
        opacity: 1;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/Component.scss:11 */
.x-base-color {
    color: #00adee !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/Component.scss:15 */
.x-base-background-color {
    background-color: #00adee !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/Component.scss:21 */
.x-region-collapsed-left-placeholder + .x-border-region-slide-in {
    border-right: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/Component.scss:26 */
.x-region-collapsed-right-placeholder + .x-border-region-slide-in {
    border-left: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/Component.scss:32 */
.x-border-region-slide-in {
    z-index: 9 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/LoadMask.scss:4 */
.x-mask[id^=loadmask-] {
    background-color: rgba(255, 255, 255, 0.55) !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/LoadMask.scss:11 */
.x-page-spinner .x-loading-circle:before {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-filter-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-filter-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-filter-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-filter-small-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-filter-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-filter-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-filter-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-filter-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-filter-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-filter-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-filter-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-filter-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-filter-small-tr,
.x-btn-filter-small-br,
.x-btn-filter-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-filter-small-tl,
.x-btn-filter-small-bl,
.x-btn-filter-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-filter-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-filter-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-filter-small-tl,
.x-btn-filter-small-bl,
.x-btn-filter-small-tr,
.x-btn-filter-small-br,
.x-btn-filter-small-tc,
.x-btn-filter-small-bc,
.x-btn-filter-small-ml,
.x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-filter-small-ml,
.x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-filter-small-mc {
    padding: 5px 5px 5px 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-filter-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-filter-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-filter-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-filter-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-filter-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-filter-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-filter-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-filter-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-filter-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-filter-small {
    font-size: 16px;
    height: 16px;
    color: #000;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-filter-small,
.x-btn-icon-right > .x-btn-icon-el-filter-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-filter-small,
.x-btn-icon-bottom > .x-btn-icon-el-filter-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-filter-small.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-filter-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-filter-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-filter-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-filter-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-filter-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-filter-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-filter-small,
.x-btn-split-bottom > .x-btn-button-filter-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-filter-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-filter-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-filter-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-filter-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-filter-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-filter-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-filter-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-filter-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-filter-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-filter-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-filter-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-filter-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-filter-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-filter-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-filter-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-filter-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-filter-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-filter-small,
.x-btn.x-btn-pressed.x-btn-filter-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-filter-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-filter-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-filter-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-filter-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-filter-small {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-bc {
    background-image: url(images/btn/btn-filter-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-filter-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-filter-small-tl,
.x-btn-over .x-btn-filter-small-bl,
.x-btn-over .x-btn-filter-small-tr,
.x-btn-over .x-btn-filter-small-br,
.x-btn-over .x-btn-filter-small-tc,
.x-btn-over .x-btn-filter-small-bc {
    background-image: url(images/btn/btn-filter-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-filter-small-ml,
.x-btn-over .x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-filter-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-bc {
    background-image: url(images/btn/btn-filter-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-filter-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-filter-small-tl,
.x-btn.x-btn-menu-active .x-btn-filter-small-bl,
.x-btn.x-btn-menu-active .x-btn-filter-small-tr,
.x-btn.x-btn-menu-active .x-btn-filter-small-br,
.x-btn.x-btn-menu-active .x-btn-filter-small-tc,
.x-btn.x-btn-menu-active .x-btn-filter-small-bc,
.x-btn.x-btn-pressed .x-btn-filter-small-tl,
.x-btn.x-btn-pressed .x-btn-filter-small-bl,
.x-btn.x-btn-pressed .x-btn-filter-small-tr,
.x-btn.x-btn-pressed .x-btn-filter-small-br,
.x-btn.x-btn-pressed .x-btn-filter-small-tc,
.x-btn.x-btn-pressed .x-btn-filter-small-bc {
    background-image: url(images/btn/btn-filter-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-filter-small-ml,
.x-btn.x-btn-menu-active .x-btn-filter-small-mr,
.x-btn.x-btn-pressed .x-btn-filter-small-ml,
.x-btn.x-btn-pressed .x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-filter-small-mc,
.x-btn.x-btn-pressed .x-btn-filter-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-bc {
    background-image: url(images/btn/btn-filter-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-filter-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-filter-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-filter-small-tl,
.x-btn.x-btn-disabled .x-btn-filter-small-bl,
.x-btn.x-btn-disabled .x-btn-filter-small-tr,
.x-btn.x-btn-disabled .x-btn-filter-small-br,
.x-btn.x-btn-disabled .x-btn-filter-small-tc,
.x-btn.x-btn-disabled .x-btn-filter-small-bc {
    background-image: url(images/btn/btn-filter-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-filter-small-ml,
.x-btn.x-btn-disabled .x-btn-filter-small-mr {
    background-image: url(images/btn/btn-filter-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-filter-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-filter-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-filter-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small.x-segmented-button-first .x-btn-filter-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small.x-segmented-button-middle .x-btn-filter-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small.x-segmented-button-last .x-btn-filter-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small.x-segmented-button-first .x-btn-filter-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small.x-segmented-button-middle .x-btn-filter-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small.x-segmented-button-last .x-btn-filter-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-filter-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-filter-small.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-filter-small.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-filter-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-filter-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-filter-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-filter-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-filter-small-cell > .x-grid-cell-inner {
    padding-top: 1px;
    padding-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-filter-small-cell > .x-grid-cell-inner >.x-btn-filter-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-function-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 1px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-function-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-function-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-function-small-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-function-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-function-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-function-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-function-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-function-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-function-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-function-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-function-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-function-small-tr,
.x-btn-function-small-br,
.x-btn-function-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-function-small-tl,
.x-btn-function-small-bl,
.x-btn-function-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-function-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-function-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-function-small-tl,
.x-btn-function-small-bl,
.x-btn-function-small-tr,
.x-btn-function-small-br,
.x-btn-function-small-tc,
.x-btn-function-small-bc,
.x-btn-function-small-ml,
.x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-function-small-ml,
.x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-function-small-mc {
    padding: 5px 5px 5px 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-function-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-function-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-function-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-function-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-function-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-function-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-function-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-function-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-function-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-function-small {
    font-size: 16px;
    height: 16px;
    color: #000;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-function-small,
.x-btn-icon-right > .x-btn-icon-el-function-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-function-small,
.x-btn-icon-bottom > .x-btn-icon-el-function-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-function-small.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-function-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-function-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-function-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-function-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-function-small,
.x-btn-split-bottom > .x-btn-button-function-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-function-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-function-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-function-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-function-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-function-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-function-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-function-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-function-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-function-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-function-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-function-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-function-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-function-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-function-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-function-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-function-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-function-small,
.x-btn.x-btn-pressed.x-btn-function-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-function-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-function-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-function-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-function-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-function-small {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-function-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-function-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-function-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-function-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-function-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-function-small-bc {
    background-image: url(images/btn/btn-function-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-function-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-function-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-function-small-tl,
.x-btn-over .x-btn-function-small-bl,
.x-btn-over .x-btn-function-small-tr,
.x-btn-over .x-btn-function-small-br,
.x-btn-over .x-btn-function-small-tc,
.x-btn-over .x-btn-function-small-bc {
    background-image: url(images/btn/btn-function-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-function-small-ml,
.x-btn-over .x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-function-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-bc {
    background-image: url(images/btn/btn-function-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-function-small-tl,
.x-btn.x-btn-menu-active .x-btn-function-small-bl,
.x-btn.x-btn-menu-active .x-btn-function-small-tr,
.x-btn.x-btn-menu-active .x-btn-function-small-br,
.x-btn.x-btn-menu-active .x-btn-function-small-tc,
.x-btn.x-btn-menu-active .x-btn-function-small-bc,
.x-btn.x-btn-pressed .x-btn-function-small-tl,
.x-btn.x-btn-pressed .x-btn-function-small-bl,
.x-btn.x-btn-pressed .x-btn-function-small-tr,
.x-btn.x-btn-pressed .x-btn-function-small-br,
.x-btn.x-btn-pressed .x-btn-function-small-tc,
.x-btn.x-btn-pressed .x-btn-function-small-bc {
    background-image: url(images/btn/btn-function-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-function-small-ml,
.x-btn.x-btn-menu-active .x-btn-function-small-mr,
.x-btn.x-btn-pressed .x-btn-function-small-ml,
.x-btn.x-btn-pressed .x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-function-small-mc,
.x-btn.x-btn-pressed .x-btn-function-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-bc {
    background-image: url(images/btn/btn-function-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-function-small-tl,
.x-btn.x-btn-disabled .x-btn-function-small-bl,
.x-btn.x-btn-disabled .x-btn-function-small-tr,
.x-btn.x-btn-disabled .x-btn-function-small-br,
.x-btn.x-btn-disabled .x-btn-function-small-tc,
.x-btn.x-btn-disabled .x-btn-function-small-bc {
    background-image: url(images/btn/btn-function-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-function-small-ml,
.x-btn.x-btn-disabled .x-btn-function-small-mr {
    background-image: url(images/btn/btn-function-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-function-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-function-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-function-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small.x-segmented-button-first .x-btn-function-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small.x-segmented-button-middle .x-btn-function-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small.x-segmented-button-last .x-btn-function-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small.x-segmented-button-first .x-btn-function-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small.x-segmented-button-middle .x-btn-function-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small.x-segmented-button-last .x-btn-function-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-function-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-small.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-small.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-function-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-function-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-function-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-function-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-function-small-cell > .x-grid-cell-inner {
    padding-top: 1px;
    padding-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-function-small-cell > .x-grid-cell-inner >.x-btn-function-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-function-action-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 0px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-function-action-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-function-action-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-function-action-small-frameInfo {
    font-family: th-3-3-3-3-0-0-0-0-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-function-action-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-function-action-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-function-action-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-function-action-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-function-action-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-function-action-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-function-action-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-function-action-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-function-action-small-tr,
.x-btn-function-action-small-br,
.x-btn-function-action-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-function-action-small-tl,
.x-btn-function-action-small-bl,
.x-btn-function-action-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-function-action-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-function-action-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-function-action-small-mc {
    padding: 4px 4px 4px 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-function-action-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-function-action-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-function-action-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-function-action-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-function-action-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-function-action-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-function-action-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-function-action-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-function-action-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-function-action-small {
    font-size: 16px;
    height: 16px;
    color: #000;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-function-action-small,
.x-btn-icon-right > .x-btn-icon-el-function-action-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-function-action-small,
.x-btn-icon-bottom > .x-btn-icon-el-function-action-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-function-action-small.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-function-action-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-action-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-function-action-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-function-action-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-function-action-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-action-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-function-action-small,
.x-btn-split-bottom > .x-btn-button-function-action-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-function-action-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-function-action-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-function-action-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-function-action-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-function-action-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-function-action-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-function-action-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-function-action-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-function-action-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-action-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-function-action-small {
    border-color: #00adee;
    background-image: none;
    background-color: transparent;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-function-action-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-function-action-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-function-action-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-function-action-small {
    border-color: #00adee;
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-function-action-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-function-action-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-function-action-small,
.x-btn.x-btn-pressed.x-btn-function-action-small {
    border-color: #00adee;
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-function-action-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-function-action-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-function-action-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-function-action-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-function-action-small {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-bc {
    background-image: url(images/btn/btn-function-action-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-mr {
    background-image: url(images/btn/btn-function-action-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-function-action-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-function-action-small-tl,
.x-btn-over .x-btn-function-action-small-bl,
.x-btn-over .x-btn-function-action-small-tr,
.x-btn-over .x-btn-function-action-small-br,
.x-btn-over .x-btn-function-action-small-tc,
.x-btn-over .x-btn-function-action-small-bc {
    background-image: url(images/btn/btn-function-action-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-function-action-small-ml,
.x-btn-over .x-btn-function-action-small-mr {
    background-image: url(images/btn/btn-function-action-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-function-action-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-bc {
    background-image: url(images/btn/btn-function-action-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-mr {
    background-image: url(images/btn/btn-function-action-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-action-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-function-action-small-tl,
.x-btn.x-btn-menu-active .x-btn-function-action-small-bl,
.x-btn.x-btn-menu-active .x-btn-function-action-small-tr,
.x-btn.x-btn-menu-active .x-btn-function-action-small-br,
.x-btn.x-btn-menu-active .x-btn-function-action-small-tc,
.x-btn.x-btn-menu-active .x-btn-function-action-small-bc,
.x-btn.x-btn-pressed .x-btn-function-action-small-tl,
.x-btn.x-btn-pressed .x-btn-function-action-small-bl,
.x-btn.x-btn-pressed .x-btn-function-action-small-tr,
.x-btn.x-btn-pressed .x-btn-function-action-small-br,
.x-btn.x-btn-pressed .x-btn-function-action-small-tc,
.x-btn.x-btn-pressed .x-btn-function-action-small-bc {
    background-image: url(images/btn/btn-function-action-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-function-action-small-ml,
.x-btn.x-btn-menu-active .x-btn-function-action-small-mr,
.x-btn.x-btn-pressed .x-btn-function-action-small-ml,
.x-btn.x-btn-pressed .x-btn-function-action-small-mr {
    background-image: url(images/btn/btn-function-action-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-function-action-small-mc,
.x-btn.x-btn-pressed .x-btn-function-action-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-bc {
    background-image: url(images/btn/btn-function-action-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-mr {
    background-image: url(images/btn/btn-function-action-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-action-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-action-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-function-action-small-tl,
.x-btn.x-btn-disabled .x-btn-function-action-small-bl,
.x-btn.x-btn-disabled .x-btn-function-action-small-tr,
.x-btn.x-btn-disabled .x-btn-function-action-small-br,
.x-btn.x-btn-disabled .x-btn-function-action-small-tc,
.x-btn.x-btn-disabled .x-btn-function-action-small-bc {
    background-image: url(images/btn/btn-function-action-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-function-action-small-ml,
.x-btn.x-btn-disabled .x-btn-function-action-small-mr {
    background-image: url(images/btn/btn-function-action-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-function-action-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-function-action-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-function-action-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small.x-segmented-button-first {
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small.x-segmented-button-first .x-btn-function-action-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small.x-segmented-button-middle {
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small.x-segmented-button-middle .x-btn-function-action-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small.x-segmented-button-last .x-btn-function-action-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small.x-segmented-button-first {
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small.x-segmented-button-first .x-btn-function-action-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small.x-segmented-button-middle {
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small.x-segmented-button-middle .x-btn-function-action-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small.x-segmented-button-last .x-btn-function-action-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-function-action-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small:after {
    top: 0px;
    right: 0;
    bottom: 0px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small.x-segmented-button-first:after {
    left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-action-small.x-segmented-button-last:after {
    right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small:after {
    top: 0;
    right: 0px;
    bottom: 0;
    left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small.x-segmented-button-first:after {
    top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-action-small.x-segmented-button-last:after {
    bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-function-action-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-function-action-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-function-action-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-function-action-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-function-action-small-cell > .x-grid-cell-inner {
    padding-top: 2px;
    padding-bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-function-action-small-cell > .x-grid-cell-inner >.x-btn-function-action-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-function-filter-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 0px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-function-filter-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-function-filter-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-function-filter-small-frameInfo {
    font-family: th-3-3-3-3-0-0-0-0-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-function-filter-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-function-filter-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-function-filter-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-function-filter-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-function-filter-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-function-filter-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-function-filter-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-function-filter-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-function-filter-small-tr,
.x-btn-function-filter-small-br,
.x-btn-function-filter-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-function-filter-small-tl,
.x-btn-function-filter-small-bl,
.x-btn-function-filter-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-function-filter-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-function-filter-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-function-filter-small-mc {
    padding: 4px 4px 4px 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-function-filter-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-function-filter-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-function-filter-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-function-filter-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-function-filter-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-function-filter-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-function-filter-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-function-filter-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-function-filter-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-function-filter-small {
    font-size: 16px;
    height: 16px;
    color: #000;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-function-filter-small,
.x-btn-icon-right > .x-btn-icon-el-function-filter-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-function-filter-small,
.x-btn-icon-bottom > .x-btn-icon-el-function-filter-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-function-filter-small.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-function-filter-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-filter-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-function-filter-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-function-filter-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-function-filter-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-filter-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-function-filter-small,
.x-btn-split-bottom > .x-btn-button-function-filter-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-function-filter-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-function-filter-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-function-filter-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-function-filter-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-function-filter-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-function-filter-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-function-filter-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-function-filter-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-function-filter-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-function-filter-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-function-filter-small {
    border-color: #00adee;
    background-image: none;
    background-color: transparent;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-function-filter-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-function-filter-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-function-filter-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-function-filter-small {
    border-color: #00adee;
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-function-filter-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-function-filter-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-function-filter-small,
.x-btn.x-btn-pressed.x-btn-function-filter-small {
    border-color: #00adee;
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-function-filter-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-function-filter-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-function-filter-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-function-filter-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-function-filter-small {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-bc {
    background-image: url(images/btn/btn-function-filter-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-mr {
    background-image: url(images/btn/btn-function-filter-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-function-filter-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-function-filter-small-tl,
.x-btn-over .x-btn-function-filter-small-bl,
.x-btn-over .x-btn-function-filter-small-tr,
.x-btn-over .x-btn-function-filter-small-br,
.x-btn-over .x-btn-function-filter-small-tc,
.x-btn-over .x-btn-function-filter-small-bc {
    background-image: url(images/btn/btn-function-filter-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-function-filter-small-ml,
.x-btn-over .x-btn-function-filter-small-mr {
    background-image: url(images/btn/btn-function-filter-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-function-filter-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-bc {
    background-image: url(images/btn/btn-function-filter-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-mr {
    background-image: url(images/btn/btn-function-filter-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-function-filter-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-function-filter-small-tl,
.x-btn.x-btn-menu-active .x-btn-function-filter-small-bl,
.x-btn.x-btn-menu-active .x-btn-function-filter-small-tr,
.x-btn.x-btn-menu-active .x-btn-function-filter-small-br,
.x-btn.x-btn-menu-active .x-btn-function-filter-small-tc,
.x-btn.x-btn-menu-active .x-btn-function-filter-small-bc,
.x-btn.x-btn-pressed .x-btn-function-filter-small-tl,
.x-btn.x-btn-pressed .x-btn-function-filter-small-bl,
.x-btn.x-btn-pressed .x-btn-function-filter-small-tr,
.x-btn.x-btn-pressed .x-btn-function-filter-small-br,
.x-btn.x-btn-pressed .x-btn-function-filter-small-tc,
.x-btn.x-btn-pressed .x-btn-function-filter-small-bc {
    background-image: url(images/btn/btn-function-filter-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-function-filter-small-ml,
.x-btn.x-btn-menu-active .x-btn-function-filter-small-mr,
.x-btn.x-btn-pressed .x-btn-function-filter-small-ml,
.x-btn.x-btn-pressed .x-btn-function-filter-small-mr {
    background-image: url(images/btn/btn-function-filter-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-function-filter-small-mc,
.x-btn.x-btn-pressed .x-btn-function-filter-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-bc {
    background-image: url(images/btn/btn-function-filter-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-mr {
    background-image: url(images/btn/btn-function-filter-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-function-filter-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-function-filter-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-function-filter-small-tl,
.x-btn.x-btn-disabled .x-btn-function-filter-small-bl,
.x-btn.x-btn-disabled .x-btn-function-filter-small-tr,
.x-btn.x-btn-disabled .x-btn-function-filter-small-br,
.x-btn.x-btn-disabled .x-btn-function-filter-small-tc,
.x-btn.x-btn-disabled .x-btn-function-filter-small-bc {
    background-image: url(images/btn/btn-function-filter-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-function-filter-small-ml,
.x-btn.x-btn-disabled .x-btn-function-filter-small-mr {
    background-image: url(images/btn/btn-function-filter-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-function-filter-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-function-filter-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-function-filter-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small.x-segmented-button-first {
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small.x-segmented-button-first .x-btn-function-filter-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small.x-segmented-button-middle {
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small.x-segmented-button-middle .x-btn-function-filter-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small.x-segmented-button-last .x-btn-function-filter-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small.x-segmented-button-first {
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small.x-segmented-button-first .x-btn-function-filter-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small.x-segmented-button-middle {
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small.x-segmented-button-middle .x-btn-function-filter-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small.x-segmented-button-last .x-btn-function-filter-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-function-filter-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small:after {
    top: 0px;
    right: 0;
    bottom: 0px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small.x-segmented-button-first:after {
    left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-function-filter-small.x-segmented-button-last:after {
    right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small:after {
    top: 0;
    right: 0px;
    bottom: 0;
    left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small.x-segmented-button-first:after {
    top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-function-filter-small.x-segmented-button-last:after {
    bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-function-filter-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-function-filter-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-function-filter-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-function-filter-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-function-filter-small-cell > .x-grid-cell-inner {
    padding-top: 2px;
    padding-bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-function-filter-small-cell > .x-grid-cell-inner >.x-btn-function-filter-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-primary-button-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 1px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-primary-button-small-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-primary-button-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-primary-button-small-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-primary-button-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-primary-button-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-primary-button-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-primary-button-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-primary-button-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-primary-button-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-primary-button-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-primary-button-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-primary-button-small-tr,
.x-btn-primary-button-small-br,
.x-btn-primary-button-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-primary-button-small-tl,
.x-btn-primary-button-small-bl,
.x-btn-primary-button-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-primary-button-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-primary-button-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-primary-button-small-tl,
.x-btn-primary-button-small-bl,
.x-btn-primary-button-small-tr,
.x-btn-primary-button-small-br,
.x-btn-primary-button-small-tc,
.x-btn-primary-button-small-bc,
.x-btn-primary-button-small-ml,
.x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-primary-button-small-ml,
.x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-primary-button-small-mc {
    padding: 5px 5px 5px 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-primary-button-small {
    border-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-primary-button-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-primary-button-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-primary-button-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: white;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-primary-button-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-primary-button-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-primary-button-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-primary-button-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-primary-button-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-primary-button-small {
    font-size: 16px;
    height: 16px;
    color: white;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-primary-button-small,
.x-btn-icon-right > .x-btn-icon-el-primary-button-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-primary-button-small,
.x-btn-icon-bottom > .x-btn-icon-el-primary-button-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-primary-button-small.x-btn-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-primary-button-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-primary-button-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-primary-button-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-primary-button-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-primary-button-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-primary-button-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-primary-button-small,
.x-btn-split-bottom > .x-btn-button-primary-button-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-primary-button-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-primary-button-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-primary-button-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-primary-button-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-primary-button-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-primary-button-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-primary-button-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-primary-button-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-primary-button-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-primary-button-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-primary-button-small {
    background-image: none;
    background-color: black;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-primary-button-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-primary-button-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-primary-button-small {
    border-color: #000;
    background-image: none;
    background-color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-primary-button-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-primary-button-small,
.x-btn.x-btn-pressed.x-btn-primary-button-small {
    border-color: #000;
    background-image: none;
    background-color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-primary-button-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-primary-button-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-primary-button-small {
    background-image: none;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-bc {
    background-image: url(images/btn/btn-primary-button-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-primary-button-small-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-primary-button-small-tl,
.x-btn-over .x-btn-primary-button-small-bl,
.x-btn-over .x-btn-primary-button-small-tr,
.x-btn-over .x-btn-primary-button-small-br,
.x-btn-over .x-btn-primary-button-small-tc,
.x-btn-over .x-btn-primary-button-small-bc {
    background-image: url(images/btn/btn-primary-button-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-primary-button-small-ml,
.x-btn-over .x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-primary-button-small-mc {
    background-color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-bc {
    background-image: url(images/btn/btn-primary-button-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-primary-button-small-mc {
    background-color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-primary-button-small-tl,
.x-btn.x-btn-menu-active .x-btn-primary-button-small-bl,
.x-btn.x-btn-menu-active .x-btn-primary-button-small-tr,
.x-btn.x-btn-menu-active .x-btn-primary-button-small-br,
.x-btn.x-btn-menu-active .x-btn-primary-button-small-tc,
.x-btn.x-btn-menu-active .x-btn-primary-button-small-bc,
.x-btn.x-btn-pressed .x-btn-primary-button-small-tl,
.x-btn.x-btn-pressed .x-btn-primary-button-small-bl,
.x-btn.x-btn-pressed .x-btn-primary-button-small-tr,
.x-btn.x-btn-pressed .x-btn-primary-button-small-br,
.x-btn.x-btn-pressed .x-btn-primary-button-small-tc,
.x-btn.x-btn-pressed .x-btn-primary-button-small-bc {
    background-image: url(images/btn/btn-primary-button-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-primary-button-small-ml,
.x-btn.x-btn-menu-active .x-btn-primary-button-small-mr,
.x-btn.x-btn-pressed .x-btn-primary-button-small-ml,
.x-btn.x-btn-pressed .x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-primary-button-small-mc,
.x-btn.x-btn-pressed .x-btn-primary-button-small-mc {
    background-color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-bc {
    background-image: url(images/btn/btn-primary-button-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-primary-button-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-primary-button-small-mc {
    background-color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-primary-button-small-tl,
.x-btn.x-btn-disabled .x-btn-primary-button-small-bl,
.x-btn.x-btn-disabled .x-btn-primary-button-small-tr,
.x-btn.x-btn-disabled .x-btn-primary-button-small-br,
.x-btn.x-btn-disabled .x-btn-primary-button-small-tc,
.x-btn.x-btn-disabled .x-btn-primary-button-small-bc {
    background-image: url(images/btn/btn-primary-button-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-primary-button-small-ml,
.x-btn.x-btn-disabled .x-btn-primary-button-small-mr {
    background-image: url(images/btn/btn-primary-button-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-primary-button-small-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-primary-button-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-primary-button-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small.x-segmented-button-first .x-btn-primary-button-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small.x-segmented-button-middle .x-btn-primary-button-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small.x-segmented-button-last .x-btn-primary-button-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small.x-segmented-button-first .x-btn-primary-button-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small.x-segmented-button-middle .x-btn-primary-button-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small.x-segmented-button-last .x-btn-primary-button-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-primary-button-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-primary-button-small.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-primary-button-small.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-primary-button-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-primary-button-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-primary-button-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-primary-button-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-primary-button-small-cell > .x-grid-cell-inner {
    padding-top: 1px;
    padding-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-primary-button-small-cell > .x-grid-cell-inner >.x-btn-primary-button-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:109 */
.x-btn-menu-active.x-btn-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:112 */
.x-btn-menu-active.x-btn-filter-small .x-btn-icon-el-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:115 */
.x-btn-menu-active.x-btn-filter-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:124 */
.x-btn-menu-active.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:129 */
.x-btn-menu-active.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:143 */
.x-btn-menu-active.x-btn-default-toolbar-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:148 */
.x-btn-menu-active.x-btn-default-toolbar-small .x-btn-icon-el-default-toolbar-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:153 */
.x-btn-menu-active.x-btn-default-toolbar-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:163 */
.x-btn-menu-active.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:168 */
.x-btn-menu-active.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:181 */
.x-btn-menu-active.x-btn-default-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:186 */
.x-btn-menu-active.x-btn-default-small .x-btn-icon-el-default-toolbar-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:191 */
.x-btn-menu-active.x-btn-default-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:201 */
.x-btn-menu-active.x-btn-default-small .x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:206 */
.x-btn-menu-active.x-btn-default-small .x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:225 */
.x-btn-over.x-btn-function-action-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:227 */
.x-btn-over.x-btn-function-action-small .x-btn-icon-el-function-action-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:231 */
.x-btn-over.x-btn-function-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:233 */
.x-btn-over.x-btn-function-filter-small .x-btn-icon-el-function-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:236 */
.x-btn-over.x-btn-function-filter-small .x-btn-icon-el-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:240 */
.x-btn-over.x-btn-function-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:245 */
.x-btn-over.x-btn-function-small .x-btn-icon-el-function-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:252 */
.x-btn-over.x-btn-function-small .x-btn-inner-function-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:261 */
.x-btn-over.x-btn-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:264 */
.x-btn-over.x-btn-filter-small .x-btn-icon-el-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:267 */
.x-btn-over.x-btn-filter-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:276 */
.x-btn-over.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:281 */
.x-btn-over.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:295 */
.x-btn-over.x-btn-default-toolbar-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:300 */
.x-btn-over.x-btn-default-toolbar-small .x-btn-icon-el-default-toolbar-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:305 */
.x-btn-over.x-btn-default-toolbar-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:315 */
.x-btn-over.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:320 */
.x-btn-over.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:333 */
.x-btn-over.x-btn-default-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:338 */
.x-btn-over.x-btn-default-small .x-btn-icon-el-default-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:343 */
.x-btn-over.x-btn-default-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:352 */
.x-btn-over.x-btn-default-small .x-btn-wrap-default-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:357 */
.x-btn-over.x-btn-default-small .x-btn-wrap-default-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:369 */
.x-btn-over.x-btn-icecap-tab-new-small {
    box-shadow: none !important;
    background-color: #fbfbfb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:378 */
.x-btn-pressed.x-btn-function-action-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:382 */
.x-btn-pressed.x-btn-function-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:385 */
.x-btn-pressed.x-btn-function-filter-active-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:389 */
.x-btn-pressed.x-btn-function-small-focus {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:394 */
.x-btn-pressed.x-btn-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:397 */
.x-btn-pressed.x-btn-filter-small .x-btn-icon-el-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:400 */
.x-btn-pressed.x-btn-filter-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:409 */
.x-btn-pressed.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:414 */
.x-btn-pressed.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:428 */
.x-btn-pressed.x-btn-default-toolbar-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:433 */
.x-btn-pressed.x-btn-default-toolbar-small .x-btn-icon-el-default-toolbar-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:438 */
.x-btn-pressed.x-btn-default-toolbar-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:448 */
.x-btn-pressed.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:453 */
.x-btn-pressed.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:466 */
.x-btn-pressed.x-btn-default-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:471 */
.x-btn-pressed.x-btn-default-small .x-btn-icon-el-default-toolbar-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:476 */
.x-btn-pressed.x-btn-default-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:486 */
.x-btn-pressed.x-btn-default-small .x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:491 */
.x-btn-pressed.x-btn-default-small .x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:505 */
.x-btn-pressed.x-btn-primary-button-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:509 */
.x-btn-pressed.x-btn-icecap-tab-new-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:517 */
.x-btn-focus.x-btn-function-action-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:519 */
.x-btn-focus.x-btn-function-action-small .x-btn-icon-el-function-action-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:524 */
.x-btn-focus.x-btn-function-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:526 */
.x-btn-focus.x-btn-function-filter-small .x-btn-icon-el-function-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:529 */
.x-btn-focus.x-btn-function-filter-small .x-btn-icon-el-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:533 */
.x-btn-focus.x-btn-function-filter-active-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:537 */
.x-btn-focus.x-btn-function-small-focus {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:542 */
.x-btn-focus.x-btn-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:545 */
.x-btn-focus.x-btn-filter-small .x-btn-icon-el-filter-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:548 */
.x-btn-focus.x-btn-filter-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:557 */
.x-btn-focus.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:562 */
.x-btn-focus.x-btn-filter-small .x-btn-wrap-filter-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:576 */
.x-btn-focus.x-btn-default-toolbar-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:581 */
.x-btn-focus.x-btn-default-toolbar-small .x-btn-icon-el-default-toolbar-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:586 */
.x-btn-focus.x-btn-default-toolbar-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:596 */
.x-btn-focus.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:601 */
.x-btn-focus.x-btn-default-toolbar-small .x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:614 */
.x-btn-focus.x-btn-default-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:619 */
.x-btn-focus.x-btn-default-small .x-btn-icon-el-default-toolbar-small {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:624 */
.x-btn-focus.x-btn-default-small .x-btn-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:634 */
.x-btn-focus.x-btn-default-small .x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:639 */
.x-btn-focus.x-btn-default-small .x-btn-wrap-default-toolbar-small.x-btn-split-right:after {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:653 */
.x-btn-focus.x-btn-primary-button-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:657 */
.x-btn-focus.x-btn-icecap-tab-new-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:667 */
.x-btn-function-small .x-btn-inner-function-small {
    font-weight: 700;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:676 */
.x-btn-filter-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:680 */
.x-btn-filter-small.x-arrow-focus-arrow-el {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:693 */
.x-btn-wrap-filter-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:707 */
.x-btn-wrap-default-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:719 */
.x-btn-wrap-default-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:733 */
.x-btn .x-btn-icon-el-function-action-small {
    font-weight: bold !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:739 */
.x-btn .x-btn-icon-el-function-filter-active-small {
    font-weight: bold !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/button/Button.scss:743 */
.x-btn .x-btn-icon-el-function-filter-small {
    font-weight: bold !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/resizer/Splitter.scss:10 */
.x-splitter {
    background-color: #d0d0d0 !important;
    z-index: 2;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:598 */
.x-toolbar-filter {
    padding: 6px 0 6px 8px;
    border-style: solid;
    border-color: #d0d0d0;
    border-width: 1px;
    background-image: none;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:614 */
.x-toolbar-filter .x-tool-img {
    color: #919191;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:629 */
.x-toolbar-filter .x-toolbar-item {
    margin: 0 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:639 */
.x-toolbar-filter .x-toolbar-separator-horizontal {
    margin: 0 8px 0 0;
    height: 14px;
    border-style: solid;
    border-width: 0 0 0 1px;
    border-left-color: #d0d0d0;
    border-right-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:648 */
.x-toolbar-filter .x-box-menu-after {
    margin: 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:653 */
.x-toolbar-filter-vertical {
    padding: 6px 8px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:662 */
.x-toolbar-filter-vertical .x-toolbar-item {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:671 */
.x-toolbar-filter-vertical .x-toolbar-separator-vertical {
    margin: 0 5px 6px;
    border-style: solid none;
    border-width: 1px 0 0;
    border-top-color: #d0d0d0;
    border-bottom-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:679 */
.x-toolbar-filter-vertical .x-box-menu-after {
    margin: 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:694 */
.x-toolbar-text-filter {
    padding: 0 4px;
    color: #34454c;
    font: 400 14px/16px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:700 */
.x-toolbar-spacer-filter {
    width: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-toolbar-filter-scroller .x-box-scroller-body-horizontal {
    margin-left: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-toolbar-filter-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-toolbar-filter {
    cursor: pointer;
    color: #919191;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-toolbar-filter.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-toolbar-filter.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-toolbar-filter.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-toolbar-filter.x-box-scroller-left,
.x-box-scroller-toolbar-filter.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-toolbar-filter.x-box-scroller-left {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-filter.x-box-scroller-left:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-toolbar-filter.x-box-scroller-right {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-filter.x-box-scroller-right:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-toolbar-filter.x-box-scroller-top,
.x-box-scroller-toolbar-filter.x-box-scroller-bottom {
    height: 24px;
    width: 24px;
    left: 50%;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-toolbar-filter.x-box-scroller-top {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-filter.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-toolbar-filter.x-box-scroller-bottom {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-filter.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:742 */
.x-ie8 .x-box-scroller-toolbar-filter {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:748 */
.x-toolbar-more-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-toolbar-more-icon:before {
    content: "\f0c9";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:8 */
.x-toolbar-filter {
    padding: 0px 0px 10px 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:11 */
.x-toolbar-footer {
    border-top: 1px solid #ececec !important;
    background-color: white !important;
    padding: 10px 10px 10px 10px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:15 */
.x-toolbar-footer .x-btn {
    min-width: 80px;
    height: 30px;
    min-height: 30px;
    max-height: 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:21 */
.x-toolbar-footer .x-btn-default-small {
    background-color: white;
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:30 */
.x-toolbar-footer .x-btn-focus.x-btn-pressed.x-btn-default-small {
    border-color: #00adee;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:34 */
.x-toolbar-footer .x-btn-focus.x-btn-pressed.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:43 */
.x-toolbar-footer .x-btn-focus.x-btn-over.x-btn-default-small {
    border-color: #00adee;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:47 */
.x-toolbar-footer .x-btn-focus.x-btn-over.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:54 */
.x-toolbar-footer .x-btn-focus.x-btn-default-small {
    box-shadow: none !important;
    border-color: #00adee;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:59 */
.x-toolbar-footer .x-btn-focus.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:66 */
.x-toolbar-footer .x-btn-focus.x-btn-primary-button-small {
    box-shadow: none !important;
    border-color: #009eda;
    background-color: #009eda;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:78 */
.x-toolbar-footer .x-btn-over.x-btn-default-small {
    border-color: #00adee;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:82 */
.x-toolbar-footer .x-btn-over.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/toolbar/Toolbar.scss:91 */
.x-toolbar-footer .x-btn .x-btn-inner {
    font-weight: bold;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:799 */
.x-panel-menu-navigation {
    border-color: #d0d0d0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:802 */
.x-panel-menu-navigation.x-masked {
    border-color: #e8e8e8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:810 */
.x-panel-header-menu-navigation {
    font-size: 14px;
    border: 1px solid transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:836 */
.x-panel-header-menu-navigation .x-tool-tool-el {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:842 */
.x-panel-header-menu-navigation-horizontal {
    padding: 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:846 */
.x-panel-header-menu-navigation-horizontal .x-panel-header-menu-navigation-tab-bar {
    margin-top: -11px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:854 */
.x-panel-header-menu-navigation-horizontal.x-header-noborder {
    padding: 12px 16px 12px 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:858 */
.x-panel-header-menu-navigation-horizontal.x-header-noborder .x-panel-header-menu-navigation-tab-bar {
    margin-top: -12px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:866 */
.x-panel-header-menu-navigation-vertical {
    padding: 15px 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:870 */
.x-panel-header-menu-navigation-vertical .x-panel-header-menu-navigation-tab-bar {
    margin-right: -11px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:878 */
.x-panel-header-menu-navigation-vertical.x-header-noborder {
    padding: 16px 12px 16px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:882 */
.x-panel-header-menu-navigation-vertical.x-header-noborder .x-panel-header-menu-navigation-tab-bar {
    margin-right: -12px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:916 */
.x-panel-header-title-menu-navigation {
    color: #000;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:929 */
.x-keyboard-mode .x-panel-header-title-menu-navigation.x-title-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-title-menu-navigation.x-title-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-title-menu-navigation.x-title-focus,
.x-edge .x-keyboard-mode .x-panel-header-title-menu-navigation.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-title-menu-navigation.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-title-menu-navigation.x-title-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-title-menu-navigation.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:950 */
.x-panel-header-title-menu-navigation > .x-title-text-menu-navigation {
    text-transform: none;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:997 */
.x-panel-header-title-menu-navigation > .x-title-icon-wrap-menu-navigation.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1002 */
.x-panel-header-title-menu-navigation > .x-title-icon-wrap-menu-navigation.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1014 */
.x-panel-header-title-menu-navigation > .x-title-icon-wrap-menu-navigation.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1019 */
.x-panel-header-title-menu-navigation > .x-title-icon-wrap-menu-navigation.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1031 */
.x-panel-header-title-menu-navigation > .x-title-icon-wrap-menu-navigation > .x-title-icon-menu-navigation {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #000;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1051 */
.x-ie8 .x-panel-header-title-menu-navigation > .x-title-icon-wrap-menu-navigation > .x-title-icon-menu-navigation.x-title-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1062 */
.x-panel-body-menu-navigation {
    background: white;
    border-color: #d0d0d0;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1226 */
.x-panel-header-menu-navigation {
    background-image: none;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1230 */
.x-panel-header-menu-navigation-vertical {
    background-image: none;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1288 */
.x-panel .x-panel-header-menu-navigation-collapsed-border-top {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1292 */
.x-panel .x-panel-header-menu-navigation-collapsed-border-right {
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1296 */
.x-panel .x-panel-header-menu-navigation-collapsed-border-bottom {
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1300 */
.x-panel .x-panel-header-menu-navigation-collapsed-border-left {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1336 */
.x-panel-header-menu-navigation-horizontal .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1346 */
.x-panel-header-menu-navigation-horizontal .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1358 */
.x-panel-header-menu-navigation-vertical .x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1368 */
.x-panel-header-menu-navigation-vertical .x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1381 */
.x-keyboard-mode .x-panel-header-menu-navigation .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-menu-navigation .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-menu-navigation .x-tool-focus,
.x-edge .x-keyboard-mode .x-panel-header-menu-navigation .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-menu-navigation .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-menu-navigation .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-menu-navigation .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1429 */
.x-panel-menu-navigation-resizable .x-panel-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-panel-menu-navigation-outer-border-l {
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-panel-menu-navigation-outer-border-b {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-panel-menu-navigation-outer-border-bl {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-panel-menu-navigation-outer-border-r {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-panel-menu-navigation-outer-border-rl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-panel-menu-navigation-outer-border-rb {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-panel-menu-navigation-outer-border-rbl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-panel-menu-navigation-outer-border-t {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-panel-menu-navigation-outer-border-tl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-panel-menu-navigation-outer-border-tb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-panel-menu-navigation-outer-border-tbl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-panel-menu-navigation-outer-border-tr {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-panel-menu-navigation-outer-border-trl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-panel-menu-navigation-outer-border-trb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-panel-menu-navigation-outer-border-trbl {
    border-color: #d0d0d0 !important;
    border-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/panel/Panel.scss:22 */
.x-panel-header-menu-navigation-horizontal.x-header-noborder {
    border-top: 1px solid #eee !important;
    border-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/panel/Panel.scss:30 */
.x-panel-header-default-horizontal.x-header-noborder {
    border-top: 1px solid #eee !important;
    border-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/panel/Panel.scss:42 */
.x-window .x-tabpanel-child .x-panel-header-default-horizontal.x-header-noborder {
    border-top: 0px !important;
    border-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/panel/Panel.scss:52 */
.x-tabpanel-child .x-panel-header-default-horizontal.x-header-noborder {
    border-top: 0px !important;
    border-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:545 */
.x-window-message {
    border-color: transparent;
    -webkit-border-radius: 0 0 0 0;
    -moz-border-radius: 0 0 0 0;
    -ms-border-radius: 0 0 0 0;
    -o-border-radius: 0 0 0 0;
    border-radius: 0 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-message {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 0 0 0 0;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-message-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-message {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-message-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-0px-0px-0px-0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-message-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-message-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-message-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-message-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-message-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-message-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-message-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-message-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-message-tr,
.x-window-message-br,
.x-window-message-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-message-tl,
.x-window-message-bl,
.x-window-message-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-message-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-message-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-message-tl,
.x-window-message-bl,
.x-window-message-tr,
.x-window-message-br,
.x-window-message-tc,
.x-window-message-bc,
.x-window-message-ml,
.x-window-message-mr {
    background-image: url(images/window/window-message-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-message-ml,
.x-window-message-mr {
    background-image: url(images/window/window-message-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-message-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:567 */
.x-window-body-message {
    border-color: #00adee;
    border-width: 1px;
    border-style: solid;
    background: white;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:581 */
.x-window-header-message {
    font-size: 14px;
    border-color: transparent;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:586 */
.x-window-header-message .x-tool-img {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:599 */
.x-window-header-message-horizontal .x-window-header-message-tab-bar {
    margin-top: -10px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:606 */
.x-window-header-message-vertical .x-window-header-message-tab-bar {
    margin-right: -10px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:622 */
.x-window-header-title-message {
    color: black;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:631 */
.x-window-header-title-message > .x-title-text-message {
    padding: 0px 0px 0px 5px;
    text-transform: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:678 */
.x-window-header-title-message > .x-title-icon-wrap-message.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:683 */
.x-window-header-title-message > .x-title-icon-wrap-message.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:695 */
.x-window-header-title-message > .x-title-icon-wrap-message.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:700 */
.x-window-header-title-message > .x-title-icon-wrap-message.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:712 */
.x-window-header-title-message > .x-title-icon-wrap-message > .x-title-icon-message {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #fff;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:732 */
.x-ie8 .x-window-header-title-message > .x-title-icon-wrap-message > .x-title-icon-message.x-title-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-top-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-top-tr,
.x-window-header-message-top-br,
.x-window-header-message-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-top-tl,
.x-window-header-message-top-bl,
.x-window-header-message-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-top-tl,
.x-window-header-message-top-bl,
.x-window-header-message-top-tr,
.x-window-header-message-top-br,
.x-window-header-message-top-tc,
.x-window-header-message-top-bc,
.x-window-header-message-top-ml,
.x-window-header-message-top-mr {
    background-image: url(images/window-header/window-header-message-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-top-ml,
.x-window-header-message-top-mr {
    background-image: url(images/window-header/window-header-message-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-right-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-right-tr,
.x-window-header-message-right-br,
.x-window-header-message-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-right-tl,
.x-window-header-message-right-bl,
.x-window-header-message-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-right-tl,
.x-window-header-message-right-bl,
.x-window-header-message-right-tr,
.x-window-header-message-right-br,
.x-window-header-message-right-tc,
.x-window-header-message-right-bc,
.x-window-header-message-right-ml,
.x-window-header-message-right-mr {
    background-image: url(images/window-header/window-header-message-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-right-ml,
.x-window-header-message-right-mr {
    background-image: url(images/window-header/window-header-message-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-bottom-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-bottom-tr,
.x-window-header-message-bottom-br,
.x-window-header-message-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-bottom-tl,
.x-window-header-message-bottom-bl,
.x-window-header-message-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-bottom-tl,
.x-window-header-message-bottom-bl,
.x-window-header-message-bottom-tr,
.x-window-header-message-bottom-br,
.x-window-header-message-bottom-tc,
.x-window-header-message-bottom-bc,
.x-window-header-message-bottom-ml,
.x-window-header-message-bottom-mr {
    background-image: url(images/window-header/window-header-message-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-bottom-ml,
.x-window-header-message-bottom-mr {
    background-image: url(images/window-header/window-header-message-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-left-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-left-tr,
.x-window-header-message-left-br,
.x-window-header-message-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-left-tl,
.x-window-header-message-left-bl,
.x-window-header-message-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-left-tl,
.x-window-header-message-left-bl,
.x-window-header-message-left-tr,
.x-window-header-message-left-br,
.x-window-header-message-left-tc,
.x-window-header-message-left-bc,
.x-window-header-message-left-ml,
.x-window-header-message-left-mr {
    background-image: url(images/window-header/window-header-message-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-left-ml,
.x-window-header-message-left-mr {
    background-image: url(images/window-header/window-header-message-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-collapsed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-collapsed-top-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-collapsed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-collapsed-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-collapsed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-collapsed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-collapsed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-collapsed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-collapsed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-collapsed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-collapsed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-collapsed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-collapsed-top-tr,
.x-window-header-message-collapsed-top-br,
.x-window-header-message-collapsed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-collapsed-top-tl,
.x-window-header-message-collapsed-top-bl,
.x-window-header-message-collapsed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-collapsed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-collapsed-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-collapsed-top-tl,
.x-window-header-message-collapsed-top-bl,
.x-window-header-message-collapsed-top-tr,
.x-window-header-message-collapsed-top-br,
.x-window-header-message-collapsed-top-tc,
.x-window-header-message-collapsed-top-bc,
.x-window-header-message-collapsed-top-ml,
.x-window-header-message-collapsed-top-mr {
    background-image: url(images/window-header/window-header-message-collapsed-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-collapsed-top-ml,
.x-window-header-message-collapsed-top-mr {
    background-image: url(images/window-header/window-header-message-collapsed-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-collapsed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-collapsed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-collapsed-right-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-collapsed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-collapsed-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-collapsed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-collapsed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-collapsed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-collapsed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-collapsed-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-collapsed-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-collapsed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-collapsed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-collapsed-right-tr,
.x-window-header-message-collapsed-right-br,
.x-window-header-message-collapsed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-collapsed-right-tl,
.x-window-header-message-collapsed-right-bl,
.x-window-header-message-collapsed-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-collapsed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-collapsed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-collapsed-right-tl,
.x-window-header-message-collapsed-right-bl,
.x-window-header-message-collapsed-right-tr,
.x-window-header-message-collapsed-right-br,
.x-window-header-message-collapsed-right-tc,
.x-window-header-message-collapsed-right-bc,
.x-window-header-message-collapsed-right-ml,
.x-window-header-message-collapsed-right-mr {
    background-image: url(images/window-header/window-header-message-collapsed-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-collapsed-right-ml,
.x-window-header-message-collapsed-right-mr {
    background-image: url(images/window-header/window-header-message-collapsed-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-collapsed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-collapsed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-collapsed-bottom-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-collapsed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-collapsed-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-collapsed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-collapsed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-collapsed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-collapsed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-collapsed-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-collapsed-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-collapsed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-collapsed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-collapsed-bottom-tr,
.x-window-header-message-collapsed-bottom-br,
.x-window-header-message-collapsed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-collapsed-bottom-tl,
.x-window-header-message-collapsed-bottom-bl,
.x-window-header-message-collapsed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-collapsed-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-collapsed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-collapsed-bottom-tl,
.x-window-header-message-collapsed-bottom-bl,
.x-window-header-message-collapsed-bottom-tr,
.x-window-header-message-collapsed-bottom-br,
.x-window-header-message-collapsed-bottom-tc,
.x-window-header-message-collapsed-bottom-bc,
.x-window-header-message-collapsed-bottom-ml,
.x-window-header-message-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-message-collapsed-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-collapsed-bottom-ml,
.x-window-header-message-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-message-collapsed-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-collapsed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-message-collapsed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-message-collapsed-left-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-message-collapsed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-message-collapsed-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-message-collapsed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-message-collapsed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-message-collapsed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-message-collapsed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-message-collapsed-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-message-collapsed-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-message-collapsed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-message-collapsed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-message-collapsed-left-tr,
.x-window-header-message-collapsed-left-br,
.x-window-header-message-collapsed-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-message-collapsed-left-tl,
.x-window-header-message-collapsed-left-bl,
.x-window-header-message-collapsed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-message-collapsed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-message-collapsed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-message-collapsed-left-tl,
.x-window-header-message-collapsed-left-bl,
.x-window-header-message-collapsed-left-tr,
.x-window-header-message-collapsed-left-br,
.x-window-header-message-collapsed-left-tc,
.x-window-header-message-collapsed-left-bc,
.x-window-header-message-collapsed-left-ml,
.x-window-header-message-collapsed-left-mr {
    background-image: url(images/window-header/window-header-message-collapsed-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-message-collapsed-left-ml,
.x-window-header-message-collapsed-left-mr {
    background-image: url(images/window-header/window-header-message-collapsed-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-message-collapsed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:857 */
.x-window-header-message .x-window-header-icon {
    width: 16px;
    height: 16px;
    color: #fff;
    font-size: 16px;
    line-height: 16px;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:866 */
.x-window-header-message .x-window-header-glyph {
    color: #fff;
    font-size: 16px;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:883 */
.x-ie8 .x-window-header-message .x-window-header-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:892 */
.x-window-header-message-horizontal .x-tool-after-title {
    margin: 0 0 0 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:902 */
.x-window-header-message-horizontal .x-tool-before-title {
    margin: 0 30px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:914 */
.x-window-header-message-vertical .x-tool-after-title {
    margin: 30px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:924 */
.x-window-header-message-vertical .x-tool-before-title {
    margin: 0 0 30px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:937 */
.x-keyboard-mode .x-window-header-message .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-window-header-message .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-window-header-message .x-tool-focus,
.x-edge .x-keyboard-mode .x-window-header-message .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-window-header-message .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-window-header-message .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-window-header-message .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:951 */
.x-window-header-message {
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:961 */
.x-nbr .x-window-message-collapsed .x-window-header {
    border-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-window-message-outer-border-l {
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-window-message-outer-border-b {
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-window-message-outer-border-bl {
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-window-message-outer-border-r {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-window-message-outer-border-rl {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-window-message-outer-border-rb {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-window-message-outer-border-rbl {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-window-message-outer-border-t {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-window-message-outer-border-tl {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-window-message-outer-border-tb {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-window-message-outer-border-tbl {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-window-message-outer-border-tr {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-right-color: transparent !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-window-message-outer-border-trl {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-window-message-outer-border-trb {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-window-message-outer-border-trbl {
    border-color: transparent !important;
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:545 */
.x-window-blur {
    border-color: black;
    -webkit-border-radius: 0 0 0 0;
    -moz-border-radius: 0 0 0 0;
    -ms-border-radius: 0 0 0 0;
    -o-border-radius: 0 0 0 0;
    border-radius: 0 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-blur {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 0 0 0 0;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-blur-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-blur {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-blur-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-0px-0px-0px-0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-blur-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-blur-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-blur-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-blur-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-blur-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-blur-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-blur-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-blur-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-blur-tr,
.x-window-blur-br,
.x-window-blur-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-blur-tl,
.x-window-blur-bl,
.x-window-blur-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-blur-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-blur-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-blur-tl,
.x-window-blur-bl,
.x-window-blur-tr,
.x-window-blur-br,
.x-window-blur-tc,
.x-window-blur-bc,
.x-window-blur-ml,
.x-window-blur-mr {
    background-image: url(images/window/window-blur-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-blur-ml,
.x-window-blur-mr {
    background-image: url(images/window/window-blur-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-blur-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:567 */
.x-window-body-blur {
    border-color: #00adee;
    border-width: 1px;
    border-style: solid;
    background: white;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:581 */
.x-window-header-blur {
    font-size: 14px;
    border-color: black;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:586 */
.x-window-header-blur .x-tool-img {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:599 */
.x-window-header-blur-horizontal .x-window-header-blur-tab-bar {
    margin-top: -10px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:606 */
.x-window-header-blur-vertical .x-window-header-blur-tab-bar {
    margin-right: -10px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:622 */
.x-window-header-title-blur {
    color: black;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:631 */
.x-window-header-title-blur > .x-title-text-blur {
    padding: 0px 0px 0px 5px;
    text-transform: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:678 */
.x-window-header-title-blur > .x-title-icon-wrap-blur.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:683 */
.x-window-header-title-blur > .x-title-icon-wrap-blur.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:695 */
.x-window-header-title-blur > .x-title-icon-wrap-blur.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:700 */
.x-window-header-title-blur > .x-title-icon-wrap-blur.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:712 */
.x-window-header-title-blur > .x-title-icon-wrap-blur > .x-title-icon-blur {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #fff;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:732 */
.x-ie8 .x-window-header-title-blur > .x-title-icon-wrap-blur > .x-title-icon-blur.x-title-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-top-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-top-tr,
.x-window-header-blur-top-br,
.x-window-header-blur-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-top-tl,
.x-window-header-blur-top-bl,
.x-window-header-blur-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-top-tl,
.x-window-header-blur-top-bl,
.x-window-header-blur-top-tr,
.x-window-header-blur-top-br,
.x-window-header-blur-top-tc,
.x-window-header-blur-top-bc,
.x-window-header-blur-top-ml,
.x-window-header-blur-top-mr {
    background-image: url(images/window-header/window-header-blur-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-top-ml,
.x-window-header-blur-top-mr {
    background-image: url(images/window-header/window-header-blur-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-right-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-right-tr,
.x-window-header-blur-right-br,
.x-window-header-blur-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-right-tl,
.x-window-header-blur-right-bl,
.x-window-header-blur-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-right-tl,
.x-window-header-blur-right-bl,
.x-window-header-blur-right-tr,
.x-window-header-blur-right-br,
.x-window-header-blur-right-tc,
.x-window-header-blur-right-bc,
.x-window-header-blur-right-ml,
.x-window-header-blur-right-mr {
    background-image: url(images/window-header/window-header-blur-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-right-ml,
.x-window-header-blur-right-mr {
    background-image: url(images/window-header/window-header-blur-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-bottom-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-bottom-tr,
.x-window-header-blur-bottom-br,
.x-window-header-blur-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-bottom-tl,
.x-window-header-blur-bottom-bl,
.x-window-header-blur-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-bottom-tl,
.x-window-header-blur-bottom-bl,
.x-window-header-blur-bottom-tr,
.x-window-header-blur-bottom-br,
.x-window-header-blur-bottom-tc,
.x-window-header-blur-bottom-bc,
.x-window-header-blur-bottom-ml,
.x-window-header-blur-bottom-mr {
    background-image: url(images/window-header/window-header-blur-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-bottom-ml,
.x-window-header-blur-bottom-mr {
    background-image: url(images/window-header/window-header-blur-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-left-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-left-tr,
.x-window-header-blur-left-br,
.x-window-header-blur-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-left-tl,
.x-window-header-blur-left-bl,
.x-window-header-blur-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-left-tl,
.x-window-header-blur-left-bl,
.x-window-header-blur-left-tr,
.x-window-header-blur-left-br,
.x-window-header-blur-left-tc,
.x-window-header-blur-left-bc,
.x-window-header-blur-left-ml,
.x-window-header-blur-left-mr {
    background-image: url(images/window-header/window-header-blur-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-left-ml,
.x-window-header-blur-left-mr {
    background-image: url(images/window-header/window-header-blur-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-collapsed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-collapsed-top-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-collapsed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-collapsed-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-collapsed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-collapsed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-collapsed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-collapsed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-collapsed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-collapsed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-collapsed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-collapsed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-collapsed-top-tr,
.x-window-header-blur-collapsed-top-br,
.x-window-header-blur-collapsed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-collapsed-top-tl,
.x-window-header-blur-collapsed-top-bl,
.x-window-header-blur-collapsed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-collapsed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-collapsed-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-collapsed-top-tl,
.x-window-header-blur-collapsed-top-bl,
.x-window-header-blur-collapsed-top-tr,
.x-window-header-blur-collapsed-top-br,
.x-window-header-blur-collapsed-top-tc,
.x-window-header-blur-collapsed-top-bc,
.x-window-header-blur-collapsed-top-ml,
.x-window-header-blur-collapsed-top-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-collapsed-top-ml,
.x-window-header-blur-collapsed-top-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-collapsed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-collapsed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-collapsed-right-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-collapsed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-collapsed-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-collapsed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-collapsed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-collapsed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-collapsed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-collapsed-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-collapsed-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-collapsed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-collapsed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-collapsed-right-tr,
.x-window-header-blur-collapsed-right-br,
.x-window-header-blur-collapsed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-collapsed-right-tl,
.x-window-header-blur-collapsed-right-bl,
.x-window-header-blur-collapsed-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-collapsed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-collapsed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-collapsed-right-tl,
.x-window-header-blur-collapsed-right-bl,
.x-window-header-blur-collapsed-right-tr,
.x-window-header-blur-collapsed-right-br,
.x-window-header-blur-collapsed-right-tc,
.x-window-header-blur-collapsed-right-bc,
.x-window-header-blur-collapsed-right-ml,
.x-window-header-blur-collapsed-right-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-collapsed-right-ml,
.x-window-header-blur-collapsed-right-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-collapsed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-collapsed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-collapsed-bottom-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-collapsed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-collapsed-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-collapsed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-collapsed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-collapsed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-collapsed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-collapsed-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-collapsed-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-collapsed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-collapsed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-collapsed-bottom-tr,
.x-window-header-blur-collapsed-bottom-br,
.x-window-header-blur-collapsed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-collapsed-bottom-tl,
.x-window-header-blur-collapsed-bottom-bl,
.x-window-header-blur-collapsed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-collapsed-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-collapsed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-collapsed-bottom-tl,
.x-window-header-blur-collapsed-bottom-bl,
.x-window-header-blur-collapsed-bottom-tr,
.x-window-header-blur-collapsed-bottom-br,
.x-window-header-blur-collapsed-bottom-tc,
.x-window-header-blur-collapsed-bottom-bc,
.x-window-header-blur-collapsed-bottom-ml,
.x-window-header-blur-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-collapsed-bottom-ml,
.x-window-header-blur-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-collapsed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-blur-collapsed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-blur-collapsed-left-mc {
    background-color: black;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-blur-collapsed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-blur-collapsed-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-blur-collapsed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-blur-collapsed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-blur-collapsed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-blur-collapsed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-blur-collapsed-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-blur-collapsed-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-blur-collapsed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-blur-collapsed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-blur-collapsed-left-tr,
.x-window-header-blur-collapsed-left-br,
.x-window-header-blur-collapsed-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-blur-collapsed-left-tl,
.x-window-header-blur-collapsed-left-bl,
.x-window-header-blur-collapsed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-blur-collapsed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-blur-collapsed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-blur-collapsed-left-tl,
.x-window-header-blur-collapsed-left-bl,
.x-window-header-blur-collapsed-left-tr,
.x-window-header-blur-collapsed-left-br,
.x-window-header-blur-collapsed-left-tc,
.x-window-header-blur-collapsed-left-bc,
.x-window-header-blur-collapsed-left-ml,
.x-window-header-blur-collapsed-left-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-blur-collapsed-left-ml,
.x-window-header-blur-collapsed-left-mr {
    background-image: url(images/window-header/window-header-blur-collapsed-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-blur-collapsed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:857 */
.x-window-header-blur .x-window-header-icon {
    width: 16px;
    height: 16px;
    color: #fff;
    font-size: 16px;
    line-height: 16px;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:866 */
.x-window-header-blur .x-window-header-glyph {
    color: #fff;
    font-size: 16px;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:883 */
.x-ie8 .x-window-header-blur .x-window-header-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:892 */
.x-window-header-blur-horizontal .x-tool-after-title {
    margin: 0 0 0 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:902 */
.x-window-header-blur-horizontal .x-tool-before-title {
    margin: 0 30px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:914 */
.x-window-header-blur-vertical .x-tool-after-title {
    margin: 30px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:924 */
.x-window-header-blur-vertical .x-tool-before-title {
    margin: 0 0 30px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:937 */
.x-keyboard-mode .x-window-header-blur .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-window-header-blur .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-window-header-blur .x-tool-focus,
.x-edge .x-keyboard-mode .x-window-header-blur .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-window-header-blur .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-window-header-blur .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-window-header-blur .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:951 */
.x-window-header-blur {
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:961 */
.x-nbr .x-window-blur-collapsed .x-window-header {
    border-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-window-blur-outer-border-l {
    border-left-color: black !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-window-blur-outer-border-b {
    border-bottom-color: black !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-window-blur-outer-border-bl {
    border-bottom-color: black !important;
    border-bottom-width: 2px !important;
    border-left-color: black !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-window-blur-outer-border-r {
    border-right-color: black !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-window-blur-outer-border-rl {
    border-right-color: black !important;
    border-right-width: 2px !important;
    border-left-color: black !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-window-blur-outer-border-rb {
    border-right-color: black !important;
    border-right-width: 2px !important;
    border-bottom-color: black !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-window-blur-outer-border-rbl {
    border-right-color: black !important;
    border-right-width: 2px !important;
    border-bottom-color: black !important;
    border-bottom-width: 2px !important;
    border-left-color: black !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-window-blur-outer-border-t {
    border-top-color: black !important;
    border-top-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-window-blur-outer-border-tl {
    border-top-color: black !important;
    border-top-width: 2px !important;
    border-left-color: black !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-window-blur-outer-border-tb {
    border-top-color: black !important;
    border-top-width: 2px !important;
    border-bottom-color: black !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-window-blur-outer-border-tbl {
    border-top-color: black !important;
    border-top-width: 2px !important;
    border-bottom-color: black !important;
    border-bottom-width: 2px !important;
    border-left-color: black !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-window-blur-outer-border-tr {
    border-top-color: black !important;
    border-top-width: 2px !important;
    border-right-color: black !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-window-blur-outer-border-trl {
    border-top-color: black !important;
    border-top-width: 2px !important;
    border-right-color: black !important;
    border-right-width: 2px !important;
    border-left-color: black !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-window-blur-outer-border-trb {
    border-top-color: black !important;
    border-top-width: 2px !important;
    border-right-color: black !important;
    border-right-width: 2px !important;
    border-bottom-color: black !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-window-blur-outer-border-trbl {
    border-color: black !important;
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:26 */
.x-window-message {
    box-shadow: 0px 7px 9px -2px rgba(0, 0, 0, 0.28) !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:29 */
.x-window-message .x-panel-body {
    background-color: white;
    padding: 10px 20px 30px 20px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:35 */
.x-window-message .x-toolbar-footer {
    border-top: 1px solid transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:44 */
.x-window-header-message .x-tool-tool-el {
    color: black !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:52 */
.x-window .x-tool {
    color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:55 */
.x-window .x-tool-tool-el {
    color: white;
    font-weight: bold;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:62 */
.x-window .x-tool-collapse-top:before {
    content: "\ed29";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/window/Window.scss:69 */
.x-window .x-tool-expand-bottom:before {
    content: "\ed1e";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/Labelable.scss:4 */
.x-form-item-label-top {
    font-size: 12px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:201 */
.x-form-text-field-body-function-field {
    min-width: 170px;
    max-width: 170px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:221 */
.x-form-trigger-wrap-function-field {
    border-width: 1px;
    border-style: solid;
    border-color: #393939;
    border-radius: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:229 */
.x-form-trigger-wrap-function-field.x-form-trigger-wrap-focus {
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:233 */
.x-form-trigger-wrap-function-field.x-form-trigger-wrap-invalid {
    border-color: #d81818;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:258 */
.x-form-text-function-field {
    color: #000;
    padding: 5px 10px 4px;
    background-color: #fff;
    border-radius: 3px;
    font: 400 14px/17px Open Sans, sans-serif;
    min-height: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:272 */
.x-ie8 .x-form-text-function-field {
    min-height: 17px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:278 */
.x-form-text-function-field.x-form-textarea {
    line-height: 21px;
    min-height: 84px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:283 */
.x-ie8 .x-form-text-function-field.x-form-textarea {
    min-height: 75px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:290 */
.x-form-text-function-field.x-form-text-file {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:294 */
.x-form-text-function-field.x-webkit-border-box-bug {
    height: calc(100% + 9px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:300 */
.x-placeholder-label-function-field {
    padding: 5px 10px 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:304 */
.x-form-empty-field-function-field + .x-placeholder-label-function-field {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:309 */
.x-form-text-function-field:-ms-input-placeholder {
    color: grey;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:313 */
.x-form-invalid-field-function-field {
    background-color: #fceded;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:324 */
.x-form-trigger-function-field {
    width: 30px;
    font: 16px/26px Portfolio, FontAwesome, Extjs;
    background: #fff;
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-form-trigger-function-field:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:347 */
.x-form-trigger-function-field.x-form-trigger-over {
    background-position: -30px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:353 */
.x-form-trigger-function-field.x-form-trigger-over.x-form-trigger-focus {
    background-position: -120px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:358 */
.x-form-trigger-function-field.x-form-trigger-focus {
    background-position: -90px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:367 */
.x-form-trigger.x-form-trigger-function-field.x-form-trigger-click {
    background-position: -60px center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/form/field/Text.scss:376 */
.x-textfield-function-field-cell > .x-grid-cell-inner {
    padding-top: 3px;
    padding-bottom: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:24 */
.x-form-trigger-function-field {
    line-height: 28px !important;
    border-left: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:29 */
.x-form-trigger-function-field.x-form-trigger-focus {
    border-left: 1px solid #00adee;
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:37 */
.x-form-trigger-default {
    border-left: 1px solid #d0d0d0;
    vertical-align: middle !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:42 */
.x-form-trigger-default.x-form-trigger-focus {
    border-left: 1px solid #00adee;
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:52 */
.x-form-trigger-spinner-function-field:before {
    content: "";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:56 */
.x-form-trigger-spinner-function-field .x-form-spinner {
    line-height: 14px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:58 */
.x-form-trigger-spinner-function-field .x-form-spinner-focus {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:62 */
.x-form-trigger-spinner-function-field .x-form-spinner-up:before {
    content: "\ed25";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:67 */
.x-form-trigger-spinner-function-field .x-form-spinner-down:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:76 */
.x-form-trigger-wrap {
    overflow: hidden;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:83 */
.x-form-trigger-wrap-focus .x-form-trigger-spinner-function-field {
    border-left: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:95 */
.x-form-clear-trigger {
    border-left: 0px solid transparent !important;
    vertical-align: middle !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:98 */
@supports (-ms-ime-align: auto) {
    .x-form-clear-trigger {
        line-height: unset !important;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:105 */
.x-ux-form-trigger-upload:before {
    content: "\ea48"!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:111 */
.x-ux-form-trigger-clear:before {
    content: "\ed1d"!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:117 */
.x-ux-form-trigger-add:before {
    content: "\ed26"!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:123 */
.x-ux-form-trigger-download:before {
    content: "\ea3e"!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:129 */
.x-ux-form-trigger-copy:before {
    content: "\ea71"!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:135 */
.x-ux-form-trigger-send:before {
    content: "\ec96"!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/field/Text.scss:141 */
.x-ux-preview-trigger:before {
    content: "\eb19"!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:12 */
.x-fieldset {
    background: none !important;
    border-top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:17 */
.x-fieldset-header .x-tool-toggle {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:32 */
.x-fieldset-with-legend .x-fieldset-header .x-fieldset-header-text:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 14px;
    font-weight: bold;
    display: block;
    width: 14px;
    height: 14px;
    float: left;
    margin-right: 10px;
    margin-top: 0px;
    content: "\ed1e";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:44 */
.x-fieldset-with-legend .x-fieldset-header .x-fieldset-header-text:hover {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:47 */
.x-fieldset-with-legend .x-fieldset-header .x-fieldset-header-text:focus {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:53 */
.x-fieldset-with-legend .x-fieldset-header .x-fieldset-header-tool-default:focus {
    outline: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:56 */
.x-fieldset-with-legend .x-fieldset-header .x-fieldset-header-tool-default:focus + .x-fieldset-header-text {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:72 */
.x-fieldset-with-legend.x-fieldset-collapsed .x-fieldset-header-text:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 14px;
    font-weight: bold;
    display: block;
    width: 14px;
    height: 14px;
    float: left;
    margin-right: 10px;
    margin-top: 0px;
    content: "\ed27";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:84 */
.x-fieldset-with-legend.x-fieldset-collapsed .x-fieldset-header-text:hover {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/form/FieldSet.scss:87 */
.x-fieldset-with-legend.x-fieldset-collapsed .x-fieldset-header-text:focus {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/Panel.scss:8 */
.x-grid-body {
    border-width: 1px 1px 1px !important;
    background-color: #fff !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/Panel.scss:15 */
@supports (-ms-ime-align: auto) {
    .x-grid-view .x-grid-item {
        width: 0px !important;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/Panel.scss:19 */
.x-grid-view .x-grid-item .x-grid-row {
    font: normal 14px/32px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/Panel.scss:22 */
.x-grid-view .x-grid-item .x-grid-row .x-grid-td {
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/Panel.scss:31 */
.x-grid-view .x-grid-item-selected .x-grid-row td:first-child {
    border-left: 3px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/Panel.scss:34 */
.x-grid-view .x-grid-item-selected .x-grid-row td:first-child > .x-grid-cell-inner {
    margin-left: -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/Panel.scss:48 */
.x-grid-locked-split .x-grid-inner-normal {
    border-style: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/column/Action.scss:8 */
.x-grid-item-over .x-action-col-icon:hover {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/grid/column/Action.scss:19 */
.x-grid-item .x-grid-cell-inner-action-col {
    line-height: 30px;
    font-size: 14px;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Tab.scss:17 */
.x-tab-button {
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-system-item-top {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
    padding: 12px 24px 14px 24px;
    border-width: 0px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-system-item-top-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-system-item-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-system-item-top-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-12-24-14-24;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-system-item-top-tl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-system-item-top-tr {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-system-item-top-bl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-system-item-top-br {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-system-item-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-system-item-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-system-item-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-system-item-top-bc {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-system-item-top-tr,
.x-tab-system-item-top-br,
.x-tab-system-item-top-mr {
    padding-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-system-item-top-tl,
.x-tab-system-item-top-bl,
.x-tab-system-item-top-ml {
    padding-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-system-item-top-tc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-system-item-top-bc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-system-item-top-mc {
    padding: 12px 24px 14px 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-system-item-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 24px 12px 24px;
    border-width: 0px 0px 0px 0px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-system-item-bottom-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-system-item-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-system-item-bottom-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-14-24-12-24;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-system-item-bottom-tl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-system-item-bottom-tr {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-system-item-bottom-bl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-system-item-bottom-br {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-system-item-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-system-item-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-system-item-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-system-item-bottom-bc {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-system-item-bottom-tr,
.x-tab-system-item-bottom-br,
.x-tab-system-item-bottom-mr {
    padding-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-system-item-bottom-tl,
.x-tab-system-item-bottom-bl,
.x-tab-system-item-bottom-ml {
    padding-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-system-item-bottom-tc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-system-item-bottom-bc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-system-item-bottom-mc {
    padding: 14px 24px 12px 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-system-item-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 12px 24px 14px 24px;
    border-width: 0px 0px 0px 0px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-system-item-left-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-system-item-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-system-item-left-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-12-24-14-24;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-system-item-left-tl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-system-item-left-tr {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-system-item-left-bl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-system-item-left-br {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-system-item-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-system-item-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-system-item-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-system-item-left-bc {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-system-item-left-tr,
.x-tab-system-item-left-br,
.x-tab-system-item-left-mr {
    padding-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-system-item-left-tl,
.x-tab-system-item-left-bl,
.x-tab-system-item-left-ml {
    padding-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-system-item-left-tc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-system-item-left-bc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-system-item-left-mc {
    padding: 12px 24px 14px 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-system-item-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 12px 24px 14px 24px;
    border-width: 0px 0px 0px 0px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-system-item-right-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-system-item-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-system-item-right-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-12-24-14-24;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-system-item-right-tl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-system-item-right-tr {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-system-item-right-bl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-system-item-right-br {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-system-item-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-system-item-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-system-item-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-system-item-right-bc {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-system-item-right-tr,
.x-tab-system-item-right-br,
.x-tab-system-item-right-mr {
    padding-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-system-item-right-tl,
.x-tab-system-item-right-bl,
.x-tab-system-item-right-ml {
    padding-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-system-item-right-tc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-system-item-right-bc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-system-item-right-mc {
    padding: 12px 24px 14px 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2672 */
.x-tab-system-item {
    border-color: transparent;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2731 */
.x-tab-system-item-top {
    margin: 0px 12px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2740 */
.x-tab-system-item-top.x-tab-rotate-left {
    margin: 0px 0px 0px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2763 */
.x-keyboard-mode .x-tab-system-item-top.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2794 */
.x-keyboard-mode .x-tab-system-item-top.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2825 */
.x-keyboard-mode .x-tab-system-item-top.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2852 */
.x-tab-system-item-right {
    margin: 0px 0px 12px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2861 */
.x-tab-system-item-right.x-tab-rotate-right {
    margin: 12px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2884 */
.x-keyboard-mode .x-tab-system-item-right.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2915 */
.x-keyboard-mode .x-tab-system-item-right.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2946 */
.x-keyboard-mode .x-tab-system-item-right.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2973 */
.x-tab-system-item-bottom {
    margin: 0px 12px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2982 */
.x-tab-system-item-bottom.x-tab-rotate-left {
    margin: 0px 0px 0px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3005 */
.x-keyboard-mode .x-tab-system-item-bottom.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3036 */
.x-keyboard-mode .x-tab-system-item-bottom.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3067 */
.x-keyboard-mode .x-tab-system-item-bottom.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3094 */
.x-tab-system-item-left {
    margin: 0px 0px 12px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3103 */
.x-tab-system-item-left.x-tab-rotate-right {
    margin: 12px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3126 */
.x-keyboard-mode .x-tab-system-item-left.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3157 */
.x-keyboard-mode .x-tab-system-item-left.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3188 */
.x-keyboard-mode .x-tab-system-item-left.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3215 */
.x-tab-button-system-item {
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3220 */
.x-tab-inner-system-item {
    font: 400 14px/16px "Roboto";
    color: rgba(255, 255, 255, 0.5);
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3236 */
.x-tab-icon-right > .x-tab-inner-system-item,
.x-tab-icon-left > .x-tab-inner-system-item {
    max-width: calc(100% - 20px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3244 */
.x-tab-icon-el-system-item {
    min-height: 20px;
    background-position: center center;
    font-size: 20px;
    line-height: 20px;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3245 */
.x-tab-icon-left > .x-tab-icon-el-system-item,
.x-tab-icon-right > .x-tab-icon-el-system-item {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3250 */
.x-tab-icon-top > .x-tab-icon-el-system-item,
.x-tab-icon-bottom > .x-tab-icon-el-system-item {
    min-width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3261 */
.x-tab-bar-plain .x-tab-icon-el-system-item {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3266 */
.x-tab-icon-el-system-item.x-tab-glyph {
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3286 */
.x-tab-text.x-tab-icon-left > .x-tab-icon-el-system-item {
    margin-right: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3297 */
.x-tab-text.x-tab-icon-right > .x-tab-icon-el-system-item {
    margin-left: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3308 */
.x-tab-text.x-tab-icon-top > .x-tab-icon-el-system-item {
    margin-bottom: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3312 */
.x-tab-text.x-tab-icon-bottom > .x-tab-icon-el-system-item {
    margin-top: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3318 */
.x-keyboard-mode .x-tab-focus.x-tab-system-item {
    border-color: transparent;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3398 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-system-item .x-tab-inner-system-item {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3404 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-system-item .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3454 */
.x-tab-over.x-tab-system-item {
    border-color: transparent;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3483 */
.x-ie8 .x-tab-over.x-tab-system-item.x-tab-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3489 */
.x-ie8 .x-tab-over.x-tab-system-item.x-tab-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3510 */
.x-tab-over.x-tab-system-item .x-tab-inner-system-item {
    color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3515 */
.x-tab-bar-plain .x-tab-over.x-tab-system-item .x-tab-inner-system-item {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3546 */
.x-tab-bar-plain .x-tab-over.x-tab-system-item .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3567 */
.x-keyboard-mode .x-tab-focus.x-tab-over.x-tab-system-item {
    border-color: transparent;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3612 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-over.x-tab-system-item .x-tab-inner-system-item {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3618 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-over.x-tab-system-item .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3642 */
.x-keyboard-mode.x-ie8 .x-tab-focus.x-tab-over.x-tab-system-item.x-tab-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3646 */
.x-keyboard-mode.x-ie8 .x-tab-focus.x-tab-over.x-tab-system-item.x-tab-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3685 */
.x-tab.x-tab-active.x-tab-system-item {
    border-color: #eee;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3741 */
.x-tab.x-tab-active.x-tab-system-item .x-tab-inner-system-item {
    color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3746 */
.x-tab-bar-plain .x-tab.x-tab-active.x-tab-system-item .x-tab-inner-system-item {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3761 */
.x-tab.x-tab-active.x-tab-system-item .x-tab-icon-el {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3797 */
.x-keyboard-mode .x-tab-focus.x-tab-active.x-tab-system-item {
    border-color: #eee;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3842 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-active.x-tab-system-item .x-tab-inner-system-item {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3916 */
.x-tab.x-tab-disabled.x-tab-system-item {
    border-color: transparent;
    background-color: transparent;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3976 */
.x-tab.x-tab-disabled.x-tab-system-item .x-tab-inner-system-item {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3981 */
.x-tab-bar-plain .x-tab.x-tab-disabled.x-tab-system-item .x-tab-inner-system-item {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4000 */
.x-tab.x-tab-disabled.x-tab-system-item .x-tab-icon-el-system-item {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4005 */
.x-tab.x-tab-disabled.x-tab-system-item .x-tab-icon-el {
    color: #000;
    opacity: 0.3;
    filter: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4026 */
.x-tab-bar-plain .x-tab.x-tab-disabled.x-tab-system-item .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4046 */
.x-nbr .x-tab-system-item {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-system-item-top-tl,
.x-tab-over .x-tab-system-item-top-bl,
.x-tab-over .x-tab-system-item-top-tr,
.x-tab-over .x-tab-system-item-top-br,
.x-tab-over .x-tab-system-item-top-tc,
.x-tab-over .x-tab-system-item-top-bc {
    background-image: url(images/tab/tab-system-item-top-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-system-item-top-ml,
.x-tab-over .x-tab-system-item-top-mr {
    background-image: url(images/tab/tab-system-item-top-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-system-item-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-top-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-system-item-top-tl,
.x-tab-focus .x-tab-system-item-top-bl,
.x-tab-focus .x-tab-system-item-top-tr,
.x-tab-focus .x-tab-system-item-top-br,
.x-tab-focus .x-tab-system-item-top-tc,
.x-tab-focus .x-tab-system-item-top-bc {
    background-image: url(images/tab/tab-system-item-top-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-system-item-top-ml,
.x-tab-focus .x-tab-system-item-top-mr {
    background-image: url(images/tab/tab-system-item-top-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-system-item-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-top-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-system-item-top-tl,
.x-tab-focus.x-tab-over .x-tab-system-item-top-bl,
.x-tab-focus.x-tab-over .x-tab-system-item-top-tr,
.x-tab-focus.x-tab-over .x-tab-system-item-top-br,
.x-tab-focus.x-tab-over .x-tab-system-item-top-tc,
.x-tab-focus.x-tab-over .x-tab-system-item-top-bc {
    background-image: url(images/tab/tab-system-item-top-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-system-item-top-ml,
.x-tab-focus.x-tab-over .x-tab-system-item-top-mr {
    background-image: url(images/tab/tab-system-item-top-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-system-item-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-top-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-system-item-top-tl,
.x-tab.x-tab-active .x-tab-system-item-top-bl,
.x-tab.x-tab-active .x-tab-system-item-top-tr,
.x-tab.x-tab-active .x-tab-system-item-top-br,
.x-tab.x-tab-active .x-tab-system-item-top-tc,
.x-tab.x-tab-active .x-tab-system-item-top-bc {
    background-image: url(images/tab/tab-system-item-top-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-system-item-top-ml,
.x-tab.x-tab-active .x-tab-system-item-top-mr {
    background-image: url(images/tab/tab-system-item-top-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-system-item-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-top-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-system-item-top-tl,
.x-tab-focus.x-tab-active .x-tab-system-item-top-bl,
.x-tab-focus.x-tab-active .x-tab-system-item-top-tr,
.x-tab-focus.x-tab-active .x-tab-system-item-top-br,
.x-tab-focus.x-tab-active .x-tab-system-item-top-tc,
.x-tab-focus.x-tab-active .x-tab-system-item-top-bc {
    background-image: url(images/tab/tab-system-item-top-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-system-item-top-ml,
.x-tab-focus.x-tab-active .x-tab-system-item-top-mr {
    background-image: url(images/tab/tab-system-item-top-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-system-item-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-top-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-system-item-top-tl,
.x-tab.x-tab-disabled .x-tab-system-item-top-bl,
.x-tab.x-tab-disabled .x-tab-system-item-top-tr,
.x-tab.x-tab-disabled .x-tab-system-item-top-br,
.x-tab.x-tab-disabled .x-tab-system-item-top-tc,
.x-tab.x-tab-disabled .x-tab-system-item-top-bc {
    background-image: url(images/tab/tab-system-item-top-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-system-item-top-ml,
.x-tab.x-tab-disabled .x-tab-system-item-top-mr {
    background-image: url(images/tab/tab-system-item-top-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-system-item-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-top-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-system-item-right-tl,
.x-tab-over .x-tab-system-item-right-bl,
.x-tab-over .x-tab-system-item-right-tr,
.x-tab-over .x-tab-system-item-right-br,
.x-tab-over .x-tab-system-item-right-tc,
.x-tab-over .x-tab-system-item-right-bc {
    background-image: url(images/tab/tab-system-item-right-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-system-item-right-ml,
.x-tab-over .x-tab-system-item-right-mr {
    background-image: url(images/tab/tab-system-item-right-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-system-item-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-right-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-system-item-right-tl,
.x-tab-focus .x-tab-system-item-right-bl,
.x-tab-focus .x-tab-system-item-right-tr,
.x-tab-focus .x-tab-system-item-right-br,
.x-tab-focus .x-tab-system-item-right-tc,
.x-tab-focus .x-tab-system-item-right-bc {
    background-image: url(images/tab/tab-system-item-right-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-system-item-right-ml,
.x-tab-focus .x-tab-system-item-right-mr {
    background-image: url(images/tab/tab-system-item-right-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-system-item-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-right-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-system-item-right-tl,
.x-tab-focus.x-tab-over .x-tab-system-item-right-bl,
.x-tab-focus.x-tab-over .x-tab-system-item-right-tr,
.x-tab-focus.x-tab-over .x-tab-system-item-right-br,
.x-tab-focus.x-tab-over .x-tab-system-item-right-tc,
.x-tab-focus.x-tab-over .x-tab-system-item-right-bc {
    background-image: url(images/tab/tab-system-item-right-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-system-item-right-ml,
.x-tab-focus.x-tab-over .x-tab-system-item-right-mr {
    background-image: url(images/tab/tab-system-item-right-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-system-item-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-right-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-system-item-right-tl,
.x-tab.x-tab-active .x-tab-system-item-right-bl,
.x-tab.x-tab-active .x-tab-system-item-right-tr,
.x-tab.x-tab-active .x-tab-system-item-right-br,
.x-tab.x-tab-active .x-tab-system-item-right-tc,
.x-tab.x-tab-active .x-tab-system-item-right-bc {
    background-image: url(images/tab/tab-system-item-right-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-system-item-right-ml,
.x-tab.x-tab-active .x-tab-system-item-right-mr {
    background-image: url(images/tab/tab-system-item-right-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-system-item-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-right-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-system-item-right-tl,
.x-tab-focus.x-tab-active .x-tab-system-item-right-bl,
.x-tab-focus.x-tab-active .x-tab-system-item-right-tr,
.x-tab-focus.x-tab-active .x-tab-system-item-right-br,
.x-tab-focus.x-tab-active .x-tab-system-item-right-tc,
.x-tab-focus.x-tab-active .x-tab-system-item-right-bc {
    background-image: url(images/tab/tab-system-item-right-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-system-item-right-ml,
.x-tab-focus.x-tab-active .x-tab-system-item-right-mr {
    background-image: url(images/tab/tab-system-item-right-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-system-item-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-right-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-system-item-right-tl,
.x-tab.x-tab-disabled .x-tab-system-item-right-bl,
.x-tab.x-tab-disabled .x-tab-system-item-right-tr,
.x-tab.x-tab-disabled .x-tab-system-item-right-br,
.x-tab.x-tab-disabled .x-tab-system-item-right-tc,
.x-tab.x-tab-disabled .x-tab-system-item-right-bc {
    background-image: url(images/tab/tab-system-item-right-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-system-item-right-ml,
.x-tab.x-tab-disabled .x-tab-system-item-right-mr {
    background-image: url(images/tab/tab-system-item-right-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-system-item-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-right-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-system-item-bottom-tl,
.x-tab-over .x-tab-system-item-bottom-bl,
.x-tab-over .x-tab-system-item-bottom-tr,
.x-tab-over .x-tab-system-item-bottom-br,
.x-tab-over .x-tab-system-item-bottom-tc,
.x-tab-over .x-tab-system-item-bottom-bc {
    background-image: url(images/tab/tab-system-item-bottom-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-system-item-bottom-ml,
.x-tab-over .x-tab-system-item-bottom-mr {
    background-image: url(images/tab/tab-system-item-bottom-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-system-item-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-bottom-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-system-item-bottom-tl,
.x-tab-focus .x-tab-system-item-bottom-bl,
.x-tab-focus .x-tab-system-item-bottom-tr,
.x-tab-focus .x-tab-system-item-bottom-br,
.x-tab-focus .x-tab-system-item-bottom-tc,
.x-tab-focus .x-tab-system-item-bottom-bc {
    background-image: url(images/tab/tab-system-item-bottom-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-system-item-bottom-ml,
.x-tab-focus .x-tab-system-item-bottom-mr {
    background-image: url(images/tab/tab-system-item-bottom-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-system-item-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-bottom-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-tl,
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-bl,
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-tr,
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-br,
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-tc,
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-bc {
    background-image: url(images/tab/tab-system-item-bottom-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-ml,
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-mr {
    background-image: url(images/tab/tab-system-item-bottom-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-system-item-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-bottom-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-system-item-bottom-tl,
.x-tab.x-tab-active .x-tab-system-item-bottom-bl,
.x-tab.x-tab-active .x-tab-system-item-bottom-tr,
.x-tab.x-tab-active .x-tab-system-item-bottom-br,
.x-tab.x-tab-active .x-tab-system-item-bottom-tc,
.x-tab.x-tab-active .x-tab-system-item-bottom-bc {
    background-image: url(images/tab/tab-system-item-bottom-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-system-item-bottom-ml,
.x-tab.x-tab-active .x-tab-system-item-bottom-mr {
    background-image: url(images/tab/tab-system-item-bottom-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-system-item-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-bottom-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-tl,
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-bl,
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-tr,
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-br,
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-tc,
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-bc {
    background-image: url(images/tab/tab-system-item-bottom-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-ml,
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-mr {
    background-image: url(images/tab/tab-system-item-bottom-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-system-item-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-bottom-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-system-item-bottom-tl,
.x-tab.x-tab-disabled .x-tab-system-item-bottom-bl,
.x-tab.x-tab-disabled .x-tab-system-item-bottom-tr,
.x-tab.x-tab-disabled .x-tab-system-item-bottom-br,
.x-tab.x-tab-disabled .x-tab-system-item-bottom-tc,
.x-tab.x-tab-disabled .x-tab-system-item-bottom-bc {
    background-image: url(images/tab/tab-system-item-bottom-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-system-item-bottom-ml,
.x-tab.x-tab-disabled .x-tab-system-item-bottom-mr {
    background-image: url(images/tab/tab-system-item-bottom-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-system-item-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-bottom-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-system-item-left-tl,
.x-tab-over .x-tab-system-item-left-bl,
.x-tab-over .x-tab-system-item-left-tr,
.x-tab-over .x-tab-system-item-left-br,
.x-tab-over .x-tab-system-item-left-tc,
.x-tab-over .x-tab-system-item-left-bc {
    background-image: url(images/tab/tab-system-item-left-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-system-item-left-ml,
.x-tab-over .x-tab-system-item-left-mr {
    background-image: url(images/tab/tab-system-item-left-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-system-item-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-left-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-system-item-left-tl,
.x-tab-focus .x-tab-system-item-left-bl,
.x-tab-focus .x-tab-system-item-left-tr,
.x-tab-focus .x-tab-system-item-left-br,
.x-tab-focus .x-tab-system-item-left-tc,
.x-tab-focus .x-tab-system-item-left-bc {
    background-image: url(images/tab/tab-system-item-left-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-system-item-left-ml,
.x-tab-focus .x-tab-system-item-left-mr {
    background-image: url(images/tab/tab-system-item-left-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-system-item-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-left-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-system-item-left-tl,
.x-tab-focus.x-tab-over .x-tab-system-item-left-bl,
.x-tab-focus.x-tab-over .x-tab-system-item-left-tr,
.x-tab-focus.x-tab-over .x-tab-system-item-left-br,
.x-tab-focus.x-tab-over .x-tab-system-item-left-tc,
.x-tab-focus.x-tab-over .x-tab-system-item-left-bc {
    background-image: url(images/tab/tab-system-item-left-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-system-item-left-ml,
.x-tab-focus.x-tab-over .x-tab-system-item-left-mr {
    background-image: url(images/tab/tab-system-item-left-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-system-item-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-left-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-system-item-left-tl,
.x-tab.x-tab-active .x-tab-system-item-left-bl,
.x-tab.x-tab-active .x-tab-system-item-left-tr,
.x-tab.x-tab-active .x-tab-system-item-left-br,
.x-tab.x-tab-active .x-tab-system-item-left-tc,
.x-tab.x-tab-active .x-tab-system-item-left-bc {
    background-image: url(images/tab/tab-system-item-left-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-system-item-left-ml,
.x-tab.x-tab-active .x-tab-system-item-left-mr {
    background-image: url(images/tab/tab-system-item-left-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-system-item-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-left-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-system-item-left-tl,
.x-tab-focus.x-tab-active .x-tab-system-item-left-bl,
.x-tab-focus.x-tab-active .x-tab-system-item-left-tr,
.x-tab-focus.x-tab-active .x-tab-system-item-left-br,
.x-tab-focus.x-tab-active .x-tab-system-item-left-tc,
.x-tab-focus.x-tab-active .x-tab-system-item-left-bc {
    background-image: url(images/tab/tab-system-item-left-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-system-item-left-ml,
.x-tab-focus.x-tab-active .x-tab-system-item-left-mr {
    background-image: url(images/tab/tab-system-item-left-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-system-item-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-left-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-system-item-left-tl,
.x-tab.x-tab-disabled .x-tab-system-item-left-bl,
.x-tab.x-tab-disabled .x-tab-system-item-left-tr,
.x-tab.x-tab-disabled .x-tab-system-item-left-br,
.x-tab.x-tab-disabled .x-tab-system-item-left-tc,
.x-tab.x-tab-disabled .x-tab-system-item-left-bc {
    background-image: url(images/tab/tab-system-item-left-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-system-item-left-ml,
.x-tab.x-tab-disabled .x-tab-system-item-left-mr {
    background-image: url(images/tab/tab-system-item-left-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-system-item-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-system-item-left-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4089 */
.x-tab-system-item-tl,
.x-tab-system-item-bl,
.x-tab-system-item-tr,
.x-tab-system-item-br {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#00FFFFFF,endColorstr=#00FFFFFF)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4099 */
.x-tab-system-item .x-tab-close-btn {
    top: 0;
    right: 0;
    width: 16px;
    height: 16px;
    font: 12px/1 Portfolio, FontAwesome, Extjs;
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tab-system-item .x-tab-close-btn:before {
    content: "\ed1d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4109 */
.x-tab-bar-plain .x-tab-system-item .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4121 */
.x-tab-system-item .x-tab-close-btn-over {
    background-position: -16px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4131 */
.x-tab-system-item .x-tab-close-btn-pressed {
    background-position: -32px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4139 */
.x-keyboard-mode .x-tab-system-item.x-tab-focus .x-tab-close-btn {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4145 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-system-item.x-tab-focus .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4156 */
.x-tab-system-item.x-tab-over .x-tab-close-btn {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4160 */
.x-tab-bar-plain .x-tab-system-item.x-tab-over .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4171 */
.x-keyboard-mode .x-tab-system-item.x-tab-focus.x-tab-over .x-tab-close-btn {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4177 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-system-item.x-tab-focus.x-tab-over .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4188 */
.x-tab-system-item.x-tab-active .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4219 */
.x-keyboard-mode .x-tab-system-item.x-tab-focus.x-tab-active .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4235 */
.x-tab-system-item.x-tab-disabled .x-tab-close-btn {
    color: #fff;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4240 */
.x-tab-bar-plain .x-tab-system-item.x-tab-disabled .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4262 */
.x-tab-closable.x-tab-system-item .x-tab-button {
    padding-right: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Tab.scss:46 */
.x-tab-over.x-tab-system-item .x-tab-inner-system-item {
    transition: color 0.3s ease;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Tab.scss:51 */
.x-tab.x-tab-system-item {
    text-transform: uppercase;
    border-bottom: 2px solid transparent;
    letter-spacing: 1.25px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Tab.scss:58 */
.x-tab-focus.x-tab-active.x-tab-system-item {
    border-bottom: 2px solid white !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Tab.scss:64 */
.x-tab.x-tab-active.x-tab-system-item {
    border-bottom: 2px solid white;
    transition: border-bottom 0.3s ease;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Tab.scss:70 */
.x-tab-error .x-tab-inner {
    color: #d81818 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:12 */
.x-box-scroller-tab-bar-default.x-box-scroller-top:before {
    color: #393939;
    font-size: 14px;
    content: "\ed23";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:17 */
.x-box-scroller-tab-bar-default.x-box-scroller-top:hover {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:22 */
.x-box-scroller-tab-bar-default.x-box-scroller-left:before {
    color: #393939;
    font-size: 14px;
    content: "\ed23";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:27 */
.x-box-scroller-tab-bar-default.x-box-scroller-left:hover {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:32 */
.x-box-scroller-tab-bar-default.x-box-scroller-right:before {
    color: #393939;
    font-size: 14px;
    content: "\ed28";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:37 */
.x-box-scroller-tab-bar-default.x-box-scroller-right:hover {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:389 */
.x-tab-bar-system-list {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:428 */
.x-tab-bar-system-list-top > .x-tab-bar-body-system-list {
    padding: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:432 */
.x-tab-bar-system-list-bottom > .x-tab-bar-body-system-list {
    padding: 0 !important 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:436 */
.x-tab-bar-system-list-left > .x-tab-bar-body-system-list {
    padding: !important 0 !important 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:446 */
.x-tab-bar-system-list-right > .x-tab-bar-body-system-list {
    padding: !important 0 !important 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:459 */
.x-tab-bar-plain.x-tab-bar-system-list-top > .x-tab-bar-body-system-list {
    padding: 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:463 */
.x-tab-bar-plain.x-tab-bar-system-list-bottom > .x-tab-bar-body-system-list {
    padding: 0 0 8px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:467 */
.x-tab-bar-plain.x-tab-bar-system-list-left > .x-tab-bar-body-system-list {
    padding: 0 0 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:477 */
.x-tab-bar-plain.x-tab-bar-system-list-right > .x-tab-bar-body-system-list {
    padding: 0 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:490 */
.x-tab-bar-plain.x-tab-bar-system-list-horizontal {
    border-top-color: transparent;
    border-bottom-color: transparent;
    border-left-width: 0;
    border-right-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:497 */
.x-tab-bar-plain.x-tab-bar-system-list-vertical {
    border-right-color: transparent;
    border-left-color: transparent;
    border-top-width: 0;
    border-bottom-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:611 */
.x-tab-bar-horizontal > .x-tab-bar-body-system-list {
    min-height: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:614 */
.x-ie8m .x-tab-bar-horizontal > .x-tab-bar-body-system-list {
    min-height: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:621 */
.x-tab-bar-vertical > .x-tab-bar-body-system-list {
    min-width: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:624 */
.x-ie8m .x-tab-bar-vertical > .x-tab-bar-body-system-list {
    min-width: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-tab-bar-system-list-scroller .x-box-scroller-body-horizontal {
    margin-left: 24px-!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-tab-bar-system-list-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-tab-bar-system-list {
    cursor: pointer;
    color: #fff;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-left,
.x-box-scroller-tab-bar-system-list.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-left {
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-left:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-right {
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-right:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-top,
.x-box-scroller-tab-bar-system-list.x-box-scroller-bottom {
    height: 24px;
    width: 24px;
    left: 50%;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-top {
    margin-top: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-bottom {
    margin-top: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-system-list.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:704 */
.x-tab-bar-more-icon {
    font-family: Portfolio, FontAwesome, Extjs;
    line-height: 1;
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tab-bar-more-icon:before {
    content: "\efca";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:721 */
.x-tab-bar-plain.x-tab-bar-system-list-scroller .x-box-scroller-body-horizontal {
    margin-left: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:727 */
.x-tab-bar-plain.x-tab-bar-system-list-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:732 */
.x-tab-bar-plain .x-box-scroller-tab-bar-system-list {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:780 */
.x-tab-bar-system-list-top .x-box-scroller-tab-bar-system-list {
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:784 */
.x-tab-bar-system-list-right .x-box-scroller-tab-bar-system-list {
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:788 */
.x-tab-bar-system-list-bottom .x-box-scroller-tab-bar-system-list {
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:792 */
.x-tab-bar-system-list-left .x-box-scroller-tab-bar-system-list {
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:801 */
.x-box-scroller-tab-bar-system-list {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:807 */
.x-box-scroller-tab-bar-system-list .x-ie8 .x-box-scroller-plain {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:72 */
.x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:74 */
.x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:77 */
.x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active {
    background-color: #eee;
    border-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:80 */
.x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus {
    background-color: #eee;
    border-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:85 */
.x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over {
    background-color: #eee;
    border-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:93 */
.x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:96 */
.x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:100 */
.x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:119 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:122 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab {
    background-color: #eee;
    border-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:125 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:128 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:133 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:140 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:143 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:147 */
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:173 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:176 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab {
    background-color: #eee;
    border-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:179 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:182 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:187 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:194 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:197 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:201 */
.x-panel ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:220 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:223 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab {
    background-color: #eee;
    border-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:226 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:229 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-active.x-tab-focus {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:234 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-tab-bar .x-tab-over {
    background-color: white;
    border-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:242 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-body,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-body {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:245 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-panel-header,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel-header {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:249 */
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel ~ .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] ~ .x-panel[id^=tabpanel-] .x-toolbar,
.x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-panel[id^=tabpanel-] .x-toolbar {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Bar.scss:254 */
.x-tab-bar-default-top > .x-tab-bar-body-default {
    padding: 10px 4px 0 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-centertabs-top {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-centertabs-top-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-centertabs-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-centertabs-top-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-centertabs-top-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-centertabs-top-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-centertabs-top-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-centertabs-top-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-centertabs-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-centertabs-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-centertabs-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-centertabs-top-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-centertabs-top-tr,
.x-tab-centertabs-top-br,
.x-tab-centertabs-top-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-centertabs-top-tl,
.x-tab-centertabs-top-bl,
.x-tab-centertabs-top-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-centertabs-top-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-centertabs-top-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-centertabs-top-tl,
.x-tab-centertabs-top-bl,
.x-tab-centertabs-top-tr,
.x-tab-centertabs-top-br,
.x-tab-centertabs-top-tc,
.x-tab-centertabs-top-bc,
.x-tab-centertabs-top-ml,
.x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-centertabs-top-ml,
.x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-centertabs-top-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-centertabs-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 6px 15px 10px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-centertabs-bottom-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-centertabs-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-centertabs-bottom-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-6-15-10-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-centertabs-bottom-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-centertabs-bottom-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-centertabs-bottom-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-centertabs-bottom-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-centertabs-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-centertabs-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-centertabs-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-centertabs-bottom-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-centertabs-bottom-tr,
.x-tab-centertabs-bottom-br,
.x-tab-centertabs-bottom-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-centertabs-bottom-tl,
.x-tab-centertabs-bottom-bl,
.x-tab-centertabs-bottom-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-centertabs-bottom-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-centertabs-bottom-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-centertabs-bottom-tl,
.x-tab-centertabs-bottom-bl,
.x-tab-centertabs-bottom-tr,
.x-tab-centertabs-bottom-br,
.x-tab-centertabs-bottom-tc,
.x-tab-centertabs-bottom-bc,
.x-tab-centertabs-bottom-ml,
.x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-centertabs-bottom-ml,
.x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-centertabs-bottom-mc {
    padding: 6px 15px 10px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-centertabs-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-centertabs-left-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-centertabs-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-centertabs-left-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-centertabs-left-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-centertabs-left-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-centertabs-left-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-centertabs-left-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-centertabs-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-centertabs-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-centertabs-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-centertabs-left-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-centertabs-left-tr,
.x-tab-centertabs-left-br,
.x-tab-centertabs-left-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-centertabs-left-tl,
.x-tab-centertabs-left-bl,
.x-tab-centertabs-left-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-centertabs-left-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-centertabs-left-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-centertabs-left-tl,
.x-tab-centertabs-left-bl,
.x-tab-centertabs-left-tr,
.x-tab-centertabs-left-br,
.x-tab-centertabs-left-tc,
.x-tab-centertabs-left-bc,
.x-tab-centertabs-left-ml,
.x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-centertabs-left-ml,
.x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-centertabs-left-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-centertabs-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-centertabs-right-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-centertabs-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-centertabs-right-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-centertabs-right-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-centertabs-right-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-centertabs-right-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-centertabs-right-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-centertabs-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-centertabs-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-centertabs-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-centertabs-right-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-centertabs-right-tr,
.x-tab-centertabs-right-br,
.x-tab-centertabs-right-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-centertabs-right-tl,
.x-tab-centertabs-right-bl,
.x-tab-centertabs-right-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-centertabs-right-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-centertabs-right-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-centertabs-right-tl,
.x-tab-centertabs-right-bl,
.x-tab-centertabs-right-tr,
.x-tab-centertabs-right-br,
.x-tab-centertabs-right-tc,
.x-tab-centertabs-right-bc,
.x-tab-centertabs-right-ml,
.x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-centertabs-right-ml,
.x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-centertabs-right-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2672 */
.x-tab-centertabs {
    border-color: #eee;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2731 */
.x-tab-centertabs-top {
    margin: 0 4px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2740 */
.x-tab-centertabs-top.x-tab-rotate-left {
    margin: 0 0 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2763 */
.x-keyboard-mode .x-tab-centertabs-top.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2794 */
.x-keyboard-mode .x-tab-centertabs-top.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2825 */
.x-keyboard-mode .x-tab-centertabs-top.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2852 */
.x-tab-centertabs-right {
    margin: 0 0 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2861 */
.x-tab-centertabs-right.x-tab-rotate-right {
    margin: 4px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2884 */
.x-keyboard-mode .x-tab-centertabs-right.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2915 */
.x-keyboard-mode .x-tab-centertabs-right.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2946 */
.x-keyboard-mode .x-tab-centertabs-right.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2973 */
.x-tab-centertabs-bottom {
    margin: 0 4px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2982 */
.x-tab-centertabs-bottom.x-tab-rotate-left {
    margin: 0 0 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3005 */
.x-keyboard-mode .x-tab-centertabs-bottom.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3036 */
.x-keyboard-mode .x-tab-centertabs-bottom.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3067 */
.x-keyboard-mode .x-tab-centertabs-bottom.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3094 */
.x-tab-centertabs-left {
    margin: 0 0 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3103 */
.x-tab-centertabs-left.x-tab-rotate-right {
    margin: 4px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3126 */
.x-keyboard-mode .x-tab-centertabs-left.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3157 */
.x-keyboard-mode .x-tab-centertabs-left.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3188 */
.x-keyboard-mode .x-tab-centertabs-left.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3215 */
.x-tab-button-centertabs {
    height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3220 */
.x-tab-inner-centertabs {
    font: 400 14px/24px Open Sans, sans-serif;
    color: #393939;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3236 */
.x-tab-icon-right > .x-tab-inner-centertabs,
.x-tab-icon-left > .x-tab-inner-centertabs {
    max-width: calc(100% - 20px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3244 */
.x-tab-icon-el-centertabs {
    min-height: 20px;
    background-position: center center;
    font-size: 20px;
    line-height: 20px;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3245 */
.x-tab-icon-left > .x-tab-icon-el-centertabs,
.x-tab-icon-right > .x-tab-icon-el-centertabs {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3250 */
.x-tab-icon-top > .x-tab-icon-el-centertabs,
.x-tab-icon-bottom > .x-tab-icon-el-centertabs {
    min-width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3261 */
.x-tab-bar-plain .x-tab-icon-el-centertabs {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3266 */
.x-tab-icon-el-centertabs.x-tab-glyph {
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3279 */
.x-ie8 .x-tab-icon-el-centertabs.x-tab-glyph {
    color: #474747;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3286 */
.x-tab-text.x-tab-icon-left > .x-tab-icon-el-centertabs {
    margin-right: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3297 */
.x-tab-text.x-tab-icon-right > .x-tab-icon-el-centertabs {
    margin-left: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3308 */
.x-tab-text.x-tab-icon-top > .x-tab-icon-el-centertabs {
    margin-bottom: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3312 */
.x-tab-text.x-tab-icon-bottom > .x-tab-icon-el-centertabs {
    margin-top: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3318 */
.x-keyboard-mode .x-tab-focus.x-tab-centertabs {
    border-color: #eee;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3398 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-centertabs .x-tab-inner-centertabs {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3404 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-centertabs .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3454 */
.x-tab-over.x-tab-centertabs {
    border-color: #000;
    background-image: none;
    background-color: rgba(0, 0, 0, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/background-opacity.scss:19 */
.x-ie8 .x-tab-over.x-tab-centertabs {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#14000000, endColorstr=#14000000)";
    zoom: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3483 */
.x-ie8 .x-tab-over.x-tab-centertabs.x-tab-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3489 */
.x-ie8 .x-tab-over.x-tab-centertabs.x-tab-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3510 */
.x-tab-over.x-tab-centertabs .x-tab-inner-centertabs {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3515 */
.x-tab-bar-plain .x-tab-over.x-tab-centertabs .x-tab-inner-centertabs {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3546 */
.x-tab-bar-plain .x-tab-over.x-tab-centertabs .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3567 */
.x-keyboard-mode .x-tab-focus.x-tab-over.x-tab-centertabs {
    border-color: #000;
    background-image: none;
    background-color: rgba(0, 0, 0, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/background-opacity.scss:19 */
.x-ie8 .x-keyboard-mode .x-tab-focus.x-tab-over.x-tab-centertabs {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#14000000, endColorstr=#14000000)";
    zoom: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3612 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-over.x-tab-centertabs .x-tab-inner-centertabs {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3618 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-over.x-tab-centertabs .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3642 */
.x-keyboard-mode.x-ie8 .x-tab-focus.x-tab-over.x-tab-centertabs.x-tab-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3646 */
.x-keyboard-mode.x-ie8 .x-tab-focus.x-tab-over.x-tab-centertabs.x-tab-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3685 */
.x-tab.x-tab-active.x-tab-centertabs {
    border-color: #eee;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3741 */
.x-tab.x-tab-active.x-tab-centertabs .x-tab-inner-centertabs {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3761 */
.x-tab.x-tab-active.x-tab-centertabs .x-tab-icon-el {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3769 */
.x-ie8 .x-tab.x-tab-active.x-tab-centertabs .x-tab-icon-el {
    color: #4d4d4d;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3797 */
.x-keyboard-mode .x-tab-focus.x-tab-active.x-tab-centertabs {
    border-color: #eee;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3916 */
.x-tab.x-tab-disabled.x-tab-centertabs {
    border-color: #eee;
    background-color: #eee;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3976 */
.x-tab.x-tab-disabled.x-tab-centertabs .x-tab-inner-centertabs {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3981 */
.x-tab-bar-plain .x-tab.x-tab-disabled.x-tab-centertabs .x-tab-inner-centertabs {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4000 */
.x-tab.x-tab-disabled.x-tab-centertabs .x-tab-icon-el-centertabs {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4005 */
.x-tab.x-tab-disabled.x-tab-centertabs .x-tab-icon-el {
    color: #000;
    opacity: 0.3;
    filter: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4020 */
.x-ie8 .x-tab.x-tab-disabled.x-tab-centertabs .x-tab-icon-el {
    color: #a7a7a7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4026 */
.x-tab-bar-plain .x-tab.x-tab-disabled.x-tab-centertabs .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4046 */
.x-nbr .x-tab-centertabs {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-centertabs-top-tl,
.x-tab-over .x-tab-centertabs-top-bl,
.x-tab-over .x-tab-centertabs-top-tr,
.x-tab-over .x-tab-centertabs-top-br,
.x-tab-over .x-tab-centertabs-top-tc,
.x-tab-over .x-tab-centertabs-top-bc {
    background-image: url(images/tab/tab-centertabs-top-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-centertabs-top-ml,
.x-tab-over .x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-centertabs-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-top-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-centertabs-top-tl,
.x-tab-focus .x-tab-centertabs-top-bl,
.x-tab-focus .x-tab-centertabs-top-tr,
.x-tab-focus .x-tab-centertabs-top-br,
.x-tab-focus .x-tab-centertabs-top-tc,
.x-tab-focus .x-tab-centertabs-top-bc {
    background-image: url(images/tab/tab-centertabs-top-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-centertabs-top-ml,
.x-tab-focus .x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-centertabs-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-top-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-centertabs-top-tl,
.x-tab-focus.x-tab-over .x-tab-centertabs-top-bl,
.x-tab-focus.x-tab-over .x-tab-centertabs-top-tr,
.x-tab-focus.x-tab-over .x-tab-centertabs-top-br,
.x-tab-focus.x-tab-over .x-tab-centertabs-top-tc,
.x-tab-focus.x-tab-over .x-tab-centertabs-top-bc {
    background-image: url(images/tab/tab-centertabs-top-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-centertabs-top-ml,
.x-tab-focus.x-tab-over .x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-centertabs-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-top-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-centertabs-top-tl,
.x-tab.x-tab-active .x-tab-centertabs-top-bl,
.x-tab.x-tab-active .x-tab-centertabs-top-tr,
.x-tab.x-tab-active .x-tab-centertabs-top-br,
.x-tab.x-tab-active .x-tab-centertabs-top-tc,
.x-tab.x-tab-active .x-tab-centertabs-top-bc {
    background-image: url(images/tab/tab-centertabs-top-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-centertabs-top-ml,
.x-tab.x-tab-active .x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-centertabs-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-top-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-centertabs-top-tl,
.x-tab-focus.x-tab-active .x-tab-centertabs-top-bl,
.x-tab-focus.x-tab-active .x-tab-centertabs-top-tr,
.x-tab-focus.x-tab-active .x-tab-centertabs-top-br,
.x-tab-focus.x-tab-active .x-tab-centertabs-top-tc,
.x-tab-focus.x-tab-active .x-tab-centertabs-top-bc {
    background-image: url(images/tab/tab-centertabs-top-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-centertabs-top-ml,
.x-tab-focus.x-tab-active .x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-centertabs-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-top-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-centertabs-top-tl,
.x-tab.x-tab-disabled .x-tab-centertabs-top-bl,
.x-tab.x-tab-disabled .x-tab-centertabs-top-tr,
.x-tab.x-tab-disabled .x-tab-centertabs-top-br,
.x-tab.x-tab-disabled .x-tab-centertabs-top-tc,
.x-tab.x-tab-disabled .x-tab-centertabs-top-bc {
    background-image: url(images/tab/tab-centertabs-top-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-centertabs-top-ml,
.x-tab.x-tab-disabled .x-tab-centertabs-top-mr {
    background-image: url(images/tab/tab-centertabs-top-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-centertabs-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-top-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-centertabs-right-tl,
.x-tab-over .x-tab-centertabs-right-bl,
.x-tab-over .x-tab-centertabs-right-tr,
.x-tab-over .x-tab-centertabs-right-br,
.x-tab-over .x-tab-centertabs-right-tc,
.x-tab-over .x-tab-centertabs-right-bc {
    background-image: url(images/tab/tab-centertabs-right-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-centertabs-right-ml,
.x-tab-over .x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-centertabs-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-right-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-centertabs-right-tl,
.x-tab-focus .x-tab-centertabs-right-bl,
.x-tab-focus .x-tab-centertabs-right-tr,
.x-tab-focus .x-tab-centertabs-right-br,
.x-tab-focus .x-tab-centertabs-right-tc,
.x-tab-focus .x-tab-centertabs-right-bc {
    background-image: url(images/tab/tab-centertabs-right-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-centertabs-right-ml,
.x-tab-focus .x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-centertabs-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-right-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-centertabs-right-tl,
.x-tab-focus.x-tab-over .x-tab-centertabs-right-bl,
.x-tab-focus.x-tab-over .x-tab-centertabs-right-tr,
.x-tab-focus.x-tab-over .x-tab-centertabs-right-br,
.x-tab-focus.x-tab-over .x-tab-centertabs-right-tc,
.x-tab-focus.x-tab-over .x-tab-centertabs-right-bc {
    background-image: url(images/tab/tab-centertabs-right-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-centertabs-right-ml,
.x-tab-focus.x-tab-over .x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-centertabs-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-right-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-centertabs-right-tl,
.x-tab.x-tab-active .x-tab-centertabs-right-bl,
.x-tab.x-tab-active .x-tab-centertabs-right-tr,
.x-tab.x-tab-active .x-tab-centertabs-right-br,
.x-tab.x-tab-active .x-tab-centertabs-right-tc,
.x-tab.x-tab-active .x-tab-centertabs-right-bc {
    background-image: url(images/tab/tab-centertabs-right-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-centertabs-right-ml,
.x-tab.x-tab-active .x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-centertabs-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-right-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-centertabs-right-tl,
.x-tab-focus.x-tab-active .x-tab-centertabs-right-bl,
.x-tab-focus.x-tab-active .x-tab-centertabs-right-tr,
.x-tab-focus.x-tab-active .x-tab-centertabs-right-br,
.x-tab-focus.x-tab-active .x-tab-centertabs-right-tc,
.x-tab-focus.x-tab-active .x-tab-centertabs-right-bc {
    background-image: url(images/tab/tab-centertabs-right-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-centertabs-right-ml,
.x-tab-focus.x-tab-active .x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-centertabs-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-right-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-centertabs-right-tl,
.x-tab.x-tab-disabled .x-tab-centertabs-right-bl,
.x-tab.x-tab-disabled .x-tab-centertabs-right-tr,
.x-tab.x-tab-disabled .x-tab-centertabs-right-br,
.x-tab.x-tab-disabled .x-tab-centertabs-right-tc,
.x-tab.x-tab-disabled .x-tab-centertabs-right-bc {
    background-image: url(images/tab/tab-centertabs-right-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-centertabs-right-ml,
.x-tab.x-tab-disabled .x-tab-centertabs-right-mr {
    background-image: url(images/tab/tab-centertabs-right-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-centertabs-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-right-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-centertabs-bottom-tl,
.x-tab-over .x-tab-centertabs-bottom-bl,
.x-tab-over .x-tab-centertabs-bottom-tr,
.x-tab-over .x-tab-centertabs-bottom-br,
.x-tab-over .x-tab-centertabs-bottom-tc,
.x-tab-over .x-tab-centertabs-bottom-bc {
    background-image: url(images/tab/tab-centertabs-bottom-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-centertabs-bottom-ml,
.x-tab-over .x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-centertabs-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-bottom-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-centertabs-bottom-tl,
.x-tab-focus .x-tab-centertabs-bottom-bl,
.x-tab-focus .x-tab-centertabs-bottom-tr,
.x-tab-focus .x-tab-centertabs-bottom-br,
.x-tab-focus .x-tab-centertabs-bottom-tc,
.x-tab-focus .x-tab-centertabs-bottom-bc {
    background-image: url(images/tab/tab-centertabs-bottom-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-centertabs-bottom-ml,
.x-tab-focus .x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-centertabs-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-bottom-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-tl,
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-bl,
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-tr,
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-br,
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-tc,
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-bc {
    background-image: url(images/tab/tab-centertabs-bottom-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-ml,
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-centertabs-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-bottom-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-centertabs-bottom-tl,
.x-tab.x-tab-active .x-tab-centertabs-bottom-bl,
.x-tab.x-tab-active .x-tab-centertabs-bottom-tr,
.x-tab.x-tab-active .x-tab-centertabs-bottom-br,
.x-tab.x-tab-active .x-tab-centertabs-bottom-tc,
.x-tab.x-tab-active .x-tab-centertabs-bottom-bc {
    background-image: url(images/tab/tab-centertabs-bottom-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-centertabs-bottom-ml,
.x-tab.x-tab-active .x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-centertabs-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-bottom-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-tl,
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-bl,
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-tr,
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-br,
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-tc,
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-bc {
    background-image: url(images/tab/tab-centertabs-bottom-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-ml,
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-centertabs-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-bottom-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-tl,
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-bl,
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-tr,
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-br,
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-tc,
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-bc {
    background-image: url(images/tab/tab-centertabs-bottom-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-ml,
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-mr {
    background-image: url(images/tab/tab-centertabs-bottom-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-centertabs-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-bottom-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-centertabs-left-tl,
.x-tab-over .x-tab-centertabs-left-bl,
.x-tab-over .x-tab-centertabs-left-tr,
.x-tab-over .x-tab-centertabs-left-br,
.x-tab-over .x-tab-centertabs-left-tc,
.x-tab-over .x-tab-centertabs-left-bc {
    background-image: url(images/tab/tab-centertabs-left-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-centertabs-left-ml,
.x-tab-over .x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-centertabs-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-left-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-centertabs-left-tl,
.x-tab-focus .x-tab-centertabs-left-bl,
.x-tab-focus .x-tab-centertabs-left-tr,
.x-tab-focus .x-tab-centertabs-left-br,
.x-tab-focus .x-tab-centertabs-left-tc,
.x-tab-focus .x-tab-centertabs-left-bc {
    background-image: url(images/tab/tab-centertabs-left-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-centertabs-left-ml,
.x-tab-focus .x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-centertabs-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-left-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-centertabs-left-tl,
.x-tab-focus.x-tab-over .x-tab-centertabs-left-bl,
.x-tab-focus.x-tab-over .x-tab-centertabs-left-tr,
.x-tab-focus.x-tab-over .x-tab-centertabs-left-br,
.x-tab-focus.x-tab-over .x-tab-centertabs-left-tc,
.x-tab-focus.x-tab-over .x-tab-centertabs-left-bc {
    background-image: url(images/tab/tab-centertabs-left-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-centertabs-left-ml,
.x-tab-focus.x-tab-over .x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-centertabs-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-left-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-centertabs-left-tl,
.x-tab.x-tab-active .x-tab-centertabs-left-bl,
.x-tab.x-tab-active .x-tab-centertabs-left-tr,
.x-tab.x-tab-active .x-tab-centertabs-left-br,
.x-tab.x-tab-active .x-tab-centertabs-left-tc,
.x-tab.x-tab-active .x-tab-centertabs-left-bc {
    background-image: url(images/tab/tab-centertabs-left-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-centertabs-left-ml,
.x-tab.x-tab-active .x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-centertabs-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-left-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-centertabs-left-tl,
.x-tab-focus.x-tab-active .x-tab-centertabs-left-bl,
.x-tab-focus.x-tab-active .x-tab-centertabs-left-tr,
.x-tab-focus.x-tab-active .x-tab-centertabs-left-br,
.x-tab-focus.x-tab-active .x-tab-centertabs-left-tc,
.x-tab-focus.x-tab-active .x-tab-centertabs-left-bc {
    background-image: url(images/tab/tab-centertabs-left-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-centertabs-left-ml,
.x-tab-focus.x-tab-active .x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-centertabs-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-left-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-centertabs-left-tl,
.x-tab.x-tab-disabled .x-tab-centertabs-left-bl,
.x-tab.x-tab-disabled .x-tab-centertabs-left-tr,
.x-tab.x-tab-disabled .x-tab-centertabs-left-br,
.x-tab.x-tab-disabled .x-tab-centertabs-left-tc,
.x-tab.x-tab-disabled .x-tab-centertabs-left-bc {
    background-image: url(images/tab/tab-centertabs-left-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-centertabs-left-ml,
.x-tab.x-tab-disabled .x-tab-centertabs-left-mr {
    background-image: url(images/tab/tab-centertabs-left-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-centertabs-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-centertabs-left-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4089 */
.x-tab-centertabs-tl,
.x-tab-centertabs-bl,
.x-tab-centertabs-tr,
.x-tab-centertabs-br {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#00FFFFFF,endColorstr=#00FFFFFF)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4099 */
.x-tab-centertabs .x-tab-close-btn {
    top: 0;
    right: 0;
    width: 16px;
    height: 16px;
    font: 12px/1 Portfolio, FontAwesome, Extjs;
    color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tab-centertabs .x-tab-close-btn:before {
    content: "\ed1d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4109 */
.x-tab-bar-plain .x-tab-centertabs .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4121 */
.x-tab-centertabs .x-tab-close-btn-over {
    background-position: -16px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4131 */
.x-tab-centertabs .x-tab-close-btn-pressed {
    background-position: -32px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4139 */
.x-keyboard-mode .x-tab-centertabs.x-tab-focus .x-tab-close-btn {
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4145 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-centertabs.x-tab-focus .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4156 */
.x-tab-centertabs.x-tab-over .x-tab-close-btn {
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4160 */
.x-tab-bar-plain .x-tab-centertabs.x-tab-over .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4171 */
.x-keyboard-mode .x-tab-centertabs.x-tab-focus.x-tab-over .x-tab-close-btn {
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4177 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-centertabs.x-tab-focus.x-tab-over .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4188 */
.x-tab-centertabs.x-tab-active .x-tab-close-btn {
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4192 */
.x-tab-bar-plain .x-tab-centertabs.x-tab-active .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4219 */
.x-keyboard-mode .x-tab-centertabs.x-tab-focus.x-tab-active .x-tab-close-btn {
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4225 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-centertabs.x-tab-focus.x-tab-active .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4235 */
.x-tab-centertabs.x-tab-disabled .x-tab-close-btn {
    color: #eee;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4240 */
.x-tab-bar-plain .x-tab-centertabs.x-tab-disabled .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4262 */
.x-tab-closable.x-tab-centertabs .x-tab-button {
    padding-right: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:389 */
.x-tab-bar-centertabs {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:428 */
.x-tab-bar-centertabs-top > .x-tab-bar-body-centertabs {
    padding: 8px 4px 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:432 */
.x-tab-bar-centertabs-bottom > .x-tab-bar-body-centertabs {
    padding: 0 4px 8px 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:436 */
.x-tab-bar-centertabs-left > .x-tab-bar-body-centertabs {
    padding: 4px 0 8px 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:446 */
.x-tab-bar-centertabs-right > .x-tab-bar-body-centertabs {
    padding: 8px 8px 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:459 */
.x-tab-bar-plain.x-tab-bar-centertabs-top > .x-tab-bar-body-centertabs {
    padding: 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:463 */
.x-tab-bar-plain.x-tab-bar-centertabs-bottom > .x-tab-bar-body-centertabs {
    padding: 0 0 8px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:467 */
.x-tab-bar-plain.x-tab-bar-centertabs-left > .x-tab-bar-body-centertabs {
    padding: 0 0 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:477 */
.x-tab-bar-plain.x-tab-bar-centertabs-right > .x-tab-bar-body-centertabs {
    padding: 0 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:490 */
.x-tab-bar-plain.x-tab-bar-centertabs-horizontal {
    border-top-color: transparent;
    border-bottom-color: transparent;
    border-left-width: 0;
    border-right-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:497 */
.x-tab-bar-plain.x-tab-bar-centertabs-vertical {
    border-right-color: transparent;
    border-left-color: transparent;
    border-top-width: 0;
    border-bottom-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:611 */
.x-tab-bar-horizontal > .x-tab-bar-body-centertabs {
    min-height: 48px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:614 */
.x-ie8m .x-tab-bar-horizontal > .x-tab-bar-body-centertabs {
    min-height: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:621 */
.x-tab-bar-vertical > .x-tab-bar-body-centertabs {
    min-width: 48px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:624 */
.x-ie8m .x-tab-bar-vertical > .x-tab-bar-body-centertabs {
    min-width: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-tab-bar-centertabs-scroller .x-box-scroller-body-horizontal {
    margin-left: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-tab-bar-centertabs-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-tab-bar-centertabs {
    cursor: pointer;
    color: #fff;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-left,
.x-box-scroller-tab-bar-centertabs.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-left {
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-left:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-right {
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-right:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-top,
.x-box-scroller-tab-bar-centertabs.x-box-scroller-bottom {
    height: 24px;
    width: 24px;
    left: 50%;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-top {
    margin-top: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-bottom {
    margin-top: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-centertabs.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:704 */
.x-tab-bar-more-icon {
    font-family: Portfolio, FontAwesome, Extjs;
    line-height: 1;
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tab-bar-more-icon:before {
    content: "\efca";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:721 */
.x-tab-bar-plain.x-tab-bar-centertabs-scroller .x-box-scroller-body-horizontal {
    margin-left: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:727 */
.x-tab-bar-plain.x-tab-bar-centertabs-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:732 */
.x-tab-bar-plain .x-box-scroller-tab-bar-centertabs {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:780 */
.x-tab-bar-centertabs-top .x-box-scroller-tab-bar-centertabs {
    margin-top: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:784 */
.x-tab-bar-centertabs-right .x-box-scroller-tab-bar-centertabs {
    margin-left: -16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:788 */
.x-tab-bar-centertabs-bottom .x-box-scroller-tab-bar-centertabs {
    margin-top: -16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:792 */
.x-tab-bar-centertabs-left .x-box-scroller-tab-bar-centertabs {
    margin-left: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:801 */
.x-box-scroller-tab-bar-centertabs {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:807 */
.x-box-scroller-tab-bar-centertabs .x-ie8 .x-box-scroller-plain {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:799 */
.x-panel-centertabs {
    border-color: #d0d0d0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:802 */
.x-panel-centertabs.x-masked {
    border-color: #e8e8e8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:810 */
.x-panel-header-centertabs {
    font-size: 14px;
    border: 1px solid transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:836 */
.x-panel-header-centertabs .x-tool-tool-el {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:842 */
.x-panel-header-centertabs-horizontal {
    padding: 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:846 */
.x-panel-header-centertabs-horizontal .x-panel-header-centertabs-tab-bar {
    margin-top: -11px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:854 */
.x-panel-header-centertabs-horizontal.x-header-noborder {
    padding: 12px 16px 12px 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:858 */
.x-panel-header-centertabs-horizontal.x-header-noborder .x-panel-header-centertabs-tab-bar {
    margin-top: -12px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:866 */
.x-panel-header-centertabs-vertical {
    padding: 15px 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:870 */
.x-panel-header-centertabs-vertical .x-panel-header-centertabs-tab-bar {
    margin-right: -11px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:878 */
.x-panel-header-centertabs-vertical.x-header-noborder {
    padding: 16px 12px 16px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:882 */
.x-panel-header-centertabs-vertical.x-header-noborder .x-panel-header-centertabs-tab-bar {
    margin-right: -12px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:916 */
.x-panel-header-title-centertabs {
    color: #000;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:929 */
.x-keyboard-mode .x-panel-header-title-centertabs.x-title-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-title-centertabs.x-title-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-title-centertabs.x-title-focus,
.x-edge .x-keyboard-mode .x-panel-header-title-centertabs.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-title-centertabs.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-title-centertabs.x-title-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-title-centertabs.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:950 */
.x-panel-header-title-centertabs > .x-title-text-centertabs {
    text-transform: none;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:997 */
.x-panel-header-title-centertabs > .x-title-icon-wrap-centertabs.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1002 */
.x-panel-header-title-centertabs > .x-title-icon-wrap-centertabs.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1014 */
.x-panel-header-title-centertabs > .x-title-icon-wrap-centertabs.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1019 */
.x-panel-header-title-centertabs > .x-title-icon-wrap-centertabs.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1031 */
.x-panel-header-title-centertabs > .x-title-icon-wrap-centertabs > .x-title-icon-centertabs {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #000;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1051 */
.x-ie8 .x-panel-header-title-centertabs > .x-title-icon-wrap-centertabs > .x-title-icon-centertabs.x-title-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1062 */
.x-panel-body-centertabs {
    background: white;
    border-color: #d0d0d0;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1226 */
.x-panel-header-centertabs {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1230 */
.x-panel-header-centertabs-vertical {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1288 */
.x-panel .x-panel-header-centertabs-collapsed-border-top {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1292 */
.x-panel .x-panel-header-centertabs-collapsed-border-right {
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1296 */
.x-panel .x-panel-header-centertabs-collapsed-border-bottom {
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1300 */
.x-panel .x-panel-header-centertabs-collapsed-border-left {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1336 */
.x-panel-header-centertabs-horizontal .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1346 */
.x-panel-header-centertabs-horizontal .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1358 */
.x-panel-header-centertabs-vertical .x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1368 */
.x-panel-header-centertabs-vertical .x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1381 */
.x-keyboard-mode .x-panel-header-centertabs .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-centertabs .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-centertabs .x-tool-focus,
.x-edge .x-keyboard-mode .x-panel-header-centertabs .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-centertabs .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-centertabs .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-centertabs .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1429 */
.x-panel-centertabs-resizable .x-panel-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-panel-centertabs-outer-border-l {
    border-left-color: #d0d0d0 !important;
    border-left-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-panel-centertabs-outer-border-b {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-panel-centertabs-outer-border-bl {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 0px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-panel-centertabs-outer-border-r {
    border-right-color: #d0d0d0 !important;
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-panel-centertabs-outer-border-rl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 0px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-panel-centertabs-outer-border-rb {
    border-right-color: #d0d0d0 !important;
    border-right-width: 0px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-panel-centertabs-outer-border-rbl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 0px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 0px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-panel-centertabs-outer-border-t {
    border-top-color: #d0d0d0 !important;
    border-top-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-panel-centertabs-outer-border-tl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 0px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-panel-centertabs-outer-border-tb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 0px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-panel-centertabs-outer-border-tbl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 0px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 0px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-panel-centertabs-outer-border-tr {
    border-top-color: #d0d0d0 !important;
    border-top-width: 0px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-panel-centertabs-outer-border-trl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 0px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 0px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-panel-centertabs-outer-border-trb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 0px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 0px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-panel-centertabs-outer-border-trbl {
    border-color: #d0d0d0 !important;
    border-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tab/Panel.scss:20 */
.x-tab-bar-centertabs-top > .x-tab-bar-body-centertabs {
    padding: 10px 4px 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:3 */
.x-tree-view {
    background-color: white !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:5 */
.x-tree-view .x-grid-cell-inner {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:11 */
.x-tree-view .x-grid-item .x-grid-row {
    font: normal 14px/20px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:18 */
.x-tree-view .x-grid-item-selected .x-grid-row:before {
    background-color: #00adee;
    content: " ";
    position: absolute;
    display: block;
    left: 0;
    top: 0;
    width: 3px;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:40 */
.x-tree-panel .x-tree-view .x-grid-item {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:42 */
.x-tree-panel .x-tree-view .x-grid-item-over {
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:45 */
.x-tree-panel .x-tree-view .x-grid-item-selected {
    background-color: rgba(0, 173, 238, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:52 */
.x-tree-panel .x-grid-body {
    border-top: 0px #d0d0d0 solid !important;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:56 */
.x-tree-panel .x-grid-body .x-panel-body {
    border-top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:68 */
.x-tree-lines .x-grid-tree-node-expanded .x-tree-elbow-img {
    margin-right: 11px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:73 */
.x-tree-lines .x-grid-tree-node-expanded .x-tree-elbow-end-plus:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efc5";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:83 */
.x-tree-lines .x-tree-elbow-img {
    margin-right: 11px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:87 */
.x-tree-lines .x-tree-elbow-line:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efbe";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:95 */
.x-tree-lines .x-tree-elbow-end-plus:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efc6";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:101 */
.x-tree-lines .x-tree-elbow-end:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efbf";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:107 */
.x-tree-lines .x-tree-elbow:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efc0";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:120 */
.x-tree-no-lines .x-grid-tree-node-expanded .x-tree-elbow-img {
    margin-right: 11px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:124 */
.x-tree-no-lines .x-grid-tree-node-expanded .x-tree-elbow-plus:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efc3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:133 */
.x-tree-no-lines .x-tree-elbow-img {
    margin-right: 11px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:138 */
.x-tree-no-lines .x-tree-elbow-end-plus:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efc4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:146 */
.x-tree-no-lines .x-tree-elbow-plus:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efc4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:158 */
.x-tree-lines .x-tree-elbow-img {
    margin-right: 11px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:162 */
.x-tree-lines .x-tree-elbow-line:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efbe";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:169 */
.x-tree-lines .x-tree-elbow-end:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efbf";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/sitemule-theme/sass/var/tree/Panel.scss:175 */
.x-tree-lines .x-tree-elbow:before {
    font-family: Portfolio, FontAwesome, Extjs;
    font-size: 32px !important;
    content: "\efc0";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:1 */
@font-face {
    font-family: "Andale Mono";
    font-style: normal;
    font-weight: normal;
    src: url("/system/shared/ext-6.6.0/build/classic/icecap-theme/resources/font-andale/fonts/ANDALEMO.woff") format("woff");
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:8 */
@media print {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:9 */
    html,
    body {
        zoom: 80%;
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:12 */
    @page {
        size: A4 landscape;
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:18 */
.icecap-icon-excel {
    background-image: url(/system/images/icons/excel.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:21 */
.icecap-icon-krak {
    background-image: url(/system/images/icons/earth2.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:24 */
.icecap-icon-send {
    background-image: url(/system/images/icons/edit.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:27 */
.icecap-icon-create {
    background-image: url(/system/images/icons/add2.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:30 */
.icecap-icon-change {
    background-image: url(/system/images/icons/edit.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:33 */
.icecap-icon-copy {
    background-image: url(/system/images/icons/copy.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:36 */
.icecap-icon-hold {
    background-image: url(/system/images/icons/edit.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:39 */
.icecap-icon-delete {
    background-image: url(/system/images/icons/delete2.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:42 */
.icecap-icon-display {
    background-image: url(/system/images/icons/view.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:45 */
.icecap-icon-release {
    background-image: url(/system/images/icons/edit.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:48 */
.icecap-icon-messages {
    background-image: url(/system/images/icons/edit.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:51 */
.icecap-icon-attributes {
    background-image: url(/system/images/icons/edit.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:54 */
.icecap-icon-work-with-printing-status {
    background-image: url(/system/images/icons/edit.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:58 */
.icecap-icon-inputfield {
    background-image: url(/menu/images/input_field.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:61 */
.icecap-icon-outputfield {
    background-image: url(/menu/images/output_field.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:64 */
.icecap-icon-label {
    background-image: url(/menu/images/label.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:67 */
.icecap-icon-grid {
    background-image: url(/system/images/icons/16x16/table_sql.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:70 */
.icecap-icon-column {
    background-image: url(/system/images/icons/16x16/window_split_hor.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:73 */
.icecap-icon-panel {
    background-image: url(/system/images/icons/16x16/window.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:76 */
.icecap-icon-ignorearea {
    background-image: url(/system/images/icons/16x16/window_delete.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:80 */
.icecap-icon-page-next {
    background-image: url(/system/images/icons/16x16/arrow_right_blue.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:84 */
.icecap-icon-page-prev {
    background-image: url(/system/images/icons/16x16/arrow_left_blue.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:88 */
.icecap-form-link-trigger {
    background-image: url(/system/images/icons/earth-trigger.png);
    background-position: 0 center !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:93 */
.icecap-default {
    font-weight: bold !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:97 */
.icecap-statusbar {
    color: #858585;
    font-weight: 400 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:102 */
.icecap-statusbar-error {
    color: #d81818;
    font-weight: bold;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:107 */
.icecap-invalid {
    border: 1px solid #d81818;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:112 */
.iceCap-input-password .x-form-trigger-wrap-default {
    background-color: transparent !important;
    border: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:119 */
.iceCap-input-password input {
    caret-color: black !important;
    color: transparent !important;
    background-color: transparent !important;
    -webkit-text-security: disc;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:125 */
.iceCap-input-password::selection {
    color: transparent !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:130 */
.icecap-marker-vertical-default {
    margin: 0px;
    position: absolute;
    border-left: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:136 */
.icecap-marker-horizontal-default {
    margin: 0px;
    position: absolute;
    border-top: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:143 */
.x-icecap-cursor {
    border: 1px solid #00adee;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/default.scss:150 */
.x-icecap-selector {
    border: 1px solid #00adee;
    position: absolute !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/Component.scss:9 */
.x-icecap-selector {
    border: 1px solid #00adee;
    position: absolute !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-icecap-tab-new-small {
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    padding: 7px 7px 7px 7px;
    border-width: 0px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-icecap-tab-new-small-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-icecap-tab-new-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-icecap-tab-new-small-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-icecap-tab-new-small-tl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-icecap-tab-new-small-tr {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-icecap-tab-new-small-bl {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-icecap-tab-new-small-br {
    background-position: right 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-icecap-tab-new-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-icecap-tab-new-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-icecap-tab-new-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-icecap-tab-new-small-bc {
    background-position: 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-icecap-tab-new-small-tr,
.x-btn-icecap-tab-new-small-br,
.x-btn-icecap-tab-new-small-mr {
    padding-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-icecap-tab-new-small-tl,
.x-btn-icecap-tab-new-small-bl,
.x-btn-icecap-tab-new-small-ml {
    padding-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-icecap-tab-new-small-tc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-icecap-tab-new-small-bc {
    height: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-btn-icecap-tab-new-small-tl,
.x-btn-icecap-tab-new-small-bl,
.x-btn-icecap-tab-new-small-tr,
.x-btn-icecap-tab-new-small-br,
.x-btn-icecap-tab-new-small-tc,
.x-btn-icecap-tab-new-small-bc,
.x-btn-icecap-tab-new-small-ml,
.x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-btn-icecap-tab-new-small-ml,
.x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-icecap-tab-new-small-mc {
    padding: 7px 7px 7px 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-icecap-tab-new-small {
    border-color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-icecap-tab-new-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-icecap-tab-new-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-icecap-tab-new-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-icecap-tab-new-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-icecap-tab-new-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-icecap-tab-new-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-icecap-tab-new-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-icecap-tab-new-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-icecap-tab-new-small {
    font-size: 16px;
    height: 16px;
    color: #000;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-icecap-tab-new-small,
.x-btn-icon-right > .x-btn-icon-el-icecap-tab-new-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-icecap-tab-new-small,
.x-btn-icon-bottom > .x-btn-icon-el-icecap-tab-new-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-icecap-tab-new-small.x-btn-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-icecap-tab-new-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-icecap-tab-new-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-icecap-tab-new-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-icecap-tab-new-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-icecap-tab-new-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-icecap-tab-new-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-icecap-tab-new-small,
.x-btn-split-bottom > .x-btn-button-icecap-tab-new-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-icecap-tab-new-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-icecap-tab-new-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-icecap-tab-new-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-icecap-tab-new-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-icecap-tab-new-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-icecap-tab-new-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-icecap-tab-new-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-icecap-tab-new-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-icecap-tab-new-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-icecap-tab-new-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-icecap-tab-new-small {
    border-color: #00adee;
    background-image: none;
    background-color: white;
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-icecap-tab-new-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-icecap-tab-new-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-icecap-tab-new-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-icecap-tab-new-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fbfbfb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-icecap-tab-new-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-icecap-tab-new-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-icecap-tab-new-small,
.x-btn.x-btn-pressed.x-btn-icecap-tab-new-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fbfbfb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-icecap-tab-new-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-icecap-tab-new-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-icecap-tab-new-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-icecap-tab-new-small {
    -webkit-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    -moz-box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
    box-shadow: #33bdf1 0 1px 0px 0 inset, #33bdf1 0 -1px 0px 0 inset, #33bdf1 -1px 0 0px 0 inset, #33bdf1 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-icecap-tab-new-small {
    background-image: none;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-bc {
    background-image: url(images/btn/btn-icecap-tab-new-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-icecap-tab-new-small-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-icecap-tab-new-small-tl,
.x-btn-over .x-btn-icecap-tab-new-small-bl,
.x-btn-over .x-btn-icecap-tab-new-small-tr,
.x-btn-over .x-btn-icecap-tab-new-small-br,
.x-btn-over .x-btn-icecap-tab-new-small-tc,
.x-btn-over .x-btn-icecap-tab-new-small-bc {
    background-image: url(images/btn/btn-icecap-tab-new-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-icecap-tab-new-small-ml,
.x-btn-over .x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-icecap-tab-new-small-mc {
    background-color: #fbfbfb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-bc {
    background-image: url(images/btn/btn-icecap-tab-new-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-icecap-tab-new-small-mc {
    background-color: #fbfbfb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-tl,
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-bl,
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-tr,
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-br,
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-tc,
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-bc,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-tl,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-bl,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-tr,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-br,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-tc,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-bc {
    background-image: url(images/btn/btn-icecap-tab-new-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-ml,
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-mr,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-ml,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-icecap-tab-new-small-mc,
.x-btn.x-btn-pressed .x-btn-icecap-tab-new-small-mc {
    background-color: #fbfbfb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-bc {
    background-image: url(images/btn/btn-icecap-tab-new-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-icecap-tab-new-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-icecap-tab-new-small-mc {
    background-color: #fbfbfb;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-tl,
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-bl,
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-tr,
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-br,
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-tc,
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-bc {
    background-image: url(images/btn/btn-icecap-tab-new-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-ml,
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-mr {
    background-image: url(images/btn/btn-icecap-tab-new-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-icecap-tab-new-small-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-icecap-tab-new-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-icecap-tab-new-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small.x-segmented-button-first {
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small.x-segmented-button-first .x-btn-icecap-tab-new-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small.x-segmented-button-middle {
    border-right-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small.x-segmented-button-middle .x-btn-icecap-tab-new-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small.x-segmented-button-last .x-btn-icecap-tab-new-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small.x-segmented-button-first {
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small.x-segmented-button-first .x-btn-icecap-tab-new-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small.x-segmented-button-middle {
    border-bottom-width: 0px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small.x-segmented-button-middle .x-btn-icecap-tab-new-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small.x-segmented-button-last .x-btn-icecap-tab-new-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-icecap-tab-new-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small:after {
    top: 0px;
    right: 0;
    bottom: 0px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small.x-segmented-button-first:after {
    left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-icecap-tab-new-small.x-segmented-button-last:after {
    right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small:after {
    top: 0;
    right: 0px;
    bottom: 0;
    left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small.x-segmented-button-first:after {
    top: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-icecap-tab-new-small.x-segmented-button-last:after {
    bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-icecap-tab-new-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-icecap-tab-new-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-icecap-tab-new-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-icecap-tab-new-small:after {
    border-width: 1px;
    border-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-icecap-tab-new-small-cell > .x-grid-cell-inner {
    padding-top: 2px;
    padding-bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-icecap-tab-new-small-cell > .x-grid-cell-inner >.x-btn-icecap-tab-new-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:598 */
.x-toolbar-statusbar {
    padding: 6px 0 6px 8px;
    border-style: solid;
    border-color: #d0d0d0;
    border-width: 1px;
    background-image: none;
    background-color: white !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:614 */
.x-toolbar-statusbar .x-tool-img {
    color: #919191;
    background-color: white !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:629 */
.x-toolbar-statusbar .x-toolbar-item {
    margin: 0 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:639 */
.x-toolbar-statusbar .x-toolbar-separator-horizontal {
    margin: 0 8px 0 0;
    height: 14px;
    border-style: solid;
    border-width: 0 0 0 1px;
    border-left-color: #d0d0d0;
    border-right-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:648 */
.x-toolbar-statusbar .x-box-menu-after {
    margin: 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:653 */
.x-toolbar-statusbar-vertical {
    padding: 6px 8px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:662 */
.x-toolbar-statusbar-vertical .x-toolbar-item {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:671 */
.x-toolbar-statusbar-vertical .x-toolbar-separator-vertical {
    margin: 0 5px 6px;
    border-style: solid none;
    border-width: 1px 0 0;
    border-top-color: #d0d0d0;
    border-bottom-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:679 */
.x-toolbar-statusbar-vertical .x-box-menu-after {
    margin: 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:694 */
.x-toolbar-text-statusbar {
    padding: 0 4px;
    color: #34454c;
    font: 400 14px/16px Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:700 */
.x-toolbar-spacer-statusbar {
    width: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-toolbar-statusbar-scroller .x-box-scroller-body-horizontal {
    margin-left: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-toolbar-statusbar-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 26px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-toolbar-statusbar {
    cursor: pointer;
    color: #919191;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-left,
.x-box-scroller-toolbar-statusbar.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-left {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-left:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-right {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-right:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-top,
.x-box-scroller-toolbar-statusbar.x-box-scroller-bottom {
    height: 24px;
    width: 24px;
    left: 50%;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-top {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-bottom {
    margin-top: 4px;
    margin-right: 0;
    margin-bottom: 4px;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-toolbar-statusbar.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:742 */
.x-ie8 .x-box-scroller-toolbar-statusbar {
    background-color: white !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Toolbar.scss:748 */
.x-toolbar-more-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-toolbar-more-icon:before {
    content: "\f0c9";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/toolbar/Toolbar.scss:7 */
.x-toolbar-statusbar {
    border-top: 0px solid #ececec !important;
    padding: 0px 0px 6px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:799 */
.x-panel-icecap-keyarea {
    border-color: #d0d0d0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:802 */
.x-panel-icecap-keyarea.x-masked {
    border-color: #e8e8e8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:810 */
.x-panel-header-icecap-keyarea {
    font-size: 14px;
    border: 1px solid transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:836 */
.x-panel-header-icecap-keyarea .x-tool-tool-el {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:842 */
.x-panel-header-icecap-keyarea-horizontal {
    padding: 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:846 */
.x-panel-header-icecap-keyarea-horizontal .x-panel-header-icecap-keyarea-tab-bar {
    margin-top: -11px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:854 */
.x-panel-header-icecap-keyarea-horizontal.x-header-noborder {
    padding: 12px 16px 12px 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:858 */
.x-panel-header-icecap-keyarea-horizontal.x-header-noborder .x-panel-header-icecap-keyarea-tab-bar {
    margin-top: -12px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:866 */
.x-panel-header-icecap-keyarea-vertical {
    padding: 15px 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:870 */
.x-panel-header-icecap-keyarea-vertical .x-panel-header-icecap-keyarea-tab-bar {
    margin-right: -11px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:878 */
.x-panel-header-icecap-keyarea-vertical.x-header-noborder {
    padding: 16px 12px 16px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:882 */
.x-panel-header-icecap-keyarea-vertical.x-header-noborder .x-panel-header-icecap-keyarea-tab-bar {
    margin-right: -12px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:916 */
.x-panel-header-title-icecap-keyarea {
    color: #000;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:929 */
.x-keyboard-mode .x-panel-header-title-icecap-keyarea.x-title-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-title-icecap-keyarea.x-title-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-title-icecap-keyarea.x-title-focus,
.x-edge .x-keyboard-mode .x-panel-header-title-icecap-keyarea.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-title-icecap-keyarea.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-title-icecap-keyarea.x-title-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-title-icecap-keyarea.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:950 */
.x-panel-header-title-icecap-keyarea > .x-title-text-icecap-keyarea {
    text-transform: none;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:997 */
.x-panel-header-title-icecap-keyarea > .x-title-icon-wrap-icecap-keyarea.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1002 */
.x-panel-header-title-icecap-keyarea > .x-title-icon-wrap-icecap-keyarea.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1014 */
.x-panel-header-title-icecap-keyarea > .x-title-icon-wrap-icecap-keyarea.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1019 */
.x-panel-header-title-icecap-keyarea > .x-title-icon-wrap-icecap-keyarea.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1031 */
.x-panel-header-title-icecap-keyarea > .x-title-icon-wrap-icecap-keyarea > .x-title-icon-icecap-keyarea {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #000;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1051 */
.x-ie8 .x-panel-header-title-icecap-keyarea > .x-title-icon-wrap-icecap-keyarea > .x-title-icon-icecap-keyarea.x-title-glyph {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1062 */
.x-panel-body-icecap-keyarea {
    background: white;
    border-color: #d0d0d0;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1226 */
.x-panel-header-icecap-keyarea {
    background-image: none;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1230 */
.x-panel-header-icecap-keyarea-vertical {
    background-image: none;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1288 */
.x-panel .x-panel-header-icecap-keyarea-collapsed-border-top {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1292 */
.x-panel .x-panel-header-icecap-keyarea-collapsed-border-right {
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1296 */
.x-panel .x-panel-header-icecap-keyarea-collapsed-border-bottom {
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1300 */
.x-panel .x-panel-header-icecap-keyarea-collapsed-border-left {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1336 */
.x-panel-header-icecap-keyarea-horizontal .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1346 */
.x-panel-header-icecap-keyarea-horizontal .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1358 */
.x-panel-header-icecap-keyarea-vertical .x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1368 */
.x-panel-header-icecap-keyarea-vertical .x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1381 */
.x-keyboard-mode .x-panel-header-icecap-keyarea .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-icecap-keyarea .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-icecap-keyarea .x-tool-focus,
.x-edge .x-keyboard-mode .x-panel-header-icecap-keyarea .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-icecap-keyarea .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-icecap-keyarea .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-icecap-keyarea .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1429 */
.x-panel-icecap-keyarea-resizable .x-panel-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-panel-icecap-keyarea-outer-border-l {
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-panel-icecap-keyarea-outer-border-b {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-panel-icecap-keyarea-outer-border-bl {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-panel-icecap-keyarea-outer-border-r {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-panel-icecap-keyarea-outer-border-rl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-panel-icecap-keyarea-outer-border-rb {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-panel-icecap-keyarea-outer-border-rbl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-panel-icecap-keyarea-outer-border-t {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-panel-icecap-keyarea-outer-border-tl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-panel-icecap-keyarea-outer-border-tb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-panel-icecap-keyarea-outer-border-tbl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-panel-icecap-keyarea-outer-border-tr {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-panel-icecap-keyarea-outer-border-trl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-panel-icecap-keyarea-outer-border-trb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-panel-icecap-keyarea-outer-border-trbl {
    border-color: #d0d0d0 !important;
    border-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:9 */
.x-panel-icecap-keyarea {
    border-top: 0px solid #ececec !important;
    background-color: white !important;
    padding: 10px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:13 */
.x-panel-icecap-keyarea .x-btn {
    min-width: 80px;
    height: 30px;
    min-height: 30px;
    max-height: 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:19 */
.x-panel-icecap-keyarea .x-btn-default-small {
    background-color: white;
    border-color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:23 */
.x-panel-icecap-keyarea .x-btn-default-small.x-btn-over {
    border-color: #00adee !important;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:27 */
.x-panel-icecap-keyarea .x-btn-default-small.x-btn-over .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:40 */
.x-panel-icecap-keyarea .x-btn-focus.x-btn-pressed.x-btn-default-small {
    border-color: #00adee !important;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:44 */
.x-panel-icecap-keyarea .x-btn-focus.x-btn-pressed.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:55 */
.x-panel-icecap-keyarea .x-btn-focus.x-btn-over.x-btn-default-small {
    border-color: #00adee !important;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:59 */
.x-panel-icecap-keyarea .x-btn-focus.x-btn-over.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:68 */
.x-panel-icecap-keyarea .x-btn-focus.x-btn-default-small {
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:77 */
.x-panel-icecap-keyarea .x-btn-over.x-btn-default-small {
    border-color: #00adee !important;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:81 */
.x-panel-icecap-keyarea .x-btn-over.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:93 */
.x-panel-icecap-keyarea .x-btn.x-btn-pressed.x-btn-default-small {
    border-color: #00adee !important;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:97 */
.x-panel-icecap-keyarea .x-btn.x-btn-pressed.x-btn-default-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:107 */
.x-panel-icecap-keyarea .x-btn .x-btn-inner {
    font-weight: bold;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:110 */
.x-panel-icecap-keyarea .x-btn .x-btn-inner-primary-button-small {
    color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/packages/local/icecap-theme/sass/var/panel/Panel.scss:118 */
.x-panel-body-icecap-keyarea {
    background-color: white !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:545 */
.x-window-icecap-message {
    border-color: transparent;
    -webkit-border-radius: 0 0 0 0;
    -moz-border-radius: 0 0 0 0;
    -ms-border-radius: 0 0 0 0;
    -o-border-radius: 0 0 0 0;
    border-radius: 0 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-icecap-message {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 0 0 0 0;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-icecap-message-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-icecap-message {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-icecap-message-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-0px-0px-0px-0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-icecap-message-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-icecap-message-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-icecap-message-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-icecap-message-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-icecap-message-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-icecap-message-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-icecap-message-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-icecap-message-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-icecap-message-tr,
.x-window-icecap-message-br,
.x-window-icecap-message-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-icecap-message-tl,
.x-window-icecap-message-bl,
.x-window-icecap-message-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-icecap-message-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-icecap-message-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-icecap-message-tl,
.x-window-icecap-message-bl,
.x-window-icecap-message-tr,
.x-window-icecap-message-br,
.x-window-icecap-message-tc,
.x-window-icecap-message-bc,
.x-window-icecap-message-ml,
.x-window-icecap-message-mr {
    background-image: url(images/window/window-icecap-message-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-icecap-message-ml,
.x-window-icecap-message-mr {
    background-image: url(images/window/window-icecap-message-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-icecap-message-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:567 */
.x-window-body-icecap-message {
    border-color: #00adee;
    border-width: 1px;
    border-style: solid;
    background: white;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:581 */
.x-window-header-icecap-message {
    font-size: 14px;
    border-color: transparent;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:586 */
.x-window-header-icecap-message .x-tool-img {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:599 */
.x-window-header-icecap-message-horizontal .x-window-header-icecap-message-tab-bar {
    margin-top: -10px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:606 */
.x-window-header-icecap-message-vertical .x-window-header-icecap-message-tab-bar {
    margin-right: -10px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:622 */
.x-window-header-title-icecap-message {
    color: black;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:631 */
.x-window-header-title-icecap-message > .x-title-text-icecap-message {
    padding: 0;
    text-transform: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:678 */
.x-window-header-title-icecap-message > .x-title-icon-wrap-icecap-message.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:683 */
.x-window-header-title-icecap-message > .x-title-icon-wrap-icecap-message.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:695 */
.x-window-header-title-icecap-message > .x-title-icon-wrap-icecap-message.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:700 */
.x-window-header-title-icecap-message > .x-title-icon-wrap-icecap-message.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:712 */
.x-window-header-title-icecap-message > .x-title-icon-wrap-icecap-message > .x-title-icon-icecap-message {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #fff;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:732 */
.x-ie8 .x-window-header-title-icecap-message > .x-title-icon-wrap-icecap-message > .x-title-icon-icecap-message.x-title-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-top-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-top-tr,
.x-window-header-icecap-message-top-br,
.x-window-header-icecap-message-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-top-tl,
.x-window-header-icecap-message-top-bl,
.x-window-header-icecap-message-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-top-tl,
.x-window-header-icecap-message-top-bl,
.x-window-header-icecap-message-top-tr,
.x-window-header-icecap-message-top-br,
.x-window-header-icecap-message-top-tc,
.x-window-header-icecap-message-top-bc,
.x-window-header-icecap-message-top-ml,
.x-window-header-icecap-message-top-mr {
    background-image: url(images/window-header/window-header-icecap-message-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-top-ml,
.x-window-header-icecap-message-top-mr {
    background-image: url(images/window-header/window-header-icecap-message-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-right-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-right-tr,
.x-window-header-icecap-message-right-br,
.x-window-header-icecap-message-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-right-tl,
.x-window-header-icecap-message-right-bl,
.x-window-header-icecap-message-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-right-tl,
.x-window-header-icecap-message-right-bl,
.x-window-header-icecap-message-right-tr,
.x-window-header-icecap-message-right-br,
.x-window-header-icecap-message-right-tc,
.x-window-header-icecap-message-right-bc,
.x-window-header-icecap-message-right-ml,
.x-window-header-icecap-message-right-mr {
    background-image: url(images/window-header/window-header-icecap-message-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-right-ml,
.x-window-header-icecap-message-right-mr {
    background-image: url(images/window-header/window-header-icecap-message-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-bottom-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-bottom-tr,
.x-window-header-icecap-message-bottom-br,
.x-window-header-icecap-message-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-bottom-tl,
.x-window-header-icecap-message-bottom-bl,
.x-window-header-icecap-message-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-bottom-tl,
.x-window-header-icecap-message-bottom-bl,
.x-window-header-icecap-message-bottom-tr,
.x-window-header-icecap-message-bottom-br,
.x-window-header-icecap-message-bottom-tc,
.x-window-header-icecap-message-bottom-bc,
.x-window-header-icecap-message-bottom-ml,
.x-window-header-icecap-message-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-message-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-bottom-ml,
.x-window-header-icecap-message-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-message-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-left-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-left-tr,
.x-window-header-icecap-message-left-br,
.x-window-header-icecap-message-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-left-tl,
.x-window-header-icecap-message-left-bl,
.x-window-header-icecap-message-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-left-tl,
.x-window-header-icecap-message-left-bl,
.x-window-header-icecap-message-left-tr,
.x-window-header-icecap-message-left-br,
.x-window-header-icecap-message-left-tc,
.x-window-header-icecap-message-left-bc,
.x-window-header-icecap-message-left-ml,
.x-window-header-icecap-message-left-mr {
    background-image: url(images/window-header/window-header-icecap-message-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-left-ml,
.x-window-header-icecap-message-left-mr {
    background-image: url(images/window-header/window-header-icecap-message-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-collapsed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-collapsed-top-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-collapsed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-collapsed-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-collapsed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-collapsed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-collapsed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-collapsed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-collapsed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-collapsed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-collapsed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-collapsed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-collapsed-top-tr,
.x-window-header-icecap-message-collapsed-top-br,
.x-window-header-icecap-message-collapsed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-collapsed-top-tl,
.x-window-header-icecap-message-collapsed-top-bl,
.x-window-header-icecap-message-collapsed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-collapsed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-collapsed-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-collapsed-top-tl,
.x-window-header-icecap-message-collapsed-top-bl,
.x-window-header-icecap-message-collapsed-top-tr,
.x-window-header-icecap-message-collapsed-top-br,
.x-window-header-icecap-message-collapsed-top-tc,
.x-window-header-icecap-message-collapsed-top-bc,
.x-window-header-icecap-message-collapsed-top-ml,
.x-window-header-icecap-message-collapsed-top-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-collapsed-top-ml,
.x-window-header-icecap-message-collapsed-top-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-collapsed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-collapsed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-collapsed-right-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-collapsed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-collapsed-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-collapsed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-collapsed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-collapsed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-collapsed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-collapsed-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-collapsed-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-collapsed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-collapsed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-collapsed-right-tr,
.x-window-header-icecap-message-collapsed-right-br,
.x-window-header-icecap-message-collapsed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-collapsed-right-tl,
.x-window-header-icecap-message-collapsed-right-bl,
.x-window-header-icecap-message-collapsed-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-collapsed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-collapsed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-collapsed-right-tl,
.x-window-header-icecap-message-collapsed-right-bl,
.x-window-header-icecap-message-collapsed-right-tr,
.x-window-header-icecap-message-collapsed-right-br,
.x-window-header-icecap-message-collapsed-right-tc,
.x-window-header-icecap-message-collapsed-right-bc,
.x-window-header-icecap-message-collapsed-right-ml,
.x-window-header-icecap-message-collapsed-right-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-collapsed-right-ml,
.x-window-header-icecap-message-collapsed-right-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-collapsed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-collapsed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-collapsed-bottom-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-collapsed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-collapsed-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-collapsed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-collapsed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-collapsed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-collapsed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-collapsed-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-collapsed-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-collapsed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-collapsed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-collapsed-bottom-tr,
.x-window-header-icecap-message-collapsed-bottom-br,
.x-window-header-icecap-message-collapsed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-collapsed-bottom-tl,
.x-window-header-icecap-message-collapsed-bottom-bl,
.x-window-header-icecap-message-collapsed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-collapsed-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-collapsed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-collapsed-bottom-tl,
.x-window-header-icecap-message-collapsed-bottom-bl,
.x-window-header-icecap-message-collapsed-bottom-tr,
.x-window-header-icecap-message-collapsed-bottom-br,
.x-window-header-icecap-message-collapsed-bottom-tc,
.x-window-header-icecap-message-collapsed-bottom-bc,
.x-window-header-icecap-message-collapsed-bottom-ml,
.x-window-header-icecap-message-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-collapsed-bottom-ml,
.x-window-header-icecap-message-collapsed-bottom-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-collapsed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-message-collapsed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-message-collapsed-left-mc {
    background-color: white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-message-collapsed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-message-collapsed-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-message-collapsed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-message-collapsed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-message-collapsed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-message-collapsed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-message-collapsed-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-message-collapsed-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-message-collapsed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-message-collapsed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-message-collapsed-left-tr,
.x-window-header-icecap-message-collapsed-left-br,
.x-window-header-icecap-message-collapsed-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-message-collapsed-left-tl,
.x-window-header-icecap-message-collapsed-left-bl,
.x-window-header-icecap-message-collapsed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-message-collapsed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-message-collapsed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-message-collapsed-left-tl,
.x-window-header-icecap-message-collapsed-left-bl,
.x-window-header-icecap-message-collapsed-left-tr,
.x-window-header-icecap-message-collapsed-left-br,
.x-window-header-icecap-message-collapsed-left-tc,
.x-window-header-icecap-message-collapsed-left-bc,
.x-window-header-icecap-message-collapsed-left-ml,
.x-window-header-icecap-message-collapsed-left-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-message-collapsed-left-ml,
.x-window-header-icecap-message-collapsed-left-mr {
    background-image: url(images/window-header/window-header-icecap-message-collapsed-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-message-collapsed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:857 */
.x-window-header-icecap-message .x-window-header-icon {
    width: 16px;
    height: 16px;
    color: #fff;
    font-size: 16px;
    line-height: 16px;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:866 */
.x-window-header-icecap-message .x-window-header-glyph {
    color: #fff;
    font-size: 16px;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:883 */
.x-ie8 .x-window-header-icecap-message .x-window-header-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:892 */
.x-window-header-icecap-message-horizontal .x-tool-after-title {
    margin: 0 0 0 30px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:902 */
.x-window-header-icecap-message-horizontal .x-tool-before-title {
    margin: 0 30px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:914 */
.x-window-header-icecap-message-vertical .x-tool-after-title {
    margin: 30px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:924 */
.x-window-header-icecap-message-vertical .x-tool-before-title {
    margin: 0 0 30px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:937 */
.x-keyboard-mode .x-window-header-icecap-message .x-tool-focus {
    outline: 1px solid #fff;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-window-header-icecap-message .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-window-header-icecap-message .x-tool-focus,
.x-edge .x-keyboard-mode .x-window-header-icecap-message .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-window-header-icecap-message .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-window-header-icecap-message .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-window-header-icecap-message .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #fff;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:951 */
.x-window-header-icecap-message {
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:961 */
.x-nbr .x-window-icecap-message-collapsed .x-window-header {
    border-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-window-icecap-message-outer-border-l {
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-window-icecap-message-outer-border-b {
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-window-icecap-message-outer-border-bl {
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-window-icecap-message-outer-border-r {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-window-icecap-message-outer-border-rl {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-window-icecap-message-outer-border-rb {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-window-icecap-message-outer-border-rbl {
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-window-icecap-message-outer-border-t {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-window-icecap-message-outer-border-tl {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-window-icecap-message-outer-border-tb {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-window-icecap-message-outer-border-tbl {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-window-icecap-message-outer-border-tr {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-right-color: transparent !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-window-icecap-message-outer-border-trl {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-left-color: transparent !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-window-icecap-message-outer-border-trb {
    border-top-color: transparent !important;
    border-top-width: 2px !important;
    border-right-color: transparent !important;
    border-right-width: 2px !important;
    border-bottom-color: transparent !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-window-icecap-message-outer-border-trbl {
    border-color: transparent !important;
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:545 */
.x-window-icecap-window {
    border-color: #00adee;
    -webkit-border-radius: 0 0 0 0;
    -moz-border-radius: 0 0 0 0;
    -ms-border-radius: 0 0 0 0;
    -o-border-radius: 0 0 0 0;
    border-radius: 0 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-icecap-window {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 0 0 0 0;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-icecap-window-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-icecap-window {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-icecap-window-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-0px-0px-0px-0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-icecap-window-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-icecap-window-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-icecap-window-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-icecap-window-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-icecap-window-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-icecap-window-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-icecap-window-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-icecap-window-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-icecap-window-tr,
.x-window-icecap-window-br,
.x-window-icecap-window-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-icecap-window-tl,
.x-window-icecap-window-bl,
.x-window-icecap-window-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-icecap-window-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-icecap-window-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-icecap-window-tl,
.x-window-icecap-window-bl,
.x-window-icecap-window-tr,
.x-window-icecap-window-br,
.x-window-icecap-window-tc,
.x-window-icecap-window-bc,
.x-window-icecap-window-ml,
.x-window-icecap-window-mr {
    background-image: url(images/window/window-icecap-window-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-icecap-window-ml,
.x-window-icecap-window-mr {
    background-image: url(images/window/window-icecap-window-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-icecap-window-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:567 */
.x-window-body-icecap-window {
    border-color: #00adee;
    border-width: 1px;
    border-style: solid;
    background: #eee;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:581 */
.x-window-header-icecap-window {
    font-size: 14px;
    border-color: #00adee;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:586 */
.x-window-header-icecap-window .x-tool-img {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:599 */
.x-window-header-icecap-window-horizontal .x-window-header-icecap-window-tab-bar {
    margin-top: -10px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:606 */
.x-window-header-icecap-window-vertical .x-window-header-icecap-window-tab-bar {
    margin-right: -10px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:622 */
.x-window-header-title-icecap-window {
    color: white;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:631 */
.x-window-header-title-icecap-window > .x-title-text-icecap-window {
    padding: 0;
    text-transform: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:678 */
.x-window-header-title-icecap-window > .x-title-icon-wrap-icecap-window.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:683 */
.x-window-header-title-icecap-window > .x-title-icon-wrap-icecap-window.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:695 */
.x-window-header-title-icecap-window > .x-title-icon-wrap-icecap-window.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:700 */
.x-window-header-title-icecap-window > .x-title-icon-wrap-icecap-window.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:712 */
.x-window-header-title-icecap-window > .x-title-icon-wrap-icecap-window > .x-title-icon-icecap-window {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #fff;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/window/Window.scss:732 */
.x-ie8 .x-window-header-title-icecap-window > .x-title-icon-wrap-icecap-window > .x-title-icon-icecap-window.x-title-glyph {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-top-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-top-tr,
.x-window-header-icecap-window-top-br,
.x-window-header-icecap-window-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-top-tl,
.x-window-header-icecap-window-top-bl,
.x-window-header-icecap-window-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-top-tl,
.x-window-header-icecap-window-top-bl,
.x-window-header-icecap-window-top-tr,
.x-window-header-icecap-window-top-br,
.x-window-header-icecap-window-top-tc,
.x-window-header-icecap-window-top-bc,
.x-window-header-icecap-window-top-ml,
.x-window-header-icecap-window-top-mr {
    background-image: url(images/window-header/window-header-icecap-window-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-top-ml,
.x-window-header-icecap-window-top-mr {
    background-image: url(images/window-header/window-header-icecap-window-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-right-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-right-tr,
.x-window-header-icecap-window-right-br,
.x-window-header-icecap-window-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-window-header-icecap-window-right-tl,
.x-window-header-icecap-window-right-bl,
.x-window-header-icecap-window-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-window-header-icecap-window-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-window-header-icecap-window-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-window-header-icecap-window-right-tl,
.x-window-header-icecap-window-right-bl,
.x-window-header-icecap-window-right-tr,
.x-window-header-icecap-window-right-br,
.x-window-header-icecap-window-right-tc,
.x-window-header-icecap-window-right-bc,
.x-window-header-icecap-window-right-ml,
.x-window-header-icecap-window-right-mr {
    background-image: url(images/window-header/window-header-icecap-window-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-window-header-icecap-window-right-ml,
.x-window-header-icecap-window-right-mr {
    background-image: url(images/window-header/window-header-icecap-window-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-window-header-icecap-window-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-window-header-icecap-window-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 2px 2px;
    border-style: solid;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-window-header-icecap-window-bottom-mc {
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-window-header-icecap-window-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-window-header-icecap-window-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-window-header-icecap-window-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-window-header-icecap-window-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-window-header-icecap-window-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-window-header-icecap-window-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-window-header-icecap-window-bottom-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-window-header-icecap-window-bottom-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-window-header-icecap-window-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-window-header-icecap-window-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-window-header-icecap-window-bottom-tr,
.x-window-header-icecap-window-bottom-br,
.x-window-header-icecap-window-bottom-mr {
    padding-right: 2px;
}