/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:112 */
.x-row-editor-update-button {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:115 */
.x-row-editor-cancel-button {
    margin-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:120 */
.x-rtl.x-row-editor-update-button {
    margin-left: 3px;
    margin-right: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:124 */
.x-rtl.x-row-editor-cancel-button {
    margin-right: 2px;
    margin-left: auto;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:131 */
.x-grid-row-editor-errors .x-tip-body {
    padding: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:136 */
.x-grid-row-editor-errors-item {
    list-style: disc;
    margin-left: 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowEditing.scss:143 */
.x-rtl.x-grid-row-editor-errors .x-grid-row-editor-errors-item {
    margin-left: 0;
    margin-right: 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowExpander.scss:1 */
.x-grid-cell-inner-row-expander {
    padding: 9px 8px 8px 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowExpander.scss:16 */
.x-grid-row-expander {
    width: 16px;
    height: 16px;
    cursor: pointer;
    color: #919191;
    font: 14px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-row-expander:before {
    content: "\f146";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/plugin/RowExpander.scss:31 */
.x-grid-row-collapsed .x-grid-row-expander {
    font: 14px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-row-collapsed .x-grid-row-expander:before {
    content: "\f0fe";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:1 */
.x-ssm-row-numberer-hd {
    cursor: se-resize!important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:6 */
.x-ssm-row-numberer-cell {
    cursor: e-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:11 */
.x-ssm-column-select .x-column-header {
    cursor: s-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:16 */
.x-ssm-extender-drag-handle {
    height: 7px;
    width: 7px;
    background-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/grid/selection/SpreadsheetModel.scss:22 */
.x-ssm-extender-mask {
    border: 1px dotted #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:1 */
.x-accordion-layout-ct {
    background-color: #fff;
    padding: 5px 5px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:6 */
.x-accordion-hd .x-panel-header-title {
    color: #000;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    text-transform: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:13 */
.x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus,
.x-edge .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus:after,
.x-edge .x-keyboard-mode .x-accordion-hd .x-panel-header-title.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:34 */
.x-accordion-item {
    margin: 0 0 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:37 */
.x-accordion-item .x-accordion-hd {
    background: #ececec;
    border-width: 0;
    border-color: transparent;
    padding: 12px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:45 */
.x-accordion-item .x-accordion-hd-over {
    background-color: #f6f6f6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:48 */
.x-accordion-item .x-accordion-hd-over .x-tool-tool-el {
    background-color: #f6f6f6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:54 */
.x-accordion-item .x-accordion-hd-sibling-expanded {
    border-top-color: transparent;
    border-top-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:59 */
.x-accordion-item .x-accordion-hd-last-collapsed {
    border-bottom-color: #ececec;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:63 */
.x-accordion-item .x-accordion-body {
    border-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:72 */
.x-accordion-hd .x-tool-tool-el {
    background-color: #ececec;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:77 */
.x-accordion-hd .x-tool-img {
    background-image: url(images/tools/tool-sprites-dark.png);
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:87 */
.x-accordion-hd .x-tool-collapse-top,
.x-accordion-hd .x-tool-collapse-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-accordion-hd .x-tool-collapse-top:before,
.x-accordion-hd .x-tool-collapse-bottom:before {
    content: "\ecce";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:106 */
.x-accordion-hd .x-tool-expand-top,
.x-accordion-hd .x-tool-expand-bottom {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-accordion-hd .x-tool-expand-top:before,
.x-accordion-hd .x-tool-expand-bottom:before {
    content: "\edac";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Accordion.scss:126 */
.x-keyboard-mode .x-accordion-hd .x-tool-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-tool-focus,
.x-edge .x-keyboard-mode .x-accordion-hd .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-accordion-hd .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-accordion-hd .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-accordion-hd .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Border.scss:5 */
body.x-border-layout-ct,
div.x-border-layout-ct {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/layout/container/Form.scss:1 */
.x-form-layout-wrap {
    border-spacing: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:1 */
.x-resizable-handle {
    position: absolute;
    z-index: 100;
    font-size: 1px;
    line-height: 10px;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
    background-color: #ececec;
    color: #919191;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:20 */
.x-collapsed .x-resizable-handle {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:24 */
.x-resizable-handle-southeast {
    cursor: se-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:27 */
.x-resizable-handle-southeast:before {
    position: absolute;
    bottom: 0;
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:34 */
.x-resizable-handle-northwest {
    cursor: nw-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:37 */
.x-resizable-handle-northwest:before {
    position: absolute;
    top: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:44 */
.x-resizable-handle-northeast {
    cursor: ne-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:47 */
.x-resizable-handle-northeast:before {
    position: absolute;
    top: 0;
    right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:54 */
.x-resizable-handle-southwest {
    cursor: sw-resize;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:57 */
.x-resizable-handle-southwest:before {
    position: absolute;
    bottom: 0;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:68 */
.x-resizable-handle-east:before,
.x-resizable-handle-west:before {
    display: block;
    position: absolute;
    top: 50%;
    margin-top: -0.5em;
    width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:78 */
.x-resizable-handle-east {
    cursor: e-resize;
    width: 10px;
    right: 0;
    top: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:86 */
.x-resizable-handle-south {
    cursor: s-resize;
    height: 10px;
    left: 0;
    right: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:94 */
.x-resizable-handle-west {
    cursor: w-resize;
    width: 10px;
    left: 0;
    top: 0;
    bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:102 */
.x-resizable-handle-north {
    cursor: n-resize;
    height: 10px;
    left: 0;
    right: 0;
    top: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:110 */
.x-resizable-handle-southeast {
    width: 10px;
    height: 10px;
    right: 0;
    bottom: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:118 */
.x-resizable-handle-northwest {
    width: 10px;
    height: 10px;
    left: 0;
    top: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:126 */
.x-resizable-handle-northeast {
    width: 10px;
    height: 10px;
    right: 0;
    top: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:134 */
.x-resizable-handle-southwest {
    width: 10px;
    height: 10px;
    left: 0;
    bottom: 0;
    z-index: 101;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:145 */
.x-tablet .x-resizable-handle-north,
.x-tablet .x-resizable-handle-south {
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:149 */
.x-tablet .x-resizable-handle-east,
.x-tablet .x-resizable-handle-west {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:153 */
.x-tablet .x-resizable-handle-northwest,
.x-tablet .x-resizable-handle-northeast,
.x-tablet .x-resizable-handle-southwest,
.x-tablet .x-resizable-handle-southeast {
    width: 20px;
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:163 */
.x-window .x-window-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:167 */
.x-window-collapsed .x-window-handle {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:172 */
.x-resizable-proxy {
    border: 1px dashed #3b5a82;
    position: absolute;
    overflow: hidden;
    z-index: 50000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:180 */
.x-resizable-handle-over,
.x-resizable-pinned .x-resizable-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:186 */
.x-resizable-handle-east-over,
.x-resizable-handle-west-over,
.x-resizable-pinned > .x-resizable-handle-east,
.x-resizable-pinned > .x-resizable-handle-west {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-east-over:before,
.x-resizable-handle-west-over:before,
.x-resizable-pinned > .x-resizable-handle-east:before,
.x-resizable-pinned > .x-resizable-handle-west:before {
    content: "\f142";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:198 */
.x-resizable-handle-south-over,
.x-resizable-handle-north-over,
.x-resizable-pinned > .x-resizable-handle-south,
.x-resizable-pinned > .x-resizable-handle-north {
    font: 16px/10px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-south-over:before,
.x-resizable-handle-north-over:before,
.x-resizable-pinned > .x-resizable-handle-south:before,
.x-resizable-pinned > .x-resizable-handle-north:before {
    content: "\f141";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:210 */
.x-resizable-handle-southeast-over,
.x-resizable-pinned > .x-resizable-handle-southeast {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-southeast-over:before,
.x-resizable-pinned > .x-resizable-handle-southeast:before {
    content: "\e60c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:220 */
.x-resizable-handle-northwest-over,
.x-resizable-pinned > .x-resizable-handle-northwest {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-northwest-over:before,
.x-resizable-pinned > .x-resizable-handle-northwest:before {
    content: "\e609";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:230 */
.x-resizable-handle-northeast-over,
.x-resizable-pinned > .x-resizable-handle-northeast {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-northeast-over:before,
.x-resizable-pinned > .x-resizable-handle-northeast:before {
    content: "\e60a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/resizer/Resizer.scss:240 */
.x-resizable-handle-southwest-over,
.x-resizable-pinned > .x-resizable-handle-southwest {
    font: 16px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-resizable-handle-southwest-over:before,
.x-resizable-pinned > .x-resizable-handle-southwest:before {
    content: "\e60b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:2 */
.x-slider:before {
    border: 1px solid #d0d0d0;
    content: '';
    position: absolute;
    border-radius: 2px;
    background-color: #eee;
    box-sizing: border-box;
    -moz-box-sizing: border-box;
    -ms-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:20 */
.x-slider-thumb {
    background-color: #f6f6f6;
    border: 1px solid #d0d0d0;
    border-radius: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:28 */
.x-slider-thumb:before {
    color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:33 */
.x-slider-thumb-over {
    background-color: #fcfcfc;
    border-color: #c0ced3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:36 */
.x-slider-thumb-over:before {
    color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:42 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb {
    background-color: #f6f6f6;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:45 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb:before {
    color: #76cded;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:52 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb-over {
    background-color: #fcfcfc;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:57 */
.x-slider-thumb-drag {
    background-color: #f1f1f1;
    border-color: #b5c9d1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:60 */
.x-slider-thumb-drag:before {
    color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:66 */
.x-keyboard-mode .x-slider-focus .x-slider-thumb-drag {
    background-color: #f1f1f1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:79 */
.x-slider-horz {
    padding-left: 10px;
    background: no-repeat 0 -20px;
    margin: 10px 0 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:86 */
.x-slider-horz .x-slider-end {
    padding-right: 10px;
    background: no-repeat right -40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:91 */
.x-slider-horz .x-slider-inner {
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:96 */
.x-slider-horz:before {
    height: 10px;
    width: 100%;
    top: 50%;
    left: 0;
    margin-top: -5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:106 */
.x-slider-horz .x-slider-thumb {
    width: 20px;
    height: 20px;
    margin-left: -10px;
    font: 12px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-slider-horz .x-slider-thumb:before {
    content: "\e612";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:148 */
.x-rtl.x-slider-horz {
    padding-left: 0;
    padding-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:155 */
.x-rtl.x-slider-horz .x-slider-end {
    padding-right: 0;
    padding-left: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:163 */
.x-rtl.x-slider-horz .x-slider-thumb {
    margin-right: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:170 */
.x-slider-ct-vert {
    /* Vertical styles */
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:174 */
.x-slider-vert {
    padding-top: 10px;
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:181 */
.x-slider-vert > .x-slider-end {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:183 */
.x-slider-vert > .x-slider-end > .x-slider-inner {
    height: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:189 */
.x-slider-vert:before {
    width: 10px;
    height: 100%;
    left: 10px;
    top: 0;
    margin-left: -5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:199 */
.x-slider-vert .x-slider-end {
    padding-bottom: 10px;
    background: no-repeat -20px bottom;
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:205 */
.x-slider-vert .x-slider-inner {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:209 */
.x-slider-vert .x-slider-thumb {
    width: 20px;
    height: 20px;
    margin-bottom: -10px;
    font: 12px/1 ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-slider-vert .x-slider-thumb:before {
    content: "\e605";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/slider/Multi.scss:262 */
.x-slider-default-cell > .x-grid-cell-inner,
.x-sliderwidget-default-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-top {
    -webkit-border-radius: 0;
    -moz-border-radius: 0;
    -ms-border-radius: 0;
    -o-border-radius: 0;
    border-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-top-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-top-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-top-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-top-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-top-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-top-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-top-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-default-top-tr,
.x-tab-default-top-br,
.x-tab-default-top-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-default-top-tl,
.x-tab-default-top-bl,
.x-tab-default-top-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-default-top-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-default-top-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-default-top-tl,
.x-tab-default-top-bl,
.x-tab-default-top-tr,
.x-tab-default-top-br,
.x-tab-default-top-tc,
.x-tab-default-top-bc,
.x-tab-default-top-ml,
.x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-default-top-ml,
.x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-default-top-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 6px 15px 10px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-bottom-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-bottom-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-6-15-10-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-bottom-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-bottom-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-bottom-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-bottom-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-bottom-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-default-bottom-tr,
.x-tab-default-bottom-br,
.x-tab-default-bottom-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-default-bottom-tl,
.x-tab-default-bottom-bl,
.x-tab-default-bottom-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-default-bottom-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-default-bottom-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-default-bottom-tl,
.x-tab-default-bottom-bl,
.x-tab-default-bottom-tr,
.x-tab-default-bottom-br,
.x-tab-default-bottom-tc,
.x-tab-default-bottom-bc,
.x-tab-default-bottom-ml,
.x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-default-bottom-ml,
.x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-default-bottom-mc {
    padding: 6px 15px 10px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-left-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-left-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-left-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-left-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-left-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-left-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-left-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-left-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-left-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-default-left-tr,
.x-tab-default-left-br,
.x-tab-default-left-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-default-left-tl,
.x-tab-default-left-bl,
.x-tab-default-left-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-default-left-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-default-left-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-default-left-tl,
.x-tab-default-left-bl,
.x-tab-default-left-tr,
.x-tab-default-left-br,
.x-tab-default-left-tc,
.x-tab-default-left-bc,
.x-tab-default-left-ml,
.x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-default-left-ml,
.x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-default-left-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-tab-default-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 15px 6px 15px;
    border-width: 0 0 0 0;
    border-style: solid;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-tab-default-right-mc {
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-tab-default-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-tab-default-right-frameInfo {
    font-family: th-0-0-0-0-0-0-0-0-10-15-6-15;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-tab-default-right-tl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-tab-default-right-tr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-tab-default-right-bl {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-tab-default-right-br {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-tab-default-right-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-tab-default-right-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-tab-default-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-tab-default-right-bc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-tab-default-right-tr,
.x-tab-default-right-br,
.x-tab-default-right-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-tab-default-right-tl,
.x-tab-default-right-bl,
.x-tab-default-right-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-tab-default-right-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-tab-default-right-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-tab-default-right-tl,
.x-tab-default-right-bl,
.x-tab-default-right-tr,
.x-tab-default-right-br,
.x-tab-default-right-tc,
.x-tab-default-right-bc,
.x-tab-default-right-ml,
.x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-tab-default-right-ml,
.x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-tab-default-right-mc {
    padding: 10px 15px 6px 15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2672 */
.x-tab-default {
    border-color: #eee;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2731 */
.x-tab-default-top {
    margin: 0 4px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2735 */
.x-tab-default-top.x-rtl {
    margin: 0 0 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2740 */
.x-tab-default-top.x-tab-rotate-left {
    margin: 0 0 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2744 */
.x-tab-default-top.x-tab-rotate-left.x-rtl {
    margin: 0 4px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2763 */
.x-keyboard-mode .x-tab-default-top.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2794 */
.x-keyboard-mode .x-tab-default-top.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2825 */
.x-keyboard-mode .x-tab-default-top.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2852 */
.x-tab-default-right {
    margin: 0 0 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2856 */
.x-tab-default-right.x-rtl {
    margin: 0 0 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2861 */
.x-tab-default-right.x-tab-rotate-right {
    margin: 4px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2865 */
.x-tab-default-right.x-tab-rotate-right.x-rtl {
    margin: 4px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2884 */
.x-keyboard-mode .x-tab-default-right.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2915 */
.x-keyboard-mode .x-tab-default-right.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2946 */
.x-keyboard-mode .x-tab-default-right.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2973 */
.x-tab-default-bottom {
    margin: 0 4px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2977 */
.x-tab-default-bottom.x-rtl {
    margin: 0 0 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2982 */
.x-tab-default-bottom.x-tab-rotate-left {
    margin: 0 0 0 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:2986 */
.x-tab-default-bottom.x-tab-rotate-left.x-rtl {
    margin: 0 4px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3005 */
.x-keyboard-mode .x-tab-default-bottom.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3036 */
.x-keyboard-mode .x-tab-default-bottom.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3067 */
.x-keyboard-mode .x-tab-default-bottom.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3094 */
.x-tab-default-left {
    margin: 0 0 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3098 */
.x-tab-default-left.x-rtl {
    margin: 0 0 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3103 */
.x-tab-default-left.x-tab-rotate-right {
    margin: 4px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3107 */
.x-tab-default-left.x-tab-rotate-right.x-rtl {
    margin: 4px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3126 */
.x-keyboard-mode .x-tab-default-left.x-tab-focus {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3157 */
.x-keyboard-mode .x-tab-default-left.x-tab-focus.x-tab-over {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3188 */
.x-keyboard-mode .x-tab-default-left.x-tab-focus.x-tab-active {
    -webkit-box-shadow: none;
    -moz-box-shadow: none;
    box-shadow: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3215 */
.x-tab-button-default {
    height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3220 */
.x-tab-inner-default {
    font: 400 14px/24px Open Sans, sans-serif;
    color: #000;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3228 */
.x-tab-bar-plain .x-tab-inner-default {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3236 */
.x-tab-icon-right > .x-tab-inner-default,
.x-tab-icon-left > .x-tab-inner-default {
    max-width: calc(100% - 20px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3244 */
.x-tab-icon-el-default {
    min-height: 20px;
    background-position: center center;
    font-size: 20px;
    line-height: 20px;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3245 */
.x-tab-icon-left > .x-tab-icon-el-default,
.x-tab-icon-right > .x-tab-icon-el-default {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3250 */
.x-tab-icon-top > .x-tab-icon-el-default,
.x-tab-icon-bottom > .x-tab-icon-el-default {
    min-width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3261 */
.x-tab-bar-plain .x-tab-icon-el-default {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3266 */
.x-tab-icon-el-default.x-tab-glyph {
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3279 */
.x-ie8 .x-tab-icon-el-default.x-tab-glyph {
    color: #474747;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3286 */
.x-tab-text.x-tab-icon-left > .x-tab-icon-el-default {
    margin-right: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3290 */
.x-tab-text.x-tab-icon-left > .x-tab-icon-el-default.x-rtl {
    margin-right: 0;
    margin-left: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3297 */
.x-tab-text.x-tab-icon-right > .x-tab-icon-el-default {
    margin-left: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3301 */
.x-tab-text.x-tab-icon-right > .x-tab-icon-el-default.x-rtl {
    margin-left: 0;
    margin-right: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3308 */
.x-tab-text.x-tab-icon-top > .x-tab-icon-el-default {
    margin-bottom: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3312 */
.x-tab-text.x-tab-icon-bottom > .x-tab-icon-el-default {
    margin-top: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3318 */
.x-keyboard-mode .x-tab-focus.x-tab-default {
    border-color: #eee;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3398 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-default .x-tab-inner-default {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3404 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-default .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3454 */
.x-tab-over.x-tab-default {
    border-color: #000;
    background-image: none;
    background-color: rgba(0, 0, 0, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/background-opacity.scss:19 */
.x-ie8 .x-tab-over.x-tab-default {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#14000000, endColorstr=#14000000)";
    zoom: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3483 */
.x-ie8 .x-tab-over.x-tab-default.x-tab-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3489 */
.x-ie8 .x-tab-over.x-tab-default.x-tab-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3515 */
.x-tab-bar-plain .x-tab-over.x-tab-default .x-tab-inner-default {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3546 */
.x-tab-bar-plain .x-tab-over.x-tab-default .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3567 */
.x-keyboard-mode .x-tab-focus.x-tab-over.x-tab-default {
    border-color: #000;
    background-image: none;
    background-color: rgba(0, 0, 0, 0.08);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/background-opacity.scss:19 */
.x-ie8 .x-keyboard-mode .x-tab-focus.x-tab-over.x-tab-default {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#14000000, endColorstr=#14000000)";
    zoom: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3612 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-over.x-tab-default .x-tab-inner-default {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3618 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-focus.x-tab-over.x-tab-default .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3642 */
.x-keyboard-mode.x-ie8 .x-tab-focus.x-tab-over.x-tab-default.x-tab-rotate-left {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3646 */
.x-keyboard-mode.x-ie8 .x-tab-focus.x-tab-over.x-tab-default.x-tab-rotate-right {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3685 */
.x-tab.x-tab-active.x-tab-default {
    border-color: #eee;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3761 */
.x-tab.x-tab-active.x-tab-default .x-tab-icon-el {
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3769 */
.x-ie8 .x-tab.x-tab-active.x-tab-default .x-tab-icon-el {
    color: #474747;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3797 */
.x-keyboard-mode .x-tab-focus.x-tab-active.x-tab-default {
    border-color: #eee;
    background-color: #eee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3916 */
.x-tab.x-tab-disabled.x-tab-default {
    border-color: #eee;
    background-color: #eee;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3976 */
.x-tab.x-tab-disabled.x-tab-default .x-tab-inner-default {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:3981 */
.x-tab-bar-plain .x-tab.x-tab-disabled.x-tab-default .x-tab-inner-default {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4000 */
.x-tab.x-tab-disabled.x-tab-default .x-tab-icon-el-default {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4005 */
.x-tab.x-tab-disabled.x-tab-default .x-tab-icon-el {
    color: #000;
    opacity: 0.3;
    filter: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4020 */
.x-ie8 .x-tab.x-tab-disabled.x-tab-default .x-tab-icon-el {
    color: #a7a7a7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4026 */
.x-tab-bar-plain .x-tab.x-tab-disabled.x-tab-default .x-tab-icon-el {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4046 */
.x-nbr .x-tab-default {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-default-top-tl,
.x-tab-over .x-tab-default-top-bl,
.x-tab-over .x-tab-default-top-tr,
.x-tab-over .x-tab-default-top-br,
.x-tab-over .x-tab-default-top-tc,
.x-tab-over .x-tab-default-top-bc {
    background-image: url(images/tab/tab-default-top-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-default-top-ml,
.x-tab-over .x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-default-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-top-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-default-top-tl,
.x-tab-focus .x-tab-default-top-bl,
.x-tab-focus .x-tab-default-top-tr,
.x-tab-focus .x-tab-default-top-br,
.x-tab-focus .x-tab-default-top-tc,
.x-tab-focus .x-tab-default-top-bc {
    background-image: url(images/tab/tab-default-top-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-default-top-ml,
.x-tab-focus .x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-default-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-top-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-default-top-tl,
.x-tab-focus.x-tab-over .x-tab-default-top-bl,
.x-tab-focus.x-tab-over .x-tab-default-top-tr,
.x-tab-focus.x-tab-over .x-tab-default-top-br,
.x-tab-focus.x-tab-over .x-tab-default-top-tc,
.x-tab-focus.x-tab-over .x-tab-default-top-bc {
    background-image: url(images/tab/tab-default-top-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-default-top-ml,
.x-tab-focus.x-tab-over .x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-default-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-top-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-default-top-tl,
.x-tab.x-tab-active .x-tab-default-top-bl,
.x-tab.x-tab-active .x-tab-default-top-tr,
.x-tab.x-tab-active .x-tab-default-top-br,
.x-tab.x-tab-active .x-tab-default-top-tc,
.x-tab.x-tab-active .x-tab-default-top-bc {
    background-image: url(images/tab/tab-default-top-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-default-top-ml,
.x-tab.x-tab-active .x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-default-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-top-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-default-top-tl,
.x-tab-focus.x-tab-active .x-tab-default-top-bl,
.x-tab-focus.x-tab-active .x-tab-default-top-tr,
.x-tab-focus.x-tab-active .x-tab-default-top-br,
.x-tab-focus.x-tab-active .x-tab-default-top-tc,
.x-tab-focus.x-tab-active .x-tab-default-top-bc {
    background-image: url(images/tab/tab-default-top-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-default-top-ml,
.x-tab-focus.x-tab-active .x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-default-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-top-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-default-top-tl,
.x-tab.x-tab-disabled .x-tab-default-top-bl,
.x-tab.x-tab-disabled .x-tab-default-top-tr,
.x-tab.x-tab-disabled .x-tab-default-top-br,
.x-tab.x-tab-disabled .x-tab-default-top-tc,
.x-tab.x-tab-disabled .x-tab-default-top-bc {
    background-image: url(images/tab/tab-default-top-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-default-top-ml,
.x-tab.x-tab-disabled .x-tab-default-top-mr {
    background-image: url(images/tab/tab-default-top-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-default-top-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-top-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-default-right-tl,
.x-tab-over .x-tab-default-right-bl,
.x-tab-over .x-tab-default-right-tr,
.x-tab-over .x-tab-default-right-br,
.x-tab-over .x-tab-default-right-tc,
.x-tab-over .x-tab-default-right-bc {
    background-image: url(images/tab/tab-default-right-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-default-right-ml,
.x-tab-over .x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-default-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-right-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-default-right-tl,
.x-tab-focus .x-tab-default-right-bl,
.x-tab-focus .x-tab-default-right-tr,
.x-tab-focus .x-tab-default-right-br,
.x-tab-focus .x-tab-default-right-tc,
.x-tab-focus .x-tab-default-right-bc {
    background-image: url(images/tab/tab-default-right-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-default-right-ml,
.x-tab-focus .x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-default-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-right-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-default-right-tl,
.x-tab-focus.x-tab-over .x-tab-default-right-bl,
.x-tab-focus.x-tab-over .x-tab-default-right-tr,
.x-tab-focus.x-tab-over .x-tab-default-right-br,
.x-tab-focus.x-tab-over .x-tab-default-right-tc,
.x-tab-focus.x-tab-over .x-tab-default-right-bc {
    background-image: url(images/tab/tab-default-right-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-default-right-ml,
.x-tab-focus.x-tab-over .x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-default-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-right-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-default-right-tl,
.x-tab.x-tab-active .x-tab-default-right-bl,
.x-tab.x-tab-active .x-tab-default-right-tr,
.x-tab.x-tab-active .x-tab-default-right-br,
.x-tab.x-tab-active .x-tab-default-right-tc,
.x-tab.x-tab-active .x-tab-default-right-bc {
    background-image: url(images/tab/tab-default-right-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-default-right-ml,
.x-tab.x-tab-active .x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-default-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-right-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-default-right-tl,
.x-tab-focus.x-tab-active .x-tab-default-right-bl,
.x-tab-focus.x-tab-active .x-tab-default-right-tr,
.x-tab-focus.x-tab-active .x-tab-default-right-br,
.x-tab-focus.x-tab-active .x-tab-default-right-tc,
.x-tab-focus.x-tab-active .x-tab-default-right-bc {
    background-image: url(images/tab/tab-default-right-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-default-right-ml,
.x-tab-focus.x-tab-active .x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-default-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-right-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-default-right-tl,
.x-tab.x-tab-disabled .x-tab-default-right-bl,
.x-tab.x-tab-disabled .x-tab-default-right-tr,
.x-tab.x-tab-disabled .x-tab-default-right-br,
.x-tab.x-tab-disabled .x-tab-default-right-tc,
.x-tab.x-tab-disabled .x-tab-default-right-bc {
    background-image: url(images/tab/tab-default-right-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-default-right-ml,
.x-tab.x-tab-disabled .x-tab-default-right-mr {
    background-image: url(images/tab/tab-default-right-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-default-right-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-right-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-default-bottom-tl,
.x-tab-over .x-tab-default-bottom-bl,
.x-tab-over .x-tab-default-bottom-tr,
.x-tab-over .x-tab-default-bottom-br,
.x-tab-over .x-tab-default-bottom-tc,
.x-tab-over .x-tab-default-bottom-bc {
    background-image: url(images/tab/tab-default-bottom-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-default-bottom-ml,
.x-tab-over .x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-default-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-bottom-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-default-bottom-tl,
.x-tab-focus .x-tab-default-bottom-bl,
.x-tab-focus .x-tab-default-bottom-tr,
.x-tab-focus .x-tab-default-bottom-br,
.x-tab-focus .x-tab-default-bottom-tc,
.x-tab-focus .x-tab-default-bottom-bc {
    background-image: url(images/tab/tab-default-bottom-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-default-bottom-ml,
.x-tab-focus .x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-default-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-bottom-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-default-bottom-tl,
.x-tab-focus.x-tab-over .x-tab-default-bottom-bl,
.x-tab-focus.x-tab-over .x-tab-default-bottom-tr,
.x-tab-focus.x-tab-over .x-tab-default-bottom-br,
.x-tab-focus.x-tab-over .x-tab-default-bottom-tc,
.x-tab-focus.x-tab-over .x-tab-default-bottom-bc {
    background-image: url(images/tab/tab-default-bottom-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-default-bottom-ml,
.x-tab-focus.x-tab-over .x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-default-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-bottom-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-default-bottom-tl,
.x-tab.x-tab-active .x-tab-default-bottom-bl,
.x-tab.x-tab-active .x-tab-default-bottom-tr,
.x-tab.x-tab-active .x-tab-default-bottom-br,
.x-tab.x-tab-active .x-tab-default-bottom-tc,
.x-tab.x-tab-active .x-tab-default-bottom-bc {
    background-image: url(images/tab/tab-default-bottom-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-default-bottom-ml,
.x-tab.x-tab-active .x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-default-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-bottom-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-default-bottom-tl,
.x-tab-focus.x-tab-active .x-tab-default-bottom-bl,
.x-tab-focus.x-tab-active .x-tab-default-bottom-tr,
.x-tab-focus.x-tab-active .x-tab-default-bottom-br,
.x-tab-focus.x-tab-active .x-tab-default-bottom-tc,
.x-tab-focus.x-tab-active .x-tab-default-bottom-bc {
    background-image: url(images/tab/tab-default-bottom-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-default-bottom-ml,
.x-tab-focus.x-tab-active .x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-default-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-bottom-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-default-bottom-tl,
.x-tab.x-tab-disabled .x-tab-default-bottom-bl,
.x-tab.x-tab-disabled .x-tab-default-bottom-tr,
.x-tab.x-tab-disabled .x-tab-default-bottom-br,
.x-tab.x-tab-disabled .x-tab-default-bottom-tc,
.x-tab.x-tab-disabled .x-tab-default-bottom-bc {
    background-image: url(images/tab/tab-default-bottom-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-default-bottom-ml,
.x-tab.x-tab-disabled .x-tab-default-bottom-mr {
    background-image: url(images/tab/tab-default-bottom-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-default-bottom-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-bottom-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-over .x-tab-default-left-tl,
.x-tab-over .x-tab-default-left-bl,
.x-tab-over .x-tab-default-left-tr,
.x-tab-over .x-tab-default-left-br,
.x-tab-over .x-tab-default-left-tc,
.x-tab-over .x-tab-default-left-bc {
    background-image: url(images/tab/tab-default-left-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-over .x-tab-default-left-ml,
.x-tab-over .x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-over .x-tab-default-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-left-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus .x-tab-default-left-tl,
.x-tab-focus .x-tab-default-left-bl,
.x-tab-focus .x-tab-default-left-tr,
.x-tab-focus .x-tab-default-left-br,
.x-tab-focus .x-tab-default-left-tc,
.x-tab-focus .x-tab-default-left-bc {
    background-image: url(images/tab/tab-default-left-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus .x-tab-default-left-ml,
.x-tab-focus .x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus .x-tab-default-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-left-focus-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-over .x-tab-default-left-tl,
.x-tab-focus.x-tab-over .x-tab-default-left-bl,
.x-tab-focus.x-tab-over .x-tab-default-left-tr,
.x-tab-focus.x-tab-over .x-tab-default-left-br,
.x-tab-focus.x-tab-over .x-tab-default-left-tc,
.x-tab-focus.x-tab-over .x-tab-default-left-bc {
    background-image: url(images/tab/tab-default-left-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-over .x-tab-default-left-ml,
.x-tab-focus.x-tab-over .x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-over .x-tab-default-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-left-focus-over-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-active .x-tab-default-left-tl,
.x-tab.x-tab-active .x-tab-default-left-bl,
.x-tab.x-tab-active .x-tab-default-left-tr,
.x-tab.x-tab-active .x-tab-default-left-br,
.x-tab.x-tab-active .x-tab-default-left-tc,
.x-tab.x-tab-active .x-tab-default-left-bc {
    background-image: url(images/tab/tab-default-left-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-active .x-tab-default-left-ml,
.x-tab.x-tab-active .x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-active .x-tab-default-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-left-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab-focus.x-tab-active .x-tab-default-left-tl,
.x-tab-focus.x-tab-active .x-tab-default-left-bl,
.x-tab-focus.x-tab-active .x-tab-default-left-tr,
.x-tab-focus.x-tab-active .x-tab-default-left-br,
.x-tab-focus.x-tab-active .x-tab-default-left-tc,
.x-tab-focus.x-tab-active .x-tab-default-left-bc {
    background-image: url(images/tab/tab-default-left-focus-active-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab-focus.x-tab-active .x-tab-default-left-ml,
.x-tab-focus.x-tab-active .x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-focus-active-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab-focus.x-tab-active .x-tab-default-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-left-focus-active-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4065 */
.x-tab.x-tab-disabled .x-tab-default-left-tl,
.x-tab.x-tab-disabled .x-tab-default-left-bl,
.x-tab.x-tab-disabled .x-tab-default-left-tr,
.x-tab.x-tab-disabled .x-tab-default-left-br,
.x-tab.x-tab-disabled .x-tab-default-left-tc,
.x-tab.x-tab-disabled .x-tab-default-left-bc {
    background-image: url(images/tab/tab-default-left-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4074 */
.x-tab.x-tab-disabled .x-tab-default-left-ml,
.x-tab.x-tab-disabled .x-tab-default-left-mr {
    background-image: url(images/tab/tab-default-left-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4079 */
.x-tab.x-tab-disabled .x-tab-default-left-mc {
    background-repeat: repeat-x;
    background-image: url(images/tab/tab-default-left-disabled-fbg.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4089 */
.x-tab-default-tl,
.x-tab-default-bl,
.x-tab-default-tr,
.x-tab-default-br {
    -ms-filter: "progid:DXImageTransform.Microsoft.gradient(startColorstr=#00FFFFFF,endColorstr=#00FFFFFF)";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4099 */
.x-tab-default .x-tab-close-btn {
    top: 0;
    right: 0;
    width: 16px;
    height: 16px;
    font: 12px/1 Portfolio, FontAwesome, Extjs;
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tab-default .x-tab-close-btn:before {
    content: "\ed1d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4109 */
.x-tab-bar-plain .x-tab-default .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4121 */
.x-tab-default .x-tab-close-btn-over {
    background-position: -16px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4131 */
.x-tab-default .x-tab-close-btn-pressed {
    background-position: -32px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4139 */
.x-keyboard-mode .x-tab-default.x-tab-focus .x-tab-close-btn {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4145 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-default.x-tab-focus .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4156 */
.x-tab-default.x-tab-over .x-tab-close-btn {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4160 */
.x-tab-bar-plain .x-tab-default.x-tab-over .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4171 */
.x-keyboard-mode .x-tab-default.x-tab-focus.x-tab-over .x-tab-close-btn {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4177 */
.x-keyboard-mode .x-tab-bar-plain .x-tab-default.x-tab-focus.x-tab-over .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4188 */
.x-tab-default.x-tab-active .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4219 */
.x-keyboard-mode .x-tab-default.x-tab-focus.x-tab-active .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4235 */
.x-tab-default.x-tab-disabled .x-tab-close-btn {
    color: #fff;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=30)";
    opacity: 0.3;
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4240 */
.x-tab-bar-plain .x-tab-default.x-tab-disabled .x-tab-close-btn {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4256 */
.x-rtl.x-tab-default .x-tab-close-btn {
    right: auto;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4262 */
.x-tab-closable.x-tab-default .x-tab-button {
    padding-right: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Tab.scss:4267 */
.x-rtl.x-tab-closable.x-tab-default .x-tab-button {
    padding-right: 0px;
    padding-left: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:389 */
.x-tab-bar-default {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:428 */
.x-tab-bar-default-top > .x-tab-bar-body-default {
    padding: 8px 4px 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:432 */
.x-tab-bar-default-bottom > .x-tab-bar-body-default {
    padding: 0 4px 8px 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:436 */
.x-tab-bar-default-left > .x-tab-bar-body-default {
    padding: 4px 0 8px 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:441 */
.x-rtl.x-tab-bar-default-left > .x-tab-bar-body-default {
    padding: 4px 8px 8px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:446 */
.x-tab-bar-default-right > .x-tab-bar-body-default {
    padding: 8px 8px 4px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:451 */
.x-rtl.x-tab-bar-default-right > .x-tab-bar-body-default {
    padding: 8px 0 4px 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:459 */
.x-tab-bar-plain.x-tab-bar-default-top > .x-tab-bar-body-default {
    padding: 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:463 */
.x-tab-bar-plain.x-tab-bar-default-bottom > .x-tab-bar-body-default {
    padding: 0 0 8px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:467 */
.x-tab-bar-plain.x-tab-bar-default-left > .x-tab-bar-body-default {
    padding: 0 0 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:472 */
.x-rtl.x-tab-bar-plain.x-tab-bar-default-left > .x-tab-bar-body-default {
    padding: 0 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:477 */
.x-tab-bar-plain.x-tab-bar-default-right > .x-tab-bar-body-default {
    padding: 0 8px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:482 */
.x-rtl.x-tab-bar-plain.x-tab-bar-default-right > .x-tab-bar-body-default {
    padding: 0 0 0 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:490 */
.x-tab-bar-plain.x-tab-bar-default-horizontal {
    border-top-color: transparent;
    border-bottom-color: transparent;
    border-left-width: 0;
    border-right-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:497 */
.x-tab-bar-plain.x-tab-bar-default-vertical {
    border-right-color: transparent;
    border-left-color: transparent;
    border-top-width: 0;
    border-bottom-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:611 */
.x-tab-bar-horizontal > .x-tab-bar-body-default {
    min-height: 48px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:614 */
.x-ie8m .x-tab-bar-horizontal > .x-tab-bar-body-default {
    min-height: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:621 */
.x-tab-bar-vertical > .x-tab-bar-body-default {
    min-width: 48px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:624 */
.x-ie8m .x-tab-bar-vertical > .x-tab-bar-body-default {
    min-width: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-tab-bar-default-scroller .x-box-scroller-body-horizontal {
    margin-left: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:187 */
.x-tab-bar-default-scroller.x-rtl .x-box-scroller-body-horizontal {
    margin-left: 0;
    margin-right: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-tab-bar-default-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-tab-bar-default {
    cursor: pointer;
    color: #fff;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-tab-bar-default.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-tab-bar-default.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=70)";
    opacity: 0.7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-tab-bar-default.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-tab-bar-default.x-box-scroller-left,
.x-box-scroller-tab-bar-default.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-tab-bar-default.x-box-scroller-left {
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-default.x-box-scroller-left:before {
    content: "\f053";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-tab-bar-default.x-box-scroller-right {
    margin-left: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-default.x-box-scroller-right:before {
    content: "\f054";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:311 */
.x-box-scroller-tab-bar-default.x-box-scroller-top,
.x-box-scroller-tab-bar-default.x-box-scroller-bottom {
    height: 24px;
    width: 24px;
    left: 50%;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:338 */
.x-box-scroller-tab-bar-default.x-box-scroller-top {
    margin-top: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-default.x-box-scroller-top:before {
    content: "\f077";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:363 */
.x-box-scroller-tab-bar-default.x-box-scroller-bottom {
    margin-top: 0;
    margin-right: 0;
    margin-bottom: 0;
    font: 16px/24px Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-box-scroller-tab-bar-default.x-box-scroller-bottom:before {
    content: "\f078";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:704 */
.x-tab-bar-more-icon {
    font-family: Portfolio, FontAwesome, Extjs;
    line-height: 1;
    color: #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tab-bar-more-icon:before {
    content: "\efca";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:721 */
.x-tab-bar-plain.x-tab-bar-default-scroller .x-box-scroller-body-horizontal {
    margin-left: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:727 */
.x-tab-bar-plain.x-tab-bar-default-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:732 */
.x-tab-bar-plain .x-box-scroller-tab-bar-default {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:780 */
.x-tab-bar-default-top .x-box-scroller-tab-bar-default {
    margin-top: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:784 */
.x-tab-bar-default-right .x-box-scroller-tab-bar-default {
    margin-left: -16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:788 */
.x-tab-bar-default-bottom .x-box-scroller-tab-bar-default {
    margin-top: -16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:792 */
.x-tab-bar-default-left .x-box-scroller-tab-bar-default {
    margin-left: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:801 */
.x-box-scroller-tab-bar-default {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/tab/Bar.scss:807 */
.x-box-scroller-tab-bar-default .x-ie8 .x-box-scroller-plain {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:406 */
.x-breadcrumb-btn-default {
    margin: 0 0 0 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:410 */
.x-breadcrumb-icon-folder-default {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-breadcrumb-icon-folder-default:before {
    content: "\f114";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:418 */
.x-btn-menu-active .x-breadcrumb-icon-folder-default {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-btn-menu-active .x-breadcrumb-icon-folder-default:before {
    content: "\f115";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:428 */
.x-breadcrumb-icon-leaf-default {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-breadcrumb-icon-leaf-default:before {
    content: "\f016";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:438 */
.x-breadcrumb-btn .x-btn-wrap-plain-toolbar-small.x-btn-arrow:after {
    width: 20px;
    background-image: url(images/breadcrumb/default-arrow.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:444 */
.x-rtl.x-breadcrumb-btn .x-btn-wrap-plain-toolbar-small.x-btn-arrow:after {
    background-image: url(images/breadcrumb/default-arrow-rtl.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:450 */
.x-btn-menu-active.x-breadcrumb-btn .x-btn-wrap-plain-toolbar-small.x-btn-arrow:after {
    background-image: url(images/breadcrumb/default-arrow-open.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:455 */
.x-rtl.x-btn-menu-active.x-breadcrumb-btn .x-btn-wrap-plain-toolbar-small.x-btn-arrow:after {
    background-image: url(images/breadcrumb/default-arrow-open-rtl.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:463 */
.x-breadcrumb-btn .x-btn-wrap-plain-toolbar-small.x-btn-split:after {
    width: 20px;
    content: "\f105";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:477 */
.x-rtl.x-breadcrumb-btn .x-btn-wrap-plain-toolbar-small.x-btn-split:after {
    content: "\f104";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/toolbar/Breadcrumb.scss:500 */
.x-btn-menu-active.x-breadcrumb-btn .x-btn-wrap-plain-toolbar-small.x-btn-split:after {
    content: "\f107";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #919191;
    background: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:182 */
.x-breadcrumb-default-scroller .x-box-scroller-body-horizontal {
    margin-left: 32px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:187 */
.x-breadcrumb-default-scroller.x-rtl .x-box-scroller-body-horizontal {
    margin-left: 0;
    margin-right: 32px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:195 */
.x-breadcrumb-default-vertical-scroller .x-box-scroller-body-vertical {
    margin-top: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:200 */
.x-box-scroller-breadcrumb-default {
    cursor: pointer;
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=60)";
    opacity: 0.6;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:210 */
.x-box-scroller-breadcrumb-default.x-box-scroller-hover {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=80)";
    opacity: 0.8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:216 */
.x-box-scroller-breadcrumb-default.x-box-scroller-pressed {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=100)";
    opacity: 1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:222 */
.x-box-scroller-breadcrumb-default.x-box-scroller-disabled {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=25)";
    opacity: 0.25;
    cursor: default;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:232 */
.x-box-scroller-breadcrumb-default.x-box-scroller-left,
.x-box-scroller-breadcrumb-default.x-box-scroller-right {
    width: 24px;
    height: 24px;
    top: 50%;
    margin-top: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:259 */
.x-box-scroller-breadcrumb-default.x-box-scroller-left {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    background-image: url(images/breadcrumb/default-scroll-left.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/layout/container/Box.scss:284 */
.x-box-scroller-breadcrumb-default.x-box-scroller-right {
    margin-left: 4px;
    margin-right: 4px;
    margin-bottom: 0;
    background-image: url(images/breadcrumb/default-scroll-right.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:1 */
.x-tree-expander {
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:8 */
.x-tree-arrows .x-tree-expander {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-arrows .x-tree-expander:before {
    content: "\ed21";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:13 */
.x-tree-arrows .x-tree-expander.x-rtl {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-arrows .x-tree-expander.x-rtl:before {
    content: "\f0d9";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:18 */
.x-tree-arrows .x-grid-tree-node-expanded .x-tree-expander {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-arrows .x-grid-tree-node-expanded .x-tree-expander:before {
    content: "\ed1b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:61 */
.x-tree-elbow-plus,
.x-tree-elbow-end-plus {
    font-size: 32px;
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-elbow-plus:before,
.x-tree-elbow-end-plus:before {
    content: "\efc2";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:69 */
.x-grid-tree-node-expanded .x-tree-elbow-plus,
.x-grid-tree-node-expanded .x-tree-elbow-end-plus {
    font-size: 32px;
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-grid-tree-node-expanded .x-tree-elbow-plus:before,
.x-grid-tree-node-expanded .x-tree-elbow-end-plus:before {
    content: "\efc1";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:157 */
.x-tree-icon {
    width: 16px;
    height: 33px;
    line-height: 33px;
    color: #000;
    font-size: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:165 */
.x-tree-elbow-img {
    width: 18px;
    height: 33px;
    line-height: 33px;
    margin-right: 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:173 */
.x-rtl.x-tree-elbow-img {
    margin-right: 0;
    margin-left: 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:179 */
.x-tree-icon,
.x-tree-elbow-img,
.x-tree-checkbox {
    margin-top: -7px;
    margin-bottom: -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:189 */
.x-tree-icon-leaf {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-icon-leaf:before {
    content: "\eab6";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:204 */
.x-tree-icon-parent {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-icon-parent:before {
    content: "\eb42";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:220 */
.x-tree-icon-parent-expanded {
    font-size: 16px;
    font-family: Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-icon-parent-expanded:before {
    content: "\eb4a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:236 */
.x-tree-icon-custom {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:240 */
.x-tree-icon-custom:before {
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:246 */
.x-tree-icon-custom.x-rtl {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:252 */
.x-tree-checkbox {
    margin-right: 6px;
    top: 8px;
    width: 18px;
    height: 18px;
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-checkbox:before {
    content: "\ea14";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:266 */
.x-rtl.x-tree-checkbox {
    margin-right: 0;
    margin-left: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:272 */
.x-tree-checkbox-checked {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-checkbox-checked:before {
    content: "\ea16";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:280 */
.x-grid-tree-loading .x-tree-icon {
    background-image: url(images/tree/loading.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:285 */
.x-grid-tree-loading .x-rtl.x-tree-icon {
    background-image: url(images/tree/loading.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:290 */
.x-tree-node-text {
    padding-left: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:295 */
.x-rtl.x-tree-node-text {
    padding-left: 0;
    padding-right: 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/View.scss:302 */
.x-grid-cell-inner-treecolumn {
    padding: 7px 10px 6px 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/ViewDropZone.scss:2 */
.x-tree-drop-ok-append .x-dd-drop-icon,
.x-tree-drop-ok-above .x-dd-drop-icon,
.x-tree-drop-ok-below .x-dd-drop-icon,
.x-tree-drop-ok-between .x-dd-drop-icon {
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #a4cf6d;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/etc/mixins/font-icon.scss:132 */
.x-tree-drop-ok-append .x-dd-drop-icon:before,
.x-tree-drop-ok-above .x-dd-drop-icon:before,
.x-tree-drop-ok-below .x-dd-drop-icon:before,
.x-tree-drop-ok-between .x-dd-drop-icon:before {
    content: "\f055";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/tree/ViewDropZone.scss:26 */
.x-tree-ddindicator {
    height: 1px;
    border-width: 1px 0px 0px;
    border-style: dotted;
    border-color: green;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/MultiSelector.scss:1 */
.x-multiselector-remove {
    font-size: 110%;
    color: #d0d0d0;
    cursor: pointer;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/MultiSelector.scss:6 */
.x-multiselector-remove .x-grid-cell-inner {
    padding: 7px 4px 6px 4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/MultiSelector.scss:11 */
.x-grid-item-over .x-multiselector-remove {
    color: red;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/view/MultiSelector.scss:16 */
.x-multiselector-search-input .x-form-text::-ms-clear {
    display: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Toast.scss:1 */
.x-toast-icon-information {
    background-image: url(images/window/toast/icon16_info.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Toast.scss:5 */
.x-toast-icon-error {
    background-image: url(images/window/toast/icon16_error.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Toast.scss:11 */
.x-toast-window .x-window-body {
    /* Using standard theme */
    padding: 15px 5px 15px 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Toast.scss:17 */
.x-toast-light .x-window-header {
    /* Custom styling */
    background-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Toast.scss:21 */
.x-toast-light .x-tool-img {
    background-color: #33bdf1;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Toast.scss:25 */
.x-toast-light {
    background-image: url(images/window/toast/fader.png);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/src/window/Toast.scss:29 */
.x-toast-light .x-window-body {
    padding: 15px 5px 20px 5px;
    background-color: transparent;
    border: 0px solid white;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-plain-toolbar-small {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 7px 7px 7px 7px;
    border-width: 1px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-plain-toolbar-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-plain-toolbar-small {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-plain-toolbar-small-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-7-7-7-7;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-plain-toolbar-small-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-plain-toolbar-small-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-plain-toolbar-small-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-plain-toolbar-small-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-plain-toolbar-small-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-plain-toolbar-small-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-plain-toolbar-small-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-plain-toolbar-small-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-plain-toolbar-small-tr,
.x-btn-plain-toolbar-small-br,
.x-btn-plain-toolbar-small-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-plain-toolbar-small-tl,
.x-btn-plain-toolbar-small-bl,
.x-btn-plain-toolbar-small-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-plain-toolbar-small-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-plain-toolbar-small-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-plain-toolbar-small-mc {
    padding: 5px 5px 5px 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-plain-toolbar-small {
    border-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-plain-toolbar-small {
    min-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-plain-toolbar-small {
    min-height: auto;
    height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-plain-toolbar-small {
    font: 400 14px/16px Open Sans, sans-serif;
    color: #000;
    padding: 0 5px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-plain-toolbar-small,
.x-ie9 .x-btn-icon-left > .x-btn-inner-plain-toolbar-small {
    max-width: calc(100% - 16px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-plain-toolbar-small,
.x-safari8m .x-btn-icon-left > .x-btn-inner-plain-toolbar-small {
    max-width: calc(100% - 15px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-plain-toolbar-small {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-plain-toolbar-small {
    font-size: 16px;
    height: 16px;
    color: #919191;
    line-height: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-small,
.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-small {
    width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-plain-toolbar-small,
.x-btn-icon-bottom > .x-btn-icon-el-plain-toolbar-small {
    min-width: 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-plain-toolbar-small.x-btn-glyph {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-small {
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2565 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-small.x-rtl {
    margin-right: 0;
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-small {
    margin-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2576 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-small.x-rtl {
    margin-left: 0;
    margin-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-plain-toolbar-small {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-plain-toolbar-small {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-plain-toolbar-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-plain-toolbar-small,
.x-btn-split-bottom > .x-btn-button-plain-toolbar-small {
    padding-bottom: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-plain-toolbar-small.x-btn-arrow-right:after {
    width: 18px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-plain-toolbar-small.x-btn-arrow-bottom:after {
    height: 12px;
    content: "\ed1b";
    font: 16px/12px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-plain-toolbar-small.x-btn-split-right > .x-btn-button {
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2666 */
.x-btn-wrap-plain-toolbar-small.x-btn-split-right > .x-btn-button.x-rtl {
    padding-right: 0;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-plain-toolbar-small.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-plain-toolbar-small.x-btn-split-right:after {
    width: 20px;
    content: "\ed1b";
    font: 16px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2692 */
.x-btn-wrap-plain-toolbar-small.x-rtl.x-btn-split-right:after {
    padding-left: 0;
    padding-right: 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-plain-toolbar-small.x-btn-split-bottom {
    margin-bottom: -7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-plain-toolbar-small.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-plain-toolbar-small.x-btn-split-bottom:after {
    height: 20px;
    content: "\ed1b";
    font: 16px/20px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-plain-toolbar-small {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-small {
    margin-right: 5px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-plain-toolbar-small {
    background-image: none;
    background-color: transparent;
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-plain-toolbar-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-plain-toolbar-small .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 27px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2802 */
.x-btn-plain-toolbar-small .x-btn-arrow-el.x-rtl {
    right: inherit;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-plain-toolbar-small.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-plain-toolbar-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-plain-toolbar-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-plain-toolbar-small {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-plain-toolbar-small,
.x-btn.x-btn-pressed.x-btn-plain-toolbar-small {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-plain-toolbar-small .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-plain-toolbar-small .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-plain-toolbar-small,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-plain-toolbar-small {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-plain-toolbar-small {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-br,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-bc {
    background-image: url(images/btn/btn-plain-toolbar-small-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-mr {
    background-image: url(images/btn/btn-plain-toolbar-small-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-plain-toolbar-small-tl,
.x-btn-over .x-btn-plain-toolbar-small-bl,
.x-btn-over .x-btn-plain-toolbar-small-tr,
.x-btn-over .x-btn-plain-toolbar-small-br,
.x-btn-over .x-btn-plain-toolbar-small-tc,
.x-btn-over .x-btn-plain-toolbar-small-bc {
    background-image: url(images/btn/btn-plain-toolbar-small-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-plain-toolbar-small-ml,
.x-btn-over .x-btn-plain-toolbar-small-mr {
    background-image: url(images/btn/btn-plain-toolbar-small-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-plain-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-bc {
    background-image: url(images/btn/btn-plain-toolbar-small-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-mr {
    background-image: url(images/btn/btn-plain-toolbar-small-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-tl,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-bl,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-tr,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-br,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-tc,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-bc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-tl,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-bl,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-tr,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-br,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-tc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-bc {
    background-image: url(images/btn/btn-plain-toolbar-small-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-ml,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-mr,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-ml,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-mr {
    background-image: url(images/btn/btn-plain-toolbar-small-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-small-mc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-bc {
    background-image: url(images/btn/btn-plain-toolbar-small-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-mr {
    background-image: url(images/btn/btn-plain-toolbar-small-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-small-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-small-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-tl,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-bl,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-tr,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-br,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-tc,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-bc {
    background-image: url(images/btn/btn-plain-toolbar-small-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-ml,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-mr {
    background-image: url(images/btn/btn-plain-toolbar-small-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-small-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-plain-toolbar-small {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-plain-toolbar-small {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small.x-segmented-button-first .x-btn-plain-toolbar-small-mc {
    padding-right: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small.x-segmented-button-middle .x-btn-plain-toolbar-small-mc {
    padding-right: 7px !important;
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small.x-segmented-button-last .x-btn-plain-toolbar-small-mc {
    padding-left: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small.x-segmented-button-first .x-btn-plain-toolbar-small-mc {
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small.x-segmented-button-middle .x-btn-plain-toolbar-small-mc {
    padding-top: 7px !important;
    padding-bottom: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small.x-segmented-button-last .x-btn-plain-toolbar-small-mc {
    padding-top: 7px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-plain-toolbar-small:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-small.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-small.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-plain-toolbar-small:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-plain-toolbar-small:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-plain-toolbar-small:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-plain-toolbar-small:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-plain-toolbar-small-cell > .x-grid-cell-inner {
    padding-top: 1px;
    padding-bottom: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-plain-toolbar-small-cell > .x-grid-cell-inner >.x-btn-plain-toolbar-small {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-plain-toolbar-medium {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 8px 8px 8px 8px;
    border-width: 1px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-plain-toolbar-medium-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-plain-toolbar-medium {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-plain-toolbar-medium-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-8-8-8-8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-plain-toolbar-medium-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-plain-toolbar-medium-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-plain-toolbar-medium-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-plain-toolbar-medium-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-plain-toolbar-medium-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-plain-toolbar-medium-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-plain-toolbar-medium-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-plain-toolbar-medium-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-plain-toolbar-medium-tr,
.x-btn-plain-toolbar-medium-br,
.x-btn-plain-toolbar-medium-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-plain-toolbar-medium-tl,
.x-btn-plain-toolbar-medium-bl,
.x-btn-plain-toolbar-medium-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-plain-toolbar-medium-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-plain-toolbar-medium-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-plain-toolbar-medium-mc {
    padding: 6px 6px 6px 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-plain-toolbar-medium {
    border-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-plain-toolbar-medium {
    min-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-plain-toolbar-medium {
    min-height: auto;
    height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-plain-toolbar-medium {
    font: 400 14px/18px Open Sans, sans-serif;
    color: #000;
    padding: 0 8px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-plain-toolbar-medium,
.x-ie9 .x-btn-icon-left > .x-btn-inner-plain-toolbar-medium {
    max-width: calc(100% - 20px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-plain-toolbar-medium,
.x-safari8m .x-btn-icon-left > .x-btn-inner-plain-toolbar-medium {
    max-width: calc(100% - 19px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-plain-toolbar-medium {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-plain-toolbar-medium {
    font-size: 20px;
    height: 20px;
    color: #919191;
    line-height: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-medium,
.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-medium {
    width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-plain-toolbar-medium,
.x-btn-icon-bottom > .x-btn-icon-el-plain-toolbar-medium {
    min-width: 20px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-plain-toolbar-medium.x-btn-glyph {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-medium {
    margin-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2565 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-medium.x-rtl {
    margin-right: 0;
    margin-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-medium {
    margin-left: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2576 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-medium.x-rtl {
    margin-left: 0;
    margin-right: 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-plain-toolbar-medium {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-plain-toolbar-medium {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-plain-toolbar-medium {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-medium {
    margin-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-plain-toolbar-medium,
.x-btn-split-bottom > .x-btn-button-plain-toolbar-medium {
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-plain-toolbar-medium.x-btn-arrow-right:after {
    width: 20px;
    content: "\f0d7";
    font: 20px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-plain-toolbar-medium.x-btn-arrow-bottom:after {
    height: 14px;
    content: "\f0d7";
    font: 20px/14px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-plain-toolbar-medium.x-btn-split-right > .x-btn-button {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2666 */
.x-btn-wrap-plain-toolbar-medium.x-btn-split-right > .x-btn-button.x-rtl {
    padding-right: 0;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-plain-toolbar-medium.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-plain-toolbar-medium.x-btn-split-right:after {
    width: 26px;
    content: "\f0d7";
    font: 20px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2692 */
.x-btn-wrap-plain-toolbar-medium.x-rtl.x-btn-split-right:after {
    padding-left: 0;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-plain-toolbar-medium.x-btn-split-bottom {
    margin-bottom: -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-plain-toolbar-medium.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-plain-toolbar-medium.x-btn-split-bottom:after {
    height: 24px;
    content: "\f0d7";
    font: 20px/24px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-plain-toolbar-medium {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-medium {
    margin-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-plain-toolbar-medium {
    background-image: none;
    background-color: transparent;
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-plain-toolbar-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-plain-toolbar-medium .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 34px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2802 */
.x-btn-plain-toolbar-medium .x-btn-arrow-el.x-rtl {
    right: inherit;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-plain-toolbar-medium.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-plain-toolbar-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-plain-toolbar-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-plain-toolbar-medium {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-plain-toolbar-medium,
.x-btn.x-btn-pressed.x-btn-plain-toolbar-medium {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-plain-toolbar-medium .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-plain-toolbar-medium .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-plain-toolbar-medium,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-plain-toolbar-medium {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-plain-toolbar-medium {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-bc {
    background-image: url(images/btn/btn-plain-toolbar-medium-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-mr {
    background-image: url(images/btn/btn-plain-toolbar-medium-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-medium-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-plain-toolbar-medium-tl,
.x-btn-over .x-btn-plain-toolbar-medium-bl,
.x-btn-over .x-btn-plain-toolbar-medium-tr,
.x-btn-over .x-btn-plain-toolbar-medium-br,
.x-btn-over .x-btn-plain-toolbar-medium-tc,
.x-btn-over .x-btn-plain-toolbar-medium-bc {
    background-image: url(images/btn/btn-plain-toolbar-medium-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-plain-toolbar-medium-ml,
.x-btn-over .x-btn-plain-toolbar-medium-mr {
    background-image: url(images/btn/btn-plain-toolbar-medium-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-plain-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-bc {
    background-image: url(images/btn/btn-plain-toolbar-medium-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-mr {
    background-image: url(images/btn/btn-plain-toolbar-medium-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-tl,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-bl,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-tr,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-br,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-tc,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-bc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-tl,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-bl,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-tr,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-br,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-tc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-bc {
    background-image: url(images/btn/btn-plain-toolbar-medium-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-ml,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-mr,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-ml,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-mr {
    background-image: url(images/btn/btn-plain-toolbar-medium-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-medium-mc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-bc {
    background-image: url(images/btn/btn-plain-toolbar-medium-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-mr {
    background-image: url(images/btn/btn-plain-toolbar-medium-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-medium-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-medium-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-tl,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-bl,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-tr,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-br,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-tc,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-bc {
    background-image: url(images/btn/btn-plain-toolbar-medium-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-ml,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-mr {
    background-image: url(images/btn/btn-plain-toolbar-medium-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-medium-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-plain-toolbar-medium {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-plain-toolbar-medium {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium.x-segmented-button-first .x-btn-plain-toolbar-medium-mc {
    padding-right: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium.x-segmented-button-middle .x-btn-plain-toolbar-medium-mc {
    padding-right: 8px !important;
    padding-left: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium.x-segmented-button-last .x-btn-plain-toolbar-medium-mc {
    padding-left: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium.x-segmented-button-first .x-btn-plain-toolbar-medium-mc {
    padding-bottom: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium.x-segmented-button-middle .x-btn-plain-toolbar-medium-mc {
    padding-top: 8px !important;
    padding-bottom: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium.x-segmented-button-last .x-btn-plain-toolbar-medium-mc {
    padding-top: 8px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-plain-toolbar-medium:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-medium.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-medium.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-plain-toolbar-medium:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-plain-toolbar-medium:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-plain-toolbar-medium:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-plain-toolbar-medium:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-plain-toolbar-medium-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-plain-toolbar-medium-cell > .x-grid-cell-inner >.x-btn-plain-toolbar-medium {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-btn-plain-toolbar-large {
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    -ms-border-radius: 3px;
    -o-border-radius: 3px;
    border-radius: 3px;
    padding: 9px 9px 9px 9px;
    border-width: 1px;
    border-style: solid;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-btn-plain-toolbar-large-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-btn-plain-toolbar-large {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-btn-plain-toolbar-large-frameInfo {
    font-family: th-3-3-3-3-1-1-1-1-9-9-9-9;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-btn-plain-toolbar-large-tl {
    background-position: 0 -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-btn-plain-toolbar-large-tr {
    background-position: right -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-btn-plain-toolbar-large-bl {
    background-position: 0 -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-btn-plain-toolbar-large-br {
    background-position: right -15px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-btn-plain-toolbar-large-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-btn-plain-toolbar-large-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-btn-plain-toolbar-large-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-btn-plain-toolbar-large-bc {
    background-position: 0 -3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-btn-plain-toolbar-large-tr,
.x-btn-plain-toolbar-large-br,
.x-btn-plain-toolbar-large-mr {
    padding-right: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-btn-plain-toolbar-large-tl,
.x-btn-plain-toolbar-large-bl,
.x-btn-plain-toolbar-large-ml {
    padding-left: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-btn-plain-toolbar-large-tc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-btn-plain-toolbar-large-bc {
    height: 3px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-btn-plain-toolbar-large-mc {
    padding: 7px 7px 7px 7px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2463 */
.x-btn-plain-toolbar-large {
    border-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2470 */
.x-btn-button-plain-toolbar-large {
    min-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2475 */
.x-ie9m .x-btn-button-plain-toolbar-large {
    min-height: auto;
    height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2482 */
.x-btn-inner-plain-toolbar-large {
    font: 400 16px/20px Open Sans, sans-serif;
    color: #000;
    padding: 0 10px;
    max-width: 100%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2502 */
.x-ie9 .x-btn-icon-right > .x-btn-inner-plain-toolbar-large,
.x-ie9 .x-btn-icon-left > .x-btn-inner-plain-toolbar-large {
    max-width: calc(100% - 24px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2510 */
.x-safari8m .x-btn-icon-right > .x-btn-inner-plain-toolbar-large,
.x-safari8m .x-btn-icon-left > .x-btn-inner-plain-toolbar-large {
    max-width: calc(100% - 23px);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2516 */
.x-ie10p .x-btn-inner-plain-toolbar-large {
    max-width: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2521 */
.x-btn-icon-el-plain-toolbar-large {
    font-size: 24px;
    height: 24px;
    color: #919191;
    line-height: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2527 */
.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-large,
.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-large {
    width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2532 */
.x-btn-icon-top > .x-btn-icon-el-plain-toolbar-large,
.x-btn-icon-bottom > .x-btn-icon-el-plain-toolbar-large {
    min-width: 24px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2554 */
.x-ie8 .x-btn-icon-el-plain-toolbar-large.x-btn-glyph {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2561 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-large {
    margin-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2565 */
.x-btn-text.x-btn-icon-left > .x-btn-icon-el-plain-toolbar-large.x-rtl {
    margin-right: 0;
    margin-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2572 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-large {
    margin-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2576 */
.x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-large.x-rtl {
    margin-left: 0;
    margin-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2583 */
.x-btn-text.x-btn-icon-top > .x-btn-icon-el-plain-toolbar-large {
    margin-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2587 */
.x-btn-text.x-btn-icon-bottom > .x-btn-icon-el-plain-toolbar-large {
    margin-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2593 */
.x-btn-arrow-right > .x-btn-icon.x-btn-no-text.x-btn-button-plain-toolbar-large {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2596 */
.x-btn-arrow-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-large {
    margin-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2603 */
.x-btn-arrow-bottom > .x-btn-button-plain-toolbar-large,
.x-btn-split-bottom > .x-btn-button-plain-toolbar-large {
    padding-bottom: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2609 */
.x-btn-wrap-plain-toolbar-large.x-btn-arrow-right:after {
    width: 22px;
    content: "\f0d7";
    font: 24px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2636 */
.x-btn-wrap-plain-toolbar-large.x-btn-arrow-bottom:after {
    height: 16px;
    content: "\f0d7";
    font: 24px/16px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2663 */
.x-btn-wrap-plain-toolbar-large.x-btn-split-right > .x-btn-button {
    padding-right: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2666 */
.x-btn-wrap-plain-toolbar-large.x-btn-split-right > .x-btn-button.x-rtl {
    padding-right: 0;
    padding-left: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2671 */
.x-btn-wrap-plain-toolbar-large.x-btn-split-right > .x-btn-button:after {
    border-right: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2676 */
.x-btn-wrap-plain-toolbar-large.x-btn-split-right:after {
    width: 32px;
    content: "\f0d7";
    font: 24px/1 Portfolio, FontAwesome, Extjs;
    color: #000;
    padding-left: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2692 */
.x-btn-wrap-plain-toolbar-large.x-rtl.x-btn-split-right:after {
    padding-left: 0;
    padding-right: 9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2702 */
.x-btn-wrap-plain-toolbar-large.x-btn-split-bottom {
    margin-bottom: -9px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2704 */
.x-btn-wrap-plain-toolbar-large.x-btn-split-bottom > .x-btn-button:after {
    border-bottom: 1px solid #393939;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2715 */
.x-btn-wrap-plain-toolbar-large.x-btn-split-bottom:after {
    height: 28px;
    content: "\f0d7";
    font: 24px/28px Portfolio, FontAwesome, Extjs;
    color: #000;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2748 */
.x-btn-split-right > .x-btn-icon.x-btn-no-text.x-btn-button-plain-toolbar-large {
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2751 */
.x-btn-split-right > .x-btn-text.x-btn-icon-right > .x-btn-icon-el-plain-toolbar-large {
    margin-right: 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2757 */
.x-keyboard-mode .x-btn-focus.x-btn-plain-toolbar-large {
    background-image: none;
    background-color: transparent;
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2776 */
.x-keyboard-mode .x-btn-focus.x-btn-plain-toolbar-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2793 */
.x-btn-plain-toolbar-large .x-btn-arrow-el {
    position: absolute;
    top: 0;
    right: 0;
    height: 100%;
    width: 41px;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2802 */
.x-btn-plain-toolbar-large .x-btn-arrow-el.x-rtl {
    right: inherit;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2810 */
.x-keyboard-mode .x-btn-plain-toolbar-large.x-arrow-focus .x-btn-arrow-el {
    border: 1px solid #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2817 */
.x-btn-over.x-btn-plain-toolbar-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2828 */
.x-btn-over.x-btn-plain-toolbar-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2845 */
.x-keyboard-mode .x-btn-focus.x-btn-over.x-btn-plain-toolbar-large {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2874 */
.x-btn.x-btn-menu-active.x-btn-plain-toolbar-large,
.x-btn.x-btn-pressed.x-btn-plain-toolbar-large {
    border-color: #00adee;
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2886 */
.x-btn.x-btn-menu-active.x-btn-plain-toolbar-large .x-btn-inner,
.x-btn.x-btn-pressed.x-btn-plain-toolbar-large .x-btn-inner {
    color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2904 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active.x-btn-plain-toolbar-large,
.x-keyboard-mode .x-btn-focus.x-btn-pressed.x-btn-plain-toolbar-large {
    -webkit-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    -moz-box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
    box-shadow: #00adee 0 1px 0px 0 inset, #00adee 0 -1px 0px 0 inset, #00adee -1px 0 0px 0 inset, #00adee 1px 0 0px 0 inset;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2933 */
.x-btn.x-btn-disabled.x-btn-plain-toolbar-large {
    background-image: none;
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2966 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-br,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-bc {
    background-image: url(images/btn/btn-plain-toolbar-large-focus-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2974 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-mr {
    background-image: url(images/btn/btn-plain-toolbar-large-focus-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2978 */
.x-keyboard-mode .x-btn-focus .x-btn-plain-toolbar-large-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2991 */
.x-btn-over .x-btn-plain-toolbar-large-tl,
.x-btn-over .x-btn-plain-toolbar-large-bl,
.x-btn-over .x-btn-plain-toolbar-large-tr,
.x-btn-over .x-btn-plain-toolbar-large-br,
.x-btn-over .x-btn-plain-toolbar-large-tc,
.x-btn-over .x-btn-plain-toolbar-large-bc {
    background-image: url(images/btn/btn-plain-toolbar-large-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:2999 */
.x-btn-over .x-btn-plain-toolbar-large-ml,
.x-btn-over .x-btn-plain-toolbar-large-mr {
    background-image: url(images/btn/btn-plain-toolbar-large-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3003 */
.x-btn-over .x-btn-plain-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3016 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-bc {
    background-image: url(images/btn/btn-plain-toolbar-large-focus-over-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3024 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-mr {
    background-image: url(images/btn/btn-plain-toolbar-large-focus-over-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3028 */
.x-keyboard-mode .x-btn-focus.x-btn-over .x-btn-plain-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3043 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-tl,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-bl,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-tr,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-br,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-tc,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-bc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-tl,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-bl,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-tr,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-br,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-tc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-bc {
    background-image: url(images/btn/btn-plain-toolbar-large-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3051 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-ml,
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-mr,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-ml,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-mr {
    background-image: url(images/btn/btn-plain-toolbar-large-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3055 */
.x-btn.x-btn-menu-active .x-btn-plain-toolbar-large-mc,
.x-btn.x-btn-pressed .x-btn-plain-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3069 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-bc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-tl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-bl,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-tr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-br,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-tc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-bc {
    background-image: url(images/btn/btn-plain-toolbar-large-focus-pressed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3077 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-mr,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-ml,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-mr {
    background-image: url(images/btn/btn-plain-toolbar-large-focus-pressed-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3081 */
.x-keyboard-mode .x-btn-focus.x-btn-menu-active .x-btn-plain-toolbar-large-mc,
.x-keyboard-mode .x-btn-focus.x-btn-pressed .x-btn-plain-toolbar-large-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3095 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-tl,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-bl,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-tr,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-br,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-tc,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-bc {
    background-image: url(images/btn/btn-plain-toolbar-large-disabled-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3103 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-ml,
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-mr {
    background-image: url(images/btn/btn-plain-toolbar-large-disabled-sides.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3107 */
.x-btn.x-btn-disabled .x-btn-plain-toolbar-large-mc {
    background-color: transparent;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3117 */
.x-nbr .x-btn-plain-toolbar-large {
    background-image: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3123 */
.x-btn-disabled.x-btn-plain-toolbar-large {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3142 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large.x-segmented-button-first {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3144 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large.x-segmented-button-first .x-btn-plain-toolbar-large-mc {
    padding-right: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3148 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large.x-segmented-button-middle {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3150 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large.x-segmented-button-middle .x-btn-plain-toolbar-large-mc {
    padding-right: 9px !important;
    padding-left: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3156 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large.x-segmented-button-last .x-btn-plain-toolbar-large-mc {
    padding-left: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3163 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large.x-segmented-button-first {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3165 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large.x-segmented-button-first .x-btn-plain-toolbar-large-mc {
    padding-bottom: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3169 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large.x-segmented-button-middle {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3171 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large.x-segmented-button-middle .x-btn-plain-toolbar-large-mc {
    padding-top: 9px !important;
    padding-bottom: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3177 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large.x-segmented-button-last .x-btn-plain-toolbar-large-mc {
    padding-top: 9px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3183 */
.x-nbr .x-segmented-button-item.x-btn-plain-toolbar-large:after {
    content: ' ';
    border-style: solid;
    border-width: 0;
    position: absolute;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3201 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large:after {
    top: 1px;
    right: 0;
    bottom: 1px;
    left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3207 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large.x-segmented-button-first:after {
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3210 */
.x-nbr .x-segmented-button-item-horizontal.x-btn-plain-toolbar-large.x-segmented-button-last:after {
    right: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3216 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large:after {
    top: 0;
    right: 1px;
    bottom: 0;
    left: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3222 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large.x-segmented-button-first:after {
    top: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3225 */
.x-nbr .x-segmented-button-item-vertical.x-btn-plain-toolbar-large.x-segmented-button-last:after {
    bottom: 1px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3233 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-plain-toolbar-large:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3249 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-over.x-btn-plain-toolbar-large:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3267 */
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-menu-active.x-btn-plain-toolbar-large:after,
.x-keyboard-mode .x-nbr .x-segmented-button-item.x-btn-focus.x-btn-pressed.x-btn-plain-toolbar-large:after {
    border-width: 1px;
    border-color: #00adee;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3294 */
.x-button-plain-toolbar-large-cell > .x-grid-cell-inner {
    padding-top: 0;
    padding-bottom: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/button/Button.scss:3299 */
.x-button-plain-toolbar-large-cell > .x-grid-cell-inner >.x-btn-plain-toolbar-large {
    vertical-align: top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/button/Button.scss:220 */
.x-btn-plain-toolbar-small-disabled .x-btn-icon-el,
.x-btn-plain-toolbar-medium-disabled .x-btn-icon-el,
.x-btn-plain-toolbar-large-disabled .x-btn-icon-el {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/button/Button.scss:223 */
.x-ie8 .x-btn-plain-toolbar-small-disabled .x-btn-icon-el,
.x-ie8 .x-btn-plain-toolbar-medium-disabled .x-btn-icon-el,
.x-ie8 .x-btn-plain-toolbar-large-disabled .x-btn-icon-el {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=50)";
    opacity: 0.5;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:799 */
.x-panel-light {
    border-color: #d0d0d0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:802 */
.x-panel-light.x-masked {
    border-color: #e8e8e8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:810 */
.x-panel-header-light {
    font-size: 14px;
    border: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:819 */
.x-panel-header-light .x-tool-tool-el {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:836 */
.x-panel-header-light .x-tool-tool-el {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:842 */
.x-panel-header-light-horizontal {
    padding: 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:846 */
.x-panel-header-light-horizontal .x-panel-header-light-tab-bar {
    margin-top: -11px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:854 */
.x-panel-header-light-horizontal.x-header-noborder {
    padding: 12px 16px 12px 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:858 */
.x-panel-header-light-horizontal.x-header-noborder .x-panel-header-light-tab-bar {
    margin-top: -12px;
    margin-bottom: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:866 */
.x-panel-header-light-vertical {
    padding: 15px 11px 15px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:870 */
.x-panel-header-light-vertical .x-panel-header-light-tab-bar {
    margin-right: -11px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:878 */
.x-panel-header-light-vertical.x-header-noborder {
    padding: 16px 12px 16px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:882 */
.x-panel-header-light-vertical.x-header-noborder .x-panel-header-light-tab-bar {
    margin-right: -12px;
    margin-left: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:891 */
.x-rtl.x-panel-header-light-vertical {
    padding: 15px 12px 15px 11px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:895 */
.x-rtl.x-panel-header-light-vertical .x-panel-header-light-tab-bar {
    margin-left: -11px;
    margin-right: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:903 */
.x-rtl.x-panel-header-light-vertical.x-header-noborder {
    padding: 16px 12px 16px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:907 */
.x-rtl.x-panel-header-light-vertical.x-header-noborder .x-panel-header-light-tab-bar {
    margin-left: -12px;
    margin-right: -12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:916 */
.x-panel-header-title-light {
    color: #606060;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:929 */
.x-keyboard-mode .x-panel-header-title-light.x-title-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-title-light.x-title-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-title-light.x-title-focus,
.x-edge .x-keyboard-mode .x-panel-header-title-light.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-title-light.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-title-light.x-title-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-title-light.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:950 */
.x-panel-header-title-light > .x-title-text-light {
    text-transform: none;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:997 */
.x-panel-header-title-light > .x-title-icon-wrap-light.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1002 */
.x-panel-header-title-light > .x-title-icon-wrap-light.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1007 */
.x-panel-header-title-light > .x-title-icon-wrap-light.x-title-icon-right.x-rtl {
    padding-left: 0;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1014 */
.x-panel-header-title-light > .x-title-icon-wrap-light.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1019 */
.x-panel-header-title-light > .x-title-icon-wrap-light.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1024 */
.x-panel-header-title-light > .x-title-icon-wrap-light.x-title-icon-left.x-rtl {
    padding-right: 0;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1031 */
.x-panel-header-title-light > .x-title-icon-wrap-light > .x-title-icon-light {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #606060;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1051 */
.x-ie8 .x-panel-header-title-light > .x-title-icon-wrap-light > .x-title-icon-light.x-title-glyph {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1062 */
.x-panel-body-light {
    background: #fff;
    border-color: #d0d0d0;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1226 */
.x-panel-header-light {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1230 */
.x-panel-header-light-vertical {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1235 */
.x-rtl.x-panel-header-light-vertical {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1288 */
.x-panel .x-panel-header-light-collapsed-border-top {
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1292 */
.x-panel .x-panel-header-light-collapsed-border-right {
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1296 */
.x-panel .x-panel-header-light-collapsed-border-bottom {
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1300 */
.x-panel .x-panel-header-light-collapsed-border-left {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1336 */
.x-panel-header-light-horizontal .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1341 */
.x-panel-header-light-horizontal .x-rtl.x-tool-after-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1346 */
.x-panel-header-light-horizontal .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1351 */
.x-panel-header-light-horizontal .x-rtl.x-tool-before-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1358 */
.x-panel-header-light-vertical .x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1363 */
.x-panel-header-light-vertical .x-rtl.x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1368 */
.x-panel-header-light-vertical .x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1373 */
.x-panel-header-light-vertical .x-rtl.x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1381 */
.x-keyboard-mode .x-panel-header-light .x-tool-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-light .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-light .x-tool-focus,
.x-edge .x-keyboard-mode .x-panel-header-light .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-light .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-light .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-light .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1412 */
.x-rtl.x-panel-header-light-collapsed-border-right {
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1415 */
.x-rtl.x-panel-header-light-collapsed-border-left {
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1429 */
.x-panel-light-resizable .x-panel-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-panel-light-outer-border-l {
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-panel-light-outer-border-b {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-panel-light-outer-border-bl {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-panel-light-outer-border-r {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-panel-light-outer-border-rl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-panel-light-outer-border-rb {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-panel-light-outer-border-rbl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-panel-light-outer-border-t {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-panel-light-outer-border-tl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-panel-light-outer-border-tb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-panel-light-outer-border-tbl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-panel-light-outer-border-tr {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-panel-light-outer-border-trl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-panel-light-outer-border-trb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 1px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 1px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-panel-light-outer-border-trbl {
    border-color: #d0d0d0 !important;
    border-width: 1px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:799 */
.x-panel-light-framed {
    border-color: #d0d0d0;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:802 */
.x-panel-light-framed.x-masked {
    border-color: #e8e8e8;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:810 */
.x-panel-header-light-framed {
    font-size: 14px;
    border: 2px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:819 */
.x-panel-header-light-framed .x-tool-tool-el {
    color: #919191;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:836 */
.x-panel-header-light-framed .x-tool-tool-el {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:842 */
.x-panel-header-light-framed-horizontal {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:846 */
.x-panel-header-light-framed-horizontal .x-panel-header-light-framed-tab-bar {
    margin-top: -10px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:854 */
.x-panel-header-light-framed-horizontal.x-header-noborder {
    padding: 12px 16px 10px 16px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:858 */
.x-panel-header-light-framed-horizontal.x-header-noborder .x-panel-header-light-framed-tab-bar {
    margin-top: -12px;
    margin-bottom: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:866 */
.x-panel-header-light-framed-vertical {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:870 */
.x-panel-header-light-framed-vertical .x-panel-header-light-framed-tab-bar {
    margin-right: -10px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:878 */
.x-panel-header-light-framed-vertical.x-header-noborder {
    padding: 16px 12px 16px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:882 */
.x-panel-header-light-framed-vertical.x-header-noborder .x-panel-header-light-framed-tab-bar {
    margin-right: -12px;
    margin-left: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:891 */
.x-rtl.x-panel-header-light-framed-vertical {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:895 */
.x-rtl.x-panel-header-light-framed-vertical .x-panel-header-light-framed-tab-bar {
    margin-left: -10px;
    margin-right: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:903 */
.x-rtl.x-panel-header-light-framed-vertical.x-header-noborder {
    padding: 16px 10px 16px 12px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:907 */
.x-rtl.x-panel-header-light-framed-vertical.x-header-noborder .x-panel-header-light-framed-tab-bar {
    margin-left: -12px;
    margin-right: -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:916 */
.x-panel-header-title-light-framed {
    color: #606060;
    font-size: 14px;
    font-weight: 700;
    font-family: Open Sans, sans-serif;
    line-height: 27px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:929 */
.x-keyboard-mode .x-panel-header-title-light-framed.x-title-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-title-light-framed.x-title-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-title-light-framed.x-title-focus,
.x-edge .x-keyboard-mode .x-panel-header-title-light-framed.x-title-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-title-light-framed.x-title-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-title-light-framed.x-title-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-title-light-framed.x-title-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:950 */
.x-panel-header-title-light-framed > .x-title-text-light-framed {
    text-transform: none;
    padding: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:997 */
.x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed.x-title-icon-top {
    height: 24px;
    padding-bottom: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1002 */
.x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed.x-title-icon-right {
    width: 24px;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1007 */
.x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed.x-title-icon-right.x-rtl {
    padding-left: 0;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1014 */
.x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed.x-title-icon-bottom {
    height: 24px;
    padding-top: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1019 */
.x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed.x-title-icon-left {
    width: 24px;
    padding-right: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1024 */
.x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed.x-title-icon-left.x-rtl {
    padding-right: 0;
    padding-left: 8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1031 */
.x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed > .x-title-icon-light-framed {
    width: 16px;
    height: 16px;
    font-size: 16px;
    color: #606060;
    background-position: center center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1051 */
.x-ie8 .x-panel-header-title-light-framed > .x-title-icon-wrap-light-framed > .x-title-icon-light-framed.x-title-glyph {
    color: #606060;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1062 */
.x-panel-body-light-framed {
    background: #fff;
    border-color: #d0d0d0;
    color: #000;
    font-size: 14px;
    font-weight: 400;
    font-family: Open Sans, sans-serif;
    border-width: 1px;
    border-style: solid;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-light-framed {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 0 0 0 0;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-light-framed-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-light-framed {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-light-framed-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-0px-0px-0px-0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-light-framed-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-light-framed-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-light-framed-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-light-framed-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-light-framed-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-light-framed-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-light-framed-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-light-framed-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-light-framed-tr,
.x-panel-light-framed-br,
.x-panel-light-framed-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-light-framed-tl,
.x-panel-light-framed-bl,
.x-panel-light-framed-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-light-framed-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-light-framed-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-light-framed-tl,
.x-panel-light-framed-bl,
.x-panel-light-framed-tr,
.x-panel-light-framed-br,
.x-panel-light-framed-tc,
.x-panel-light-framed-bc,
.x-panel-light-framed-ml,
.x-panel-light-framed-mr {
    background-image: url(images/panel/panel-light-framed-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-light-framed-ml,
.x-panel-light-framed-mr {
    background-image: url(images/panel/panel-light-framed-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-light-framed-mc {
    padding: 0px 0px 0px 0px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px 2px 0 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-top-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-top-frameInfo {
    font-family: dh-2-2-0-2-2-2-0-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-top-tr,
.x-panel-header-light-framed-top-br,
.x-panel-header-light-framed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-top-tl,
.x-panel-header-light-framed-top-bl,
.x-panel-header-light-framed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-top-bc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-top-tl,
.x-panel-header-light-framed-top-bl,
.x-panel-header-light-framed-top-tr,
.x-panel-header-light-framed-top-br,
.x-panel-header-light-framed-top-tc,
.x-panel-header-light-framed-top-bc,
.x-panel-header-light-framed-top-ml,
.x-panel-header-light-framed-top-mr {
    background-image: url(images/panel-header/panel-header-light-framed-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-top-ml,
.x-panel-header-light-framed-top-mr {
    background-image: url(images/panel-header/panel-header-light-framed-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 2px 2px 0;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:226 */
.x-rtl.x-panel-header-light-framed-right {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-right-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-right-frameInfo {
    font-family: dh-2-2-2-0-2-2-2-0-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-right-ml {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-right-mr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-right-tr,
.x-panel-header-light-framed-right-br,
.x-panel-header-light-framed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-right-tl,
.x-panel-header-light-framed-right-bl,
.x-panel-header-light-framed-right-ml {
    padding-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-right-tl,
.x-panel-header-light-framed-right-bl,
.x-panel-header-light-framed-right-tr,
.x-panel-header-light-framed-right-br,
.x-panel-header-light-framed-right-tc,
.x-panel-header-light-framed-right-bc,
.x-panel-header-light-framed-right-ml,
.x-panel-header-light-framed-right-mr {
    background-image: url(images/panel-header/panel-header-light-framed-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:423 */
.x-rtl.x-panel-header-light-framed-right-tl,
.x-rtl.x-panel-header-light-framed-right-ml,
.x-rtl.x-panel-header-light-framed-right-bl,
.x-rtl.x-panel-header-light-framed-right-tr,
.x-rtl.x-panel-header-light-framed-right-mr,
.x-rtl.x-panel-header-light-framed-right-br {
    background-image: url(images/panel-header/panel-header-light-framed-right-corners-rtl.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-right-ml,
.x-panel-header-light-framed-right-mr {
    background-image: url(images/panel-header/panel-header-light-framed-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 0 2px 2px 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-bottom-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-bottom-frameInfo {
    font-family: dh-0-2-2-2-0-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-bottom-tr,
.x-panel-header-light-framed-bottom-br,
.x-panel-header-light-framed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-bottom-tl,
.x-panel-header-light-framed-bottom-bl,
.x-panel-header-light-framed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-bottom-tc {
    height: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-bottom-tl,
.x-panel-header-light-framed-bottom-bl,
.x-panel-header-light-framed-bottom-tr,
.x-panel-header-light-framed-bottom-br,
.x-panel-header-light-framed-bottom-tc,
.x-panel-header-light-framed-bottom-bc,
.x-panel-header-light-framed-bottom-ml,
.x-panel-header-light-framed-bottom-mr {
    background-image: url(images/panel-header/panel-header-light-framed-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-bottom-ml,
.x-panel-header-light-framed-bottom-mr {
    background-image: url(images/panel-header/panel-header-light-framed-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px 0 2px 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:226 */
.x-rtl.x-panel-header-light-framed-left {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-left-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-left-frameInfo {
    font-family: dh-2-0-2-2-2-0-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-left-ml {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-left-mr {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-left-tr,
.x-panel-header-light-framed-left-br,
.x-panel-header-light-framed-left-mr {
    padding-right: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-left-tl,
.x-panel-header-light-framed-left-bl,
.x-panel-header-light-framed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-left-tl,
.x-panel-header-light-framed-left-bl,
.x-panel-header-light-framed-left-tr,
.x-panel-header-light-framed-left-br,
.x-panel-header-light-framed-left-tc,
.x-panel-header-light-framed-left-bc,
.x-panel-header-light-framed-left-ml,
.x-panel-header-light-framed-left-mr {
    background-image: url(images/panel-header/panel-header-light-framed-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:423 */
.x-rtl.x-panel-header-light-framed-left-tl,
.x-rtl.x-panel-header-light-framed-left-ml,
.x-rtl.x-panel-header-light-framed-left-bl,
.x-rtl.x-panel-header-light-framed-left-tr,
.x-rtl.x-panel-header-light-framed-left-mr,
.x-rtl.x-panel-header-light-framed-left-br {
    background-image: url(images/panel-header/panel-header-light-framed-left-corners-rtl.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-left-ml,
.x-panel-header-light-framed-left-mr {
    background-image: url(images/panel-header/panel-header-light-framed-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-collapsed-top {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-collapsed-top-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-collapsed-top {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-collapsed-top-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-collapsed-top-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-collapsed-top-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-collapsed-top-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-collapsed-top-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-collapsed-top-ml {
    background-position: 0 top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-collapsed-top-mr {
    background-position: right top;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-collapsed-top-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-collapsed-top-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-collapsed-top-tr,
.x-panel-header-light-framed-collapsed-top-br,
.x-panel-header-light-framed-collapsed-top-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-collapsed-top-tl,
.x-panel-header-light-framed-collapsed-top-bl,
.x-panel-header-light-framed-collapsed-top-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-collapsed-top-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-collapsed-top-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-collapsed-top-tl,
.x-panel-header-light-framed-collapsed-top-bl,
.x-panel-header-light-framed-collapsed-top-tr,
.x-panel-header-light-framed-collapsed-top-br,
.x-panel-header-light-framed-collapsed-top-tc,
.x-panel-header-light-framed-collapsed-top-bc,
.x-panel-header-light-framed-collapsed-top-ml,
.x-panel-header-light-framed-collapsed-top-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-top-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-collapsed-top-ml,
.x-panel-header-light-framed-collapsed-top-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-top-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-collapsed-top-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-collapsed-right {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:226 */
.x-rtl.x-panel-header-light-framed-collapsed-right {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-collapsed-right-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-collapsed-right {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-collapsed-right-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-collapsed-right-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-collapsed-right-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-collapsed-right-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-collapsed-right-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-collapsed-right-ml {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-collapsed-right-mr {
    background-position: right 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-collapsed-right-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-collapsed-right-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-collapsed-right-tr,
.x-panel-header-light-framed-collapsed-right-br,
.x-panel-header-light-framed-collapsed-right-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-collapsed-right-tl,
.x-panel-header-light-framed-collapsed-right-bl,
.x-panel-header-light-framed-collapsed-right-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-collapsed-right-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-collapsed-right-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-collapsed-right-tl,
.x-panel-header-light-framed-collapsed-right-bl,
.x-panel-header-light-framed-collapsed-right-tr,
.x-panel-header-light-framed-collapsed-right-br,
.x-panel-header-light-framed-collapsed-right-tc,
.x-panel-header-light-framed-collapsed-right-bc,
.x-panel-header-light-framed-collapsed-right-ml,
.x-panel-header-light-framed-collapsed-right-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-right-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:423 */
.x-rtl.x-panel-header-light-framed-collapsed-right-tl,
.x-rtl.x-panel-header-light-framed-collapsed-right-ml,
.x-rtl.x-panel-header-light-framed-collapsed-right-bl,
.x-rtl.x-panel-header-light-framed-collapsed-right-tr,
.x-rtl.x-panel-header-light-framed-collapsed-right-mr,
.x-rtl.x-panel-header-light-framed-collapsed-right-br {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-right-corners-rtl.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-collapsed-right-ml,
.x-panel-header-light-framed-collapsed-right-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-right-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-collapsed-right-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-collapsed-bottom {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 10px 14px 10px 14px;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-collapsed-bottom-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-collapsed-bottom {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-collapsed-bottom-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-10-14-10-14;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-collapsed-bottom-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-collapsed-bottom-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-collapsed-bottom-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-collapsed-bottom-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-collapsed-bottom-ml {
    background-position: 0 bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-collapsed-bottom-mr {
    background-position: right bottom;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-collapsed-bottom-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-collapsed-bottom-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-collapsed-bottom-tr,
.x-panel-header-light-framed-collapsed-bottom-br,
.x-panel-header-light-framed-collapsed-bottom-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-collapsed-bottom-tl,
.x-panel-header-light-framed-collapsed-bottom-bl,
.x-panel-header-light-framed-collapsed-bottom-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-collapsed-bottom-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-collapsed-bottom-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-collapsed-bottom-tl,
.x-panel-header-light-framed-collapsed-bottom-bl,
.x-panel-header-light-framed-collapsed-bottom-tr,
.x-panel-header-light-framed-collapsed-bottom-br,
.x-panel-header-light-framed-collapsed-bottom-tc,
.x-panel-header-light-framed-collapsed-bottom-bc,
.x-panel-header-light-framed-collapsed-bottom-ml,
.x-panel-header-light-framed-collapsed-bottom-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-bottom-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-collapsed-bottom-ml,
.x-panel-header-light-framed-collapsed-bottom-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-bottom-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-collapsed-bottom-mc {
    padding: 10px 14px 10px 14px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:187 */
.x-panel-header-light-framed-collapsed-left {
    -moz-border-radius-topleft: 0;
    -webkit-border-top-left-radius: 0;
    border-top-left-radius: 0;
    -moz-border-radius-topright: 0;
    -webkit-border-top-right-radius: 0;
    border-top-right-radius: 0;
    -moz-border-radius-bottomright: 0;
    -webkit-border-bottom-right-radius: 0;
    border-bottom-right-radius: 0;
    -moz-border-radius-bottomleft: 0;
    -webkit-border-bottom-left-radius: 0;
    border-bottom-left-radius: 0;
    padding: 14px 10px 14px 10px;
    border-width: 2px;
    border-style: solid;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:226 */
.x-rtl.x-panel-header-light-framed-collapsed-left {
    background-image: none;
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:237 */
.x-panel-header-light-framed-collapsed-left-mc {
    background-color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:264 */
.x-nbr .x-panel-header-light-framed-collapsed-left {
    padding: 0 !important;
    border-width: 0 !important;
    -webkit-border-radius: 0px;
    -moz-border-radius: 0px;
    -ms-border-radius: 0px;
    -o-border-radius: 0px;
    border-radius: 0px;
    background-color: transparent !important;
    box-shadow: none !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:281 */
.x-panel-header-light-framed-collapsed-left-frameInfo {
    font-family: dh-2-2-2-2-2-2-2-2-14-10-14-10;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:347 */
.x-panel-header-light-framed-collapsed-left-tl {
    background-position: 0 -4px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:351 */
.x-panel-header-light-framed-collapsed-left-tr {
    background-position: right -6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:355 */
.x-panel-header-light-framed-collapsed-left-bl {
    background-position: 0 -8px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:359 */
.x-panel-header-light-framed-collapsed-left-br {
    background-position: right -10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:363 */
.x-panel-header-light-framed-collapsed-left-ml {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:371 */
.x-panel-header-light-framed-collapsed-left-mr {
    background-position: left 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:379 */
.x-panel-header-light-framed-collapsed-left-tc {
    background-position: 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:383 */
.x-panel-header-light-framed-collapsed-left-bc {
    background-position: 0 -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:388 */
.x-panel-header-light-framed-collapsed-left-tr,
.x-panel-header-light-framed-collapsed-left-br,
.x-panel-header-light-framed-collapsed-left-mr {
    padding-right: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:394 */
.x-panel-header-light-framed-collapsed-left-tl,
.x-panel-header-light-framed-collapsed-left-bl,
.x-panel-header-light-framed-collapsed-left-ml {
    padding-left: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:400 */
.x-panel-header-light-framed-collapsed-left-tc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:403 */
.x-panel-header-light-framed-collapsed-left-bc {
    height: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:407 */
.x-panel-header-light-framed-collapsed-left-tl,
.x-panel-header-light-framed-collapsed-left-bl,
.x-panel-header-light-framed-collapsed-left-tr,
.x-panel-header-light-framed-collapsed-left-br,
.x-panel-header-light-framed-collapsed-left-tc,
.x-panel-header-light-framed-collapsed-left-bc,
.x-panel-header-light-framed-collapsed-left-ml,
.x-panel-header-light-framed-collapsed-left-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-left-corners.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:423 */
.x-rtl.x-panel-header-light-framed-collapsed-left-tl,
.x-rtl.x-panel-header-light-framed-collapsed-left-ml,
.x-rtl.x-panel-header-light-framed-collapsed-left-bl,
.x-rtl.x-panel-header-light-framed-collapsed-left-tr,
.x-rtl.x-panel-header-light-framed-collapsed-left-mr,
.x-rtl.x-panel-header-light-framed-collapsed-left-br {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-left-corners-rtl.gif);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:453 */
.x-panel-header-light-framed-collapsed-left-ml,
.x-panel-header-light-framed-collapsed-left-mr {
    background-image: url(images/panel-header/panel-header-light-framed-collapsed-left-sides.gif);
    background-repeat: repeat-y;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/frame.scss:464 */
.x-panel-header-light-framed-collapsed-left-mc {
    padding: 14px 10px 14px 10px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1188 */
.x-panel .x-panel-header-light-framed-top {
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1192 */
.x-panel .x-panel-header-light-framed-right {
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1196 */
.x-panel .x-panel-header-light-framed-bottom {
    border-top-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1200 */
.x-panel .x-panel-header-light-framed-left {
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1206 */
.x-nbr .x-panel-header-light-framed-collapsed-top {
    border-bottom-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1210 */
.x-nbr .x-panel-header-light-framed-collapsed-right {
    border-left-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1214 */
.x-nbr .x-panel-header-light-framed-collapsed-bottom {
    border-top-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1218 */
.x-nbr .x-panel-header-light-framed-collapsed-left {
    border-right-width: 0 !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1336 */
.x-panel-header-light-framed-horizontal .x-tool-after-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1341 */
.x-panel-header-light-framed-horizontal .x-rtl.x-tool-after-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1346 */
.x-panel-header-light-framed-horizontal .x-tool-before-title {
    margin: 0 6px 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1351 */
.x-panel-header-light-framed-horizontal .x-rtl.x-tool-before-title {
    margin: 0 0 0 6px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1358 */
.x-panel-header-light-framed-vertical .x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1363 */
.x-panel-header-light-framed-vertical .x-rtl.x-tool-after-title {
    margin: 6px 0 0 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1368 */
.x-panel-header-light-framed-vertical .x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1373 */
.x-panel-header-light-framed-vertical .x-rtl.x-tool-before-title {
    margin: 0 0 6px 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1381 */
.x-keyboard-mode .x-panel-header-light-framed .x-tool-focus {
    outline: 1px solid #00adee;
    outline-offset: 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:63 */
.x-ie .x-keyboard-mode .x-panel-header-light-framed .x-tool-focus,
.x-ie10p .x-keyboard-mode .x-panel-header-light-framed .x-tool-focus,
.x-edge .x-keyboard-mode .x-panel-header-light-framed .x-tool-focus {
    outline: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/css-outline.scss:39 */
.x-ie .x-keyboard-mode .x-panel-header-light-framed .x-tool-focus:after,
.x-ie10p .x-keyboard-mode .x-panel-header-light-framed .x-tool-focus:after,
.x-edge .x-keyboard-mode .x-panel-header-light-framed .x-tool-focus:after {
    position: absolute;
    content: ' ';
    top: -3px;
    right: -3px;
    bottom: -3px;
    left: -3px;
    border: 1px solid #00adee;
    pointer-events: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1412 */
.x-rtl.x-panel-header-light-framed-collapsed-border-right {
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1415 */
.x-rtl.x-panel-header-light-framed-collapsed-border-left {
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neutral/sass/var/panel/Panel.scss:1429 */
.x-panel-light-framed-resizable .x-panel-handle {
    -ms-filter: "progid:DXImageTransform.Microsoft.Alpha(Opacity=0)";
    opacity: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:2 */
.x-panel-light-framed-outer-border-l {
    border-left-color: #d0d0d0 !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:6 */
.x-panel-light-framed-outer-border-b {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:10 */
.x-panel-light-framed-outer-border-bl {
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 2px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:16 */
.x-panel-light-framed-outer-border-r {
    border-right-color: #d0d0d0 !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:20 */
.x-panel-light-framed-outer-border-rl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 2px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:26 */
.x-panel-light-framed-outer-border-rb {
    border-right-color: #d0d0d0 !important;
    border-right-width: 2px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:32 */
.x-panel-light-framed-outer-border-rbl {
    border-right-color: #d0d0d0 !important;
    border-right-width: 2px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 2px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:40 */
.x-panel-light-framed-outer-border-t {
    border-top-color: #d0d0d0 !important;
    border-top-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:44 */
.x-panel-light-framed-outer-border-tl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 2px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:50 */
.x-panel-light-framed-outer-border-tb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 2px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:56 */
.x-panel-light-framed-outer-border-tbl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 2px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 2px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:64 */
.x-panel-light-framed-outer-border-tr {
    border-top-color: #d0d0d0 !important;
    border-top-width: 2px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:70 */
.x-panel-light-framed-outer-border-trl {
    border-top-color: #d0d0d0 !important;
    border-top-width: 2px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 2px !important;
    border-left-color: #d0d0d0 !important;
    border-left-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:78 */
.x-panel-light-framed-outer-border-trb {
    border-top-color: #d0d0d0 !important;
    border-top-width: 2px !important;
    border-right-color: #d0d0d0 !important;
    border-right-width: 2px !important;
    border-bottom-color: #d0d0d0 !important;
    border-bottom-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-base/sass/etc/mixins/border-management.scss:86 */
.x-panel-light-framed-outer-border-trbl {
    border-color: #d0d0d0 !important;
    border-width: 2px !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/form/field/File.scss:3 */
.x-form-file-wrap .x-form-trigger-wrap {
    border: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/form/field/File.scss:7 */
.x-form-file-wrap .x-form-trigger-wrap .x-form-text {
    border: 1px solid;
    border-color: #d0d0d0;
    height: 40px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/form/field/File.scss:12 */
.x-form-file-wrap .x-form-trigger-wrap .x-form-text.x-form-invalid-field {
    border-color: #d81818;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/form/field/HtmlEditor.scss:1 */
.x-html-editor-container {
    border: 1px solid;
    border-color: #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/grid/header/Container.scss:1 */
.x-grid-header-ct {
    border: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/grid/column/Column.scss:6 */
.x-column-header-trigger {
    background-color: rgba(0, 173, 238, 0.08);
    border-left: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/grid/column/Column.scss:12 */
.x-rtl.x-column-header-trigger {
    border-right: 1px solid #d0d0d0;
    border-left: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/grid/column/Column.scss:18 */
.x-column-header-last {
    border-right-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/grid/column/Column.scss:20 */
.x-column-header-last .x-column-header-over .x-column-header-trigger {
    border-right: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/grid/column/Column.scss:26 */
.x-rtl.x-column-header-last {
    border-left-width: 0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/grid/column/Column.scss:28 */
.x-rtl.x-column-header-last .x-column-header-over .x-column-header-trigger {
    border-left: 1px solid #d0d0d0;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:1 */
.x-resizable-handle {
    background-repeat: no-repeat;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:6 */
.x-resizable-handle-east-over,
.x-resizable-handle-west-over {
    background-position: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:11 */
.x-resizable-handle-south-over,
.x-resizable-handle-north-over {
    background-position: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:16 */
.x-resizable-handle-southeast-over {
    background-position: -2px -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:20 */
.x-resizable-handle-northwest-over {
    background-position: 2px 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:24 */
.x-resizable-handle-northeast-over {
    background-position: -2px 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:28 */
.x-resizable-handle-southwest-over {
    background-position: 2px -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:33 */
.x-resizable-pinned .x-resizable-handle-east,
.x-resizable-pinned .x-resizable-handle-west {
    background-position: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:38 */
.x-resizable-pinned .x-resizable-handle-south,
.x-resizable-pinned .x-resizable-handle-north {
    background-position: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:43 */
.x-resizable-pinned .x-resizable-handle-southeast {
    background-position: -2px -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:47 */
.x-resizable-pinned .x-resizable-handle-northwest {
    background-position: 2px 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:51 */
.x-resizable-pinned .x-resizable-handle-northeast {
    background-position: -2px 2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-neptune/sass/src/resizer/Resizer.scss:55 */
.x-resizable-pinned .x-resizable-handle-southwest {
    background-position: 2px -2px;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_path.scss:5 */
@font-face {
    /* FONT PATH
 * -------------------------- */
    /* FONT PATH
 * -------------------------- */
    font-family: 'FontAwesome';
    src: url('font-awesome/fonts/fontawesome-webfont.eot?v=4.7.0');
    src: url('font-awesome/fonts/fontawesome-webfont.eot?#iefix&v=4.7.0') format('embedded-opentype'), url('font-awesome/fonts/fontawesome-webfont.woff2?v=4.7.0') format('woff2'), url('font-awesome/fonts/fontawesome-webfont.woff?v=4.7.0') format('woff'), url('font-awesome/fonts/fontawesome-webfont.ttf?v=4.7.0') format('truetype'), url('font-awesome/fonts/fontawesome-webfont.svg?v=4.7.0#fontawesomeregular') format('svg');
    font-weight: normal;
    font-style: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_core.scss:4 */
.fa {
    display: inline-block;
    font: normal normal normal 14px/1 FontAwesome;
    font-size: inherit;
    text-rendering: auto;
    -webkit-font-smoothing: antialiased;
    -moz-osx-font-smoothing: grayscale;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_larger.scss:5 */
.fa-lg {
    /* makes the font 33% larger relative to the icon container */
    font-size: 1.33333em;
    line-height: 0.75em;
    vertical-align: -15%;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_larger.scss:10 */
.fa-2x {
    font-size: 2em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_larger.scss:11 */
.fa-3x {
    font-size: 3em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_larger.scss:12 */
.fa-4x {
    font-size: 4em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_larger.scss:13 */
.fa-5x {
    font-size: 5em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_fixed-width.scss:3 */
.fa-fw {
    width: 1.28571em;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_list.scss:4 */
.fa-ul {
    padding-left: 0;
    margin-left: 2.14286em;
    list-style-type: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_list.scss:8 */
.fa-ul > li {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_list.scss:10 */
.fa-li {
    position: absolute;
    left: -2.14286em;
    width: 2.14286em;
    top: 0.14286em;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_list.scss:16 */
.fa-li.fa-lg {
    left: -1.85714em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:4 */
.fa-border {
    padding: 0.2em 0.25em 0.15em;
    border: solid 0.08em #eee;
    border-radius: 0.1em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:10 */
.fa-pull-left {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:11 */
.fa-pull-right {
    float: right;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:14 */
.fa.fa-pull-left {
    margin-right: 0.3em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:15 */
.fa.fa-pull-right {
    margin-left: 0.3em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:19 */
.pull-right {
    /* Deprecated as of 4.4.0 */
    float: right;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:20 */
.pull-left {
    float: left;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:23 */
.fa.pull-left {
    margin-right: 0.3em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_bordered-pulled.scss:24 */
.fa.pull-right {
    margin-left: 0.3em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:4 */
.fa-spin {
    -webkit-animation: fa-spin 2s infinite linear;
    animation: fa-spin 2s infinite linear;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:9 */
.fa-pulse {
    -webkit-animation: fa-spin 1s infinite steps(8);
    animation: fa-spin 1s infinite steps(8);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:14 */
@-webkit-keyframes fa-spin {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:15 */
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg);
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:19 */
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg);
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:25 */
@keyframes fa-spin {
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:26 */
    0% {
        -webkit-transform: rotate(0deg);
        transform: rotate(0deg);
    }
    /* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_animated.scss:30 */
    100% {
        -webkit-transform: rotate(359deg);
        transform: rotate(359deg);
    }
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_rotated-flipped.scss:4 */
.fa-rotate-90 {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=1)";
    -webkit-transform: rotate(90deg);
    -ms-transform: rotate(90deg);
    transform: rotate(90deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_rotated-flipped.scss:5 */
.fa-rotate-180 {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2)";
    -webkit-transform: rotate(180deg);
    -ms-transform: rotate(180deg);
    transform: rotate(180deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_rotated-flipped.scss:6 */
.fa-rotate-270 {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=3)";
    -webkit-transform: rotate(270deg);
    -ms-transform: rotate(270deg);
    transform: rotate(270deg);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_rotated-flipped.scss:8 */
.fa-flip-horizontal {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=0, mirror=1)";
    -webkit-transform: scale(-1, 1);
    -ms-transform: scale(-1, 1);
    transform: scale(-1, 1);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_rotated-flipped.scss:9 */
.fa-flip-vertical {
    -ms-filter: "progid:DXImageTransform.Microsoft.BasicImage(rotation=2, mirror=1)";
    -webkit-transform: scale(1, -1);
    -ms-transform: scale(1, -1);
    transform: scale(1, -1);
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_rotated-flipped.scss:14 */
:root .fa-rotate-90,
:root .fa-rotate-180,
:root .fa-rotate-270,
:root .fa-flip-horizontal,
:root .fa-flip-vertical {
    filter: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_stacked.scss:4 */
.fa-stack {
    position: relative;
    display: inline-block;
    width: 2em;
    height: 2em;
    line-height: 2em;
    vertical-align: middle;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_stacked.scss:12 */
.fa-stack-1x,
.fa-stack-2x {
    position: absolute;
    left: 0;
    width: 100%;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_stacked.scss:18 */
.fa-stack-1x {
    line-height: inherit;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_stacked.scss:19 */
.fa-stack-2x {
    font-size: 2em;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_stacked.scss:20 */
.fa-inverse {
    color: #fff;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:14 */
.fa-glass:before {
    content: "\f000" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:15 */
.fa-music:before {
    content: "\f001" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:16 */
.fa-search:before {
    content: "\f002" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:17 */
.fa-envelope-o:before {
    content: "\f003" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:18 */
.fa-heart:before {
    content: "\f004" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:19 */
.fa-star:before {
    content: "\f005" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:20 */
.fa-star-o:before {
    content: "\f006" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:21 */
.fa-user:before {
    content: "\f007" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:22 */
.fa-film:before {
    content: "\f008" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:23 */
.fa-th-large:before {
    content: "\f009" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:24 */
.fa-th:before {
    content: "\f00a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:25 */
.fa-th-list:before {
    content: "\f00b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:26 */
.fa-check:before {
    content: "\f00c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:27 */
.fa-remove:before,
.fa-close:before,
.fa-times:before {
    content: "\f00d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:30 */
.fa-search-plus:before {
    content: "\f00e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:31 */
.fa-search-minus:before {
    content: "\f010" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:32 */
.fa-power-off:before {
    content: "\f011" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:33 */
.fa-signal:before {
    content: "\f012" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:34 */
.fa-gear:before,
.fa-cog:before {
    content: "\f013" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:36 */
.fa-trash-o:before {
    content: "\f014" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:37 */
.fa-home:before {
    content: "\f015" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:38 */
.fa-file-o:before {
    content: "\f016" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:39 */
.fa-clock-o:before {
    content: "\f017" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:40 */
.fa-road:before {
    content: "\f018" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:41 */
.fa-download:before {
    content: "\f019" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:42 */
.fa-arrow-circle-o-down:before {
    content: "\f01a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:43 */
.fa-arrow-circle-o-up:before {
    content: "\f01b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:44 */
.fa-inbox:before {
    content: "\f01c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:45 */
.fa-play-circle-o:before {
    content: "\f01d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:46 */
.fa-rotate-right:before,
.fa-repeat:before {
    content: "\f01e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:48 */
.fa-refresh:before {
    content: "\f021" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:49 */
.fa-list-alt:before {
    content: "\f022" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:50 */
.fa-lock:before {
    content: "\f023" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:51 */
.fa-flag:before {
    content: "\f024" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:52 */
.fa-headphones:before {
    content: "\f025" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:53 */
.fa-volume-off:before {
    content: "\f026" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:54 */
.fa-volume-down:before {
    content: "\f027" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:55 */
.fa-volume-up:before {
    content: "\f028" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:56 */
.fa-qrcode:before {
    content: "\f029" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:57 */
.fa-barcode:before {
    content: "\f02a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:58 */
.fa-tag:before {
    content: "\f02b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:59 */
.fa-tags:before {
    content: "\f02c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:60 */
.fa-book:before {
    content: "\f02d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:61 */
.fa-bookmark:before {
    content: "\f02e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:62 */
.fa-print:before {
    content: "\f02f" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:63 */
.fa-camera:before {
    content: "\f030" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:64 */
.fa-font:before {
    content: "\f031" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:65 */
.fa-bold:before {
    content: "\f032" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:66 */
.fa-italic:before {
    content: "\f033" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:67 */
.fa-text-height:before {
    content: "\f034" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:68 */
.fa-text-width:before {
    content: "\f035" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:69 */
.fa-align-left:before {
    content: "\f036" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:70 */
.fa-align-center:before {
    content: "\f037" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:71 */
.fa-align-right:before {
    content: "\f038" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:72 */
.fa-align-justify:before {
    content: "\f039" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:73 */
.fa-list:before {
    content: "\f03a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:74 */
.fa-dedent:before,
.fa-outdent:before {
    content: "\f03b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:76 */
.fa-indent:before {
    content: "\f03c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:77 */
.fa-video-camera:before {
    content: "\f03d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:78 */
.fa-photo:before,
.fa-image:before,
.fa-picture-o:before {
    content: "\f03e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:81 */
.fa-pencil:before {
    content: "\f040" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:82 */
.fa-map-marker:before {
    content: "\f041" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:83 */
.fa-adjust:before {
    content: "\f042" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:84 */
.fa-tint:before {
    content: "\f043" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:85 */
.fa-edit:before,
.fa-pencil-square-o:before {
    content: "\f044" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:87 */
.fa-share-square-o:before {
    content: "\f045" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:88 */
.fa-check-square-o:before {
    content: "\f046" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:89 */
.fa-arrows:before {
    content: "\f047" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:90 */
.fa-step-backward:before {
    content: "\f048" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:91 */
.fa-fast-backward:before {
    content: "\f049" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:92 */
.fa-backward:before {
    content: "\f04a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:93 */
.fa-play:before {
    content: "\f04b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:94 */
.fa-pause:before {
    content: "\f04c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:95 */
.fa-stop:before {
    content: "\f04d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:96 */
.fa-forward:before {
    content: "\f04e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:97 */
.fa-fast-forward:before {
    content: "\f050" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:98 */
.fa-step-forward:before {
    content: "\f051" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:99 */
.fa-eject:before {
    content: "\f052" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:100 */
.fa-chevron-left:before {
    content: "\f053" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:101 */
.fa-chevron-right:before {
    content: "\f054" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:102 */
.fa-plus-circle:before {
    content: "\f055" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:103 */
.fa-minus-circle:before {
    content: "\f056" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:104 */
.fa-times-circle:before {
    content: "\f057" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:105 */
.fa-check-circle:before {
    content: "\f058" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:106 */
.fa-question-circle:before {
    content: "\f059" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:107 */
.fa-info-circle:before {
    content: "\f05a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:108 */
.fa-crosshairs:before {
    content: "\f05b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:109 */
.fa-times-circle-o:before {
    content: "\f05c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:110 */
.fa-check-circle-o:before {
    content: "\f05d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:111 */
.fa-ban:before {
    content: "\f05e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:112 */
.fa-arrow-left:before {
    content: "\f060" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:113 */
.fa-arrow-right:before {
    content: "\f061" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:114 */
.fa-arrow-up:before {
    content: "\f062" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:115 */
.fa-arrow-down:before {
    content: "\f063" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:116 */
.fa-mail-forward:before,
.fa-share:before {
    content: "\f064" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:118 */
.fa-expand:before {
    content: "\f065" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:119 */
.fa-compress:before {
    content: "\f066" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:120 */
.fa-plus:before {
    content: "\f067" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:121 */
.fa-minus:before {
    content: "\f068" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:122 */
.fa-asterisk:before {
    content: "\f069" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:123 */
.fa-exclamation-circle:before {
    content: "\f06a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:124 */
.fa-gift:before {
    content: "\f06b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:125 */
.fa-leaf:before {
    content: "\f06c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:126 */
.fa-fire:before {
    content: "\f06d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:127 */
.fa-eye:before {
    content: "\f06e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:128 */
.fa-eye-slash:before {
    content: "\f070" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:129 */
.fa-warning:before,
.fa-exclamation-triangle:before {
    content: "\f071" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:131 */
.fa-plane:before {
    content: "\f072" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:132 */
.fa-calendar:before {
    content: "\f073" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:133 */
.fa-random:before {
    content: "\f074" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:134 */
.fa-comment:before {
    content: "\f075" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:135 */
.fa-magnet:before {
    content: "\f076" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:136 */
.fa-chevron-up:before {
    content: "\f077" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:137 */
.fa-chevron-down:before {
    content: "\f078" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:138 */
.fa-retweet:before {
    content: "\f079" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:139 */
.fa-shopping-cart:before {
    content: "\f07a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:140 */
.fa-folder:before {
    content: "\f07b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:141 */
.fa-folder-open:before {
    content: "\f07c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:142 */
.fa-arrows-v:before {
    content: "\f07d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:143 */
.fa-arrows-h:before {
    content: "\f07e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:144 */
.fa-bar-chart-o:before,
.fa-bar-chart:before {
    content: "\f080" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:146 */
.fa-twitter-square:before {
    content: "\f081" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:147 */
.fa-facebook-square:before {
    content: "\f082" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:148 */
.fa-camera-retro:before {
    content: "\f083" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:149 */
.fa-key:before {
    content: "\f084" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:150 */
.fa-gears:before,
.fa-cogs:before {
    content: "\f085" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:152 */
.fa-comments:before {
    content: "\f086" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:153 */
.fa-thumbs-o-up:before {
    content: "\f087" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:154 */
.fa-thumbs-o-down:before {
    content: "\f088" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:155 */
.fa-star-half:before {
    content: "\f089" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:156 */
.fa-heart-o:before {
    content: "\f08a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:157 */
.fa-sign-out:before {
    content: "\f08b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:158 */
.fa-linkedin-square:before {
    content: "\f08c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:159 */
.fa-thumb-tack:before {
    content: "\f08d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:160 */
.fa-external-link:before {
    content: "\f08e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:161 */
.fa-sign-in:before {
    content: "\f090" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:162 */
.fa-trophy:before {
    content: "\f091" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:163 */
.fa-github-square:before {
    content: "\f092" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:164 */
.fa-upload:before {
    content: "\f093" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:165 */
.fa-lemon-o:before {
    content: "\f094" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:166 */
.fa-phone:before {
    content: "\f095" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:167 */
.fa-square-o:before {
    content: "\f096" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:168 */
.fa-bookmark-o:before {
    content: "\f097" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:169 */
.fa-phone-square:before {
    content: "\f098" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:170 */
.fa-twitter:before {
    content: "\f099" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:171 */
.fa-facebook-f:before,
.fa-facebook:before {
    content: "\f09a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:173 */
.fa-github:before {
    content: "\f09b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:174 */
.fa-unlock:before {
    content: "\f09c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:175 */
.fa-credit-card:before {
    content: "\f09d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:176 */
.fa-feed:before,
.fa-rss:before {
    content: "\f09e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:178 */
.fa-hdd-o:before {
    content: "\f0a0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:179 */
.fa-bullhorn:before {
    content: "\f0a1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:180 */
.fa-bell:before {
    content: "\f0f3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:181 */
.fa-certificate:before {
    content: "\f0a3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:182 */
.fa-hand-o-right:before {
    content: "\f0a4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:183 */
.fa-hand-o-left:before {
    content: "\f0a5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:184 */
.fa-hand-o-up:before {
    content: "\f0a6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:185 */
.fa-hand-o-down:before {
    content: "\f0a7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:186 */
.fa-arrow-circle-left:before {
    content: "\f0a8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:187 */
.fa-arrow-circle-right:before {
    content: "\f0a9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:188 */
.fa-arrow-circle-up:before {
    content: "\f0aa" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:189 */
.fa-arrow-circle-down:before {
    content: "\f0ab" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:190 */
.fa-globe:before {
    content: "\f0ac" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:191 */
.fa-wrench:before {
    content: "\f0ad" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:192 */
.fa-tasks:before {
    content: "\f0ae" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:193 */
.fa-filter:before {
    content: "\f0b0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:194 */
.fa-briefcase:before {
    content: "\f0b1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:195 */
.fa-arrows-alt:before {
    content: "\f0b2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:196 */
.fa-group:before,
.fa-users:before {
    content: "\f0c0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:198 */
.fa-chain:before,
.fa-link:before {
    content: "\f0c1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:200 */
.fa-cloud:before {
    content: "\f0c2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:201 */
.fa-flask:before {
    content: "\f0c3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:202 */
.fa-cut:before,
.fa-scissors:before {
    content: "\f0c4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:204 */
.fa-copy:before,
.fa-files-o:before {
    content: "\f0c5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:206 */
.fa-paperclip:before {
    content: "\f0c6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:207 */
.fa-save:before,
.fa-floppy-o:before {
    content: "\f0c7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:209 */
.fa-square:before {
    content: "\f0c8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:210 */
.fa-navicon:before,
.fa-reorder:before,
.fa-bars:before {
    content: "\f0c9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:213 */
.fa-list-ul:before {
    content: "\f0ca" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:214 */
.fa-list-ol:before {
    content: "\f0cb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:215 */
.fa-strikethrough:before {
    content: "\f0cc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:216 */
.fa-underline:before {
    content: "\f0cd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:217 */
.fa-table:before {
    content: "\f0ce" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:218 */
.fa-magic:before {
    content: "\f0d0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:219 */
.fa-truck:before {
    content: "\f0d1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:220 */
.fa-pinterest:before {
    content: "\f0d2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:221 */
.fa-pinterest-square:before {
    content: "\f0d3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:222 */
.fa-google-plus-square:before {
    content: "\f0d4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:223 */
.fa-google-plus:before {
    content: "\f0d5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:224 */
.fa-money:before {
    content: "\f0d6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:225 */
.fa-caret-down:before {
    content: "\f0d7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:226 */
.fa-caret-up:before {
    content: "\f0d8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:227 */
.fa-caret-left:before {
    content: "\f0d9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:228 */
.fa-caret-right:before {
    content: "\f0da" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:229 */
.fa-columns:before {
    content: "\f0db" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:230 */
.fa-unsorted:before,
.fa-sort:before {
    content: "\f0dc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:232 */
.fa-sort-down:before,
.fa-sort-desc:before {
    content: "\f0dd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:234 */
.fa-sort-up:before,
.fa-sort-asc:before {
    content: "\f0de" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:236 */
.fa-envelope:before {
    content: "\f0e0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:237 */
.fa-linkedin:before {
    content: "\f0e1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:238 */
.fa-rotate-left:before,
.fa-undo:before {
    content: "\f0e2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:240 */
.fa-legal:before,
.fa-gavel:before {
    content: "\f0e3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:242 */
.fa-dashboard:before,
.fa-tachometer:before {
    content: "\f0e4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:244 */
.fa-comment-o:before {
    content: "\f0e5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:245 */
.fa-comments-o:before {
    content: "\f0e6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:246 */
.fa-flash:before,
.fa-bolt:before {
    content: "\f0e7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:248 */
.fa-sitemap:before {
    content: "\f0e8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:249 */
.fa-umbrella:before {
    content: "\f0e9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:250 */
.fa-paste:before,
.fa-clipboard:before {
    content: "\f0ea" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:252 */
.fa-lightbulb-o:before {
    content: "\f0eb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:253 */
.fa-exchange:before {
    content: "\f0ec" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:254 */
.fa-cloud-download:before {
    content: "\f0ed" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:255 */
.fa-cloud-upload:before {
    content: "\f0ee" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:256 */
.fa-user-md:before {
    content: "\f0f0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:257 */
.fa-stethoscope:before {
    content: "\f0f1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:258 */
.fa-suitcase:before {
    content: "\f0f2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:259 */
.fa-bell-o:before {
    content: "\f0a2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:260 */
.fa-coffee:before {
    content: "\f0f4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:261 */
.fa-cutlery:before {
    content: "\f0f5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:262 */
.fa-file-text-o:before {
    content: "\f0f6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:263 */
.fa-building-o:before {
    content: "\f0f7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:264 */
.fa-hospital-o:before {
    content: "\f0f8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:265 */
.fa-ambulance:before {
    content: "\f0f9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:266 */
.fa-medkit:before {
    content: "\f0fa" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:267 */
.fa-fighter-jet:before {
    content: "\f0fb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:268 */
.fa-beer:before {
    content: "\f0fc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:269 */
.fa-h-square:before {
    content: "\f0fd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:270 */
.fa-plus-square:before {
    content: "\f0fe" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:271 */
.fa-angle-double-left:before {
    content: "\f100" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:272 */
.fa-angle-double-right:before {
    content: "\f101" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:273 */
.fa-angle-double-up:before {
    content: "\f102" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:274 */
.fa-angle-double-down:before {
    content: "\f103" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:275 */
.fa-angle-left:before {
    content: "\f104" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:276 */
.fa-angle-right:before {
    content: "\f105" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:277 */
.fa-angle-up:before {
    content: "\f106" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:278 */
.fa-angle-down:before {
    content: "\f107" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:279 */
.fa-desktop:before {
    content: "\f108" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:280 */
.fa-laptop:before {
    content: "\f109" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:281 */
.fa-tablet:before {
    content: "\f10a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:282 */
.fa-mobile-phone:before,
.fa-mobile:before {
    content: "\f10b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:284 */
.fa-circle-o:before {
    content: "\f10c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:285 */
.fa-quote-left:before {
    content: "\f10d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:286 */
.fa-quote-right:before {
    content: "\f10e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:287 */
.fa-spinner:before {
    content: "\f110" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:288 */
.fa-circle:before {
    content: "\f111" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:289 */
.fa-mail-reply:before,
.fa-reply:before {
    content: "\f112" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:291 */
.fa-github-alt:before {
    content: "\f113" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:292 */
.fa-folder-o:before {
    content: "\f114" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:293 */
.fa-folder-open-o:before {
    content: "\f115" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:294 */
.fa-smile-o:before {
    content: "\f118" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:295 */
.fa-frown-o:before {
    content: "\f119" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:296 */
.fa-meh-o:before {
    content: "\f11a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:297 */
.fa-gamepad:before {
    content: "\f11b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:298 */
.fa-keyboard-o:before {
    content: "\f11c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:299 */
.fa-flag-o:before {
    content: "\f11d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:300 */
.fa-flag-checkered:before {
    content: "\f11e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:301 */
.fa-terminal:before {
    content: "\f120" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:302 */
.fa-code:before {
    content: "\f121" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:303 */
.fa-mail-reply-all:before,
.fa-reply-all:before {
    content: "\f122" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:305 */
.fa-star-half-empty:before,
.fa-star-half-full:before,
.fa-star-half-o:before {
    content: "\f123" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:308 */
.fa-location-arrow:before {
    content: "\f124" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:309 */
.fa-crop:before {
    content: "\f125" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:310 */
.fa-code-fork:before {
    content: "\f126" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:311 */
.fa-unlink:before,
.fa-chain-broken:before {
    content: "\f127" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:313 */
.fa-question:before {
    content: "\f128" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:314 */
.fa-info:before {
    content: "\f129" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:315 */
.fa-exclamation:before {
    content: "\f12a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:316 */
.fa-superscript:before {
    content: "\f12b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:317 */
.fa-subscript:before {
    content: "\f12c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:318 */
.fa-eraser:before {
    content: "\f12d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:319 */
.fa-puzzle-piece:before {
    content: "\f12e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:320 */
.fa-microphone:before {
    content: "\f130" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:321 */
.fa-microphone-slash:before {
    content: "\f131" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:322 */
.fa-shield:before {
    content: "\f132" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:323 */
.fa-calendar-o:before {
    content: "\f133" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:324 */
.fa-fire-extinguisher:before {
    content: "\f134" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:325 */
.fa-rocket:before {
    content: "\f135" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:326 */
.fa-maxcdn:before {
    content: "\f136" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:327 */
.fa-chevron-circle-left:before {
    content: "\f137" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:328 */
.fa-chevron-circle-right:before {
    content: "\f138" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:329 */
.fa-chevron-circle-up:before {
    content: "\f139" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:330 */
.fa-chevron-circle-down:before {
    content: "\f13a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:331 */
.fa-html5:before {
    content: "\f13b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:332 */
.fa-css3:before {
    content: "\f13c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:333 */
.fa-anchor:before {
    content: "\f13d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:334 */
.fa-unlock-alt:before {
    content: "\f13e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:335 */
.fa-bullseye:before {
    content: "\f140" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:336 */
.fa-ellipsis-h:before {
    content: "\f141" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:337 */
.fa-ellipsis-v:before {
    content: "\f142" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:338 */
.fa-rss-square:before {
    content: "\f143" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:339 */
.fa-play-circle:before {
    content: "\f144" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:340 */
.fa-ticket:before {
    content: "\f145" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:341 */
.fa-minus-square:before {
    content: "\f146" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:342 */
.fa-minus-square-o:before {
    content: "\f147" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:343 */
.fa-level-up:before {
    content: "\f148" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:344 */
.fa-level-down:before {
    content: "\f149" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:345 */
.fa-check-square:before {
    content: "\f14a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:346 */
.fa-pencil-square:before {
    content: "\f14b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:347 */
.fa-external-link-square:before {
    content: "\f14c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:348 */
.fa-share-square:before {
    content: "\f14d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:349 */
.fa-compass:before {
    content: "\f14e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:350 */
.fa-toggle-down:before,
.fa-caret-square-o-down:before {
    content: "\f150" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:352 */
.fa-toggle-up:before,
.fa-caret-square-o-up:before {
    content: "\f151" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:354 */
.fa-toggle-right:before,
.fa-caret-square-o-right:before {
    content: "\f152" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:356 */
.fa-euro:before,
.fa-eur:before {
    content: "\f153" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:358 */
.fa-gbp:before {
    content: "\f154" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:359 */
.fa-dollar:before,
.fa-usd:before {
    content: "\f155" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:361 */
.fa-rupee:before,
.fa-inr:before {
    content: "\f156" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:363 */
.fa-cny:before,
.fa-rmb:before,
.fa-yen:before,
.fa-jpy:before {
    content: "\f157" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:367 */
.fa-ruble:before,
.fa-rouble:before,
.fa-rub:before {
    content: "\f158" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:370 */
.fa-won:before,
.fa-krw:before {
    content: "\f159" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:372 */
.fa-bitcoin:before,
.fa-btc:before {
    content: "\f15a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:374 */
.fa-file:before {
    content: "\f15b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:375 */
.fa-file-text:before {
    content: "\f15c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:376 */
.fa-sort-alpha-asc:before {
    content: "\f15d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:377 */
.fa-sort-alpha-desc:before {
    content: "\f15e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:378 */
.fa-sort-amount-asc:before {
    content: "\f160" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:379 */
.fa-sort-amount-desc:before {
    content: "\f161" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:380 */
.fa-sort-numeric-asc:before {
    content: "\f162" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:381 */
.fa-sort-numeric-desc:before {
    content: "\f163" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:382 */
.fa-thumbs-up:before {
    content: "\f164" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:383 */
.fa-thumbs-down:before {
    content: "\f165" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:384 */
.fa-youtube-square:before {
    content: "\f166" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:385 */
.fa-youtube:before {
    content: "\f167" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:386 */
.fa-xing:before {
    content: "\f168" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:387 */
.fa-xing-square:before {
    content: "\f169" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:388 */
.fa-youtube-play:before {
    content: "\f16a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:389 */
.fa-dropbox:before {
    content: "\f16b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:390 */
.fa-stack-overflow:before {
    content: "\f16c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:391 */
.fa-instagram:before {
    content: "\f16d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:392 */
.fa-flickr:before {
    content: "\f16e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:393 */
.fa-adn:before {
    content: "\f170" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:394 */
.fa-bitbucket:before {
    content: "\f171" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:395 */
.fa-bitbucket-square:before {
    content: "\f172" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:396 */
.fa-tumblr:before {
    content: "\f173" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:397 */
.fa-tumblr-square:before {
    content: "\f174" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:398 */
.fa-long-arrow-down:before {
    content: "\f175" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:399 */
.fa-long-arrow-up:before {
    content: "\f176" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:400 */
.fa-long-arrow-left:before {
    content: "\f177" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:401 */
.fa-long-arrow-right:before {
    content: "\f178" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:402 */
.fa-apple:before {
    content: "\f179" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:403 */
.fa-windows:before {
    content: "\f17a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:404 */
.fa-android:before {
    content: "\f17b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:405 */
.fa-linux:before {
    content: "\f17c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:406 */
.fa-dribbble:before {
    content: "\f17d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:407 */
.fa-skype:before {
    content: "\f17e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:408 */
.fa-foursquare:before {
    content: "\f180" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:409 */
.fa-trello:before {
    content: "\f181" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:410 */
.fa-female:before {
    content: "\f182" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:411 */
.fa-male:before {
    content: "\f183" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:412 */
.fa-gittip:before,
.fa-gratipay:before {
    content: "\f184" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:414 */
.fa-sun-o:before {
    content: "\f185" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:415 */
.fa-moon-o:before {
    content: "\f186" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:416 */
.fa-archive:before {
    content: "\f187" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:417 */
.fa-bug:before {
    content: "\f188" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:418 */
.fa-vk:before {
    content: "\f189" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:419 */
.fa-weibo:before {
    content: "\f18a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:420 */
.fa-renren:before {
    content: "\f18b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:421 */
.fa-pagelines:before {
    content: "\f18c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:422 */
.fa-stack-exchange:before {
    content: "\f18d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:423 */
.fa-arrow-circle-o-right:before {
    content: "\f18e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:424 */
.fa-arrow-circle-o-left:before {
    content: "\f190" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:425 */
.fa-toggle-left:before,
.fa-caret-square-o-left:before {
    content: "\f191" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:427 */
.fa-dot-circle-o:before {
    content: "\f192" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:428 */
.fa-wheelchair:before {
    content: "\f193" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:429 */
.fa-vimeo-square:before {
    content: "\f194" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:430 */
.fa-turkish-lira:before,
.fa-try:before {
    content: "\f195" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:432 */
.fa-plus-square-o:before {
    content: "\f196" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:433 */
.fa-space-shuttle:before {
    content: "\f197" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:434 */
.fa-slack:before {
    content: "\f198" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:435 */
.fa-envelope-square:before {
    content: "\f199" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:436 */
.fa-wordpress:before {
    content: "\f19a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:437 */
.fa-openid:before {
    content: "\f19b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:438 */
.fa-institution:before,
.fa-bank:before,
.fa-university:before {
    content: "\f19c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:441 */
.fa-mortar-board:before,
.fa-graduation-cap:before {
    content: "\f19d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:443 */
.fa-yahoo:before {
    content: "\f19e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:444 */
.fa-google:before {
    content: "\f1a0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:445 */
.fa-reddit:before {
    content: "\f1a1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:446 */
.fa-reddit-square:before {
    content: "\f1a2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:447 */
.fa-stumbleupon-circle:before {
    content: "\f1a3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:448 */
.fa-stumbleupon:before {
    content: "\f1a4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:449 */
.fa-delicious:before {
    content: "\f1a5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:450 */
.fa-digg:before {
    content: "\f1a6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:451 */
.fa-pied-piper-pp:before {
    content: "\f1a7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:452 */
.fa-pied-piper-alt:before {
    content: "\f1a8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:453 */
.fa-drupal:before {
    content: "\f1a9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:454 */
.fa-joomla:before {
    content: "\f1aa" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:455 */
.fa-language:before {
    content: "\f1ab" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:456 */
.fa-fax:before {
    content: "\f1ac" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:457 */
.fa-building:before {
    content: "\f1ad" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:458 */
.fa-child:before {
    content: "\f1ae" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:459 */
.fa-paw:before {
    content: "\f1b0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:460 */
.fa-spoon:before {
    content: "\f1b1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:461 */
.fa-cube:before {
    content: "\f1b2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:462 */
.fa-cubes:before {
    content: "\f1b3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:463 */
.fa-behance:before {
    content: "\f1b4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:464 */
.fa-behance-square:before {
    content: "\f1b5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:465 */
.fa-steam:before {
    content: "\f1b6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:466 */
.fa-steam-square:before {
    content: "\f1b7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:467 */
.fa-recycle:before {
    content: "\f1b8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:468 */
.fa-automobile:before,
.fa-car:before {
    content: "\f1b9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:470 */
.fa-cab:before,
.fa-taxi:before {
    content: "\f1ba" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:472 */
.fa-tree:before {
    content: "\f1bb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:473 */
.fa-spotify:before {
    content: "\f1bc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:474 */
.fa-deviantart:before {
    content: "\f1bd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:475 */
.fa-soundcloud:before {
    content: "\f1be" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:476 */
.fa-database:before {
    content: "\f1c0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:477 */
.fa-file-pdf-o:before {
    content: "\f1c1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:478 */
.fa-file-word-o:before {
    content: "\f1c2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:479 */
.fa-file-excel-o:before {
    content: "\f1c3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:480 */
.fa-file-powerpoint-o:before {
    content: "\f1c4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:481 */
.fa-file-photo-o:before,
.fa-file-picture-o:before,
.fa-file-image-o:before {
    content: "\f1c5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:484 */
.fa-file-zip-o:before,
.fa-file-archive-o:before {
    content: "\f1c6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:486 */
.fa-file-sound-o:before,
.fa-file-audio-o:before {
    content: "\f1c7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:488 */
.fa-file-movie-o:before,
.fa-file-video-o:before {
    content: "\f1c8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:490 */
.fa-file-code-o:before {
    content: "\f1c9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:491 */
.fa-vine:before {
    content: "\f1ca" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:492 */
.fa-codepen:before {
    content: "\f1cb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:493 */
.fa-jsfiddle:before {
    content: "\f1cc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:494 */
.fa-life-bouy:before,
.fa-life-buoy:before,
.fa-life-saver:before,
.fa-support:before,
.fa-life-ring:before {
    content: "\f1cd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:499 */
.fa-circle-o-notch:before {
    content: "\f1ce" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:500 */
.fa-ra:before,
.fa-resistance:before,
.fa-rebel:before {
    content: "\f1d0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:503 */
.fa-ge:before,
.fa-empire:before {
    content: "\f1d1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:505 */
.fa-git-square:before {
    content: "\f1d2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:506 */
.fa-git:before {
    content: "\f1d3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:507 */
.fa-y-combinator-square:before,
.fa-yc-square:before,
.fa-hacker-news:before {
    content: "\f1d4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:510 */
.fa-tencent-weibo:before {
    content: "\f1d5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:511 */
.fa-qq:before {
    content: "\f1d6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:512 */
.fa-wechat:before,
.fa-weixin:before {
    content: "\f1d7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:514 */
.fa-send:before,
.fa-paper-plane:before {
    content: "\f1d8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:516 */
.fa-send-o:before,
.fa-paper-plane-o:before {
    content: "\f1d9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:518 */
.fa-history:before {
    content: "\f1da" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:519 */
.fa-circle-thin:before {
    content: "\f1db" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:520 */
.fa-header:before {
    content: "\f1dc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:521 */
.fa-paragraph:before {
    content: "\f1dd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:522 */
.fa-sliders:before {
    content: "\f1de" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:523 */
.fa-share-alt:before {
    content: "\f1e0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:524 */
.fa-share-alt-square:before {
    content: "\f1e1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:525 */
.fa-bomb:before {
    content: "\f1e2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:526 */
.fa-soccer-ball-o:before,
.fa-futbol-o:before {
    content: "\f1e3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:528 */
.fa-tty:before {
    content: "\f1e4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:529 */
.fa-binoculars:before {
    content: "\f1e5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:530 */
.fa-plug:before {
    content: "\f1e6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:531 */
.fa-slideshare:before {
    content: "\f1e7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:532 */
.fa-twitch:before {
    content: "\f1e8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:533 */
.fa-yelp:before {
    content: "\f1e9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:534 */
.fa-newspaper-o:before {
    content: "\f1ea" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:535 */
.fa-wifi:before {
    content: "\f1eb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:536 */
.fa-calculator:before {
    content: "\f1ec" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:537 */
.fa-paypal:before {
    content: "\f1ed" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:538 */
.fa-google-wallet:before {
    content: "\f1ee" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:539 */
.fa-cc-visa:before {
    content: "\f1f0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:540 */
.fa-cc-mastercard:before {
    content: "\f1f1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:541 */
.fa-cc-discover:before {
    content: "\f1f2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:542 */
.fa-cc-amex:before {
    content: "\f1f3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:543 */
.fa-cc-paypal:before {
    content: "\f1f4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:544 */
.fa-cc-stripe:before {
    content: "\f1f5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:545 */
.fa-bell-slash:before {
    content: "\f1f6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:546 */
.fa-bell-slash-o:before {
    content: "\f1f7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:547 */
.fa-trash:before {
    content: "\f1f8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:548 */
.fa-copyright:before {
    content: "\f1f9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:549 */
.fa-at:before {
    content: "\f1fa" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:550 */
.fa-eyedropper:before {
    content: "\f1fb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:551 */
.fa-paint-brush:before {
    content: "\f1fc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:552 */
.fa-birthday-cake:before {
    content: "\f1fd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:553 */
.fa-area-chart:before {
    content: "\f1fe" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:554 */
.fa-pie-chart:before {
    content: "\f200" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:555 */
.fa-line-chart:before {
    content: "\f201" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:556 */
.fa-lastfm:before {
    content: "\f202" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:557 */
.fa-lastfm-square:before {
    content: "\f203" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:558 */
.fa-toggle-off:before {
    content: "\f204" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:559 */
.fa-toggle-on:before {
    content: "\f205" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:560 */
.fa-bicycle:before {
    content: "\f206" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:561 */
.fa-bus:before {
    content: "\f207" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:562 */
.fa-ioxhost:before {
    content: "\f208" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:563 */
.fa-angellist:before {
    content: "\f209" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:564 */
.fa-cc:before {
    content: "\f20a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:565 */
.fa-shekel:before,
.fa-sheqel:before,
.fa-ils:before {
    content: "\f20b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:568 */
.fa-meanpath:before {
    content: "\f20c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:569 */
.fa-buysellads:before {
    content: "\f20d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:570 */
.fa-connectdevelop:before {
    content: "\f20e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:571 */
.fa-dashcube:before {
    content: "\f210" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:572 */
.fa-forumbee:before {
    content: "\f211" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:573 */
.fa-leanpub:before {
    content: "\f212" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:574 */
.fa-sellsy:before {
    content: "\f213" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:575 */
.fa-shirtsinbulk:before {
    content: "\f214" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:576 */
.fa-simplybuilt:before {
    content: "\f215" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:577 */
.fa-skyatlas:before {
    content: "\f216" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:578 */
.fa-cart-plus:before {
    content: "\f217" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:579 */
.fa-cart-arrow-down:before {
    content: "\f218" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:580 */
.fa-diamond:before {
    content: "\f219" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:581 */
.fa-ship:before {
    content: "\f21a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:582 */
.fa-user-secret:before {
    content: "\f21b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:583 */
.fa-motorcycle:before {
    content: "\f21c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:584 */
.fa-street-view:before {
    content: "\f21d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:585 */
.fa-heartbeat:before {
    content: "\f21e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:586 */
.fa-venus:before {
    content: "\f221" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:587 */
.fa-mars:before {
    content: "\f222" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:588 */
.fa-mercury:before {
    content: "\f223" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:589 */
.fa-intersex:before,
.fa-transgender:before {
    content: "\f224" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:591 */
.fa-transgender-alt:before {
    content: "\f225" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:592 */
.fa-venus-double:before {
    content: "\f226" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:593 */
.fa-mars-double:before {
    content: "\f227" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:594 */
.fa-venus-mars:before {
    content: "\f228" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:595 */
.fa-mars-stroke:before {
    content: "\f229" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:596 */
.fa-mars-stroke-v:before {
    content: "\f22a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:597 */
.fa-mars-stroke-h:before {
    content: "\f22b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:598 */
.fa-neuter:before {
    content: "\f22c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:599 */
.fa-genderless:before {
    content: "\f22d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:600 */
.fa-facebook-official:before {
    content: "\f230" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:601 */
.fa-pinterest-p:before {
    content: "\f231" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:602 */
.fa-whatsapp:before {
    content: "\f232" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:603 */
.fa-server:before {
    content: "\f233" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:604 */
.fa-user-plus:before {
    content: "\f234" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:605 */
.fa-user-times:before {
    content: "\f235" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:606 */
.fa-hotel:before,
.fa-bed:before {
    content: "\f236" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:608 */
.fa-viacoin:before {
    content: "\f237" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:609 */
.fa-train:before {
    content: "\f238" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:610 */
.fa-subway:before {
    content: "\f239" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:611 */
.fa-medium:before {
    content: "\f23a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:612 */
.fa-yc:before,
.fa-y-combinator:before {
    content: "\f23b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:614 */
.fa-optin-monster:before {
    content: "\f23c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:615 */
.fa-opencart:before {
    content: "\f23d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:616 */
.fa-expeditedssl:before {
    content: "\f23e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:617 */
.fa-battery-4:before,
.fa-battery:before,
.fa-battery-full:before {
    content: "\f240" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:620 */
.fa-battery-3:before,
.fa-battery-three-quarters:before {
    content: "\f241" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:622 */
.fa-battery-2:before,
.fa-battery-half:before {
    content: "\f242" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:624 */
.fa-battery-1:before,
.fa-battery-quarter:before {
    content: "\f243" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:626 */
.fa-battery-0:before,
.fa-battery-empty:before {
    content: "\f244" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:628 */
.fa-mouse-pointer:before {
    content: "\f245" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:629 */
.fa-i-cursor:before {
    content: "\f246" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:630 */
.fa-object-group:before {
    content: "\f247" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:631 */
.fa-object-ungroup:before {
    content: "\f248" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:632 */
.fa-sticky-note:before {
    content: "\f249" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:633 */
.fa-sticky-note-o:before {
    content: "\f24a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:634 */
.fa-cc-jcb:before {
    content: "\f24b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:635 */
.fa-cc-diners-club:before {
    content: "\f24c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:636 */
.fa-clone:before {
    content: "\f24d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:637 */
.fa-balance-scale:before {
    content: "\f24e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:638 */
.fa-hourglass-o:before {
    content: "\f250" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:639 */
.fa-hourglass-1:before,
.fa-hourglass-start:before {
    content: "\f251" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:641 */
.fa-hourglass-2:before,
.fa-hourglass-half:before {
    content: "\f252" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:643 */
.fa-hourglass-3:before,
.fa-hourglass-end:before {
    content: "\f253" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:645 */
.fa-hourglass:before {
    content: "\f254" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:646 */
.fa-hand-grab-o:before,
.fa-hand-rock-o:before {
    content: "\f255" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:648 */
.fa-hand-stop-o:before,
.fa-hand-paper-o:before {
    content: "\f256" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:650 */
.fa-hand-scissors-o:before {
    content: "\f257" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:651 */
.fa-hand-lizard-o:before {
    content: "\f258" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:652 */
.fa-hand-spock-o:before {
    content: "\f259" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:653 */
.fa-hand-pointer-o:before {
    content: "\f25a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:654 */
.fa-hand-peace-o:before {
    content: "\f25b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:655 */
.fa-trademark:before {
    content: "\f25c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:656 */
.fa-registered:before {
    content: "\f25d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:657 */
.fa-creative-commons:before {
    content: "\f25e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:658 */
.fa-gg:before {
    content: "\f260" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:659 */
.fa-gg-circle:before {
    content: "\f261" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:660 */
.fa-tripadvisor:before {
    content: "\f262" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:661 */
.fa-odnoklassniki:before {
    content: "\f263" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:662 */
.fa-odnoklassniki-square:before {
    content: "\f264" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:663 */
.fa-get-pocket:before {
    content: "\f265" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:664 */
.fa-wikipedia-w:before {
    content: "\f266" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:665 */
.fa-safari:before {
    content: "\f267" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:666 */
.fa-chrome:before {
    content: "\f268" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:667 */
.fa-firefox:before {
    content: "\f269" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:668 */
.fa-opera:before {
    content: "\f26a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:669 */
.fa-internet-explorer:before {
    content: "\f26b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:670 */
.fa-tv:before,
.fa-television:before {
    content: "\f26c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:672 */
.fa-contao:before {
    content: "\f26d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:673 */
.fa-500px:before {
    content: "\f26e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:674 */
.fa-amazon:before {
    content: "\f270" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:675 */
.fa-calendar-plus-o:before {
    content: "\f271" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:676 */
.fa-calendar-minus-o:before {
    content: "\f272" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:677 */
.fa-calendar-times-o:before {
    content: "\f273" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:678 */
.fa-calendar-check-o:before {
    content: "\f274" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:679 */
.fa-industry:before {
    content: "\f275" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:680 */
.fa-map-pin:before {
    content: "\f276" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:681 */
.fa-map-signs:before {
    content: "\f277" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:682 */
.fa-map-o:before {
    content: "\f278" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:683 */
.fa-map:before {
    content: "\f279" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:684 */
.fa-commenting:before {
    content: "\f27a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:685 */
.fa-commenting-o:before {
    content: "\f27b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:686 */
.fa-houzz:before {
    content: "\f27c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:687 */
.fa-vimeo:before {
    content: "\f27d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:688 */
.fa-black-tie:before {
    content: "\f27e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:689 */
.fa-fonticons:before {
    content: "\f280" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:690 */
.fa-reddit-alien:before {
    content: "\f281" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:691 */
.fa-edge:before {
    content: "\f282" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:692 */
.fa-credit-card-alt:before {
    content: "\f283" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:693 */
.fa-codiepie:before {
    content: "\f284" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:694 */
.fa-modx:before {
    content: "\f285" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:695 */
.fa-fort-awesome:before {
    content: "\f286" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:696 */
.fa-usb:before {
    content: "\f287" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:697 */
.fa-product-hunt:before {
    content: "\f288" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:698 */
.fa-mixcloud:before {
    content: "\f289" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:699 */
.fa-scribd:before {
    content: "\f28a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:700 */
.fa-pause-circle:before {
    content: "\f28b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:701 */
.fa-pause-circle-o:before {
    content: "\f28c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:702 */
.fa-stop-circle:before {
    content: "\f28d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:703 */
.fa-stop-circle-o:before {
    content: "\f28e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:704 */
.fa-shopping-bag:before {
    content: "\f290" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:705 */
.fa-shopping-basket:before {
    content: "\f291" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:706 */
.fa-hashtag:before {
    content: "\f292" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:707 */
.fa-bluetooth:before {
    content: "\f293" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:708 */
.fa-bluetooth-b:before {
    content: "\f294" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:709 */
.fa-percent:before {
    content: "\f295" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:710 */
.fa-gitlab:before {
    content: "\f296" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:711 */
.fa-wpbeginner:before {
    content: "\f297" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:712 */
.fa-wpforms:before {
    content: "\f298" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:713 */
.fa-envira:before {
    content: "\f299" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:714 */
.fa-universal-access:before {
    content: "\f29a" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:715 */
.fa-wheelchair-alt:before {
    content: "\f29b" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:716 */
.fa-question-circle-o:before {
    content: "\f29c" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:717 */
.fa-blind:before {
    content: "\f29d" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:718 */
.fa-audio-description:before {
    content: "\f29e" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:719 */
.fa-volume-control-phone:before {
    content: "\f2a0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:720 */
.fa-braille:before {
    content: "\f2a1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:721 */
.fa-assistive-listening-systems:before {
    content: "\f2a2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:722 */
.fa-asl-interpreting:before,
.fa-american-sign-language-interpreting:before {
    content: "\f2a3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:724 */
.fa-deafness:before,
.fa-hard-of-hearing:before,
.fa-deaf:before {
    content: "\f2a4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:727 */
.fa-glide:before {
    content: "\f2a5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:728 */
.fa-glide-g:before {
    content: "\f2a6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:729 */
.fa-signing:before,
.fa-sign-language:before {
    content: "\f2a7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:731 */
.fa-low-vision:before {
    content: "\f2a8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:732 */
.fa-viadeo:before {
    content: "\f2a9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:733 */
.fa-viadeo-square:before {
    content: "\f2aa" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:734 */
.fa-snapchat:before {
    content: "\f2ab" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:735 */
.fa-snapchat-ghost:before {
    content: "\f2ac" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:736 */
.fa-snapchat-square:before {
    content: "\f2ad" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:737 */
.fa-pied-piper:before {
    content: "\f2ae" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:738 */
.fa-first-order:before {
    content: "\f2b0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:739 */
.fa-yoast:before {
    content: "\f2b1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:740 */
.fa-themeisle:before {
    content: "\f2b2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:741 */
.fa-google-plus-circle:before,
.fa-google-plus-official:before {
    content: "\f2b3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:743 */
.fa-fa:before,
.fa-font-awesome:before {
    content: "\f2b4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:745 */
.fa-handshake-o:before {
    content: "\f2b5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:746 */
.fa-envelope-open:before {
    content: "\f2b6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:747 */
.fa-envelope-open-o:before {
    content: "\f2b7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:748 */
.fa-linode:before {
    content: "\f2b8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:749 */
.fa-address-book:before {
    content: "\f2b9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:750 */
.fa-address-book-o:before {
    content: "\f2ba" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:751 */
.fa-vcard:before,
.fa-address-card:before {
    content: "\f2bb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:753 */
.fa-vcard-o:before,
.fa-address-card-o:before {
    content: "\f2bc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:755 */
.fa-user-circle:before {
    content: "\f2bd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:756 */
.fa-user-circle-o:before {
    content: "\f2be" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:757 */
.fa-user-o:before {
    content: "\f2c0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:758 */
.fa-id-badge:before {
    content: "\f2c1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:759 */
.fa-drivers-license:before,
.fa-id-card:before {
    content: "\f2c2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:761 */
.fa-drivers-license-o:before,
.fa-id-card-o:before {
    content: "\f2c3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:763 */
.fa-quora:before {
    content: "\f2c4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:764 */
.fa-free-code-camp:before {
    content: "\f2c5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:765 */
.fa-telegram:before {
    content: "\f2c6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:766 */
.fa-thermometer-4:before,
.fa-thermometer:before,
.fa-thermometer-full:before {
    content: "\f2c7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:769 */
.fa-thermometer-3:before,
.fa-thermometer-three-quarters:before {
    content: "\f2c8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:771 */
.fa-thermometer-2:before,
.fa-thermometer-half:before {
    content: "\f2c9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:773 */
.fa-thermometer-1:before,
.fa-thermometer-quarter:before {
    content: "\f2ca" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:775 */
.fa-thermometer-0:before,
.fa-thermometer-empty:before {
    content: "\f2cb" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:777 */
.fa-shower:before {
    content: "\f2cc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:778 */
.fa-bathtub:before,
.fa-s15:before,
.fa-bath:before {
    content: "\f2cd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:781 */
.fa-podcast:before {
    content: "\f2ce" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:782 */
.fa-window-maximize:before {
    content: "\f2d0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:783 */
.fa-window-minimize:before {
    content: "\f2d1" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:784 */
.fa-window-restore:before {
    content: "\f2d2" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:785 */
.fa-times-rectangle:before,
.fa-window-close:before {
    content: "\f2d3" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:787 */
.fa-times-rectangle-o:before,
.fa-window-close-o:before {
    content: "\f2d4" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:789 */
.fa-bandcamp:before {
    content: "\f2d5" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:790 */
.fa-grav:before {
    content: "\f2d6" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:791 */
.fa-etsy:before {
    content: "\f2d7" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:792 */
.fa-imdb:before {
    content: "\f2d8" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:793 */
.fa-ravelry:before {
    content: "\f2d9" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:794 */
.fa-eercast:before {
    content: "\f2da" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:795 */
.fa-microchip:before {
    content: "\f2db" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:796 */
.fa-snowflake-o:before {
    content: "\f2dc" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:797 */
.fa-superpowers:before {
    content: "\f2dd" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:798 */
.fa-wpexplorer:before {
    content: "\f2de" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/etc/_icons.scss:799 */
.fa-meetup:before {
    content: "\f2e0" !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-awesome/sass/src/all.scss:20 */
.x-fa:before {
    font-family: FontAwesome !important;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:3 */
@font-face {
    font-family: 'ExtJS';
    src: url('font-ext/fonts/ExtJS.eot?-tqegh9');
    src: url('font-ext/fonts/ExtJS.eot?#iefix-tqegh9') format('embedded-opentype'), url('font-ext/fonts/ExtJS.ttf?-tqegh9') format('truetype'), url('font-ext/fonts/ExtJS.woff?-tqegh9') format('woff'), url('font-ext/fonts/ExtJS.svg?-tqegh9#ExtJS') format('svg');
    font-weight: normal;
    font-style: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:14 */
.ext {
    font-family: ExtJS;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:18 */
.ext-sencha:before {
    content: "\e61e";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:21 */
.ext-checkbox-checked:before {
    content: "\e613";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:24 */
.ext-checkbox-unchecked:before {
    content: "\e614";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:27 */
.ext-chevron-left:before {
    content: "\e615";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:30 */
.ext-chevron-right:before {
    content: "\e616";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:33 */
.ext-double-chevron-left:before {
    content: "\e617";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:36 */
.ext-double-chevron-right:before {
    content: "\e618";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:39 */
.ext-sort-down:before {
    content: "\e619";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:42 */
.ext-sort-up:before {
    content: "\e61a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:45 */
.ext-spinner-down:before {
    content: "\e61b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:48 */
.ext-spinner-up:before {
    content: "\e61c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:51 */
.ext-square-edit:before {
    content: "\e61d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:54 */
.ext-equals-vertical:before {
    content: "\e612";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:57 */
.ext-expand:before {
    content: "\e600";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:60 */
.ext-columns:before {
    content: "\e601";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:63 */
.ext-dirty:before {
    content: "\e602";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:66 */
.ext-dirty-rtl:before {
    content: "\e603";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:69 */
.ext-edit-html:before {
    content: "\e604";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:72 */
.ext-equals:before {
    content: "\e605";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:75 */
.ext-collapse:before {
    content: "\e606";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:78 */
.ext-group-by:before {
    content: "\e607";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:81 */
.ext-minimize:before {
    content: "\e608";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:84 */
.ext-nw-handle:before {
    content: "\e609";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:87 */
.ext-ne-handle:before {
    content: "\e60a";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:90 */
.ext-sw-handle:before {
    content: "\e60b";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:93 */
.ext-se-handle:before {
    content: "\e60c";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:96 */
.ext-text-background-color:before {
    content: "\e60d";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:99 */
.ext-text-color:before {
    content: "\e60e";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:102 */
.ext-text-decrease:before {
    content: "\e60f";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:105 */
.ext-text-increase:before {
    content: "\e610";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/packages/font-ext/sass/src/all.scss:108 */
.ext-unpin:before {
    content: "\e611";
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:3 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-Light");
    src: url('fonts/OpenSans-Light.ttf');
    font-weight: 300;
    font-style: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:11 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-LightItalic");
    src: url('fonts/OpenSans-LightItalic.ttf');
    font-weight: 300;
    font-style: italic;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:19 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-Regular");
    src: url('fonts/OpenSans-Regular.ttf');
    font-weight: 400;
    font-style: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:27 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-Italic");
    src: url('fonts/OpenSans-Italic.ttf');
    font-weight: 400;
    font-style: italic;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:35 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-Semibold");
    src: url('fonts/OpenSans-Semibold.ttf');
    font-weight: 600;
    font-style: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:43 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-SemiboldItalic");
    src: url('fonts/OpenSans-SemiboldItalic.ttf');
    font-weight: 600;
    font-style: italic;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:51 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-Bold");
    src: url('fonts/OpenSans-Bold.ttf');
    font-weight: 700;
    font-style: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:59 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-BoldItalic");
    src: url('fonts/OpenSans-BoldItalic.ttf');
    font-weight: 700;
    font-style: italic;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:67 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-ExtraBold");
    src: url('fonts/OpenSans-ExtraBold.ttf');
    font-weight: 800;
    font-style: normal;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/Component.scss:75 */
@font-face {
    font-family: 'Open Sans';
    src: local("OpenSans-ExtraBoldItalic");
    src: url('fonts/OpenSans-ExtraBoldItalic.ttf');
    font-weight: 800;
    font-style: italic;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/form/FieldSet.scss:1 */
.x-fieldset {
    border-top: 1px solid rgba(0, 0, 0, 0.1) !important;
    background: #f6f6f6;
    position: static;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/form/FieldSet.scss:6 */
.x-fieldset .x-fieldset-body {
    position: relative;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/form/FieldSet.scss:10 */
.x-fieldset.x-fieldset-collapsed {
    background: none;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/menu/Menu.scss:1 */
.x-menu-item-active .x-menu-item-text {
    font-weight: 400;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/tab/Tab.scss:1 */
.x-tab-close-btn:before {
    display: block;
    width: 16px;
    line-height: 16px;
    text-align: center;
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/toolbar/Breadcrumb.scss:2 */
.x-breadcrumb-btn > .x-btn-arrow-right:after {
    content: '';
}
/* C:/Users/PNO.SYSMET/Desktop/DKSRV206/git/themes/icecap/ext/classic/theme-triton/sass/src/window/Toast.scss:1 */
.x-toast {
    -webkit-box-shadow: rgba(0, 0, 0, 0.5) 0 2px 2px;
    -moz-box-shadow: rgba(0, 0, 0, 0.5) 0 2px 2px;
    box-shadow: rgba(0, 0, 0, 0.5) 0 2px 2px;
}